@@ -23,6 +23,7 @@ var group__real_s_ycomputational =
     [ "ssytrd_sy2sb", "d0/d14/group__real_s_ycomputational_gaf640b5eb84ff9eb0681a6f37b740d18c.html#gaf640b5eb84ff9eb0681a6f37b740d18c", null ],
     [ "ssytrf", "d0/d14/group__real_s_ycomputational_ga12d2e56511cf7df066712c61d9acec45.html#ga12d2e56511cf7df066712c61d9acec45", null ],
     [ "ssytrf_aa", "d0/d14/group__real_s_ycomputational_ga8a8e87ecd7aa20ae7df39944d6811878.html#ga8a8e87ecd7aa20ae7df39944d6811878", null ],
+    [ "ssytrf_aa_2stage", "d0/d14/group__real_s_ycomputational_gad1b49392866a54aaaf3fb905a28f2cdc.html#gad1b49392866a54aaaf3fb905a28f2cdc", null ],
     [ "ssytrf_rook", "d0/d14/group__real_s_ycomputational_ga3ee23af3bb6160578d858a59b053f007.html#ga3ee23af3bb6160578d858a59b053f007", null ],
     [ "ssytri", "d0/d14/group__real_s_ycomputational_gaef378ec0761234aac417f487b43b7a8b.html#gaef378ec0761234aac417f487b43b7a8b", null ],
     [ "ssytri2", "d0/d14/group__real_s_ycomputational_ga7852066f959159f9701c0f63f90c5230.html#ga7852066f959159f9701c0f63f90c5230", null ],
@@ -31,6 +32,7 @@ var group__real_s_ycomputational =
     [ "ssytrs", "d0/d14/group__real_s_ycomputational_gae20133a1119b69a7319783ff982c8c62.html#gae20133a1119b69a7319783ff982c8c62", null ],
     [ "ssytrs2", "d0/d14/group__real_s_ycomputational_ga0e6312aad14fb7d54e0f3ef5111ec60a.html#ga0e6312aad14fb7d54e0f3ef5111ec60a", null ],
     [ "ssytrs_aa", "d0/d14/group__real_s_ycomputational_gabdbc5db1b83d7919f2af3f921ee18625.html#gabdbc5db1b83d7919f2af3f921ee18625", null ],
+    [ "ssytrs_aa_2stage", "d0/d14/group__real_s_ycomputational_ga7f826d71f9e154ac2935ee89ee655cb5.html#ga7f826d71f9e154ac2935ee89ee655cb5", null ],
     [ "ssytrs_rook", "d0/d14/group__real_s_ycomputational_ga919d6dd600fb34f939eb34e18751d702.html#ga919d6dd600fb34f939eb34e18751d702", null ],
     [ "stgsyl", "d0/d14/group__real_s_ycomputational_ga7be8a5fb25c1b67ea888747c1334d996.html#ga7be8a5fb25c1b67ea888747c1334d996", null ],
     [ "strsyl", "d0/d14/group__real_s_ycomputational_ga56e2ab6ac5906744561c4c1abb27b83d.html#ga56e2ab6ac5906744561c4c1abb27b83d", null ]
