@@ -7,5 +7,6 @@ var group__real_g_esolve =
     [ "sgelsy", "d0/db8/group__real_g_esolve_gaebb028f1d50049bcf4780ffc8cb4f750.html#gaebb028f1d50049bcf4780ffc8cb4f750", null ],
     [ "sgesv", "d0/db8/group__real_g_esolve_ga3b05fb3999b3d7351cb3101a1fd28e78.html#ga3b05fb3999b3d7351cb3101a1fd28e78", null ],
     [ "sgesvx", "d0/db8/group__real_g_esolve_ga1f66bf6cce2f8038b120eb11bd30cdc9.html#ga1f66bf6cce2f8038b120eb11bd30cdc9", null ],
-    [ "sgesvxx", "d0/db8/group__real_g_esolve_gad499b2a1b47541ff7f97aaaca16025e9.html#gad499b2a1b47541ff7f97aaaca16025e9", null ]
+    [ "sgesvxx", "d0/db8/group__real_g_esolve_gad499b2a1b47541ff7f97aaaca16025e9.html#gad499b2a1b47541ff7f97aaaca16025e9", null ],
+    [ "sgetsls", "d0/db8/group__real_g_esolve_ga6208039df0bf345b9befcf55a4ceaef3.html#ga6208039df0bf345b9befcf55a4ceaef3", null ]
 ];
\ No newline at end of file
