@@ -61,6 +61,7 @@ var group__double__eig =
     [ "dget37", "d1/d3c/group__double__eig_gabdcacf57969bb6f47213da97e24ca706.html#gabdcacf57969bb6f47213da97e24ca706", null ],
     [ "dget38", "d1/d3c/group__double__eig_gae6037bff69c348a29907e03c047b4ed8.html#gae6037bff69c348a29907e03c047b4ed8", null ],
     [ "dget39", "d1/d3c/group__double__eig_gaa546404302fddb3545bcd1ca639b2dd8.html#gaa546404302fddb3545bcd1ca639b2dd8", null ],
+    [ "dget40", "d1/d3c/group__double__eig_gaf37433090c87a5fa0e091b621eeaa9da.html#gaf37433090c87a5fa0e091b621eeaa9da", null ],
     [ "dget51", "d1/d3c/group__double__eig_gaf6f9376de56715d7548005efd8e71a65.html#gaf6f9376de56715d7548005efd8e71a65", null ],
     [ "dget52", "d1/d3c/group__double__eig_ga8af5c9297a5d6bc3f84223b499442944.html#ga8af5c9297a5d6bc3f84223b499442944", null ],
     [ "dget53", "d1/d3c/group__double__eig_ga50f4c00fce1f7d59566e68da4fecbf29.html#ga50f4c00fce1f7d59566e68da4fecbf29", null ],
@@ -97,5 +98,6 @@ var group__double__eig =
     [ "dsyt22", "d1/d3c/group__double__eig_gaa55d41534d46929dbd30b8abc36f11b6.html#gaa55d41534d46929dbd30b8abc36f11b6", null ],
     [ "sbdt04", "d1/d3c/group__double__eig_ga89bbc8347e92696137c0ccdfccbe8f2c.html#ga89bbc8347e92696137c0ccdfccbe8f2c", null ],
     [ "sbdt05", "d1/d3c/group__double__eig_gaf26a9f25fea5529048fecadcbd78d563.html#gaf26a9f25fea5529048fecadcbd78d563", null ],
+    [ "sget40", "d1/d3c/group__double__eig_ga62d1b533e43a7468253b13c5108b2a70.html#ga62d1b533e43a7468253b13c5108b2a70", null ],
     [ "zbdt05", "d1/d3c/group__double__eig_gafa91fb2edbe3578f0b50d3ff47be8ec7.html#gafa91fb2edbe3578f0b50d3ff47be8ec7", null ]
 ];
\ No newline at end of file
