@@ -12,6 +12,7 @@ var group__complex_o_t_h_e_rcomputational =
     [ "cgsvj1", "d3/db9/group__complex_o_t_h_e_rcomputational_gad1b1db374ee56fd9d417582e45092da5.html#gad1b1db374ee56fd9d417582e45092da5", null ],
     [ "chbgst", "d3/db9/group__complex_o_t_h_e_rcomputational_ga808bf06bc4d353a18ab94f5eaf7c67f0.html#ga808bf06bc4d353a18ab94f5eaf7c67f0", null ],
     [ "chbtrd", "d3/db9/group__complex_o_t_h_e_rcomputational_ga7de86c95768cba8a2168ee787f18f9f4.html#ga7de86c95768cba8a2168ee787f18f9f4", null ],
+    [ "chetrd_hb2st", "d3/db9/group__complex_o_t_h_e_rcomputational_ga040adda5091e3515acc9d869c3179418.html#ga040adda5091e3515acc9d869c3179418", null ],
     [ "chfrk", "d3/db9/group__complex_o_t_h_e_rcomputational_ga59df29e79096c5fab43c73667a0dea90.html#ga59df29e79096c5fab43c73667a0dea90", null ],
     [ "chpcon", "d3/db9/group__complex_o_t_h_e_rcomputational_ga87312e90d1880f272018741e5410b3b5.html#ga87312e90d1880f272018741e5410b3b5", null ],
     [ "chpgst", "d3/db9/group__complex_o_t_h_e_rcomputational_gae10c5287803da25736dd056ce455f6aa.html#gae10c5287803da25736dd056ce455f6aa", null ],
@@ -118,6 +119,9 @@ var group__complex_o_t_h_e_rcomputational =
     [ "cungr2", "d3/db9/group__complex_o_t_h_e_rcomputational_ga2728705ec9f3452eda5381167b8d142e.html#ga2728705ec9f3452eda5381167b8d142e", null ],
     [ "cungrq", "d3/db9/group__complex_o_t_h_e_rcomputational_gafd97d8010c2b1ef171ef796585c500a6.html#gafd97d8010c2b1ef171ef796585c500a6", null ],
     [ "cungtr", "d3/db9/group__complex_o_t_h_e_rcomputational_gade809826468303ab92ca55d3d2b5ab02.html#gade809826468303ab92ca55d3d2b5ab02", null ],
+    [ "cungtsqr", "d3/db9/group__complex_o_t_h_e_rcomputational_ga7e4bad9857c71fdc109810110c14fa85.html#ga7e4bad9857c71fdc109810110c14fa85", null ],
+    [ "cungtsqr_row", "d3/db9/group__complex_o_t_h_e_rcomputational_ga3aa7f05b47107bbe519826381ccd1ed2.html#ga3aa7f05b47107bbe519826381ccd1ed2", null ],
+    [ "cunhr_col", "d3/db9/group__complex_o_t_h_e_rcomputational_ga17569ec17858bb62b86640d4d1fe7902.html#ga17569ec17858bb62b86640d4d1fe7902", null ],
     [ "cunm22", "d3/db9/group__complex_o_t_h_e_rcomputational_ga36a2f1fb166689768ce6b7ca93ca01b2.html#ga36a2f1fb166689768ce6b7ca93ca01b2", null ],
     [ "cunm2l", "d3/db9/group__complex_o_t_h_e_rcomputational_ga27cb4c11e08ed1b92d6a4974c7c389ba.html#ga27cb4c11e08ed1b92d6a4974c7c389ba", null ],
     [ "cunm2r", "d3/db9/group__complex_o_t_h_e_rcomputational_gadd6fc18563da99ba29abf78e676c8794.html#gadd6fc18563da99ba29abf78e676c8794", null ],
