@@ -9,6 +9,5 @@ var group__double_g_esolve =
     [ "dgesvx", "d7/d3b/group__double_g_esolve_ga9d90ccf6e340cacd08b7bbbb502ceb21.html#ga9d90ccf6e340cacd08b7bbbb502ceb21", null ],
     [ "dgesvxx", "d7/d3b/group__double_g_esolve_ga3fed1dc691d07f1e81a049016fe0b67b.html#ga3fed1dc691d07f1e81a049016fe0b67b", null ],
     [ "dgetsls", "d7/d3b/group__double_g_esolve_ga24938f890150242a397e2094fc4643db.html#ga24938f890150242a397e2094fc4643db", null ],
-    [ "dsgesv", "d7/d3b/group__double_g_esolve_ga05bea3dc0386868e4720f22c969cb9f5.html#ga05bea3dc0386868e4720f22c969cb9f5", null ],
-    [ "sgetsls", "d7/d3b/group__double_g_esolve_ga6208039df0bf345b9befcf55a4ceaef3.html#ga6208039df0bf345b9befcf55a4ceaef3", null ]
+    [ "dsgesv", "d7/d3b/group__double_g_esolve_ga05bea3dc0386868e4720f22c969cb9f5.html#ga05bea3dc0386868e4720f22c969cb9f5", null ]
 ];
\ No newline at end of file
