@@ -1,5 +1,8 @@
 var group__complex_s_ycomputational =
 [
+    [ "chesv_aa_2stage", "da/dff/group__complex_s_ycomputational_gabb66fb23be3a7311b71271a2717b35eb.html#gabb66fb23be3a7311b71271a2717b35eb", null ],
+    [ "chetrf_aa_2stage", "da/dff/group__complex_s_ycomputational_gab8c36305b9b3b7622f6c51d782ac10dc.html#gab8c36305b9b3b7622f6c51d782ac10dc", null ],
+    [ "chetrs_aa_2stage", "da/dff/group__complex_s_ycomputational_gad484921e85594add6d0df79cced0a0d4.html#gad484921e85594add6d0df79cced0a0d4", null ],
     [ "cla_syamv", "da/dff/group__complex_s_ycomputational_ga2effd037ac49e21caf28a78b063f41a3.html#ga2effd037ac49e21caf28a78b063f41a3", null ],
     [ "cla_syrcond_c", "da/dff/group__complex_s_ycomputational_ga26da8d6aacbabc9792e7d456f1317238.html#ga26da8d6aacbabc9792e7d456f1317238", null ],
     [ "cla_syrcond_x", "da/dff/group__complex_s_ycomputational_ga93458339ea93230f0ad25a86910af28a.html#ga93458339ea93230f0ad25a86910af28a", null ],
@@ -19,11 +22,13 @@ var group__complex_s_ycomputational =
     [ "csyequb", "da/dff/group__complex_s_ycomputational_ga076074a11ac1385855e8efe9cc3ca048.html#ga076074a11ac1385855e8efe9cc3ca048", null ],
     [ "csyrfs", "da/dff/group__complex_s_ycomputational_ga1d5b0252ad96edd8494a10d06eb97482.html#ga1d5b0252ad96edd8494a10d06eb97482", null ],
     [ "csyrfsx", "da/dff/group__complex_s_ycomputational_ga0f93ca9ab2fc02b8de5f578316353b87.html#ga0f93ca9ab2fc02b8de5f578316353b87", null ],
+    [ "csysv_aa_2stage", "da/dff/group__complex_s_ycomputational_ga30ffaa7302b864fdaeaf2fafe4f448b0.html#ga30ffaa7302b864fdaeaf2fafe4f448b0", null ],
     [ "csytf2", "da/dff/group__complex_s_ycomputational_ga0f12a3d0375451dcb483147e125665a1.html#ga0f12a3d0375451dcb483147e125665a1", null ],
     [ "csytf2_rk", "da/dff/group__complex_s_ycomputational_ga3c11429e2e0abc1d273478856b74d5e3.html#ga3c11429e2e0abc1d273478856b74d5e3", null ],
     [ "csytf2_rook", "da/dff/group__complex_s_ycomputational_ga9baea00306a19fc23c46b5052f4168f7.html#ga9baea00306a19fc23c46b5052f4168f7", null ],
     [ "csytrf", "da/dff/group__complex_s_ycomputational_gacd5839d735315079d2ecc8afc9402352.html#gacd5839d735315079d2ecc8afc9402352", null ],
     [ "csytrf_aa", "da/dff/group__complex_s_ycomputational_ga652dad3ec5efe416466f2b634a0b7398.html#ga652dad3ec5efe416466f2b634a0b7398", null ],
+    [ "csytrf_aa_2stage", "da/dff/group__complex_s_ycomputational_ga480a32878b7395e53bd00b74458f425b.html#ga480a32878b7395e53bd00b74458f425b", null ],
     [ "csytrf_rk", "da/dff/group__complex_s_ycomputational_gad8ebf2778aa871f9f2efc3cea43af789.html#gad8ebf2778aa871f9f2efc3cea43af789", null ],
     [ "csytrf_rook", "da/dff/group__complex_s_ycomputational_gaaa37e0850860440f4893fef9d5f815d5.html#gaaa37e0850860440f4893fef9d5f815d5", null ],
     [ "csytri", "da/dff/group__complex_s_ycomputational_ga7f05f7e397f26b4b909379193f3530ab.html#ga7f05f7e397f26b4b909379193f3530ab", null ],
@@ -36,6 +41,7 @@ var group__complex_s_ycomputational =
     [ "csytrs2", "da/dff/group__complex_s_ycomputational_ga83c04c706f23cb68b4243cf7a40db229.html#ga83c04c706f23cb68b4243cf7a40db229", null ],
     [ "csytrs_3", "da/dff/group__complex_s_ycomputational_gafcf66602434cd99d92d69e74177d78db.html#gafcf66602434cd99d92d69e74177d78db", null ],
     [ "csytrs_aa", "da/dff/group__complex_s_ycomputational_ga12f53031b5c662c050106452af5f2d93.html#ga12f53031b5c662c050106452af5f2d93", null ],
+    [ "csytrs_aa_2stage", "da/dff/group__complex_s_ycomputational_gaf114d2ed6bf289689ae829559cb7c1e2.html#gaf114d2ed6bf289689ae829559cb7c1e2", null ],
     [ "csytrs_rook", "da/dff/group__complex_s_ycomputational_ga4ede0bcbc69ca218b7b286e767577220.html#ga4ede0bcbc69ca218b7b286e767577220", null ],
     [ "ctgsyl", "da/dff/group__complex_s_ycomputational_gaef7add4f653067c9b3e44569e6766d95.html#gaef7add4f653067c9b3e44569e6766d95", null ],
     [ "ctrsyl", "da/dff/group__complex_s_ycomputational_ga0da0534f2f1e9be1670bf62a60274a8c.html#ga0da0534f2f1e9be1670bf62a60274a8c", null ]
