@@ -2,5 +2,5 @@ var xerbla_8c =
 [
     [ "XerblaStrLen", "dd/d4e/xerbla_8c_a0977131ed05e646dd125feb45d67524d.html#a0977131ed05e646dd125feb45d67524d", null ],
     [ "XerblaStrLen1", "dd/d4e/xerbla_8c_aebcb9809cdcfb564405c0fcd85b07fcd.html#aebcb9809cdcfb564405c0fcd85b07fcd", null ],
-    [ "F77_xerbla", "dd/d4e/xerbla_8c_a9dba6501cb46384a8c483ecb5a916ed2.html#a9dba6501cb46384a8c483ecb5a916ed2", null ]
+    [ "F77_xerbla_base", "dd/d4e/xerbla_8c_aa8c89baf67271d9c44cdcfb24798f1d3.html#aa8c89baf67271d9c44cdcfb24798f1d3", null ]
 ];
\ No newline at end of file
