@@ -6,7 +6,6 @@ var group___o_t_h_e_rauxiliary =
     [ "complex16", "d0/d50/group__complex16_o_t_h_e_rauxiliary.html", "d0/d50/group__complex16_o_t_h_e_rauxiliary" ],
     [ "clartg", "df/dd1/group___o_t_h_e_rauxiliary_ga45afd4405cf6da478ce4de9576303369.html#ga45afd4405cf6da478ce4de9576303369", null ],
     [ "classq", "df/dd1/group___o_t_h_e_rauxiliary_gad00e3fc7bc325256b1115351098ebfc6.html#gad00e3fc7bc325256b1115351098ebfc6", null ],
-    [ "dcombssq", "df/dd1/group___o_t_h_e_rauxiliary_ga3475ef5d7380776f2e53811c031f2778.html#ga3475ef5d7380776f2e53811c031f2778", null ],
     [ "disnan", "df/dd1/group___o_t_h_e_rauxiliary_ga230d4e1886896853b11e44e541b2c6a3.html#ga230d4e1886896853b11e44e541b2c6a3", null ],
     [ "dlabad", "df/dd1/group___o_t_h_e_rauxiliary_ga57ac7409aedb2a380d5d0e625ffbeb7a.html#ga57ac7409aedb2a380d5d0e625ffbeb7a", null ],
     [ "dlacpy", "df/dd1/group___o_t_h_e_rauxiliary_ga7eb8731ffab2734378157c40964bf788.html#ga7eb8731ffab2734378157c40964bf788", null ],
@@ -57,7 +56,6 @@ var group___o_t_h_e_rauxiliary =
     [ "ilaenv2stage", "df/dd1/group___o_t_h_e_rauxiliary_ga5703a2c3b32069742575eb5a8e89abee.html#ga5703a2c3b32069742575eb5a8e89abee", null ],
     [ "iparmq", "df/dd1/group___o_t_h_e_rauxiliary_ga6e703cb600283f4bcb1b340cfd8ad3d9.html#ga6e703cb600283f4bcb1b340cfd8ad3d9", null ],
     [ "lsamen", "df/dd1/group___o_t_h_e_rauxiliary_ga0b496168bf04278e5e57050403c150aa.html#ga0b496168bf04278e5e57050403c150aa", null ],
-    [ "scombssq", "df/dd1/group___o_t_h_e_rauxiliary_ga85390f227787ff529bb152f028ed2128.html#ga85390f227787ff529bb152f028ed2128", null ],
     [ "sisnan", "df/dd1/group___o_t_h_e_rauxiliary_gaeca6bb0411af000e3c883ee744184991.html#gaeca6bb0411af000e3c883ee744184991", null ],
     [ "slabad", "df/dd1/group___o_t_h_e_rauxiliary_ga117e4564430a16335ad47054c447cb79.html#ga117e4564430a16335ad47054c447cb79", null ],
     [ "slacpy", "df/dd1/group___o_t_h_e_rauxiliary_ga7780c991533ce8dd1f2c22ae2d563f08.html#ga7780c991533ce8dd1f2c22ae2d563f08", null ],
