@@ -1,6 +1,5 @@
 var NAVTREEINDEX100 =
 {
-"dd/db3/group__complex16_s_ycomputational_gafdde4e07a3bfeddbf09a744d6d4c60d8.html#gafdde4e07a3bfeddbf09a744d6d4c60d8":[3,0,5,1726,0],
 "dd/db3/sget22_8f.html":[3,0,6,0,230],
 "dd/db3/sget22_8f_source.html":[3,0,6,0,230],
 "dd/db4/dggsvd_8f.html":[3,0,5,0,13],
@@ -9,15 +8,15 @@ var NAVTREEINDEX100 =
 "dd/db4/lapacke__zhetrd__work_8c.html":[3,0,4,3,2085],
 "dd/db4/lapacke__zhetrd__work_8c_abe5a0b8b2df608fe92437294044611f4.html#abe5a0b8b2df608fe92437294044611f4":[3,0,4,3,2085,0],
 "dd/db4/lapacke__zhetrd__work_8c_source.html":[3,0,4,3,2085],
-"dd/db4/zlaqz0_8f.html":[3,0,5,1796],
-"dd/db4/zlaqz0_8f_source.html":[3,0,5,1796],
+"dd/db4/zlaqz0_8f.html":[3,0,5,1794],
+"dd/db4/zlaqz0_8f_source.html":[3,0,5,1794],
 "dd/db5/clar1v_8f.html":[3,0,5,279],
 "dd/db5/clar1v_8f_source.html":[3,0,5,279],
 "dd/db5/lapacke__clarfx__work_8c.html":[3,0,4,3,355],
 "dd/db5/lapacke__clarfx__work_8c_af076c50e201f3d9220031a3b96ab8080.html#af076c50e201f3d9220031a3b96ab8080":[3,0,4,3,355,0],
 "dd/db5/lapacke__clarfx__work_8c_source.html":[3,0,4,3,355],
-"dd/db5/zgerfsx_8f.html":[3,0,5,1577],
-"dd/db5/zgerfsx_8f_source.html":[3,0,5,1577],
+"dd/db5/zgerfsx_8f.html":[3,0,5,1575],
+"dd/db5/zgerfsx_8f_source.html":[3,0,5,1575],
 "dd/db6/clansy_8f.html":[3,0,5,252],
 "dd/db6/clansy_8f_source.html":[3,0,5,252],
 "dd/db6/lapacke__dgbrfs__work_8c.html":[3,0,4,3,663],
@@ -39,8 +38,8 @@ var NAVTREEINDEX100 =
 "dd/db7/lapacke__dsygv__2stage__work_8c_source.html":[3,0,4,3,1112],
 "dd/db7/sget52_8f.html":[3,0,6,0,244],
 "dd/db7/sget52_8f_source.html":[3,0,6,0,244],
-"dd/db7/zgetrs_8f.html":[3,0,5,1594],
-"dd/db7/zgetrs_8f_source.html":[3,0,5,1594],
+"dd/db7/zgetrs_8f.html":[3,0,5,1592],
+"dd/db7/zgetrs_8f_source.html":[3,0,5,1592],
 "dd/db8/lapacke__slauum_8c.html":[3,0,4,3,1480],
 "dd/db8/lapacke__slauum_8c_a61b56e88e4522a5ed16f185059eeeaa1.html#a61b56e88e4522a5ed16f185059eeeaa1":[3,0,4,3,1480,0],
 "dd/db8/lapacke__slauum_8c_source.html":[3,0,4,3,1480],
@@ -54,18 +53,18 @@ var NAVTREEINDEX100 =
 "dd/dba/dlatmt_8f_source.html":[3,0,6,2,36],
 "dd/dba/dspr_8f.html":[3,0,0,0,53],
 "dd/dba/dspr_8f_source.html":[3,0,0,0,53],
-"dd/dba/zgeev_8f.html":[3,0,5,1547],
-"dd/dba/zgeev_8f_source.html":[3,0,5,1547],
+"dd/dba/zgeev_8f.html":[3,0,5,1545],
+"dd/dba/zgeev_8f_source.html":[3,0,5,1545],
 "dd/dbb/lapacke__zgejsv_8c.html":[3,0,4,3,1886],
 "dd/dbb/lapacke__zgejsv_8c_a325ba19e2389a84fc29f1c64649610b3.html#a325ba19e2389a84fc29f1c64649610b3":[3,0,4,3,1886,0],
 "dd/dbb/lapacke__zgejsv_8c_source.html":[3,0,4,3,1886],
-"dd/dbb/spftrs_8f.html":[3,0,5,1349],
-"dd/dbb/spftrs_8f_source.html":[3,0,5,1349],
+"dd/dbb/spftrs_8f.html":[3,0,5,1347],
+"dd/dbb/spftrs_8f_source.html":[3,0,5,1347],
 "dd/dbc/lapacke__cgges_8c.html":[3,0,4,3,130],
 "dd/dbc/lapacke__cgges_8c_a4f4612836a4b21720d5d6fe7374f212b.html#a4f4612836a4b21720d5d6fe7374f212b":[3,0,4,3,130,0],
 "dd/dbc/lapacke__cgges_8c_source.html":[3,0,4,3,130],
-"dd/dbc/ssbtrd_8f.html":[3,0,5,1393],
-"dd/dbc/ssbtrd_8f_source.html":[3,0,5,1393],
+"dd/dbc/ssbtrd_8f.html":[3,0,5,1391],
+"dd/dbc/ssbtrd_8f_source.html":[3,0,5,1391],
 "dd/dbd/csyt01__3_8f.html":[3,0,6,1,189],
 "dd/dbd/csyt01__3_8f_source.html":[3,0,6,1,189],
 "dd/dbd/lapacke__zggsvp3_8c.html":[3,0,4,3,1997],
@@ -80,13 +79,13 @@ var NAVTREEINDEX100 =
 "dd/dc0/lapacke__dsyevx_8c.html":[3,0,4,3,1104],
 "dd/dc0/lapacke__dsyevx_8c_a6a5cf3ad2545f6d4b6a2efb7e35e4523.html#a6a5cf3ad2545f6d4b6a2efb7e35e4523":[3,0,4,3,1104,0],
 "dd/dc0/lapacke__dsyevx_8c_source.html":[3,0,4,3,1104],
-"dd/dc0/zsytf2__rk_8f.html":[3,0,5,1921],
-"dd/dc0/zsytf2__rk_8f_source.html":[3,0,5,1921],
+"dd/dc0/zsytf2__rk_8f.html":[3,0,5,1919],
+"dd/dc0/zsytf2__rk_8f_source.html":[3,0,5,1919],
 "dd/dc1/lapacke__zlagge__work_8c.html":[3,0,4,3,2167],
 "dd/dc1/lapacke__zlagge__work_8c_ad8f119ce823d86c0dd6e5933e2d8c68e.html#ad8f119ce823d86c0dd6e5933e2d8c68e":[3,0,4,3,2167,0],
 "dd/dc1/lapacke__zlagge__work_8c_source.html":[3,0,4,3,2167],
-"dd/dc2/dgbsv_8f.html":[3,0,5,512],
-"dd/dc2/dgbsv_8f_source.html":[3,0,5,512],
+"dd/dc2/dgbsv_8f.html":[3,0,5,511],
+"dd/dc2/dgbsv_8f_source.html":[3,0,5,511],
 "dd/dc3/lapacke__zlacn2_8c.html":[3,0,4,3,2156],
 "dd/dc3/lapacke__zlacn2_8c_a90f548d1d8a79ac2a6cb2cba7b9d1b09.html#a90f548d1d8a79ac2a6cb2cba7b9d1b09":[3,0,4,3,2156,0],
 "dd/dc3/lapacke__zlacn2_8c_source.html":[3,0,4,3,2156],
@@ -95,20 +94,20 @@ var NAVTREEINDEX100 =
 "dd/dc4/lapacke__dtfsm__work_8c.html":[3,0,4,3,1177],
 "dd/dc4/lapacke__dtfsm__work_8c_a433557f2f0aa83459de69e268356a299.html#a433557f2f0aa83459de69e268356a299":[3,0,4,3,1177,0],
 "dd/dc4/lapacke__dtfsm__work_8c_source.html":[3,0,4,3,1177],
-"dd/dc4/sgbequb_8f.html":[3,0,5,1032],
-"dd/dc4/sgbequb_8f_source.html":[3,0,5,1032],
+"dd/dc4/sgbequb_8f.html":[3,0,5,1030],
+"dd/dc4/sgbequb_8f_source.html":[3,0,5,1030],
 "dd/dc5/lapacke__cstegr_8c.html":[3,0,4,3,464],
 "dd/dc5/lapacke__cstegr_8c_a3640b72bd2b0ea4f7a8d061b4bc59224.html#a3640b72bd2b0ea4f7a8d061b4bc59224":[3,0,4,3,464,0],
 "dd/dc5/lapacke__cstegr_8c_source.html":[3,0,4,3,464],
-"dd/dc5/slasd6_8f.html":[3,0,5,1266],
-"dd/dc5/slasd6_8f_source.html":[3,0,5,1266],
-"dd/dc5/sormrz_8f.html":[3,0,5,1336],
-"dd/dc5/sormrz_8f_source.html":[3,0,5,1336],
+"dd/dc5/slasd6_8f.html":[3,0,5,1264],
+"dd/dc5/slasd6_8f_source.html":[3,0,5,1264],
+"dd/dc5/sormrz_8f.html":[3,0,5,1334],
+"dd/dc5/sormrz_8f_source.html":[3,0,5,1334],
 "dd/dc6/group___p_t.html":[0,0,6],
 "dd/dca/cblas__snrm2_8c.html":[3,0,1,2,85],
 "dd/dca/cblas__snrm2_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,85,0],
 "dd/dca/cblas__snrm2_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,85,1],
-"dd/dca/cblas__snrm2_8c_afca20b253a39430a1435e3c7f7d023df.html#afca20b253a39430a1435e3c7f7d023df":[3,0,1,2,85,2],
+"dd/dca/cblas__snrm2_8c_ab182a5b4b77faa8db1bfd225234fa8ab.html#ab182a5b4b77faa8db1bfd225234fa8ab":[3,0,1,2,85,2],
 "dd/dca/cblas__snrm2_8c_source.html":[3,0,1,2,85],
 "dd/dca/lapacke__dlacn2_8c.html":[3,0,4,3,830],
 "dd/dca/lapacke__dlacn2_8c_a8bce9a2b7aef493d87bdee2ae1d7e6f1.html#a8bce9a2b7aef493d87bdee2ae1d7e6f1":[3,0,4,3,830,0],
@@ -119,29 +118,29 @@ var NAVTREEINDEX100 =
 "dd/dcb/lapacke__dgesvdq__work_8c.html":[3,0,4,3,753],
 "dd/dcb/lapacke__dgesvdq__work_8c_a6eca93e289ba352067e51196f6253dfc.html#a6eca93e289ba352067e51196f6253dfc":[3,0,4,3,753,0],
 "dd/dcb/lapacke__dgesvdq__work_8c_source.html":[3,0,4,3,753],
-"dd/dcc/zgsvj0_8f.html":[3,0,5,1613],
-"dd/dcc/zgsvj0_8f_source.html":[3,0,5,1613],
+"dd/dcc/zgsvj0_8f.html":[3,0,5,1611],
+"dd/dcc/zgsvj0_8f_source.html":[3,0,5,1611],
 "dd/dce/cpotrf_8f.html":[3,0,5,342],
 "dd/dce/cpotrf_8f_source.html":[3,0,5,342],
-"dd/dce/zhptrd_8f.html":[3,0,5,1700],
-"dd/dce/zhptrd_8f_source.html":[3,0,5,1700],
+"dd/dce/zhptrd_8f.html":[3,0,5,1698],
+"dd/dce/zhptrd_8f_source.html":[3,0,5,1698],
 "dd/dd0/lapacke__sspgvx_8c.html":[3,0,4,3,1640],
 "dd/dd0/lapacke__sspgvx_8c_a1ebb93cdc927a93a5329ada8b36db44d.html#a1ebb93cdc927a93a5329ada8b36db44d":[3,0,4,3,1640,0],
 "dd/dd0/lapacke__sspgvx_8c_source.html":[3,0,4,3,1640],
-"dd/dd0/zheswapr_8f.html":[3,0,5,1661],
-"dd/dd0/zheswapr_8f_source.html":[3,0,5,1661],
-"dd/dd0/zlangb_8f.html":[3,0,5,1762],
-"dd/dd0/zlangb_8f_source.html":[3,0,5,1762],
+"dd/dd0/zheswapr_8f.html":[3,0,5,1659],
+"dd/dd0/zheswapr_8f_source.html":[3,0,5,1659],
+"dd/dd0/zlangb_8f.html":[3,0,5,1760],
+"dd/dd0/zlangb_8f_source.html":[3,0,5,1760],
 "dd/dd1/csytrs__rook_8f.html":[3,0,5,418],
 "dd/dd1/csytrs__rook_8f_source.html":[3,0,5,418],
 "dd/dd1/ctzrqf_8f.html":[3,0,5,0,8],
 "dd/dd1/ctzrqf_8f_source.html":[3,0,5,0,8],
-"dd/dd1/zgetrf_8f.html":[3,0,5,1591],
-"dd/dd1/zgetrf_8f_source.html":[3,0,5,1591],
+"dd/dd1/zgetrf_8f.html":[3,0,5,1589],
+"dd/dd1/zgetrf_8f_source.html":[3,0,5,1589],
 "dd/dd2/cdrvvx_8f.html":[3,0,6,0,44],
 "dd/dd2/cdrvvx_8f_source.html":[3,0,6,0,44],
-"dd/dd4/sbdsvdx_8f.html":[3,0,5,1025],
-"dd/dd4/sbdsvdx_8f_source.html":[3,0,5,1025],
+"dd/dd4/sbdsvdx_8f.html":[3,0,5,1024],
+"dd/dd4/sbdsvdx_8f_source.html":[3,0,5,1024],
 "dd/dd6/cgeqr2p_8f.html":[3,0,5,48],
 "dd/dd6/cgeqr2p_8f_source.html":[3,0,5,48],
 "dd/dd6/zlatsp_8f.html":[3,0,6,1,701],
@@ -157,8 +156,8 @@ var NAVTREEINDEX100 =
 "dd/dd8/csytri__3x_8f_source.html":[3,0,5,411],
 "dd/dda/cla__gbrcond__x_8f.html":[3,0,5,187],
 "dd/dda/cla__gbrcond__x_8f_source.html":[3,0,5,187],
-"dd/dda/dhgeqz_8f.html":[3,0,5,602],
-"dd/dda/dhgeqz_8f_source.html":[3,0,5,602],
+"dd/dda/dhgeqz_8f.html":[3,0,5,601],
+"dd/dda/dhgeqz_8f_source.html":[3,0,5,601],
 "dd/dda/lapacke__ctgsen__work_8c.html":[3,0,4,3,551],
 "dd/dda/lapacke__ctgsen__work_8c_af4385968920786a333773ed8ecbb459d.html#af4385968920786a333773ed8ecbb459d":[3,0,4,3,551,0],
 "dd/dda/lapacke__ctgsen__work_8c_source.html":[3,0,4,3,551],
@@ -174,16 +173,16 @@ var NAVTREEINDEX100 =
 "dd/ddd/cblas__dznrm2_8c.html":[3,0,1,2,68],
 "dd/ddd/cblas__dznrm2_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,68,0],
 "dd/ddd/cblas__dznrm2_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,68,1],
-"dd/ddd/cblas__dznrm2_8c_a9d64a4ef2b06d6b378ffa43caff7525f.html#a9d64a4ef2b06d6b378ffa43caff7525f":[3,0,1,2,68,2],
+"dd/ddd/cblas__dznrm2_8c_ab463387913b5137b81a0b7f3ebdbe7d3.html#ab463387913b5137b81a0b7f3ebdbe7d3":[3,0,1,2,68,2],
 "dd/ddd/cblas__dznrm2_8c_source.html":[3,0,1,2,68],
-"dd/ddd/ztrexc_8f.html":[3,0,5,1971],
-"dd/ddd/ztrexc_8f_source.html":[3,0,5,1971],
+"dd/ddd/ztrexc_8f.html":[3,0,5,1969],
+"dd/ddd/ztrexc_8f_source.html":[3,0,5,1969],
 "dd/dde/cstedc_8f.html":[3,0,5,375],
 "dd/dde/cstedc_8f_source.html":[3,0,5,375],
 "dd/dde/sdrvev_8f.html":[3,0,6,0,215],
 "dd/dde/sdrvev_8f_source.html":[3,0,6,0,215],
-"dd/dde/spftri_8f.html":[3,0,5,1348],
-"dd/dde/spftri_8f_source.html":[3,0,5,1348],
+"dd/dde/spftri_8f.html":[3,0,5,1346],
+"dd/dde/spftri_8f_source.html":[3,0,5,1346],
 "dd/ddf/cbdt05_8f.html":[3,0,6,0,9],
 "dd/ddf/cbdt05_8f_source.html":[3,0,6,0,9],
 "dd/ddf/cgeequb_8f.html":[3,0,5,22],
@@ -191,8 +190,8 @@ var NAVTREEINDEX100 =
 "dd/ddf/lapacke__zlarft_8c.html":[3,0,4,3,2190],
 "dd/ddf/lapacke__zlarft_8c_ad5f14b1b1e18eabfe65eec156467ef35.html#ad5f14b1b1e18eabfe65eec156467ef35":[3,0,4,3,2190,0],
 "dd/ddf/lapacke__zlarft_8c_source.html":[3,0,4,3,2190],
-"dd/de0/dtbtrs_8f.html":[3,0,5,959],
-"dd/de0/dtbtrs_8f_source.html":[3,0,5,959],
+"dd/de0/dtbtrs_8f.html":[3,0,5,958],
+"dd/de0/dtbtrs_8f_source.html":[3,0,5,958],
 "dd/de0/idamax_8f.html":[3,0,0,0,73],
 "dd/de0/idamax_8f_source.html":[3,0,0,0,73],
 "dd/de0/lapacke__dgejsv__work_8c.html":[3,0,4,3,699],
@@ -210,18 +209,18 @@ var NAVTREEINDEX100 =
 "dd/de1/lapacke__ssytrs__3_8c.html":[3,0,4,3,1755],
 "dd/de1/lapacke__ssytrs__3_8c_ade1c7ae7d588de17129afbeb46f58931.html#ade1c7ae7d588de17129afbeb46f58931":[3,0,4,3,1755,0],
 "dd/de1/lapacke__ssytrs__3_8c_source.html":[3,0,4,3,1755],
-"dd/de1/zung2r_8f.html":[3,0,5,1992],
-"dd/de1/zung2r_8f_source.html":[3,0,5,1992],
-"dd/de2/dgesc2_8f.html":[3,0,5,560],
-"dd/de2/dgesc2_8f_source.html":[3,0,5,560],
+"dd/de1/zung2r_8f.html":[3,0,5,1990],
+"dd/de1/zung2r_8f_source.html":[3,0,5,1990],
+"dd/de2/dgesc2_8f.html":[3,0,5,559],
+"dd/de2/dgesc2_8f_source.html":[3,0,5,559],
 "dd/de2/lapacke__cgebak_8c.html":[3,0,4,3,26],
 "dd/de2/lapacke__cgebak_8c_aa0735ab023306f620fa6e76f276db0f6.html#aa0735ab023306f620fa6e76f276db0f6":[3,0,4,3,26,0],
 "dd/de2/lapacke__cgebak_8c_source.html":[3,0,4,3,26],
 "dd/de2/lapacke__ssytri2__work_8c.html":[3,0,4,3,1746],
 "dd/de2/lapacke__ssytri2__work_8c_afaa7d21f3e843fc07e93c1ca2c7cf8c7.html#afaa7d21f3e843fc07e93c1ca2c7cf8c7":[3,0,4,3,1746,0],
 "dd/de2/lapacke__ssytri2__work_8c_source.html":[3,0,4,3,1746],
-"dd/de2/zhegv_8f.html":[3,0,5,1648],
-"dd/de2/zhegv_8f_source.html":[3,0,5,1648],
+"dd/de2/zhegv_8f.html":[3,0,5,1646],
+"dd/de2/zhegv_8f_source.html":[3,0,5,1646],
 "dd/de3/srotg_8f90.html":[3,0,0,0,91],
 "dd/de3/srotg_8f90_source.html":[3,0,0,0,91],
 "dd/de4/lapacke__zsytrs__aa__2stage__work_8c.html":[3,0,4,3,2365],
@@ -249,5 +248,6 @@ var NAVTREEINDEX100 =
 "dd/dea/lapacke__zgetsqrhrt__work_8c_source.html":[3,0,4,3,1963],
 "dd/dea/slsets_8f.html":[3,0,6,0,261],
 "dd/dea/slsets_8f_source.html":[3,0,6,0,261],
-"dd/deb/sgtt01_8f.html":[3,0,6,1,490]
+"dd/deb/sgtt01_8f.html":[3,0,6,1,490],
+"dd/deb/sgtt01_8f_source.html":[3,0,6,1,490]
 };
