@@ -1,6 +1,5 @@
 var NAVTREEINDEX101 =
 {
-"dd/deb/sgtt01_8f_source.html":[3,0,6,1,490],
 "dd/dee/lapacke__dtfttr_8c.html":[3,0,4,3,1182],
 "dd/dee/lapacke__dtfttr_8c_a137cedf360c76b238d275cff1177b1f7.html#a137cedf360c76b238d275cff1177b1f7":[3,0,4,3,1182,0],
 "dd/dee/lapacke__dtfttr_8c_source.html":[3,0,4,3,1182],
@@ -9,7 +8,7 @@ var NAVTREEINDEX101 =
 "dd/dee/lapacke__zgbequb_8c_source.html":[3,0,4,3,1848],
 "dd/df0/cblas__zhemm_8c.html":[3,0,1,2,122],
 "dd/df0/cblas__zhemm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,122,2],
-"dd/df0/cblas__zhemm_8c_a439edc3e5b87c1183cc7dfa366f54dde.html#a439edc3e5b87c1183cc7dfa366f54dde":[3,0,1,2,122,7],
+"dd/df0/cblas__zhemm_8c_a4ba45ad84be8fc99f16dbb24af682e47.html#a4ba45ad84be8fc99f16dbb24af682e47":[3,0,1,2,122,7],
 "dd/df0/cblas__zhemm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,122,1],
 "dd/df0/cblas__zhemm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,122,4],
 "dd/df0/cblas__zhemm_8c_a8bc04ca7122be8af5c345be6464f102a.html#a8bc04ca7122be8af5c345be6464f102a":[3,0,1,2,122,5],
@@ -23,22 +22,22 @@ var NAVTREEINDEX101 =
 "dd/df1/cblas__sdsdot_8c.html":[3,0,1,2,80],
 "dd/df1/cblas__sdsdot_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,80,0],
 "dd/df1/cblas__sdsdot_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,80,1],
+"dd/df1/cblas__sdsdot_8c_a6a467ae660744511b95c6277e3e53d4c.html#a6a467ae660744511b95c6277e3e53d4c":[3,0,1,2,80,3],
 "dd/df1/cblas__sdsdot_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,80,2],
-"dd/df1/cblas__sdsdot_8c_a877174b38faa6abbb27fbc2acea33fd0.html#a877174b38faa6abbb27fbc2acea33fd0":[3,0,1,2,80,3],
 "dd/df1/cblas__sdsdot_8c_source.html":[3,0,1,2,80],
 "dd/df1/ddrvgb_8f.html":[3,0,6,1,246],
 "dd/df1/ddrvgb_8f_source.html":[3,0,6,1,246],
-"dd/df1/sormbr_8f.html":[3,0,5,1327],
-"dd/df1/sormbr_8f_source.html":[3,0,5,1327],
-"dd/df2/ztftri_8f.html":[3,0,5,1944],
-"dd/df2/ztftri_8f_source.html":[3,0,5,1944],
+"dd/df1/sormbr_8f.html":[3,0,5,1325],
+"dd/df1/sormbr_8f_source.html":[3,0,5,1325],
+"dd/df2/ztftri_8f.html":[3,0,5,1942],
+"dd/df2/ztftri_8f_source.html":[3,0,5,1942],
 "dd/df3/dpst01_8f.html":[3,0,6,1,346],
 "dd/df3/dpst01_8f_source.html":[3,0,6,1,346],
 "dd/df3/lapacke__zheevd__2stage_8c.html":[3,0,4,3,2045],
 "dd/df3/lapacke__zheevd__2stage_8c_afaaa7cf2287b381a3915fcd83364e9f5.html#afaaa7cf2287b381a3915fcd83364e9f5":[3,0,4,3,2045,0],
 "dd/df3/lapacke__zheevd__2stage_8c_source.html":[3,0,4,3,2045],
-"dd/df4/dsytrf_8f.html":[3,0,5,940],
-"dd/df4/dsytrf_8f_source.html":[3,0,5,940],
+"dd/df4/dsytrf_8f.html":[3,0,5,939],
+"dd/df4/dsytrf_8f_source.html":[3,0,5,939],
 "dd/df4/zdrvgex_8f.html":[3,0,6,1,616],
 "dd/df4/zdrvgex_8f_source.html":[3,0,6,1,616],
 "dd/df5/dlaror_8f.html":[3,0,6,2,25],
@@ -54,76 +53,76 @@ var NAVTREEINDEX101 =
 "dd/df7/lapacke__chprfs__work_8c.html":[3,0,4,3,299],
 "dd/df7/lapacke__chprfs__work_8c_a8e71fda9451ecc826f02dfaa32478b75.html#a8e71fda9451ecc826f02dfaa32478b75":[3,0,4,3,299,0],
 "dd/df7/lapacke__chprfs__work_8c_source.html":[3,0,4,3,299],
-"dd/df8/dlaneg_8f.html":[3,0,5,663],
-"dd/df8/dlaneg_8f_source.html":[3,0,5,663],
+"dd/df8/dlaneg_8f.html":[3,0,5,662],
+"dd/df8/dlaneg_8f_source.html":[3,0,5,662],
 "dd/df8/lapacke__sgeqp3__work_8c.html":[3,0,4,3,1321],
 "dd/df8/lapacke__sgeqp3__work_8c_a9fa62b58678c0393c2659748e3d003ab.html#a9fa62b58678c0393c2659748e3d003ab":[3,0,4,3,1321,0],
 "dd/df8/lapacke__sgeqp3__work_8c_source.html":[3,0,4,3,1321],
 "dd/df9/lapacke__zgbbrd__work_8c.html":[3,0,4,3,1843],
 "dd/df9/lapacke__zgbbrd__work_8c_a2694823a9f5c4a345211da17b339d29a.html#a2694823a9f5c4a345211da17b339d29a":[3,0,4,3,1843,0],
 "dd/df9/lapacke__zgbbrd__work_8c_source.html":[3,0,4,3,1843],
-"dd/df9/ssygv__2stage_8f.html":[3,0,5,1439],
-"dd/df9/ssygv__2stage_8f_source.html":[3,0,5,1439],
-"dd/dfa/zgemqr_8f.html":[3,0,5,1563],
-"dd/dfa/zgemqr_8f_aa1603634b78f8ee90f1c3a7ab89895be.html#aa1603634b78f8ee90f1c3a7ab89895be":[3,0,5,1563,0],
-"dd/dfa/zgemqr_8f_source.html":[3,0,5,1563],
+"dd/df9/ssygv__2stage_8f.html":[3,0,5,1437],
+"dd/df9/ssygv__2stage_8f_source.html":[3,0,5,1437],
+"dd/dfa/zgemqr_8f.html":[3,0,5,1561],
+"dd/dfa/zgemqr_8f_aa1603634b78f8ee90f1c3a7ab89895be.html#aa1603634b78f8ee90f1c3a7ab89895be":[3,0,5,1561,0],
+"dd/dfa/zgemqr_8f_source.html":[3,0,5,1561],
 "dd/dfb/group__complex16__eig.html":[0,1,2,3],
-"dd/dfb/group__complex16__eig_ga06b79b13bd73f94f9dd9091c656edf38.html#ga06b79b13bd73f94f9dd9091c656edf38":[0,1,2,3,49],
 "dd/dfb/group__complex16__eig_ga06b79b13bd73f94f9dd9091c656edf38.html#ga06b79b13bd73f94f9dd9091c656edf38":[3,0,6,0,329,0],
+"dd/dfb/group__complex16__eig_ga06b79b13bd73f94f9dd9091c656edf38.html#ga06b79b13bd73f94f9dd9091c656edf38":[0,1,2,3,49],
 "dd/dfb/group__complex16__eig_ga06f5cd0527f88e4aed3bdbf084d050a9.html#ga06f5cd0527f88e4aed3bdbf084d050a9":[3,0,6,0,355,0],
 "dd/dfb/group__complex16__eig_ga06f5cd0527f88e4aed3bdbf084d050a9.html#ga06f5cd0527f88e4aed3bdbf084d050a9":[0,1,2,3,75],
-"dd/dfb/group__complex16__eig_ga070d0aa3531da9c4cf1187ddacfadc04.html#ga070d0aa3531da9c4cf1187ddacfadc04":[3,0,6,0,348,0],
 "dd/dfb/group__complex16__eig_ga070d0aa3531da9c4cf1187ddacfadc04.html#ga070d0aa3531da9c4cf1187ddacfadc04":[0,1,2,3,68],
-"dd/dfb/group__complex16__eig_ga09d05af8ce92a19304b6700e26d1548e.html#ga09d05af8ce92a19304b6700e26d1548e":[0,1,2,3,31],
+"dd/dfb/group__complex16__eig_ga070d0aa3531da9c4cf1187ddacfadc04.html#ga070d0aa3531da9c4cf1187ddacfadc04":[3,0,6,0,348,0],
 "dd/dfb/group__complex16__eig_ga09d05af8ce92a19304b6700e26d1548e.html#ga09d05af8ce92a19304b6700e26d1548e":[3,0,6,0,311,0],
+"dd/dfb/group__complex16__eig_ga09d05af8ce92a19304b6700e26d1548e.html#ga09d05af8ce92a19304b6700e26d1548e":[0,1,2,3,31],
 "dd/dfb/group__complex16__eig_ga0aa6f942e1e31569fa01d6b77572c3f6.html#ga0aa6f942e1e31569fa01d6b77572c3f6":[0,1,2,3,10],
 "dd/dfb/group__complex16__eig_ga0aa6f942e1e31569fa01d6b77572c3f6.html#ga0aa6f942e1e31569fa01d6b77572c3f6":[3,0,6,0,290,0],
 "dd/dfb/group__complex16__eig_ga0b24cd17637a0c7c2689c338e3beb720.html#ga0b24cd17637a0c7c2689c338e3beb720":[3,0,6,0,289,0],
 "dd/dfb/group__complex16__eig_ga0b24cd17637a0c7c2689c338e3beb720.html#ga0b24cd17637a0c7c2689c338e3beb720":[0,1,2,3,9],
 "dd/dfb/group__complex16__eig_ga0e033c8f1d94f2f9dcf5742d6c93d85b.html#ga0e033c8f1d94f2f9dcf5742d6c93d85b":[3,0,6,0,334,0],
 "dd/dfb/group__complex16__eig_ga0e033c8f1d94f2f9dcf5742d6c93d85b.html#ga0e033c8f1d94f2f9dcf5742d6c93d85b":[0,1,2,3,54],
-"dd/dfb/group__complex16__eig_ga0e8297dde284d708a45b7934df36470e.html#ga0e8297dde284d708a45b7934df36470e":[0,1,2,3,17],
 "dd/dfb/group__complex16__eig_ga0e8297dde284d708a45b7934df36470e.html#ga0e8297dde284d708a45b7934df36470e":[3,0,6,0,297,0],
-"dd/dfb/group__complex16__eig_ga0fb275b7e7ca95861483e96a8865baeb.html#ga0fb275b7e7ca95861483e96a8865baeb":[3,0,6,0,344,0],
+"dd/dfb/group__complex16__eig_ga0e8297dde284d708a45b7934df36470e.html#ga0e8297dde284d708a45b7934df36470e":[0,1,2,3,17],
 "dd/dfb/group__complex16__eig_ga0fb275b7e7ca95861483e96a8865baeb.html#ga0fb275b7e7ca95861483e96a8865baeb":[0,1,2,3,64],
-"dd/dfb/group__complex16__eig_ga15555ac728d52bb12042d5b57152ecff.html#ga15555ac728d52bb12042d5b57152ecff":[0,1,2,3,28],
+"dd/dfb/group__complex16__eig_ga0fb275b7e7ca95861483e96a8865baeb.html#ga0fb275b7e7ca95861483e96a8865baeb":[3,0,6,0,344,0],
 "dd/dfb/group__complex16__eig_ga15555ac728d52bb12042d5b57152ecff.html#ga15555ac728d52bb12042d5b57152ecff":[3,0,6,0,308,0],
-"dd/dfb/group__complex16__eig_ga1a508ad5c31cb603a890d76d4062ed1a.html#ga1a508ad5c31cb603a890d76d4062ed1a":[0,1,2,3,13],
+"dd/dfb/group__complex16__eig_ga15555ac728d52bb12042d5b57152ecff.html#ga15555ac728d52bb12042d5b57152ecff":[0,1,2,3,28],
 "dd/dfb/group__complex16__eig_ga1a508ad5c31cb603a890d76d4062ed1a.html#ga1a508ad5c31cb603a890d76d4062ed1a":[3,0,6,0,293,0],
+"dd/dfb/group__complex16__eig_ga1a508ad5c31cb603a890d76d4062ed1a.html#ga1a508ad5c31cb603a890d76d4062ed1a":[0,1,2,3,13],
 "dd/dfb/group__complex16__eig_ga23b67e5ea0fd86a8df3a60703acabef0.html#ga23b67e5ea0fd86a8df3a60703acabef0":[3,0,6,0,295,0],
 "dd/dfb/group__complex16__eig_ga23b67e5ea0fd86a8df3a60703acabef0.html#ga23b67e5ea0fd86a8df3a60703acabef0":[0,1,2,3,15],
 "dd/dfb/group__complex16__eig_ga2452dadb41e2405e8c575902c4b7a2a2.html#ga2452dadb41e2405e8c575902c4b7a2a2":[0,1,2,3,11],
 "dd/dfb/group__complex16__eig_ga2452dadb41e2405e8c575902c4b7a2a2.html#ga2452dadb41e2405e8c575902c4b7a2a2":[3,0,6,0,291,0],
 "dd/dfb/group__complex16__eig_ga2497b5e3c907b7b142fdc6a9f1fb6e84.html#ga2497b5e3c907b7b142fdc6a9f1fb6e84":[3,0,6,0,285,0],
 "dd/dfb/group__complex16__eig_ga2497b5e3c907b7b142fdc6a9f1fb6e84.html#ga2497b5e3c907b7b142fdc6a9f1fb6e84":[0,1,2,3,5],
-"dd/dfb/group__complex16__eig_ga2613f5765953757de881b744e9b72725.html#ga2613f5765953757de881b744e9b72725":[3,0,6,0,326,0],
 "dd/dfb/group__complex16__eig_ga2613f5765953757de881b744e9b72725.html#ga2613f5765953757de881b744e9b72725":[0,1,2,3,46],
-"dd/dfb/group__complex16__eig_ga278000fdcd9e195f025572375e81eb60.html#ga278000fdcd9e195f025572375e81eb60":[0,1,2,3,50],
+"dd/dfb/group__complex16__eig_ga2613f5765953757de881b744e9b72725.html#ga2613f5765953757de881b744e9b72725":[3,0,6,0,326,0],
 "dd/dfb/group__complex16__eig_ga278000fdcd9e195f025572375e81eb60.html#ga278000fdcd9e195f025572375e81eb60":[3,0,6,0,330,0],
-"dd/dfb/group__complex16__eig_ga2948dcf75ffb37ad4c8893b027ee4de1.html#ga2948dcf75ffb37ad4c8893b027ee4de1":[0,1,2,3,29],
+"dd/dfb/group__complex16__eig_ga278000fdcd9e195f025572375e81eb60.html#ga278000fdcd9e195f025572375e81eb60":[0,1,2,3,50],
 "dd/dfb/group__complex16__eig_ga2948dcf75ffb37ad4c8893b027ee4de1.html#ga2948dcf75ffb37ad4c8893b027ee4de1":[3,0,6,0,309,0],
+"dd/dfb/group__complex16__eig_ga2948dcf75ffb37ad4c8893b027ee4de1.html#ga2948dcf75ffb37ad4c8893b027ee4de1":[0,1,2,3,29],
 "dd/dfb/group__complex16__eig_ga2ded12fae46c5460170f505ca65744a2.html#ga2ded12fae46c5460170f505ca65744a2":[0,1,2,3,39],
 "dd/dfb/group__complex16__eig_ga2ded12fae46c5460170f505ca65744a2.html#ga2ded12fae46c5460170f505ca65744a2":[3,0,6,0,319,0],
-"dd/dfb/group__complex16__eig_ga3a1762cecf9f9df47372de50edff2380.html#ga3a1762cecf9f9df47372de50edff2380":[0,1,2,3,20],
 "dd/dfb/group__complex16__eig_ga3a1762cecf9f9df47372de50edff2380.html#ga3a1762cecf9f9df47372de50edff2380":[3,0,6,0,300,0],
+"dd/dfb/group__complex16__eig_ga3a1762cecf9f9df47372de50edff2380.html#ga3a1762cecf9f9df47372de50edff2380":[0,1,2,3,20],
 "dd/dfb/group__complex16__eig_ga427e9c206762384bc4e7b5bc787e6073.html#ga427e9c206762384bc4e7b5bc787e6073":[3,0,6,0,294,0],
 "dd/dfb/group__complex16__eig_ga427e9c206762384bc4e7b5bc787e6073.html#ga427e9c206762384bc4e7b5bc787e6073":[0,1,2,3,14],
 "dd/dfb/group__complex16__eig_ga4447fac086ee96b40677482c9e273ac8.html#ga4447fac086ee96b40677482c9e273ac8":[0,1,2,3,0],
 "dd/dfb/group__complex16__eig_ga4447fac086ee96b40677482c9e273ac8.html#ga4447fac086ee96b40677482c9e273ac8":[3,0,6,0,279,0],
 "dd/dfb/group__complex16__eig_ga46e5b4f2d2d900a8be48339a8fcbff42.html#ga46e5b4f2d2d900a8be48339a8fcbff42":[0,1,2,3,30],
 "dd/dfb/group__complex16__eig_ga46e5b4f2d2d900a8be48339a8fcbff42.html#ga46e5b4f2d2d900a8be48339a8fcbff42":[3,0,6,0,310,0],
-"dd/dfb/group__complex16__eig_ga4f20b187dff04372757a4008eecbc21f.html#ga4f20b187dff04372757a4008eecbc21f":[0,1,2,3,67],
 "dd/dfb/group__complex16__eig_ga4f20b187dff04372757a4008eecbc21f.html#ga4f20b187dff04372757a4008eecbc21f":[3,0,6,0,347,0],
+"dd/dfb/group__complex16__eig_ga4f20b187dff04372757a4008eecbc21f.html#ga4f20b187dff04372757a4008eecbc21f":[0,1,2,3,67],
 "dd/dfb/group__complex16__eig_ga52fe5c26c3ab6431adb83d9bba8b4eeb.html#ga52fe5c26c3ab6431adb83d9bba8b4eeb":[3,0,6,0,338,0],
 "dd/dfb/group__complex16__eig_ga52fe5c26c3ab6431adb83d9bba8b4eeb.html#ga52fe5c26c3ab6431adb83d9bba8b4eeb":[0,1,2,3,58],
-"dd/dfb/group__complex16__eig_ga5a3131eede15fe6df2ab00e42c3f2ff6.html#ga5a3131eede15fe6df2ab00e42c3f2ff6":[0,1,2,3,21],
 "dd/dfb/group__complex16__eig_ga5a3131eede15fe6df2ab00e42c3f2ff6.html#ga5a3131eede15fe6df2ab00e42c3f2ff6":[3,0,6,0,301,0],
-"dd/dfb/group__complex16__eig_ga5d4eaa3add8cbf75ae58c21d83fa54a9.html#ga5d4eaa3add8cbf75ae58c21d83fa54a9":[0,1,2,3,38],
+"dd/dfb/group__complex16__eig_ga5a3131eede15fe6df2ab00e42c3f2ff6.html#ga5a3131eede15fe6df2ab00e42c3f2ff6":[0,1,2,3,21],
 "dd/dfb/group__complex16__eig_ga5d4eaa3add8cbf75ae58c21d83fa54a9.html#ga5d4eaa3add8cbf75ae58c21d83fa54a9":[3,0,6,0,318,0],
-"dd/dfb/group__complex16__eig_ga5e12931d109ad06c796b415722e71e52.html#ga5e12931d109ad06c796b415722e71e52":[0,1,2,3,40],
+"dd/dfb/group__complex16__eig_ga5d4eaa3add8cbf75ae58c21d83fa54a9.html#ga5d4eaa3add8cbf75ae58c21d83fa54a9":[0,1,2,3,38],
 "dd/dfb/group__complex16__eig_ga5e12931d109ad06c796b415722e71e52.html#ga5e12931d109ad06c796b415722e71e52":[3,0,6,0,320,0],
-"dd/dfb/group__complex16__eig_ga5f37daf9fec134eae34b3575fff5e7c6.html#ga5f37daf9fec134eae34b3575fff5e7c6":[0,1,2,3,73],
+"dd/dfb/group__complex16__eig_ga5e12931d109ad06c796b415722e71e52.html#ga5e12931d109ad06c796b415722e71e52":[0,1,2,3,40],
 "dd/dfb/group__complex16__eig_ga5f37daf9fec134eae34b3575fff5e7c6.html#ga5f37daf9fec134eae34b3575fff5e7c6":[3,0,6,0,353,0],
+"dd/dfb/group__complex16__eig_ga5f37daf9fec134eae34b3575fff5e7c6.html#ga5f37daf9fec134eae34b3575fff5e7c6":[0,1,2,3,73],
 "dd/dfb/group__complex16__eig_ga607a14c898294891e1205e5b20b011c8.html#ga607a14c898294891e1205e5b20b011c8":[0,1,2,3,53],
 "dd/dfb/group__complex16__eig_ga607a14c898294891e1205e5b20b011c8.html#ga607a14c898294891e1205e5b20b011c8":[3,0,6,0,333,0],
 "dd/dfb/group__complex16__eig_ga63eabd833fa379aa63dafb0a57392fe4.html#ga63eabd833fa379aa63dafb0a57392fe4":[0,1,2,3,71],
@@ -132,46 +131,46 @@ var NAVTREEINDEX101 =
 "dd/dfb/group__complex16__eig_ga648d5fcaa302d5769d588aaa6f736fe8.html#ga648d5fcaa302d5769d588aaa6f736fe8":[0,1,2,3,74],
 "dd/dfb/group__complex16__eig_ga66843d0b4fb7bdf9641534ed86711b55.html#ga66843d0b4fb7bdf9641534ed86711b55":[3,0,6,0,337,0],
 "dd/dfb/group__complex16__eig_ga66843d0b4fb7bdf9641534ed86711b55.html#ga66843d0b4fb7bdf9641534ed86711b55":[0,1,2,3,57],
-"dd/dfb/group__complex16__eig_ga66d124fa093cbd4a9c70d869fae241fd.html#ga66d124fa093cbd4a9c70d869fae241fd":[3,0,6,0,324,0],
 "dd/dfb/group__complex16__eig_ga66d124fa093cbd4a9c70d869fae241fd.html#ga66d124fa093cbd4a9c70d869fae241fd":[0,1,2,3,44],
-"dd/dfb/group__complex16__eig_ga66e81745bb5ff734126fccec02c0a369.html#ga66e81745bb5ff734126fccec02c0a369":[0,1,2,3,33],
+"dd/dfb/group__complex16__eig_ga66d124fa093cbd4a9c70d869fae241fd.html#ga66d124fa093cbd4a9c70d869fae241fd":[3,0,6,0,324,0],
 "dd/dfb/group__complex16__eig_ga66e81745bb5ff734126fccec02c0a369.html#ga66e81745bb5ff734126fccec02c0a369":[3,0,6,0,313,0],
-"dd/dfb/group__complex16__eig_ga67fc2605422315893d6fec201c155a59.html#ga67fc2605422315893d6fec201c155a59":[0,1,2,3,70],
+"dd/dfb/group__complex16__eig_ga66e81745bb5ff734126fccec02c0a369.html#ga66e81745bb5ff734126fccec02c0a369":[0,1,2,3,33],
 "dd/dfb/group__complex16__eig_ga67fc2605422315893d6fec201c155a59.html#ga67fc2605422315893d6fec201c155a59":[3,0,6,0,350,0],
-"dd/dfb/group__complex16__eig_ga7573daf15e153234596fdfebe48c9ca9.html#ga7573daf15e153234596fdfebe48c9ca9":[0,1,2,3,6],
+"dd/dfb/group__complex16__eig_ga67fc2605422315893d6fec201c155a59.html#ga67fc2605422315893d6fec201c155a59":[0,1,2,3,70],
 "dd/dfb/group__complex16__eig_ga7573daf15e153234596fdfebe48c9ca9.html#ga7573daf15e153234596fdfebe48c9ca9":[3,0,6,0,286,0],
+"dd/dfb/group__complex16__eig_ga7573daf15e153234596fdfebe48c9ca9.html#ga7573daf15e153234596fdfebe48c9ca9":[0,1,2,3,6],
 "dd/dfb/group__complex16__eig_ga75c7692a13d5e19a47064c934a4b1861.html#ga75c7692a13d5e19a47064c934a4b1861":[0,1,2,3,26],
 "dd/dfb/group__complex16__eig_ga75c7692a13d5e19a47064c934a4b1861.html#ga75c7692a13d5e19a47064c934a4b1861":[3,0,6,0,306,0],
 "dd/dfb/group__complex16__eig_ga7e72d2c592f4188ce6e1f4c065edd682.html#ga7e72d2c592f4188ce6e1f4c065edd682":[0,1,2,3,52],
 "dd/dfb/group__complex16__eig_ga7e72d2c592f4188ce6e1f4c065edd682.html#ga7e72d2c592f4188ce6e1f4c065edd682":[3,0,6,0,332,0],
 "dd/dfb/group__complex16__eig_ga817c8e2419ed8d953bad714eb82d4c54.html#ga817c8e2419ed8d953bad714eb82d4c54":[3,0,6,0,345,0],
 "dd/dfb/group__complex16__eig_ga817c8e2419ed8d953bad714eb82d4c54.html#ga817c8e2419ed8d953bad714eb82d4c54":[0,1,2,3,65],
-"dd/dfb/group__complex16__eig_ga81ce6378154b5d55bedfa1241bb928d1.html#ga81ce6378154b5d55bedfa1241bb928d1":[0,1,2,3,23],
 "dd/dfb/group__complex16__eig_ga81ce6378154b5d55bedfa1241bb928d1.html#ga81ce6378154b5d55bedfa1241bb928d1":[3,0,6,0,303,0],
-"dd/dfb/group__complex16__eig_ga856fb6d577946eb001db09bd7a0bb2d3.html#ga856fb6d577946eb001db09bd7a0bb2d3":[3,0,6,0,328,0],
+"dd/dfb/group__complex16__eig_ga81ce6378154b5d55bedfa1241bb928d1.html#ga81ce6378154b5d55bedfa1241bb928d1":[0,1,2,3,23],
 "dd/dfb/group__complex16__eig_ga856fb6d577946eb001db09bd7a0bb2d3.html#ga856fb6d577946eb001db09bd7a0bb2d3":[0,1,2,3,48],
+"dd/dfb/group__complex16__eig_ga856fb6d577946eb001db09bd7a0bb2d3.html#ga856fb6d577946eb001db09bd7a0bb2d3":[3,0,6,0,328,0],
 "dd/dfb/group__complex16__eig_ga86e891f8d7e7287576454d88af3c0952.html#ga86e891f8d7e7287576454d88af3c0952":[3,0,6,0,339,0],
 "dd/dfb/group__complex16__eig_ga86e891f8d7e7287576454d88af3c0952.html#ga86e891f8d7e7287576454d88af3c0952":[0,1,2,3,59],
 "dd/dfb/group__complex16__eig_ga8cfa5d9479fe4546ef7d28e400003358.html#ga8cfa5d9479fe4546ef7d28e400003358":[0,1,2,3,55],
 "dd/dfb/group__complex16__eig_ga8cfa5d9479fe4546ef7d28e400003358.html#ga8cfa5d9479fe4546ef7d28e400003358":[3,0,6,0,335,0],
-"dd/dfb/group__complex16__eig_ga93ce24d5c1333291a37deb1d10bae67b.html#ga93ce24d5c1333291a37deb1d10bae67b":[3,0,6,0,298,0],
 "dd/dfb/group__complex16__eig_ga93ce24d5c1333291a37deb1d10bae67b.html#ga93ce24d5c1333291a37deb1d10bae67b":[0,1,2,3,18],
-"dd/dfb/group__complex16__eig_ga96a59c0d9bd47e0ed39035f813b7b684.html#ga96a59c0d9bd47e0ed39035f813b7b684":[3,0,6,0,352,0],
+"dd/dfb/group__complex16__eig_ga93ce24d5c1333291a37deb1d10bae67b.html#ga93ce24d5c1333291a37deb1d10bae67b":[3,0,6,0,298,0],
 "dd/dfb/group__complex16__eig_ga96a59c0d9bd47e0ed39035f813b7b684.html#ga96a59c0d9bd47e0ed39035f813b7b684":[0,1,2,3,72],
-"dd/dfb/group__complex16__eig_ga9fb67a93383bedd0a2573cc1e4e38008.html#ga9fb67a93383bedd0a2573cc1e4e38008":[0,1,2,3,2],
+"dd/dfb/group__complex16__eig_ga96a59c0d9bd47e0ed39035f813b7b684.html#ga96a59c0d9bd47e0ed39035f813b7b684":[3,0,6,0,352,0],
 "dd/dfb/group__complex16__eig_ga9fb67a93383bedd0a2573cc1e4e38008.html#ga9fb67a93383bedd0a2573cc1e4e38008":[3,0,6,0,281,0],
+"dd/dfb/group__complex16__eig_ga9fb67a93383bedd0a2573cc1e4e38008.html#ga9fb67a93383bedd0a2573cc1e4e38008":[0,1,2,3,2],
 "dd/dfb/group__complex16__eig_gaa43562d1ca14d490f6fb6ee555df7438.html#gaa43562d1ca14d490f6fb6ee555df7438":[0,1,2,3,43],
 "dd/dfb/group__complex16__eig_gaa43562d1ca14d490f6fb6ee555df7438.html#gaa43562d1ca14d490f6fb6ee555df7438":[3,0,6,0,323,0],
 "dd/dfb/group__complex16__eig_gaa47ecbf426a7802083f1a164e1525005.html#gaa47ecbf426a7802083f1a164e1525005":[3,0,6,0,340,0],
 "dd/dfb/group__complex16__eig_gaa47ecbf426a7802083f1a164e1525005.html#gaa47ecbf426a7802083f1a164e1525005":[0,1,2,3,60],
-"dd/dfb/group__complex16__eig_gaae18ead2df57b6911e5acdc209a39a76.html#gaae18ead2df57b6911e5acdc209a39a76":[3,0,6,0,331,0],
 "dd/dfb/group__complex16__eig_gaae18ead2df57b6911e5acdc209a39a76.html#gaae18ead2df57b6911e5acdc209a39a76":[0,1,2,3,51],
+"dd/dfb/group__complex16__eig_gaae18ead2df57b6911e5acdc209a39a76.html#gaae18ead2df57b6911e5acdc209a39a76":[3,0,6,0,331,0],
 "dd/dfb/group__complex16__eig_gaaf8818e6d955128eb738cdf86c41e7ec.html#gaaf8818e6d955128eb738cdf86c41e7ec":[3,0,6,0,304,0],
 "dd/dfb/group__complex16__eig_gaaf8818e6d955128eb738cdf86c41e7ec.html#gaaf8818e6d955128eb738cdf86c41e7ec":[0,1,2,3,24],
-"dd/dfb/group__complex16__eig_gab64718de54eca7f9e28308a0cdce411f.html#gab64718de54eca7f9e28308a0cdce411f":[0,1,2,3,56],
 "dd/dfb/group__complex16__eig_gab64718de54eca7f9e28308a0cdce411f.html#gab64718de54eca7f9e28308a0cdce411f":[3,0,6,0,336,0],
-"dd/dfb/group__complex16__eig_gab79dcd8016959527ea3d7137912e932d.html#gab79dcd8016959527ea3d7137912e932d":[0,1,2,3,61],
+"dd/dfb/group__complex16__eig_gab64718de54eca7f9e28308a0cdce411f.html#gab64718de54eca7f9e28308a0cdce411f":[0,1,2,3,56],
 "dd/dfb/group__complex16__eig_gab79dcd8016959527ea3d7137912e932d.html#gab79dcd8016959527ea3d7137912e932d":[3,0,6,0,341,0],
+"dd/dfb/group__complex16__eig_gab79dcd8016959527ea3d7137912e932d.html#gab79dcd8016959527ea3d7137912e932d":[0,1,2,3,61],
 "dd/dfb/group__complex16__eig_gab88590f7d1eca9dc769c0be30a6d16c3.html#gab88590f7d1eca9dc769c0be30a6d16c3":[3,0,6,0,287,0],
 "dd/dfb/group__complex16__eig_gab88590f7d1eca9dc769c0be30a6d16c3.html#gab88590f7d1eca9dc769c0be30a6d16c3":[0,1,2,3,7],
 "dd/dfb/group__complex16__eig_gabad24ce737431157851c19a882e12022.html#gabad24ce737431157851c19a882e12022":[3,0,6,0,296,0],
@@ -182,8 +181,8 @@ var NAVTREEINDEX101 =
 "dd/dfb/group__complex16__eig_gac25982b5c0c58a1f9f8025ab4ab33287.html#gac25982b5c0c58a1f9f8025ab4ab33287":[3,0,6,0,305,0],
 "dd/dfb/group__complex16__eig_gac3ea5af78cd94f1a41d4a27e56481087.html#gac3ea5af78cd94f1a41d4a27e56481087":[0,1,2,3,12],
 "dd/dfb/group__complex16__eig_gac3ea5af78cd94f1a41d4a27e56481087.html#gac3ea5af78cd94f1a41d4a27e56481087":[3,0,6,0,292,0],
-"dd/dfb/group__complex16__eig_gac50da824da9466bc66bfe055ebd480ae.html#gac50da824da9466bc66bfe055ebd480ae":[0,1,2,3,19],
 "dd/dfb/group__complex16__eig_gac50da824da9466bc66bfe055ebd480ae.html#gac50da824da9466bc66bfe055ebd480ae":[3,0,6,0,299,0],
+"dd/dfb/group__complex16__eig_gac50da824da9466bc66bfe055ebd480ae.html#gac50da824da9466bc66bfe055ebd480ae":[0,1,2,3,19],
 "dd/dfb/group__complex16__eig_gac8d8895448cbc459ded47dd743f46699.html#gac8d8895448cbc459ded47dd743f46699":[3,0,6,0,322,0],
 "dd/dfb/group__complex16__eig_gac8d8895448cbc459ded47dd743f46699.html#gac8d8895448cbc459ded47dd743f46699":[0,1,2,3,42],
 "dd/dfb/group__complex16__eig_gac8d92ee1ea8c00830b42ebf4017a2ae3.html#gac8d92ee1ea8c00830b42ebf4017a2ae3":[3,0,6,0,356,0],
@@ -196,8 +195,8 @@ var NAVTREEINDEX101 =
 "dd/dfb/group__complex16__eig_gacc4d5c10176e850b750b95e91577a703.html#gacc4d5c10176e850b750b95e91577a703":[3,0,6,0,315,0],
 "dd/dfb/group__complex16__eig_gad219aa578f2f410c3431c8d3642c28cb.html#gad219aa578f2f410c3431c8d3642c28cb":[0,1,2,3,37],
 "dd/dfb/group__complex16__eig_gad219aa578f2f410c3431c8d3642c28cb.html#gad219aa578f2f410c3431c8d3642c28cb":[3,0,6,0,317,0],
-"dd/dfb/group__complex16__eig_gadac8ad25581dfea4f0a2b147a7ce7da9.html#gadac8ad25581dfea4f0a2b147a7ce7da9":[0,1,2,3,32],
 "dd/dfb/group__complex16__eig_gadac8ad25581dfea4f0a2b147a7ce7da9.html#gadac8ad25581dfea4f0a2b147a7ce7da9":[3,0,6,0,312,0],
+"dd/dfb/group__complex16__eig_gadac8ad25581dfea4f0a2b147a7ce7da9.html#gadac8ad25581dfea4f0a2b147a7ce7da9":[0,1,2,3,32],
 "dd/dfb/group__complex16__eig_gadf62e94d7d1eba45c66a510ca52f9802.html#gadf62e94d7d1eba45c66a510ca52f9802":[3,0,6,0,346,0],
 "dd/dfb/group__complex16__eig_gadf62e94d7d1eba45c66a510ca52f9802.html#gadf62e94d7d1eba45c66a510ca52f9802":[0,1,2,3,66],
 "dd/dfb/group__complex16__eig_gae2e86e0081ec0a0bd76bad8463394dc5.html#gae2e86e0081ec0a0bd76bad8463394dc5":[3,0,6,0,280,0],
@@ -208,46 +207,47 @@ var NAVTREEINDEX101 =
 "dd/dfb/group__complex16__eig_gae5e4eed24a4a8519245d586b181df38f.html#gae5e4eed24a4a8519245d586b181df38f":[0,1,2,3,77],
 "dd/dfb/group__complex16__eig_gae5f31f8b72cd1f618622fe93c6b9eac1.html#gae5f31f8b72cd1f618622fe93c6b9eac1":[0,1,2,3,3],
 "dd/dfb/group__complex16__eig_gae5f31f8b72cd1f618622fe93c6b9eac1.html#gae5f31f8b72cd1f618622fe93c6b9eac1":[3,0,6,0,283,0],
-"dd/dfb/group__complex16__eig_gae8a8aba29ee582b9b36f60338693a761.html#gae8a8aba29ee582b9b36f60338693a761":[3,0,6,0,284,0],
 "dd/dfb/group__complex16__eig_gae8a8aba29ee582b9b36f60338693a761.html#gae8a8aba29ee582b9b36f60338693a761":[0,1,2,3,4],
-"dd/dfb/group__complex16__eig_gaeb52cb23aa5a5fe5a884ba5413ea8d02.html#gaeb52cb23aa5a5fe5a884ba5413ea8d02":[3,0,6,0,314,0],
+"dd/dfb/group__complex16__eig_gae8a8aba29ee582b9b36f60338693a761.html#gae8a8aba29ee582b9b36f60338693a761":[3,0,6,0,284,0],
 "dd/dfb/group__complex16__eig_gaeb52cb23aa5a5fe5a884ba5413ea8d02.html#gaeb52cb23aa5a5fe5a884ba5413ea8d02":[0,1,2,3,34],
+"dd/dfb/group__complex16__eig_gaeb52cb23aa5a5fe5a884ba5413ea8d02.html#gaeb52cb23aa5a5fe5a884ba5413ea8d02":[3,0,6,0,314,0],
 "dd/dfb/group__complex16__eig_gaf5ac8f81c63bc01215d2523af67f0a9f.html#gaf5ac8f81c63bc01215d2523af67f0a9f":[3,0,6,0,342,0],
 "dd/dfb/group__complex16__eig_gaf5ac8f81c63bc01215d2523af67f0a9f.html#gaf5ac8f81c63bc01215d2523af67f0a9f":[0,1,2,3,62],
-"dd/dfb/group__complex16__eig_gaf5eb53e84bb7255969d88aba73a1dd82.html#gaf5eb53e84bb7255969d88aba73a1dd82":[3,0,6,0,316,0],
 "dd/dfb/group__complex16__eig_gaf5eb53e84bb7255969d88aba73a1dd82.html#gaf5eb53e84bb7255969d88aba73a1dd82":[0,1,2,3,36],
+"dd/dfb/group__complex16__eig_gaf5eb53e84bb7255969d88aba73a1dd82.html#gaf5eb53e84bb7255969d88aba73a1dd82":[3,0,6,0,316,0],
 "dd/dfb/group__complex16__eig_gaf744ea7ce60893481da2287736a5e860.html#gaf744ea7ce60893481da2287736a5e860":[0,1,2,3,22],
 "dd/dfb/group__complex16__eig_gaf744ea7ce60893481da2287736a5e860.html#gaf744ea7ce60893481da2287736a5e860":[3,0,6,0,302,0],
-"dd/dfb/group__complex16__eig_gaf81dc11e477868381fba4cb8f61904ab.html#gaf81dc11e477868381fba4cb8f61904ab":[3,0,6,0,307,0],
 "dd/dfb/group__complex16__eig_gaf81dc11e477868381fba4cb8f61904ab.html#gaf81dc11e477868381fba4cb8f61904ab":[0,1,2,3,27],
-"dd/dfb/group__complex16__eig_gafb3b6ea91b75f8ed29914e8e7169adb3.html#gafb3b6ea91b75f8ed29914e8e7169adb3":[3,0,6,0,349,0],
+"dd/dfb/group__complex16__eig_gaf81dc11e477868381fba4cb8f61904ab.html#gaf81dc11e477868381fba4cb8f61904ab":[3,0,6,0,307,0],
 "dd/dfb/group__complex16__eig_gafb3b6ea91b75f8ed29914e8e7169adb3.html#gafb3b6ea91b75f8ed29914e8e7169adb3":[0,1,2,3,69],
-"dd/dfb/group__complex16__eig_gafff141ca176900b033d426a3442a5971.html#gafff141ca176900b033d426a3442a5971":[3,0,6,0,327,0],
+"dd/dfb/group__complex16__eig_gafb3b6ea91b75f8ed29914e8e7169adb3.html#gafb3b6ea91b75f8ed29914e8e7169adb3":[3,0,6,0,349,0],
 "dd/dfb/group__complex16__eig_gafff141ca176900b033d426a3442a5971.html#gafff141ca176900b033d426a3442a5971":[0,1,2,3,47],
+"dd/dfb/group__complex16__eig_gafff141ca176900b033d426a3442a5971.html#gafff141ca176900b033d426a3442a5971":[3,0,6,0,327,0],
 "dd/dfb/lapacke__sspsv__work_8c.html":[3,0,4,3,1645],
 "dd/dfb/lapacke__sspsv__work_8c_a62e4525310b8781fd02575c8c573e9fb.html#a62e4525310b8781fd02575c8c573e9fb":[3,0,4,3,1645,0],
 "dd/dfb/lapacke__sspsv__work_8c_source.html":[3,0,4,3,1645],
 "dd/dfb/schkqrt_8f.html":[3,0,6,1,412],
 "dd/dfb/schkqrt_8f_source.html":[3,0,6,1,412],
-"dd/dfb/zgtsv_8f.html":[3,0,5,1617],
-"dd/dfb/zgtsv_8f_source.html":[3,0,5,1617],
+"dd/dfb/zgtsv_8f.html":[3,0,5,1615],
+"dd/dfb/zgtsv_8f_source.html":[3,0,5,1615],
 "dd/dfd/lapacke__dlapmr__work_8c.html":[3,0,4,3,849],
 "dd/dfd/lapacke__dlapmr__work_8c_a5cc33ef1b99aaf3e196f5a0d34e52a80.html#a5cc33ef1b99aaf3e196f5a0d34e52a80":[3,0,4,3,849,0],
 "dd/dfd/lapacke__dlapmr__work_8c_source.html":[3,0,4,3,849],
 "dd/dfe/lapacke__strrfs_8c.html":[3,0,4,3,1816],
 "dd/dfe/lapacke__strrfs_8c_a3a0ead7c81622f85980d985067e88493.html#a3a0ead7c81622f85980d985067e88493":[3,0,4,3,1816,0],
 "dd/dfe/lapacke__strrfs_8c_source.html":[3,0,4,3,1816],
-"dd/dfe/slasd2_8f.html":[3,0,5,1262],
-"dd/dfe/slasd2_8f_source.html":[3,0,5,1262],
+"dd/dfe/slasd2_8f.html":[3,0,5,1260],
+"dd/dfe/slasd2_8f_source.html":[3,0,5,1260],
 "de/d00/lapacke__dorgtsqr__row__work_8c.html":[3,0,4,3,909],
 "de/d00/lapacke__dorgtsqr__row__work_8c_a6b5a426caedcdedda18c6054b56036fb.html#a6b5a426caedcdedda18c6054b56036fb":[3,0,4,3,909,0],
 "de/d00/lapacke__dorgtsqr__row__work_8c_source.html":[3,0,4,3,909],
 "de/d00/zchkhe__rook_8f.html":[3,0,6,1,582],
 "de/d00/zchkhe__rook_8f_source.html":[3,0,6,1,582],
-"de/d00/zla__hercond__x_8f.html":[3,0,5,1718],
-"de/d00/zla__hercond__x_8f_source.html":[3,0,5,1718],
+"de/d00/zla__hercond__x_8f.html":[3,0,5,1716],
+"de/d00/zla__hercond__x_8f_source.html":[3,0,5,1716],
 "de/d01/cla__gerpvgrw_8f.html":[3,0,5,194],
 "de/d01/cla__gerpvgrw_8f_source.html":[3,0,5,194],
 "de/d01/lapacke__dsysvx_8c.html":[3,0,4,3,1132],
-"de/d01/lapacke__dsysvx_8c_a2df1b526436820644782fe12664b9b8b.html#a2df1b526436820644782fe12664b9b8b":[3,0,4,3,1132,0]
+"de/d01/lapacke__dsysvx_8c_a2df1b526436820644782fe12664b9b8b.html#a2df1b526436820644782fe12664b9b8b":[3,0,4,3,1132,0],
+"de/d01/lapacke__dsysvx_8c_source.html":[3,0,4,3,1132]
 };
