@@ -1,15 +1,14 @@
 var NAVTREEINDEX102 =
 {
-"de/d01/lapacke__dsysvx_8c_source.html":[3,0,4,3,1132],
 "de/d02/lapacke__chbgv__work_8c.html":[3,0,4,3,189],
 "de/d02/lapacke__chbgv__work_8c_af86cf5ed9cc42ab138b9f46796f99fe1.html#af86cf5ed9cc42ab138b9f46796f99fe1":[3,0,4,3,189,0],
 "de/d02/lapacke__chbgv__work_8c_source.html":[3,0,4,3,189],
-"de/d02/slartv_8f.html":[3,0,5,1252],
-"de/d02/slartv_8f_source.html":[3,0,5,1252],
-"de/d02/zsytri__rook_8f.html":[3,0,5,1933],
-"de/d02/zsytri__rook_8f_source.html":[3,0,5,1933],
-"de/d04/slasd5_8f.html":[3,0,5,1265],
-"de/d04/slasd5_8f_source.html":[3,0,5,1265],
+"de/d02/slartv_8f.html":[3,0,5,1250],
+"de/d02/slartv_8f_source.html":[3,0,5,1250],
+"de/d02/zsytri__rook_8f.html":[3,0,5,1931],
+"de/d02/zsytri__rook_8f_source.html":[3,0,5,1931],
+"de/d04/slasd5_8f.html":[3,0,5,1263],
+"de/d04/slasd5_8f_source.html":[3,0,5,1263],
 "de/d05/dasum_8f.html":[3,0,0,0,35],
 "de/d05/dasum_8f_source.html":[3,0,0,0,35],
 "de/d05/lapacke__ctbtrs__work_8c.html":[3,0,4,3,537],
@@ -18,8 +17,8 @@ var NAVTREEINDEX102 =
 "de/d05/lapacke__strsen__work_8c.html":[3,0,4,3,1819],
 "de/d05/lapacke__strsen__work_8c_a3edd4c8181fca4b5faab7885c2eb0ed3.html#a3edd4c8181fca4b5faab7885c2eb0ed3":[3,0,4,3,1819,0],
 "de/d05/lapacke__strsen__work_8c_source.html":[3,0,4,3,1819],
-"de/d05/sspgvx_8f.html":[3,0,5,1402],
-"de/d05/sspgvx_8f_source.html":[3,0,5,1402],
+"de/d05/sspgvx_8f.html":[3,0,5,1400],
+"de/d05/sspgvx_8f_source.html":[3,0,5,1400],
 "de/d06/lapacke__zhesv__aa__2stage_8c.html":[3,0,4,3,2072],
 "de/d06/lapacke__zhesv__aa__2stage_8c_abe54625751a62fee82c14634f7ab96ea.html#abe54625751a62fee82c14634f7ab96ea":[3,0,4,3,2072,0],
 "de/d06/lapacke__zhesv__aa__2stage_8c_source.html":[3,0,4,3,2072],
@@ -28,17 +27,17 @@ var NAVTREEINDEX102 =
 "de/d07/lapacke__zgeqpf_8c.html":[3,0,4,3,1912],
 "de/d07/lapacke__zgeqpf_8c_a99347079494da3be644df51411deedf1.html#a99347079494da3be644df51411deedf1":[3,0,4,3,1912,0],
 "de/d07/lapacke__zgeqpf_8c_source.html":[3,0,4,3,1912],
-"de/d07/zlahqr_8f.html":[3,0,5,1754],
-"de/d07/zlahqr_8f_source.html":[3,0,5,1754],
+"de/d07/zlahqr_8f.html":[3,0,5,1752],
+"de/d07/zlahqr_8f_source.html":[3,0,5,1752],
 "de/d09/group__complex16_p_osolve.html":[0,0,4,0,3],
 "de/d09/group__complex16_p_osolve_ga3536bbd664c6152bca5e47cffd0c6676.html#ga3536bbd664c6152bca5e47cffd0c6676":[0,0,4,0,3,3],
-"de/d09/group__complex16_p_osolve_ga3536bbd664c6152bca5e47cffd0c6676.html#ga3536bbd664c6152bca5e47cffd0c6676":[3,0,5,1862,0],
+"de/d09/group__complex16_p_osolve_ga3536bbd664c6152bca5e47cffd0c6676.html#ga3536bbd664c6152bca5e47cffd0c6676":[3,0,5,1860,0],
+"de/d09/group__complex16_p_osolve_ga58f7fd3a95eb2994b1caec327ec75895.html#ga58f7fd3a95eb2994b1caec327ec75895":[3,0,5,1858,0],
 "de/d09/group__complex16_p_osolve_ga58f7fd3a95eb2994b1caec327ec75895.html#ga58f7fd3a95eb2994b1caec327ec75895":[0,0,4,0,3,1],
-"de/d09/group__complex16_p_osolve_ga58f7fd3a95eb2994b1caec327ec75895.html#ga58f7fd3a95eb2994b1caec327ec75895":[3,0,5,1860,0],
 "de/d09/group__complex16_p_osolve_gae1f1548257a84b4328773c60eefb8934.html#gae1f1548257a84b4328773c60eefb8934":[0,0,4,0,3,0],
-"de/d09/group__complex16_p_osolve_gae1f1548257a84b4328773c60eefb8934.html#gae1f1548257a84b4328773c60eefb8934":[3,0,5,1524,0],
+"de/d09/group__complex16_p_osolve_gae1f1548257a84b4328773c60eefb8934.html#gae1f1548257a84b4328773c60eefb8934":[3,0,5,1522,0],
 "de/d09/group__complex16_p_osolve_gae86e9b8504b15462b291b17032195e29.html#gae86e9b8504b15462b291b17032195e29":[0,0,4,0,3,2],
-"de/d09/group__complex16_p_osolve_gae86e9b8504b15462b291b17032195e29.html#gae86e9b8504b15462b291b17032195e29":[3,0,5,1861,0],
+"de/d09/group__complex16_p_osolve_gae86e9b8504b15462b291b17032195e29.html#gae86e9b8504b15462b291b17032195e29":[3,0,5,1859,0],
 "de/d09/lapacke__dgghrd__work_8c.html":[3,0,4,3,797],
 "de/d09/lapacke__dgghrd__work_8c_abceb8e131bbdf7d8e0b1ae59d7c8aa64.html#abceb8e131bbdf7d8e0b1ae59d7c8aa64":[3,0,4,3,797,0],
 "de/d09/lapacke__dgghrd__work_8c_source.html":[3,0,4,3,797],
@@ -50,17 +49,17 @@ var NAVTREEINDEX102 =
 "de/d0b/lapacke__ztrtri__work_8c_source.html":[3,0,4,3,2431],
 "de/d0d/group__real_s_yauxiliary.html":[0,0,2,3,1],
 "de/d0d/group__real_s_yauxiliary_ga611e1beaaad792e0753a47723c8380ed.html#ga611e1beaaad792e0753a47723c8380ed":[0,0,2,3,1,0],
-"de/d0d/group__real_s_yauxiliary_ga611e1beaaad792e0753a47723c8380ed.html#ga611e1beaaad792e0753a47723c8380ed":[3,0,5,1195,0],
+"de/d0d/group__real_s_yauxiliary_ga611e1beaaad792e0753a47723c8380ed.html#ga611e1beaaad792e0753a47723c8380ed":[3,0,5,1193,0],
+"de/d0d/group__real_s_yauxiliary_ga739f7e0603f9635371aad0683dae1dbb.html#ga739f7e0603f9635371aad0683dae1dbb":[3,0,5,1488,0],
 "de/d0d/group__real_s_yauxiliary_ga739f7e0603f9635371aad0683dae1dbb.html#ga739f7e0603f9635371aad0683dae1dbb":[0,0,2,3,1,4],
-"de/d0d/group__real_s_yauxiliary_ga739f7e0603f9635371aad0683dae1dbb.html#ga739f7e0603f9635371aad0683dae1dbb":[3,0,5,1490,0],
+"de/d0d/group__real_s_yauxiliary_ga768b34b0d6fc6604ccf54437d5e8e78c.html#ga768b34b0d6fc6604ccf54437d5e8e78c":[3,0,5,1283,0],
 "de/d0d/group__real_s_yauxiliary_ga768b34b0d6fc6604ccf54437d5e8e78c.html#ga768b34b0d6fc6604ccf54437d5e8e78c":[0,0,2,3,1,2],
-"de/d0d/group__real_s_yauxiliary_ga768b34b0d6fc6604ccf54437d5e8e78c.html#ga768b34b0d6fc6604ccf54437d5e8e78c":[3,0,5,1285,0],
-"de/d0d/group__real_s_yauxiliary_gad09b2a02a370c25292456c37fb1b8245.html#gad09b2a02a370c25292456c37fb1b8245":[3,0,5,1451,0],
+"de/d0d/group__real_s_yauxiliary_gad09b2a02a370c25292456c37fb1b8245.html#gad09b2a02a370c25292456c37fb1b8245":[3,0,5,1449,0],
 "de/d0d/group__real_s_yauxiliary_gad09b2a02a370c25292456c37fb1b8245.html#gad09b2a02a370c25292456c37fb1b8245":[0,0,2,3,1,3],
 "de/d0d/group__real_s_yauxiliary_gae8aee61b66e5c43af072432c98e8024a.html#gae8aee61b66e5c43af072432c98e8024a":[0,0,2,3,1,1],
-"de/d0d/group__real_s_yauxiliary_gae8aee61b66e5c43af072432c98e8024a.html#gae8aee61b66e5c43af072432c98e8024a":[3,0,5,1219,0],
-"de/d0d/zuncsd_8f.html":[3,0,5,1989],
-"de/d0d/zuncsd_8f_source.html":[3,0,5,1989],
+"de/d0d/group__real_s_yauxiliary_gae8aee61b66e5c43af072432c98e8024a.html#gae8aee61b66e5c43af072432c98e8024a":[3,0,5,1217,0],
+"de/d0d/zuncsd_8f.html":[3,0,5,1987],
+"de/d0d/zuncsd_8f_source.html":[3,0,5,1987],
 "de/d0e/lapacke__dgeevx_8c.html":[3,0,4,3,694],
 "de/d0e/lapacke__dgeevx_8c_a696dc5ea44dede7af9265154ef1007a5.html#a696dc5ea44dede7af9265154ef1007a5":[3,0,4,3,694,0],
 "de/d0e/lapacke__dgeevx_8c_source.html":[3,0,4,3,694],
@@ -69,9 +68,9 @@ var NAVTREEINDEX102 =
 "de/d10/lapacke__dtbtrs_8c.html":[3,0,4,3,1174],
 "de/d10/lapacke__dtbtrs_8c_a8739576d11e9eae3c3434cd75477509e.html#a8739576d11e9eae3c3434cd75477509e":[3,0,4,3,1174,0],
 "de/d10/lapacke__dtbtrs_8c_source.html":[3,0,4,3,1174],
-"de/d11/dsytrd__sb2st_8_f.html":[3,0,5,938],
-"de/d11/dsytrd__sb2st_8_f_affeb54a9c057927de95ff708e7caa9fc.html#affeb54a9c057927de95ff708e7caa9fc":[3,0,5,938,0],
-"de/d11/dsytrd__sb2st_8_f_source.html":[3,0,5,938],
+"de/d11/dsytrd__sb2st_8_f.html":[3,0,5,937],
+"de/d11/dsytrd__sb2st_8_f_affeb54a9c057927de95ff708e7caa9fc.html#affeb54a9c057927de95ff708e7caa9fc":[3,0,5,937,0],
+"de/d11/dsytrd__sb2st_8_f_source.html":[3,0,5,937],
 "de/d11/lapacke__ssytri2_8c.html":[3,0,4,3,1745],
 "de/d11/lapacke__ssytri2_8c_a53f429090cf60288bf4d8eaa481160a1.html#a53f429090cf60288bf4d8eaa481160a1":[3,0,4,3,1745,0],
 "de/d11/lapacke__ssytri2_8c_source.html":[3,0,4,3,1745],
@@ -85,18 +84,18 @@ var NAVTREEINDEX102 =
 "de/d14/cppsvx_8f_source.html":[3,0,5,350],
 "de/d14/group__complex16_s_yauxiliary.html":[0,0,2,3,3],
 "de/d14/group__complex16_s_yauxiliary_ga08a5c1ca17a783b2f7e7f3bc80b422dd.html#ga08a5c1ca17a783b2f7e7f3bc80b422dd":[0,0,2,3,3,4],
-"de/d14/group__complex16_s_yauxiliary_ga08a5c1ca17a783b2f7e7f3bc80b422dd.html#ga08a5c1ca17a783b2f7e7f3bc80b422dd":[3,0,5,1909,0],
+"de/d14/group__complex16_s_yauxiliary_ga08a5c1ca17a783b2f7e7f3bc80b422dd.html#ga08a5c1ca17a783b2f7e7f3bc80b422dd":[3,0,5,1907,0],
+"de/d14/group__complex16_s_yauxiliary_ga32c00d5ce9d568146d9396257bdea188.html#ga32c00d5ce9d568146d9396257bdea188":[3,0,5,1793,0],
 "de/d14/group__complex16_s_yauxiliary_ga32c00d5ce9d568146d9396257bdea188.html#ga32c00d5ce9d568146d9396257bdea188":[0,0,2,3,3,2],
-"de/d14/group__complex16_s_yauxiliary_ga32c00d5ce9d568146d9396257bdea188.html#ga32c00d5ce9d568146d9396257bdea188":[3,0,5,1795,0],
-"de/d14/group__complex16_s_yauxiliary_ga36d9ec6db6e6dda43c30a8727ae0d6ae.html#ga36d9ec6db6e6dda43c30a8727ae0d6ae":[3,0,5,1919,0],
 "de/d14/group__complex16_s_yauxiliary_ga36d9ec6db6e6dda43c30a8727ae0d6ae.html#ga36d9ec6db6e6dda43c30a8727ae0d6ae":[0,0,2,3,3,5],
-"de/d14/group__complex16_s_yauxiliary_gab24c8af7cc49b5eef89718d4d6a889e3.html#gab24c8af7cc49b5eef89718d4d6a889e3":[3,0,5,1953,0],
+"de/d14/group__complex16_s_yauxiliary_ga36d9ec6db6e6dda43c30a8727ae0d6ae.html#ga36d9ec6db6e6dda43c30a8727ae0d6ae":[3,0,5,1917,0],
 "de/d14/group__complex16_s_yauxiliary_gab24c8af7cc49b5eef89718d4d6a889e3.html#gab24c8af7cc49b5eef89718d4d6a889e3":[0,0,2,3,3,6],
-"de/d14/group__complex16_s_yauxiliary_gab9b336644e5cff134d305d70730e60ba.html#gab9b336644e5cff134d305d70730e60ba":[3,0,5,1908,0],
+"de/d14/group__complex16_s_yauxiliary_gab24c8af7cc49b5eef89718d4d6a889e3.html#gab24c8af7cc49b5eef89718d4d6a889e3":[3,0,5,1951,0],
 "de/d14/group__complex16_s_yauxiliary_gab9b336644e5cff134d305d70730e60ba.html#gab9b336644e5cff134d305d70730e60ba":[0,0,2,3,3,3],
-"de/d14/group__complex16_s_yauxiliary_gade54011df54cab1e5e981e6a86ac2dc2.html#gade54011df54cab1e5e981e6a86ac2dc2":[3,0,5,1745,0],
+"de/d14/group__complex16_s_yauxiliary_gab9b336644e5cff134d305d70730e60ba.html#gab9b336644e5cff134d305d70730e60ba":[3,0,5,1906,0],
 "de/d14/group__complex16_s_yauxiliary_gade54011df54cab1e5e981e6a86ac2dc2.html#gade54011df54cab1e5e981e6a86ac2dc2":[0,0,2,3,3,0],
-"de/d14/group__complex16_s_yauxiliary_gae1d67e9c7403f3d6e2c5db6073b014d3.html#gae1d67e9c7403f3d6e2c5db6073b014d3":[3,0,5,1773,0],
+"de/d14/group__complex16_s_yauxiliary_gade54011df54cab1e5e981e6a86ac2dc2.html#gade54011df54cab1e5e981e6a86ac2dc2":[3,0,5,1743,0],
+"de/d14/group__complex16_s_yauxiliary_gae1d67e9c7403f3d6e2c5db6073b014d3.html#gae1d67e9c7403f3d6e2c5db6073b014d3":[3,0,5,1771,0],
 "de/d14/group__complex16_s_yauxiliary_gae1d67e9c7403f3d6e2c5db6073b014d3.html#gae1d67e9c7403f3d6e2c5db6073b014d3":[0,0,2,3,3,1],
 "de/d14/lapacke__csysv__rk_8c.html":[3,0,4,3,491],
 "de/d14/lapacke__csysv__rk_8c_a1de0a691b64a0a4a7e90df49933a8b9f.html#a1de0a691b64a0a4a7e90df49933a8b9f":[3,0,4,3,491,0],
@@ -122,15 +121,15 @@ var NAVTREEINDEX102 =
 "de/d1c/cblas__zgerc_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,119,1],
 "de/d1c/cblas__zgerc_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,119,4],
 "de/d1c/cblas__zgerc_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,119,2],
-"de/d1c/cblas__zgerc_8c_aa04090496e1efe8ebbf16dab2fe892bf.html#aa04090496e1efe8ebbf16dab2fe892bf":[3,0,1,2,119,5],
+"de/d1c/cblas__zgerc_8c_aa62c6d75df45dc3949006ea9db5ae42d.html#aa62c6d75df45dc3949006ea9db5ae42d":[3,0,1,2,119,5],
 "de/d1c/cblas__zgerc_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,119,3],
 "de/d1c/cblas__zgerc_8c_source.html":[3,0,1,2,119],
 "de/d1c/lapacke__zlapmt__work_8c.html":[3,0,4,3,2183],
 "de/d1c/lapacke__zlapmt__work_8c_afa0a2e8c50da2edb1b99d3585e839e16.html#afa0a2e8c50da2edb1b99d3585e839e16":[3,0,4,3,2183,0],
 "de/d1c/lapacke__zlapmt__work_8c_source.html":[3,0,4,3,2183],
-"de/d1c/slarfb__gett_8f.html":[3,0,5,1230],
-"de/d1c/slarfb__gett_8f_a6521ec34bf3a213c11cd18be2b3dea9f.html#a6521ec34bf3a213c11cd18be2b3dea9f":[3,0,5,1230,0],
-"de/d1c/slarfb__gett_8f_source.html":[3,0,5,1230],
+"de/d1c/slarfb__gett_8f.html":[3,0,5,1228],
+"de/d1c/slarfb__gett_8f_a6521ec34bf3a213c11cd18be2b3dea9f.html#a6521ec34bf3a213c11cd18be2b3dea9f":[3,0,5,1228,0],
+"de/d1c/slarfb__gett_8f_source.html":[3,0,5,1228],
 "de/d1d/lapacke__ztbcon_8c.html":[3,0,4,3,2370],
 "de/d1d/lapacke__ztbcon_8c_aa8e2893be2d5073bcdc1efb6ee028536.html#aa8e2893be2d5073bcdc1efb6ee028536":[3,0,4,3,2370,0],
 "de/d1d/lapacke__ztbcon_8c_source.html":[3,0,4,3,2370],
@@ -139,22 +138,22 @@ var NAVTREEINDEX102 =
 "de/d1e/lapacke__zspsv_8c.html":[3,0,4,3,2290],
 "de/d1e/lapacke__zspsv_8c_a95f622ac1c39fba1379c3dae199b2d10.html#a95f622ac1c39fba1379c3dae199b2d10":[3,0,4,3,2290,0],
 "de/d1e/lapacke__zspsv_8c_source.html":[3,0,4,3,2290],
-"de/d1e/zgbsv_8f.html":[3,0,5,1532],
-"de/d1e/zgbsv_8f_source.html":[3,0,5,1532],
+"de/d1e/zgbsv_8f.html":[3,0,5,1530],
+"de/d1e/zgbsv_8f_source.html":[3,0,5,1530],
 "de/d1f/cchksy__rk_8f.html":[3,0,6,1,37],
 "de/d1f/cchksy__rk_8f_source.html":[3,0,6,1,37],
-"de/d20/zsymv_8f.html":[3,0,5,1908],
-"de/d20/zsymv_8f_source.html":[3,0,5,1908],
-"de/d21/sspgvd_8f.html":[3,0,5,1401],
-"de/d21/sspgvd_8f_source.html":[3,0,5,1401],
+"de/d20/zsymv_8f.html":[3,0,5,1906],
+"de/d20/zsymv_8f_source.html":[3,0,5,1906],
+"de/d21/sspgvd_8f.html":[3,0,5,1399],
+"de/d21/sspgvd_8f_source.html":[3,0,5,1399],
 "de/d22/lapacke__cgetrf2_8c.html":[3,0,4,3,115],
 "de/d22/lapacke__cgetrf2_8c_aa362ae2d6a7b9c0787699b27822df2d5.html#aa362ae2d6a7b9c0787699b27822df2d5":[3,0,4,3,115,0],
 "de/d22/lapacke__cgetrf2_8c_source.html":[3,0,4,3,115],
 "de/d23/lapacke__zgeequb__work_8c.html":[3,0,4,3,1875],
 "de/d23/lapacke__zgeequb__work_8c_a6fcfbf0ed0477560d08749d34c2b6e9f.html#a6fcfbf0ed0477560d08749d34c2b6e9f":[3,0,4,3,1875,0],
 "de/d23/lapacke__zgeequb__work_8c_source.html":[3,0,4,3,1875],
-"de/d23/slaqps_8f.html":[3,0,5,1210],
-"de/d23/slaqps_8f_source.html":[3,0,5,1210],
+"de/d23/slaqps_8f.html":[3,0,5,1208],
+"de/d23/slaqps_8f_source.html":[3,0,5,1208],
 "de/d26/zckglm_8f.html":[3,0,6,0,298],
 "de/d26/zckglm_8f_source.html":[3,0,6,0,298],
 "de/d27/lapacke__dggev_8c.html":[3,0,4,3,786],
@@ -166,8 +165,8 @@ var NAVTREEINDEX102 =
 "de/d2a/lapacke__dsytrs__3_8c.html":[3,0,4,3,1161],
 "de/d2a/lapacke__dsytrs__3_8c_a868a3fce2ff5323d3e65e37995be51b6.html#a868a3fce2ff5323d3e65e37995be51b6":[3,0,4,3,1161,0],
 "de/d2a/lapacke__dsytrs__3_8c_source.html":[3,0,4,3,1161],
-"de/d2c/zlaqp2_8f.html":[3,0,5,1785],
-"de/d2c/zlaqp2_8f_source.html":[3,0,5,1785],
+"de/d2c/zlaqp2_8f.html":[3,0,5,1783],
+"de/d2c/zlaqp2_8f_source.html":[3,0,5,1783],
 "de/d2d/cpbtrf_8f.html":[3,0,5,328],
 "de/d2d/cpbtrf_8f_source.html":[3,0,5,328],
 "de/d2d/lapacke__dormql__work_8c.html":[3,0,4,3,917],
@@ -191,12 +190,12 @@ var NAVTREEINDEX102 =
 "de/d32/lapacke__csysv__rook__work_8c.html":[3,0,4,3,494],
 "de/d32/lapacke__csysv__rook__work_8c_a783391b56021bcb987546109d4583abb.html#a783391b56021bcb987546109d4583abb":[3,0,4,3,494,0],
 "de/d32/lapacke__csysv__rook__work_8c_source.html":[3,0,4,3,494],
-"de/d32/slatrs_8f.html":[3,0,5,1294],
-"de/d32/slatrs_8f_source.html":[3,0,5,1294],
-"de/d33/sggsvp3_8f.html":[3,0,5,1115],
-"de/d33/sggsvp3_8f_source.html":[3,0,5,1115],
-"de/d34/zgelqt_8f.html":[3,0,5,1555],
-"de/d34/zgelqt_8f_source.html":[3,0,5,1555],
+"de/d32/slatrs_8f.html":[3,0,5,1292],
+"de/d32/slatrs_8f_source.html":[3,0,5,1292],
+"de/d33/sggsvp3_8f.html":[3,0,5,1113],
+"de/d33/sggsvp3_8f_source.html":[3,0,5,1113],
+"de/d34/zgelqt_8f.html":[3,0,5,1553],
+"de/d34/zgelqt_8f_source.html":[3,0,5,1553],
 "de/d35/lapacke__chesv__aa_8c.html":[3,0,4,3,233],
 "de/d35/lapacke__chesv__aa_8c_ad30c0c6ccb5fa47e784b687b82994c63.html#ad30c0c6ccb5fa47e784b687b82994c63":[3,0,4,3,233,0],
 "de/d35/lapacke__chesv__aa_8c_source.html":[3,0,4,3,233],
@@ -205,25 +204,25 @@ var NAVTREEINDEX102 =
 "de/d36/lapacke__dsytrs__3__work_8c.html":[3,0,4,3,1162],
 "de/d36/lapacke__dsytrs__3__work_8c_a36bf6c34b9a5d576106097b148a96e41.html#a36bf6c34b9a5d576106097b148a96e41":[3,0,4,3,1162,0],
 "de/d36/lapacke__dsytrs__3__work_8c_source.html":[3,0,4,3,1162],
-"de/d37/dgbsvxx_8f.html":[3,0,5,514],
-"de/d37/dgbsvxx_8f_source.html":[3,0,5,514],
-"de/d37/ssytri__3x_8f.html":[3,0,5,1469],
-"de/d37/ssytri__3x_8f_a1326995e3dce81242c18d944fe32e192.html#a1326995e3dce81242c18d944fe32e192":[3,0,5,1469,0],
-"de/d37/ssytri__3x_8f_source.html":[3,0,5,1469],
+"de/d37/dgbsvxx_8f.html":[3,0,5,513],
+"de/d37/dgbsvxx_8f_source.html":[3,0,5,513],
+"de/d37/ssytri__3x_8f.html":[3,0,5,1467],
+"de/d37/ssytri__3x_8f_a1326995e3dce81242c18d944fe32e192.html#a1326995e3dce81242c18d944fe32e192":[3,0,5,1467,0],
+"de/d37/ssytri__3x_8f_source.html":[3,0,5,1467],
 "de/d38/lapacke__spbsv_8c.html":[3,0,4,3,1532],
 "de/d38/lapacke__spbsv_8c_a631c03e88fc8e43e080b8fc0cbe9243f.html#a631c03e88fc8e43e080b8fc0cbe9243f":[3,0,4,3,1532,0],
 "de/d38/lapacke__spbsv_8c_source.html":[3,0,4,3,1532],
 "de/d39/group__double_g_eauxiliary.html":[0,0,0,5,0],
 "de/d39/group__double_g_eauxiliary_ga2ecd51f7842c100d6b4ecc99119c012f.html#ga2ecd51f7842c100d6b4ecc99119c012f":[0,0,0,5,0,1],
-"de/d39/group__double_g_eauxiliary_ga2ecd51f7842c100d6b4ecc99119c012f.html#ga2ecd51f7842c100d6b4ecc99119c012f":[3,0,5,569,0],
-"de/d39/group__double_g_eauxiliary_gaa3c93490c68259c80285d72cb61cbd99.html#gaa3c93490c68259c80285d72cb61cbd99":[3,0,5,965,0],
+"de/d39/group__double_g_eauxiliary_ga2ecd51f7842c100d6b4ecc99119c012f.html#ga2ecd51f7842c100d6b4ecc99119c012f":[3,0,5,568,0],
 "de/d39/group__double_g_eauxiliary_gaa3c93490c68259c80285d72cb61cbd99.html#gaa3c93490c68259c80285d72cb61cbd99":[0,0,0,5,0,4],
+"de/d39/group__double_g_eauxiliary_gaa3c93490c68259c80285d72cb61cbd99.html#gaa3c93490c68259c80285d72cb61cbd99":[3,0,5,964,0],
+"de/d39/group__double_g_eauxiliary_gaac3990ea4aa237d06ad9563df69abac3.html#gaac3990ea4aa237d06ad9563df69abac3":[3,0,5,684,0],
 "de/d39/group__double_g_eauxiliary_gaac3990ea4aa237d06ad9563df69abac3.html#gaac3990ea4aa237d06ad9563df69abac3":[0,0,0,5,0,3],
-"de/d39/group__double_g_eauxiliary_gaac3990ea4aa237d06ad9563df69abac3.html#gaac3990ea4aa237d06ad9563df69abac3":[3,0,5,685,0],
-"de/d39/group__double_g_eauxiliary_gac6998d2ed1a92cc28708602db64f3db6.html#gac6998d2ed1a92cc28708602db64f3db6":[3,0,5,560,0],
 "de/d39/group__double_g_eauxiliary_gac6998d2ed1a92cc28708602db64f3db6.html#gac6998d2ed1a92cc28708602db64f3db6":[0,0,0,5,0,0],
+"de/d39/group__double_g_eauxiliary_gac6998d2ed1a92cc28708602db64f3db6.html#gac6998d2ed1a92cc28708602db64f3db6":[3,0,5,559,0],
+"de/d39/group__double_g_eauxiliary_gaefa80dbd8cd1732740478618b8b622a1.html#gaefa80dbd8cd1732740478618b8b622a1":[3,0,5,664,0],
 "de/d39/group__double_g_eauxiliary_gaefa80dbd8cd1732740478618b8b622a1.html#gaefa80dbd8cd1732740478618b8b622a1":[0,0,0,5,0,2],
-"de/d39/group__double_g_eauxiliary_gaefa80dbd8cd1732740478618b8b622a1.html#gaefa80dbd8cd1732740478618b8b622a1":[3,0,5,665,0],
 "de/d3a/cchklqtp_8f.html":[3,0,6,1,20],
 "de/d3a/cchklqtp_8f_source.html":[3,0,6,1,20],
 "de/d3b/lapacke__ssbev_8c.html":[3,0,4,3,1602],
@@ -236,8 +235,8 @@ var NAVTREEINDEX102 =
 "de/d3b/struct_c_b_l_a_s___t_e_s_t___z_o_m_p_l_e_x_ac30a589dd0b6390d01b5b267845c1006.html#ac30a589dd0b6390d01b5b267845c1006":[2,0,2,0],
 "de/d3b/zlqt05_8f.html":[3,0,6,1,716],
 "de/d3b/zlqt05_8f_source.html":[3,0,6,1,716],
-"de/d3c/dlascl_8f.html":[3,0,5,735],
-"de/d3c/dlascl_8f_source.html":[3,0,5,735],
+"de/d3c/dlascl_8f.html":[3,0,5,734],
+"de/d3c/dlascl_8f_source.html":[3,0,5,734],
 "de/d3c/lapacke__dsysv__aa_8c.html":[3,0,4,3,1123],
 "de/d3c/lapacke__dsysv__aa_8c_a3324258805a409761b9cc58c6b6d58d4.html#a3324258805a409761b9cc58c6b6d58d4":[3,0,4,3,1123,0],
 "de/d3c/lapacke__dsysv__aa_8c_source.html":[3,0,4,3,1123],
@@ -246,8 +245,9 @@ var NAVTREEINDEX102 =
 "de/d3d/lapacke__dsyswapr_8c_source.html":[3,0,4,3,1136],
 "de/d3d/zchktz_8f.html":[3,0,6,1,609],
 "de/d3d/zchktz_8f_source.html":[3,0,6,1,609],
-"de/d3e/sla__gbrfsx__extended_8f.html":[3,0,5,1131],
-"de/d3e/sla__gbrfsx__extended_8f_source.html":[3,0,5,1131],
+"de/d3e/sla__gbrfsx__extended_8f.html":[3,0,5,1129],
+"de/d3e/sla__gbrfsx__extended_8f_source.html":[3,0,5,1129],
 "de/d3f/cchkpb_8f.html":[3,0,6,1,21],
-"de/d3f/cchkpb_8f_source.html":[3,0,6,1,21]
+"de/d3f/cchkpb_8f_source.html":[3,0,6,1,21],
+"de/d3f/lapacke__zungqr_8c.html":[3,0,4,3,2454]
 };
