@@ -1,5 +1,7 @@
 var NAVTREEINDEX105 =
 {
+"de/d71/dlatm4_8f.html":[3,0,6,0,162],
+"de/d71/dlatm4_8f_source.html":[3,0,6,0,162],
 "de/d71/group__complex_p_tsolve.html":[0,0,6,0,2],
 "de/d71/group__complex_p_tsolve_ga32f573f1f8ee1da3094e15474bbcc0fe.html#ga32f573f1f8ee1da3094e15474bbcc0fe":[3,0,5,360,0],
 "de/d71/group__complex_p_tsolve_ga32f573f1f8ee1da3094e15474bbcc0fe.html#ga32f573f1f8ee1da3094e15474bbcc0fe":[0,0,6,0,2,1],
@@ -15,12 +17,12 @@ var NAVTREEINDEX105 =
 "de/d72/lapacke__ztgsja_8c.html":[3,0,4,3,2390],
 "de/d72/lapacke__ztgsja_8c_a0402a65112df15bb76a9334771729023.html#a0402a65112df15bb76a9334771729023":[3,0,4,3,2390,0],
 "de/d72/lapacke__ztgsja_8c_source.html":[3,0,4,3,2390],
-"de/d72/zgges3_8f.html":[3,0,5,1600],
-"de/d72/zgges3_8f_source.html":[3,0,5,1600],
-"de/d73/zhetrs__aa__2stage_8f.html":[3,0,5,1685],
-"de/d73/zhetrs__aa__2stage_8f_source.html":[3,0,5,1685],
-"de/d73/zlanhe_8f.html":[3,0,5,1766],
-"de/d73/zlanhe_8f_source.html":[3,0,5,1766],
+"de/d72/zgges3_8f.html":[3,0,5,1598],
+"de/d72/zgges3_8f_source.html":[3,0,5,1598],
+"de/d73/zhetrs__aa__2stage_8f.html":[3,0,5,1683],
+"de/d73/zhetrs__aa__2stage_8f_source.html":[3,0,5,1683],
+"de/d73/zlanhe_8f.html":[3,0,5,1764],
+"de/d73/zlanhe_8f_source.html":[3,0,5,1764],
 "de/d74/lapacke__zgeesx_8c.html":[3,0,4,3,1878],
 "de/d74/lapacke__zgeesx_8c_ade289800aa16186eab2597ead0e4dcc4.html#ade289800aa16186eab2597ead0e4dcc4":[3,0,4,3,1878,0],
 "de/d74/lapacke__zgeesx_8c_source.html":[3,0,4,3,1878],
@@ -29,19 +31,19 @@ var NAVTREEINDEX105 =
 "de/d75/lapacke__dorgqr_8c_source.html":[3,0,4,3,902],
 "de/d75/zchkeq_8f.html":[3,0,6,1,574],
 "de/d75/zchkeq_8f_source.html":[3,0,6,1,574],
-"de/d76/dgbtrs_8f.html":[3,0,5,517],
-"de/d76/dgbtrs_8f_source.html":[3,0,5,517],
-"de/d76/dlasd1_8f.html":[3,0,5,738],
-"de/d76/dlasd1_8f_source.html":[3,0,5,738],
+"de/d76/dgbtrs_8f.html":[3,0,5,516],
+"de/d76/dgbtrs_8f_source.html":[3,0,5,516],
+"de/d76/dlasd1_8f.html":[3,0,5,737],
+"de/d76/dlasd1_8f_source.html":[3,0,5,737],
 "de/d76/lapacke__spbequ_8c.html":[3,0,4,3,1526],
 "de/d76/lapacke__spbequ_8c_a218e74fe8b2bb562674bb3f72ec719f7.html#a218e74fe8b2bb562674bb3f72ec719f7":[3,0,4,3,1526,0],
 "de/d76/lapacke__spbequ_8c_source.html":[3,0,4,3,1526],
-"de/d76/strtri_8f.html":[3,0,5,1514],
-"de/d76/strtri_8f_source.html":[3,0,5,1514],
+"de/d76/strtri_8f.html":[3,0,5,1512],
+"de/d76/strtri_8f_source.html":[3,0,5,1512],
 "de/d77/schkps_8f.html":[3,0,6,1,407],
 "de/d77/schkps_8f_source.html":[3,0,6,1,407],
-"de/d77/slasr_8f.html":[3,0,5,1279],
-"de/d77/slasr_8f_source.html":[3,0,5,1279],
+"de/d77/slasr_8f.html":[3,0,5,1277],
+"de/d77/slasr_8f_source.html":[3,0,5,1277],
 "de/d78/chptrs_8f.html":[3,0,5,182],
 "de/d78/chptrs_8f_source.html":[3,0,5,182],
 "de/d79/drqt02_8f.html":[3,0,6,1,368],
@@ -52,8 +54,8 @@ var NAVTREEINDEX105 =
 "de/d7a/lapacke__sgesvx_8c.html":[3,0,4,3,1356],
 "de/d7a/lapacke__sgesvx_8c_a8dcc3778ca99dbdaebc1e1e311cd5793.html#a8dcc3778ca99dbdaebc1e1e311cd5793":[3,0,4,3,1356,0],
 "de/d7a/lapacke__sgesvx_8c_source.html":[3,0,4,3,1356],
-"de/d7a/zlaqr1_8f.html":[3,0,5,1788],
-"de/d7a/zlaqr1_8f_source.html":[3,0,5,1788],
+"de/d7a/zlaqr1_8f.html":[3,0,5,1786],
+"de/d7a/zlaqr1_8f_source.html":[3,0,5,1786],
 "de/d7b/ctbt02_8f.html":[3,0,6,1,194],
 "de/d7b/ctbt02_8f_source.html":[3,0,6,1,194],
 "de/d7b/dchklqt_8f.html":[3,0,6,1,218],
@@ -75,36 +77,36 @@ var NAVTREEINDEX105 =
 "de/d7e/lapacke__dpprfs__work_8c_ab53d8a793431088d5dd4cd77d51d6dcf.html#ab53d8a793431088d5dd4cd77d51d6dcf":[3,0,4,3,977,0],
 "de/d7e/lapacke__dpprfs__work_8c_source.html":[3,0,4,3,977],
 "de/d80/group__real_p_osolve.html":[0,0,4,0,1],
+"de/d80/group__real_p_osolve_ga4c54383b53b5b6890439e6b6e874fb06.html#ga4c54383b53b5b6890439e6b6e874fb06":[3,0,5,1354,0],
 "de/d80/group__real_p_osolve_ga4c54383b53b5b6890439e6b6e874fb06.html#ga4c54383b53b5b6890439e6b6e874fb06":[0,0,4,0,1,1],
-"de/d80/group__real_p_osolve_ga4c54383b53b5b6890439e6b6e874fb06.html#ga4c54383b53b5b6890439e6b6e874fb06":[3,0,5,1356,0],
 "de/d80/group__real_p_osolve_gacbfa9b618a123b2a3d997f3533b9e044.html#gacbfa9b618a123b2a3d997f3533b9e044":[0,0,4,0,1,2],
-"de/d80/group__real_p_osolve_gacbfa9b618a123b2a3d997f3533b9e044.html#gacbfa9b618a123b2a3d997f3533b9e044":[3,0,5,1357,0],
+"de/d80/group__real_p_osolve_gacbfa9b618a123b2a3d997f3533b9e044.html#gacbfa9b618a123b2a3d997f3533b9e044":[3,0,5,1355,0],
+"de/d80/group__real_p_osolve_gad46400c796afc8031a8c3ec5481af8c3.html#gad46400c796afc8031a8c3ec5481af8c3":[3,0,5,1353,0],
 "de/d80/group__real_p_osolve_gad46400c796afc8031a8c3ec5481af8c3.html#gad46400c796afc8031a8c3ec5481af8c3":[0,0,4,0,1,0],
-"de/d80/group__real_p_osolve_gad46400c796afc8031a8c3ec5481af8c3.html#gad46400c796afc8031a8c3ec5481af8c3":[3,0,5,1355,0],
 "de/d80/lapacke__dporfsx__work_8c.html":[3,0,4,3,957],
 "de/d80/lapacke__dporfsx__work_8c_ad1efe0fed88693c616ffff82a9238e8e.html#ad1efe0fed88693c616ffff82a9238e8e":[3,0,4,3,957,0],
 "de/d80/lapacke__dporfsx__work_8c_source.html":[3,0,4,3,957],
 "de/d80/lapacke__dppcon_8c.html":[3,0,4,3,972],
 "de/d80/lapacke__dppcon_8c_a5b624d9fb85c13ae0d848bee2c367c69.html#a5b624d9fb85c13ae0d848bee2c367c69":[3,0,4,3,972,0],
 "de/d80/lapacke__dppcon_8c_source.html":[3,0,4,3,972],
-"de/d80/stzrzf_8f.html":[3,0,5,1518],
-"de/d80/stzrzf_8f_source.html":[3,0,5,1518],
+"de/d80/stzrzf_8f.html":[3,0,5,1516],
+"de/d80/stzrzf_8f_source.html":[3,0,5,1516],
 "de/d82/lapacke__chetrs__aa__work_8c.html":[3,0,4,3,274],
 "de/d82/lapacke__chetrs__aa__work_8c_a0c2a7ad28d9e38616270d6855bb6c898.html#a0c2a7ad28d9e38616270d6855bb6c898":[3,0,4,3,274,0],
 "de/d82/lapacke__chetrs__aa__work_8c_source.html":[3,0,4,3,274],
 "de/d82/lapacke__sgttrf_8c.html":[3,0,4,3,1418],
 "de/d82/lapacke__sgttrf_8c_a0f62ba25264733ef0f838276f70a0036.html#a0f62ba25264733ef0f838276f70a0036":[3,0,4,3,1418,0],
 "de/d82/lapacke__sgttrf_8c_source.html":[3,0,4,3,1418],
-"de/d82/slasyf__rk_8f.html":[3,0,5,1288],
-"de/d82/slasyf__rk_8f_ac5709ebe067f05b1e6083be80d3140ec.html#ac5709ebe067f05b1e6083be80d3140ec":[3,0,5,1288,0],
-"de/d82/slasyf__rk_8f_source.html":[3,0,5,1288],
+"de/d82/slasyf__rk_8f.html":[3,0,5,1286],
+"de/d82/slasyf__rk_8f_ac5709ebe067f05b1e6083be80d3140ec.html#ac5709ebe067f05b1e6083be80d3140ec":[3,0,5,1286,0],
+"de/d82/slasyf__rk_8f_source.html":[3,0,5,1286],
 "de/d83/cblas__cgemv_8c.html":[3,0,1,2,6],
 "de/d83/cblas__cgemv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,6,0],
 "de/d83/cblas__cgemv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,6,1],
 "de/d83/cblas__cgemv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,6,5],
 "de/d83/cblas__cgemv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,6,4],
 "de/d83/cblas__cgemv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,6,2],
-"de/d83/cblas__cgemv_8c_ac4a4cf222076a6482d68ce666a6ba52e.html#ac4a4cf222076a6482d68ce666a6ba52e":[3,0,1,2,6,6],
+"de/d83/cblas__cgemv_8c_ac7ce5bf58a6ca236b1fecb889afa4a63.html#ac7ce5bf58a6ca236b1fecb889afa4a63":[3,0,1,2,6,6],
 "de/d83/cblas__cgemv_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,6,3],
 "de/d83/cblas__cgemv_8c_source.html":[3,0,1,2,6],
 "de/d84/group__real_g_tauxiliary.html":[0,0,5,2,1],
@@ -131,35 +133,35 @@ var NAVTREEINDEX105 =
 "de/d88/lapacke__zporfsx_8c_source.html":[3,0,4,3,2238],
 "de/d89/cdrgev_8f.html":[3,0,6,0,32],
 "de/d89/cdrgev_8f_source.html":[3,0,6,0,32],
-"de/d89/dlat2s_8f.html":[3,0,5,767],
-"de/d89/dlat2s_8f_source.html":[3,0,5,767],
+"de/d89/dlat2s_8f.html":[3,0,5,766],
+"de/d89/dlat2s_8f_source.html":[3,0,5,766],
 "de/d8a/clangb_8f.html":[3,0,5,241],
 "de/d8a/clangb_8f_source.html":[3,0,5,241],
 "de/d8a/dlattr_8f.html":[3,0,6,1,323],
 "de/d8a/dlattr_8f_source.html":[3,0,6,1,323],
 "de/d8a/zqrt01p_8f.html":[3,0,6,1,738],
 "de/d8a/zqrt01p_8f_source.html":[3,0,6,1,738],
-"de/d8b/zhegvd_8f.html":[3,0,5,1650],
-"de/d8b/zhegvd_8f_source.html":[3,0,5,1650],
+"de/d8b/zhegvd_8f.html":[3,0,5,1648],
+"de/d8b/zhegvd_8f_source.html":[3,0,5,1648],
 "de/d8b/zunt03_8f.html":[3,0,6,0,357],
 "de/d8b/zunt03_8f_source.html":[3,0,6,0,357],
 "de/d8c/lapacke__zpbequ__work_8c.html":[3,0,4,3,2211],
 "de/d8c/lapacke__zpbequ__work_8c_a98d5243f461dfe8a4e571c21e1210a80.html#a98d5243f461dfe8a4e571c21e1210a80":[3,0,4,3,2211,0],
 "de/d8c/lapacke__zpbequ__work_8c_source.html":[3,0,4,3,2211],
-"de/d8d/ssytri__rook_8f.html":[3,0,5,1470],
-"de/d8d/ssytri__rook_8f_source.html":[3,0,5,1470],
+"de/d8d/ssytri__rook_8f.html":[3,0,5,1468],
+"de/d8d/ssytri__rook_8f_source.html":[3,0,5,1468],
 "de/d8e/derrsy_8f.html":[3,0,6,1,290],
 "de/d8e/derrsy_8f_source.html":[3,0,6,1,290],
-"de/d8e/zgecon_8f.html":[3,0,5,1542],
-"de/d8e/zgecon_8f_source.html":[3,0,5,1542],
+"de/d8e/zgecon_8f.html":[3,0,5,1540],
+"de/d8e/zgecon_8f_source.html":[3,0,5,1540],
 "de/d90/ztrt02_8f.html":[3,0,6,1,775],
 "de/d90/ztrt02_8f_source.html":[3,0,6,1,775],
-"de/d90/zungrq_8f.html":[3,0,5,2000],
-"de/d90/zungrq_8f_source.html":[3,0,5,2000],
+"de/d90/zungrq_8f.html":[3,0,5,1998],
+"de/d90/zungrq_8f_source.html":[3,0,5,1998],
 "de/d91/ddrvbd_8f.html":[3,0,6,0,117],
 "de/d91/ddrvbd_8f_source.html":[3,0,6,0,117],
-"de/d91/dsysvx_8f.html":[3,0,5,929],
-"de/d91/dsysvx_8f_source.html":[3,0,5,929],
+"de/d91/dsysvx_8f.html":[3,0,5,928],
+"de/d91/dsysvx_8f_source.html":[3,0,5,928],
 "de/d91/lapacke__dlarfx_8c.html":[3,0,4,3,862],
 "de/d91/lapacke__dlarfx_8c_aa7c509a975c1dfbceb42d1d08aaf9093.html#aa7c509a975c1dfbceb42d1d08aaf9093":[3,0,4,3,862,0],
 "de/d91/lapacke__dlarfx_8c_source.html":[3,0,4,3,862],
@@ -189,8 +191,8 @@ var NAVTREEINDEX105 =
 "de/d94/lapacke__ztf__nancheck_8c.html":[3,0,4,4,142],
 "de/d94/lapacke__ztf__nancheck_8c_a93a73424e8ab76d16aa5db599fd8a062.html#a93a73424e8ab76d16aa5db599fd8a062":[3,0,4,4,142,0],
 "de/d94/lapacke__ztf__nancheck_8c_source.html":[3,0,4,4,142],
-"de/d94/zunbdb6_8f.html":[3,0,5,1988],
-"de/d94/zunbdb6_8f_source.html":[3,0,5,1988],
+"de/d94/zunbdb6_8f.html":[3,0,5,1986],
+"de/d94/zunbdb6_8f_source.html":[3,0,5,1986],
 "de/d95/cggsvp_8f.html":[3,0,5,0,5],
 "de/d95/cggsvp_8f_source.html":[3,0,5,0,5],
 "de/d95/lapacke__cpbsv__work_8c.html":[3,0,4,3,379],
@@ -199,9 +201,9 @@ var NAVTREEINDEX105 =
 "de/d95/lapacke__shseqr__work_8c.html":[3,0,4,3,1427],
 "de/d95/lapacke__shseqr__work_8c_a3f74178861233d75e79f6e47cf6a5b83.html#a3f74178861233d75e79f6e47cf6a5b83":[3,0,4,3,1427,0],
 "de/d95/lapacke__shseqr__work_8c_source.html":[3,0,4,3,1427],
-"de/d97/dsecnd___e_x_t___e_t_i_m_e_8f.html":[3,0,3,3],
-"de/d97/dsecnd___e_x_t___e_t_i_m_e_8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,3,0],
-"de/d97/dsecnd___e_x_t___e_t_i_m_e_8f_source.html":[3,0,3,3],
+"de/d97/dsecnd___e_x_t___e_t_i_m_e_8f.html":[3,0,3,4],
+"de/d97/dsecnd___e_x_t___e_t_i_m_e_8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,4,0],
+"de/d97/dsecnd___e_x_t___e_t_i_m_e_8f_source.html":[3,0,3,4],
 "de/d99/cggglm_8f.html":[3,0,5,83],
 "de/d99/cggglm_8f_source.html":[3,0,5,83],
 "de/d99/lapacke__dstegr__work_8c.html":[3,0,4,3,1067],
@@ -218,14 +220,14 @@ var NAVTREEINDEX105 =
 "de/d9a/lapacke__csyequb_8c_source.html":[3,0,4,3,478],
 "de/d9b/cerrrfp_8f.html":[3,0,6,1,93],
 "de/d9b/cerrrfp_8f_source.html":[3,0,6,1,93],
-"de/d9b/dlagts_8f.html":[3,0,5,650],
-"de/d9b/dlagts_8f_source.html":[3,0,5,650],
+"de/d9b/dlagts_8f.html":[3,0,5,649],
+"de/d9b/dlagts_8f_source.html":[3,0,5,649],
 "de/d9b/zerrhex_8f.html":[3,0,6,1,650],
 "de/d9b/zerrhex_8f_source.html":[3,0,6,1,650],
 "de/d9c/cchksy__rook_8f.html":[3,0,6,1,38],
 "de/d9c/cchksy__rook_8f_source.html":[3,0,6,1,38],
-"de/d9e/dsbevd_8f.html":[3,0,5,863],
-"de/d9e/dsbevd_8f_source.html":[3,0,5,863],
+"de/d9e/dsbevd_8f.html":[3,0,5,862],
+"de/d9e/dsbevd_8f_source.html":[3,0,5,862],
 "de/d9e/group___s_y.html":[0,0,2],
 "de/d9e/lapacke__dpprfs_8c.html":[3,0,4,3,976],
 "de/d9e/lapacke__dpprfs_8c_aaed8ab744762a3fe829b7d5130aa8eaa.html#aaed8ab744762a3fe829b7d5130aa8eaa":[3,0,4,3,976,0],
@@ -235,19 +237,17 @@ var NAVTREEINDEX105 =
 "de/d9f/derrst_8f.html":[3,0,6,0,131],
 "de/d9f/derrst_8f_source.html":[3,0,6,0,131],
 "de/da0/cblas_8h.html":[3,0,1,1,0],
-"de/da0/cblas_8h_a02496cb4b217bdfe9d5465b95446e8a8.html#a02496cb4b217bdfe9d5465b95446e8a8":[3,0,1,1,0,61],
-"de/da0/cblas_8h_a0342726f55d19c3cc72baf9491051344.html#a0342726f55d19c3cc72baf9491051344":[3,0,1,1,0,119],
-"de/da0/cblas_8h_a06b5984a99775c2fce14594ccc4dd673.html#a06b5984a99775c2fce14594ccc4dd673":[3,0,1,1,0,140],
-"de/da0/cblas_8h_a097894e1b1d9ac77ec2a3c836246590b.html#a097894e1b1d9ac77ec2a3c836246590b":[3,0,1,1,0,47],
-"de/da0/cblas_8h_a09a58d700b287fb6e1e798eecaff80a2.html#a09a58d700b287fb6e1e798eecaff80a2":[3,0,1,1,0,121],
+"de/da0/cblas_8h_a005ecd6365bfba75121b6afa51d6bb64.html#a005ecd6365bfba75121b6afa51d6bb64":[3,0,1,1,0,106],
+"de/da0/cblas_8h_a033e206ba2b673629da7ade3179c9c6f.html#a033e206ba2b673629da7ade3179c9c6f":[3,0,1,1,0,55],
+"de/da0/cblas_8h_a03952af196c11185ada6ab90817e3e47.html#a03952af196c11185ada6ab90817e3e47":[3,0,1,1,0,25],
+"de/da0/cblas_8h_a09048af3285127b8aeb22bcae07131a6.html#a09048af3285127b8aeb22bcae07131a6":[3,0,1,1,0,111],
+"de/da0/cblas_8h_a097894e1b1d9ac77ec2a3c836246590b.html#a097894e1b1d9ac77ec2a3c836246590b":[3,0,1,1,0,48],
 "de/da0/cblas_8h_a0cc6c9831e05958bc66dc000e02f33b9.html#a0cc6c9831e05958bc66dc000e02f33b9":[3,0,1,1,0,0],
-"de/da0/cblas_8h_a0f92ebc4f1fe1dc1c71a288be9804932.html#a0f92ebc4f1fe1dc1c71a288be9804932":[3,0,1,1,0,124],
-"de/da0/cblas_8h_a100abdcc7c310b1ac4d659dd9a793ff0.html#a100abdcc7c310b1ac4d659dd9a793ff0":[3,0,1,1,0,147],
-"de/da0/cblas_8h_a102d7db8a6b2eaf211a48b38369584a5.html#a102d7db8a6b2eaf211a48b38369584a5":[3,0,1,1,0,106],
-"de/da0/cblas_8h_a1050438afc83892110500db753a419f3.html#a1050438afc83892110500db753a419f3":[3,0,1,1,0,99],
-"de/da0/cblas_8h_a1372d71c5f10db3bb6f696a0d3289478.html#a1372d71c5f10db3bb6f696a0d3289478":[3,0,1,1,0,24],
-"de/da0/cblas_8h_a1744aad4a81b294ee26c2577c4e4bb7b.html#a1744aad4a81b294ee26c2577c4e4bb7b":[3,0,1,1,0,103],
-"de/da0/cblas_8h_a1c360d8be2ab4ff408e51c99ac275835.html#a1c360d8be2ab4ff408e51c99ac275835":[3,0,1,1,0,133],
-"de/da0/cblas_8h_a1da0d5f6bdc873f6143769ab6ebbf8ca.html#a1da0d5f6bdc873f6143769ab6ebbf8ca":[3,0,1,1,0,105],
-"de/da0/cblas_8h_a1e6fa56583dce4a18e619688ff08892f.html#a1e6fa56583dce4a18e619688ff08892f":[3,0,1,1,0,11]
+"de/da0/cblas_8h_a0cca4a540f80806b9674155e3b531ebc.html#a0cca4a540f80806b9674155e3b531ebc":[3,0,1,1,0,150],
+"de/da0/cblas_8h_a0cd296c8ef26eceda9d9767a757caccc.html#a0cd296c8ef26eceda9d9767a757caccc":[3,0,1,1,0,28],
+"de/da0/cblas_8h_a0d0746067b5656aa271bc44dab91a824.html#a0d0746067b5656aa271bc44dab91a824":[3,0,1,1,0,115],
+"de/da0/cblas_8h_a0ea2e548ab8eb6e729f94421bb66d829.html#a0ea2e548ab8eb6e729f94421bb66d829":[3,0,1,1,0,53],
+"de/da0/cblas_8h_a12f99b98c48df6e09535416dd18a1ba2.html#a12f99b98c48df6e09535416dd18a1ba2":[3,0,1,1,0,90],
+"de/da0/cblas_8h_a134b0023f20040d27be120122746d9a6.html#a134b0023f20040d27be120122746d9a6":[3,0,1,1,0,81],
+"de/da0/cblas_8h_a1446cddceb275e7cd299157a5d61d5e4.html#a1446cddceb275e7cd299157a5d61d5e4":[3,0,1,1,0,96]
 };
