@@ -1,13 +1,16 @@
 var NAVTREEINDEX107 =
 {
+"de/dad/group__complex_g_bcomputational_gae7901c9eb2d9cac0f012a12a20d56956.html#gae7901c9eb2d9cac0f012a12a20d56956":[3,0,5,186,0],
+"de/dad/group__complex_g_bcomputational_gae7901c9eb2d9cac0f012a12a20d56956.html#gae7901c9eb2d9cac0f012a12a20d56956":[0,0,1,1,2,12],
 "de/dad/group__complex_g_bcomputational_gaf843a252d609da737df565e1d3461284.html#gaf843a252d609da737df565e1d3461284":[3,0,5,6,0],
-"de/dad/group__complex_g_bcomputational_gaf9b3139572990172c3ff37bd77d1486c.html#gaf9b3139572990172c3ff37bd77d1486c":[3,0,5,9,0],
+"de/dad/group__complex_g_bcomputational_gaf843a252d609da737df565e1d3461284.html#gaf843a252d609da737df565e1d3461284":[0,0,1,1,2,2],
 "de/dad/group__complex_g_bcomputational_gaf9b3139572990172c3ff37bd77d1486c.html#gaf9b3139572990172c3ff37bd77d1486c":[0,0,1,1,2,5],
+"de/dad/group__complex_g_bcomputational_gaf9b3139572990172c3ff37bd77d1486c.html#gaf9b3139572990172c3ff37bd77d1486c":[3,0,5,9,0],
 "de/dad/lapacke__zhetrf__aa__2stage_8c.html":[3,0,4,3,2088],
 "de/dad/lapacke__zhetrf__aa__2stage_8c_a756e48ac9adf7bc35ced53a6618bd60a.html#a756e48ac9adf7bc35ced53a6618bd60a":[3,0,4,3,2088,0],
 "de/dad/lapacke__zhetrf__aa__2stage_8c_source.html":[3,0,4,3,2088],
-"de/dad/zlar1v_8f.html":[3,0,5,1800],
-"de/dad/zlar1v_8f_source.html":[3,0,5,1800],
+"de/dad/zlar1v_8f.html":[3,0,5,1798],
+"de/dad/zlar1v_8f_source.html":[3,0,5,1798],
 "de/dae/cpbt01_8f.html":[3,0,6,1,147],
 "de/dae/cpbt01_8f_source.html":[3,0,6,1,147],
 "de/dae/zgbt05_8f.html":[3,0,6,1,675],
@@ -25,8 +28,8 @@ var NAVTREEINDEX107 =
 "de/db0/lapacke__sstedc__work_8c.html":[3,0,4,3,1659],
 "de/db0/lapacke__sstedc__work_8c_a539205248fcf056626de80042a3dd4dc.html#a539205248fcf056626de80042a3dd4dc":[3,0,4,3,1659,0],
 "de/db0/lapacke__sstedc__work_8c_source.html":[3,0,4,3,1659],
-"de/db1/dppequ_8f.html":[3,0,5,842],
-"de/db1/dppequ_8f_source.html":[3,0,5,842],
+"de/db1/dppequ_8f.html":[3,0,5,841],
+"de/db1/dppequ_8f_source.html":[3,0,5,841],
 "de/db1/lapacke__slarft__work_8c.html":[3,0,4,3,1459],
 "de/db1/lapacke__slarft__work_8c_ad3a4eeee20eeaa2fdb29e9d2be69d32e.html#ad3a4eeee20eeaa2fdb29e9d2be69d32e":[3,0,4,3,1459,0],
 "de/db1/lapacke__slarft__work_8c_source.html":[3,0,4,3,1459],
@@ -69,8 +72,8 @@ var NAVTREEINDEX107 =
 "de/dbc/lapacke__ssyevr__work_8c_source.html":[3,0,4,3,1697],
 "de/dbd/cgbt05_8f.html":[3,0,6,1,105],
 "de/dbd/cgbt05_8f_source.html":[3,0,6,1,105],
-"de/dbd/zhetri2_8f.html":[3,0,5,1676],
-"de/dbd/zhetri2_8f_source.html":[3,0,5,1676],
+"de/dbd/zhetri2_8f.html":[3,0,5,1674],
+"de/dbd/zhetri2_8f_source.html":[3,0,5,1674],
 "de/dbe/ctpqrt2_8f.html":[3,0,5,440],
 "de/dbe/ctpqrt2_8f_source.html":[3,0,5,440],
 "de/dbe/lapacke__zungbr__work_8c.html":[3,0,4,3,2447],
@@ -98,15 +101,15 @@ var NAVTREEINDEX107 =
 "de/dc4/lapacke__zhesv__aa_8c.html":[3,0,4,3,2071],
 "de/dc4/lapacke__zhesv__aa_8c_a1d487345e919976cb580f07dfaf8b25e.html#a1d487345e919976cb580f07dfaf8b25e":[3,0,4,3,2071,0],
 "de/dc4/lapacke__zhesv__aa_8c_source.html":[3,0,4,3,2071],
-"de/dc4/zla__gbrcond__c_8f.html":[3,0,5,1707],
-"de/dc4/zla__gbrcond__c_8f_source.html":[3,0,5,1707],
+"de/dc4/zla__gbrcond__c_8f.html":[3,0,5,1705],
+"de/dc4/zla__gbrcond__c_8f_source.html":[3,0,5,1705],
 "de/dc5/lapacke__chprfs_8c.html":[3,0,4,3,298],
 "de/dc5/lapacke__chprfs_8c_ae7bbccd113b7508493a22eb06ada520d.html#ae7bbccd113b7508493a22eb06ada520d":[3,0,4,3,298,0],
 "de/dc5/lapacke__chprfs_8c_source.html":[3,0,4,3,298],
 "de/dc8/ctpttf_8f.html":[3,0,5,445],
 "de/dc8/ctpttf_8f_source.html":[3,0,5,445],
-"de/dc8/dlaic1_8f.html":[3,0,5,654],
-"de/dc8/dlaic1_8f_source.html":[3,0,5,654],
+"de/dc8/dlaic1_8f.html":[3,0,5,653],
+"de/dc8/dlaic1_8f_source.html":[3,0,5,653],
 "de/dc8/lapacke__ctrtri__work_8c.html":[3,0,4,3,593],
 "de/dc8/lapacke__ctrtri__work_8c_a8f431935f9f07501d79b62fbbea90925.html#a8f431935f9f07501d79b62fbbea90925":[3,0,4,3,593,0],
 "de/dc8/lapacke__ctrtri__work_8c_source.html":[3,0,4,3,593],
@@ -137,8 +140,8 @@ var NAVTREEINDEX107 =
 "de/dd0/lapacke__dggsvp3_8c_source.html":[3,0,4,3,809],
 "de/dd1/zchkgk_8f.html":[3,0,6,0,290],
 "de/dd1/zchkgk_8f_source.html":[3,0,6,0,290],
-"de/dd1/zheequb_8f.html":[3,0,5,1637],
-"de/dd1/zheequb_8f_source.html":[3,0,5,1637],
+"de/dd1/zheequb_8f.html":[3,0,5,1635],
+"de/dd1/zheequb_8f_source.html":[3,0,5,1635],
 "de/dd2/lapacke__zgecon_8c.html":[3,0,4,3,1870],
 "de/dd2/lapacke__zgecon_8c_a3198454d8a479b56216ac7ef4ba86278.html#a3198454d8a479b56216ac7ef4ba86278":[3,0,4,3,1870,0],
 "de/dd2/lapacke__zgecon_8c_source.html":[3,0,4,3,1870],
@@ -153,8 +156,8 @@ var NAVTREEINDEX107 =
 "de/dd4/lapacke__ssytrf__work_8c.html":[3,0,4,3,1743],
 "de/dd4/lapacke__ssytrf__work_8c_ab8c959954c6a4d9341da40f2da8c4e3a.html#ab8c959954c6a4d9341da40f2da8c4e3a":[3,0,4,3,1743,0],
 "de/dd4/lapacke__ssytrf__work_8c_source.html":[3,0,4,3,1743],
-"de/dd4/sla__lin__berr_8f.html":[3,0,5,1137],
-"de/dd4/sla__lin__berr_8f_source.html":[3,0,5,1137],
+"de/dd4/sla__lin__berr_8f.html":[3,0,5,1135],
+"de/dd4/sla__lin__berr_8f_source.html":[3,0,5,1135],
 "de/dd7/clctes_8f.html":[3,0,6,0,76],
 "de/dd7/clctes_8f_source.html":[3,0,6,0,76],
 "de/dd7/lapacke__clarcm__work_8c.html":[3,0,4,3,347],
@@ -171,8 +174,8 @@ var NAVTREEINDEX107 =
 "de/dda/lapacke__sgebrd__work_8c_source.html":[3,0,4,3,1279],
 "de/dda/sstect_8f.html":[3,0,6,0,269],
 "de/dda/sstect_8f_source.html":[3,0,6,0,269],
-"de/dda/zppcon_8f.html":[3,0,5,1868],
-"de/dda/zppcon_8f_source.html":[3,0,5,1868],
+"de/dda/zppcon_8f.html":[3,0,5,1866],
+"de/dda/zppcon_8f_source.html":[3,0,5,1866],
 "de/ddb/clarrv_8f.html":[3,0,5,292],
 "de/ddb/clarrv_8f_source.html":[3,0,5,292],
 "de/ddb/ctbtrs_8f.html":[3,0,5,421],
@@ -246,8 +249,5 @@ var NAVTREEINDEX107 =
 "de/ddd/lapacke_8h_a05f2998bc05d77025c6552296eaedf12.html#a05f2998bc05d77025c6552296eaedf12":[3,0,4,1,1,2264],
 "de/ddd/lapacke_8h_a0614fb084f713164666302ea80ea1ca8.html#a0614fb084f713164666302ea80ea1ca8":[3,0,4,1,1,395],
 "de/ddd/lapacke_8h_a065318c51c92bfe667a05eb996a0b06a.html#a065318c51c92bfe667a05eb996a0b06a":[3,0,4,1,1,224],
-"de/ddd/lapacke_8h_a06536b61edd487afedd908275686dd6a.html#a06536b61edd487afedd908275686dd6a":[3,0,4,1,1,579],
-"de/ddd/lapacke_8h_a066c9c6fac1f1bc525034ef1ce858d52.html#a066c9c6fac1f1bc525034ef1ce858d52":[3,0,4,1,1,69],
-"de/ddd/lapacke_8h_a06ef1d679dd2b0247b1fceed6c3f5115.html#a06ef1d679dd2b0247b1fceed6c3f5115":[3,0,4,1,1,279],
-"de/ddd/lapacke_8h_a06fbb095eebe4b77737712ed3b10cc67.html#a06fbb095eebe4b77737712ed3b10cc67":[3,0,4,1,1,734]
+"de/ddd/lapacke_8h_a06536b61edd487afedd908275686dd6a.html#a06536b61edd487afedd908275686dd6a":[3,0,4,1,1,579]
 };
