@@ -1,5 +1,8 @@
 var NAVTREEINDEX118 =
 {
+"de/dee/sgbequ_8f.html":[3,0,5,1029],
+"de/dee/sgbequ_8f_source.html":[3,0,5,1029],
+"de/df1/lapacke__dpftrs_8c.html":[3,0,4,3,946],
 "de/df1/lapacke__dpftrs_8c_ababec49e6d664531cf7088b06706f4ad.html#ababec49e6d664531cf7088b06706f4ad":[3,0,4,3,946,0],
 "de/df1/lapacke__dpftrs_8c_source.html":[3,0,4,3,946],
 "de/df3/lapacke__sdisna_8c.html":[3,0,4,3,1250],
@@ -11,8 +14,8 @@ var NAVTREEINDEX118 =
 "de/df4/lapacke__slarft_8c.html":[3,0,4,3,1458],
 "de/df4/lapacke__slarft_8c_afb0a6eb6973557441dc299b886042b27.html#afb0a6eb6973557441dc299b886042b27":[3,0,4,3,1458,0],
 "de/df4/lapacke__slarft_8c_source.html":[3,0,4,3,1458],
-"de/df4/slaqsb_8f.html":[3,0,5,1217],
-"de/df4/slaqsb_8f_source.html":[3,0,5,1217],
+"de/df4/slaqsb_8f.html":[3,0,5,1215],
+"de/df4/slaqsb_8f_source.html":[3,0,5,1215],
 "de/df5/cgges_8f.html":[3,0,5,77],
 "de/df5/cgges_8f_source.html":[3,0,5,77],
 "de/df6/dblat3_8f.html":[3,0,0,1,5],
@@ -34,10 +37,10 @@ var NAVTREEINDEX118 =
 "de/df7/lapacke__zunmrz__work_8c.html":[3,0,4,3,2475],
 "de/df7/lapacke__zunmrz__work_8c_a6a1b6dde534057de2d650287702090e2.html#a6a1b6dde534057de2d650287702090e2":[3,0,4,3,2475,0],
 "de/df7/lapacke__zunmrz__work_8c_source.html":[3,0,4,3,2475],
-"de/df7/zlargv_8f.html":[3,0,5,1811],
-"de/df7/zlargv_8f_source.html":[3,0,5,1811],
-"de/df8/zupmtr_8f.html":[3,0,5,2020],
-"de/df8/zupmtr_8f_source.html":[3,0,5,2020],
+"de/df7/zlargv_8f.html":[3,0,5,1809],
+"de/df7/zlargv_8f_source.html":[3,0,5,1809],
+"de/df8/zupmtr_8f.html":[3,0,5,2018],
+"de/df8/zupmtr_8f_source.html":[3,0,5,2018],
 "de/df9/lapacke__csyswapr_8c.html":[3,0,4,3,500],
 "de/df9/lapacke__csyswapr_8c_a008e40369ea4d331563dacb424c30c41.html#a008e40369ea4d331563dacb424c30c41":[3,0,4,3,500,0],
 "de/df9/lapacke__csyswapr_8c_source.html":[3,0,4,3,500],
@@ -53,8 +56,8 @@ var NAVTREEINDEX118 =
 "de/dfc/lapacke__zhetrs__3_8c.html":[3,0,4,3,2107],
 "de/dfc/lapacke__zhetrs__3_8c_afdf85ae148f8a8c2e45ca69c617c91a5.html#afdf85ae148f8a8c2e45ca69c617c91a5":[3,0,4,3,2107,0],
 "de/dfc/lapacke__zhetrs__3_8c_source.html":[3,0,4,3,2107],
-"de/dfc/sgebrd_8f.html":[3,0,5,1044],
-"de/dfc/sgebrd_8f_source.html":[3,0,5,1044],
+"de/dfc/sgebrd_8f.html":[3,0,5,1042],
+"de/dfc/sgebrd_8f_source.html":[3,0,5,1042],
 "de/dfd/csytrf__rk_8f.html":[3,0,5,405],
 "de/dfd/csytrf__rk_8f_source.html":[3,0,5,405],
 "de/dfd/lapacke__spocon_8c.html":[3,0,4,3,1546],
@@ -63,8 +66,8 @@ var NAVTREEINDEX118 =
 "de/dfe/lapacke__zgeqrt3__work_8c.html":[3,0,4,3,1926],
 "de/dfe/lapacke__zgeqrt3__work_8c_a0a3388628cba7816fc025cafd3b1db39.html#a0a3388628cba7816fc025cafd3b1db39":[3,0,4,3,1926,0],
 "de/dfe/lapacke__zgeqrt3__work_8c_source.html":[3,0,4,3,1926],
-"de/dff/dormlq_8f.html":[3,0,5,808],
-"de/dff/dormlq_8f_source.html":[3,0,5,808],
+"de/dff/dormlq_8f.html":[3,0,5,807],
+"de/dff/dormlq_8f_source.html":[3,0,5,807],
 "de/dff/dtsqr01_8f.html":[3,0,6,1,392],
 "de/dff/dtsqr01_8f_source.html":[3,0,6,1,392],
 "de/dff/zsgt01_8f.html":[3,0,6,0,352],
@@ -105,8 +108,8 @@ var NAVTREEINDEX118 =
 "df/d07/lapacke__ctgsyl__work_8c.html":[3,0,4,3,557],
 "df/d07/lapacke__ctgsyl__work_8c_a418510cd551e456919a2e580f31b12e4.html#a418510cd551e456919a2e580f31b12e4":[3,0,4,3,557,0],
 "df/d07/lapacke__ctgsyl__work_8c_source.html":[3,0,4,3,557],
-"df/d0b/dsytrf__aa_8f.html":[3,0,5,941],
-"df/d0b/dsytrf__aa_8f_source.html":[3,0,5,941],
+"df/d0b/dsytrf__aa_8f.html":[3,0,5,940],
+"df/d0b/dsytrf__aa_8f_source.html":[3,0,5,940],
 "df/d0c/lapacke__dlasrt__work_8c.html":[3,0,4,3,875],
 "df/d0c/lapacke__dlasrt__work_8c_a0a1ed2b92e5086a4507ac1cbacdace4f.html#a0a1ed2b92e5086a4507ac1cbacdace4f":[3,0,4,3,875,0],
 "df/d0c/lapacke__dlasrt__work_8c_source.html":[3,0,4,3,875],
@@ -119,13 +122,13 @@ var NAVTREEINDEX118 =
 "df/d0f/lapacke__stgexc_8c.html":[3,0,4,3,1780],
 "df/d0f/lapacke__stgexc_8c_aff49cfe1afe2620ccb96cb25290029d6.html#aff49cfe1afe2620ccb96cb25290029d6":[3,0,4,3,1780,0],
 "df/d0f/lapacke__stgexc_8c_source.html":[3,0,4,3,1780],
-"df/d10/zungqr_8f.html":[3,0,5,1998],
-"df/d10/zungqr_8f_source.html":[3,0,5,1998],
+"df/d10/zungqr_8f.html":[3,0,5,1996],
+"df/d10/zungqr_8f_source.html":[3,0,5,1996],
 "df/d11/lapacke__ctrevc__work_8c.html":[3,0,4,3,581],
 "df/d11/lapacke__ctrevc__work_8c_a38f7ad1fb82a6f7b8df11e3499400fe6.html#a38f7ad1fb82a6f7b8df11e3499400fe6":[3,0,4,3,581,0],
 "df/d11/lapacke__ctrevc__work_8c_source.html":[3,0,4,3,581],
-"df/d11/slapll_8f.html":[3,0,5,1202],
-"df/d11/slapll_8f_source.html":[3,0,5,1202],
+"df/d11/slapll_8f.html":[3,0,5,1200],
+"df/d11/slapll_8f_source.html":[3,0,5,1200],
 "df/d12/cerrbd_8f.html":[3,0,6,0,45],
 "df/d12/cerrbd_8f_source.html":[3,0,6,0,45],
 "df/d12/lapacke__chbevx__2stage__work_8c.html":[3,0,4,3,184],
@@ -169,8 +172,8 @@ var NAVTREEINDEX118 =
 "df/d16/lapacke__dgtrfs_8c.html":[3,0,4,3,814],
 "df/d16/lapacke__dgtrfs_8c_a0c6ee6b5db49f01f1a94945c8df3cd8d.html#a0c6ee6b5db49f01f1a94945c8df3cd8d":[3,0,4,3,814,0],
 "df/d16/lapacke__dgtrfs_8c_source.html":[3,0,4,3,814],
-"df/d16/zspr_8f.html":[3,0,5,1889],
-"df/d16/zspr_8f_source.html":[3,0,5,1889],
+"df/d16/zspr_8f.html":[3,0,5,1887],
+"df/d16/zspr_8f_source.html":[3,0,5,1887],
 "df/d17/cchkbl_8f.html":[3,0,6,0,13],
 "df/d17/cchkbl_8f_source.html":[3,0,6,0,13],
 "df/d18/lapacke__dggbak_8c.html":[3,0,4,3,776],
@@ -194,20 +197,20 @@ var NAVTREEINDEX118 =
 "df/d1c/lapacke__zpbrfs_8c.html":[3,0,4,3,2212],
 "df/d1c/lapacke__zpbrfs_8c_a283915cde35c45428a10914eb039c732.html#a283915cde35c45428a10914eb039c732":[3,0,4,3,2212,0],
 "df/d1c/lapacke__zpbrfs_8c_source.html":[3,0,4,3,2212],
-"df/d1c/sstevr_8f.html":[3,0,5,1419],
-"df/d1c/sstevr_8f_source.html":[3,0,5,1419],
+"df/d1c/sstevr_8f.html":[3,0,5,1417],
+"df/d1c/sstevr_8f_source.html":[3,0,5,1417],
 "df/d1d/lapacke__ssytrs2_8c.html":[3,0,4,3,1753],
 "df/d1d/lapacke__ssytrs2_8c_afaf6cc20f7c90e462b5ed86e6f79499e.html#afaf6cc20f7c90e462b5ed86e6f79499e":[3,0,4,3,1753,0],
 "df/d1d/lapacke__ssytrs2_8c_source.html":[3,0,4,3,1753],
 "df/d1e/lapacke__clapmt_8c.html":[3,0,4,3,344],
 "df/d1e/lapacke__clapmt_8c_a5d50f6a83a2b20e6bef1e8fcb27bb52c.html#a5d50f6a83a2b20e6bef1e8fcb27bb52c":[3,0,4,3,344,0],
 "df/d1e/lapacke__clapmt_8c_source.html":[3,0,4,3,344],
-"df/d1f/dlar1v_8f.html":[3,0,5,703],
-"df/d1f/dlar1v_8f_source.html":[3,0,5,703],
+"df/d1f/dlar1v_8f.html":[3,0,5,702],
+"df/d1f/dlar1v_8f_source.html":[3,0,5,702],
 "df/d1f/sasum_8f.html":[3,0,0,0,77],
 "df/d1f/sasum_8f_source.html":[3,0,0,0,77],
-"df/d20/_s_r_c_2zlarfy_8f.html":[3,0,5,1810],
-"df/d20/_s_r_c_2zlarfy_8f_source.html":[3,0,5,1810],
+"df/d20/_s_r_c_2zlarfy_8f.html":[3,0,5,1808],
+"df/d20/_s_r_c_2zlarfy_8f_source.html":[3,0,5,1808],
 "df/d20/zsyr2k_8f.html":[3,0,0,0,141],
 "df/d20/zsyr2k_8f_source.html":[3,0,0,0,141],
 "df/d21/lapacke__dgetsls__work_8c.html":[3,0,4,3,773],
@@ -225,29 +228,26 @@ var NAVTREEINDEX118 =
 "df/d25/lapacke__sgecon__work_8c.html":[3,0,4,3,1281],
 "df/d25/lapacke__sgecon__work_8c_a9e3cb56f75c18c7b856b572ac04106db.html#a9e3cb56f75c18c7b856b572ac04106db":[3,0,4,3,1281,0],
 "df/d25/lapacke__sgecon__work_8c_source.html":[3,0,4,3,1281],
-"df/d25/ssysv__rk_8f.html":[3,0,5,1447],
-"df/d25/ssysv__rk_8f_aeb68410e46703ed4079117e14f67a653.html#aeb68410e46703ed4079117e14f67a653":[3,0,5,1447,0],
-"df/d25/ssysv__rk_8f_source.html":[3,0,5,1447],
-"df/d25/zsteqr_8f.html":[3,0,5,1900],
-"df/d25/zsteqr_8f_source.html":[3,0,5,1900],
+"df/d25/ssysv__rk_8f.html":[3,0,5,1445],
+"df/d25/ssysv__rk_8f_aeb68410e46703ed4079117e14f67a653.html#aeb68410e46703ed4079117e14f67a653":[3,0,5,1445,0],
+"df/d25/ssysv__rk_8f_source.html":[3,0,5,1445],
+"df/d25/zsteqr_8f.html":[3,0,5,1898],
+"df/d25/zsteqr_8f_source.html":[3,0,5,1898],
 "df/d28/group__single__blas__level1.html":[0,2,0,0],
-"df/d28/group__single__blas__level1_ga0a2eaca94b4941dbc351157126cbb0f6.html#ga0a2eaca94b4941dbc351157126cbb0f6":[0,2,0,0,18],
 "df/d28/group__single__blas__level1_ga0a2eaca94b4941dbc351157126cbb0f6.html#ga0a2eaca94b4941dbc351157126cbb0f6":[3,0,0,0,99,0],
-"df/d28/group__single__blas__level1_ga0ce1ab4726eb7ad925cbd89f100d5ce0.html#ga0ce1ab4726eb7ad925cbd89f100d5ce0":[3,0,0,0,90,0],
+"df/d28/group__single__blas__level1_ga0a2eaca94b4941dbc351157126cbb0f6.html#ga0a2eaca94b4941dbc351157126cbb0f6":[0,2,0,0,18],
 "df/d28/group__single__blas__level1_ga0ce1ab4726eb7ad925cbd89f100d5ce0.html#ga0ce1ab4726eb7ad925cbd89f100d5ce0":[0,2,0,0,13],
+"df/d28/group__single__blas__level1_ga0ce1ab4726eb7ad925cbd89f100d5ce0.html#ga0ce1ab4726eb7ad925cbd89f100d5ce0":[3,0,0,0,90,0],
 "df/d28/group__single__blas__level1_ga24785e467bd921df5a2b7300da57c469.html#ga24785e467bd921df5a2b7300da57c469":[0,2,0,0,9],
 "df/d28/group__single__blas__level1_ga24785e467bd921df5a2b7300da57c469.html#ga24785e467bd921df5a2b7300da57c469":[3,0,0,0,82,0],
-"df/d28/group__single__blas__level1_ga3252f1f70b29d59941e9bc65a6aefc0a.html#ga3252f1f70b29d59941e9bc65a6aefc0a":[3,0,0,0,95,0],
 "df/d28/group__single__blas__level1_ga3252f1f70b29d59941e9bc65a6aefc0a.html#ga3252f1f70b29d59941e9bc65a6aefc0a":[0,2,0,0,17],
-"df/d28/group__single__blas__level1_ga351f01fdf3baa8e6a71d56ded46b126d.html#ga351f01fdf3baa8e6a71d56ded46b126d":[0,2,0,0,6],
+"df/d28/group__single__blas__level1_ga3252f1f70b29d59941e9bc65a6aefc0a.html#ga3252f1f70b29d59941e9bc65a6aefc0a":[3,0,0,0,95,0],
 "df/d28/group__single__blas__level1_ga351f01fdf3baa8e6a71d56ded46b126d.html#ga351f01fdf3baa8e6a71d56ded46b126d":[3,0,0,0,79,0],
+"df/d28/group__single__blas__level1_ga351f01fdf3baa8e6a71d56ded46b126d.html#ga351f01fdf3baa8e6a71d56ded46b126d":[0,2,0,0,6],
 "df/d28/group__single__blas__level1_ga37a14d8598319955b711af0d64a6f56e.html#ga37a14d8598319955b711af0d64a6f56e":[0,2,0,0,10],
 "df/d28/group__single__blas__level1_ga37a14d8598319955b711af0d64a6f56e.html#ga37a14d8598319955b711af0d64a6f56e":[3,0,0,0,83,0],
 "df/d28/group__single__blas__level1_ga55d839ab27a662d848390a2bbe3ee9d3.html#ga55d839ab27a662d848390a2bbe3ee9d3":[3,0,0,0,91,0],
 "df/d28/group__single__blas__level1_ga55d839ab27a662d848390a2bbe3ee9d3.html#ga55d839ab27a662d848390a2bbe3ee9d3":[0,2,0,0,14],
-"df/d28/group__single__blas__level1_ga5633344a5729b4f0167aa441dcf95a9c.html#ga5633344a5729b4f0167aa441dcf95a9c":[0,2,0,0,15],
 "df/d28/group__single__blas__level1_ga5633344a5729b4f0167aa441dcf95a9c.html#ga5633344a5729b4f0167aa441dcf95a9c":[3,0,0,0,92,0],
-"df/d28/group__single__blas__level1_ga7a6687e52657bef3d876b03391a06d2c.html#ga7a6687e52657bef3d876b03391a06d2c":[0,2,0,0,0],
-"df/d28/group__single__blas__level1_ga7a6687e52657bef3d876b03391a06d2c.html#ga7a6687e52657bef3d876b03391a06d2c":[3,0,0,0,19,0],
-"df/d28/group__single__blas__level1_ga7f9f9febc6dc1836c9f5e7c1aa00b743.html#ga7f9f9febc6dc1836c9f5e7c1aa00b743":[0,2,0,0,3]
+"df/d28/group__single__blas__level1_ga5633344a5729b4f0167aa441dcf95a9c.html#ga5633344a5729b4f0167aa441dcf95a9c":[0,2,0,0,15]
 };
