@@ -1,24 +1,27 @@
 var NAVTREEINDEX119 =
 {
+"df/d28/group__single__blas__level1_ga7a6687e52657bef3d876b03391a06d2c.html#ga7a6687e52657bef3d876b03391a06d2c":[3,0,0,0,19,0],
+"df/d28/group__single__blas__level1_ga7a6687e52657bef3d876b03391a06d2c.html#ga7a6687e52657bef3d876b03391a06d2c":[0,2,0,0,0],
 "df/d28/group__single__blas__level1_ga7f9f9febc6dc1836c9f5e7c1aa00b743.html#ga7f9f9febc6dc1836c9f5e7c1aa00b743":[3,0,0,0,71,0],
+"df/d28/group__single__blas__level1_ga7f9f9febc6dc1836c9f5e7c1aa00b743.html#ga7f9f9febc6dc1836c9f5e7c1aa00b743":[0,2,0,0,3],
 "df/d28/group__single__blas__level1_ga97ce4e31b77723a3b60fb3f479f61316.html#ga97ce4e31b77723a3b60fb3f479f61316":[0,2,0,0,16],
 "df/d28/group__single__blas__level1_ga97ce4e31b77723a3b60fb3f479f61316.html#ga97ce4e31b77723a3b60fb3f479f61316":[3,0,0,0,93,0],
-"df/d28/group__single__blas__level1_ga97ce56a6808661b36ab62269393ac10e.html#ga97ce56a6808661b36ab62269393ac10e":[3,0,0,0,137,0],
 "df/d28/group__single__blas__level1_ga97ce56a6808661b36ab62269393ac10e.html#ga97ce56a6808661b36ab62269393ac10e":[0,2,0,0,19],
-"df/d28/group__single__blas__level1_gaafa91c51f75df6c3f2182032a221c2db.html#gaafa91c51f75df6c3f2182032a221c2db":[3,0,0,0,46,0],
+"df/d28/group__single__blas__level1_ga97ce56a6808661b36ab62269393ac10e.html#ga97ce56a6808661b36ab62269393ac10e":[3,0,0,0,137,0],
 "df/d28/group__single__blas__level1_gaafa91c51f75df6c3f2182032a221c2db.html#gaafa91c51f75df6c3f2182032a221c2db":[0,2,0,0,2],
+"df/d28/group__single__blas__level1_gaafa91c51f75df6c3f2182032a221c2db.html#gaafa91c51f75df6c3f2182032a221c2db":[3,0,0,0,46,0],
 "df/d28/group__single__blas__level1_gab5393665c8f0e7d5de9bd1dd2ff0d9d0.html#gab5393665c8f0e7d5de9bd1dd2ff0d9d0":[0,2,0,0,1],
 "df/d28/group__single__blas__level1_gab5393665c8f0e7d5de9bd1dd2ff0d9d0.html#gab5393665c8f0e7d5de9bd1dd2ff0d9d0":[3,0,0,0,44,0],
 "df/d28/group__single__blas__level1_gad179c1611098b5881f147d39afb009b8.html#gad179c1611098b5881f147d39afb009b8":[3,0,0,0,89,0],
 "df/d28/group__single__blas__level1_gad179c1611098b5881f147d39afb009b8.html#gad179c1611098b5881f147d39afb009b8":[0,2,0,0,12],
-"df/d28/group__single__blas__level1_gad2a52de0e32a6fc111931ece9b39726c.html#gad2a52de0e32a6fc111931ece9b39726c":[3,0,0,0,78,0],
 "df/d28/group__single__blas__level1_gad2a52de0e32a6fc111931ece9b39726c.html#gad2a52de0e32a6fc111931ece9b39726c":[0,2,0,0,5],
-"df/d28/group__single__blas__level1_gadd7d12f994e4868ca9998b054707d934.html#gadd7d12f994e4868ca9998b054707d934":[3,0,0,0,80,0],
+"df/d28/group__single__blas__level1_gad2a52de0e32a6fc111931ece9b39726c.html#gad2a52de0e32a6fc111931ece9b39726c":[3,0,0,0,78,0],
 "df/d28/group__single__blas__level1_gadd7d12f994e4868ca9998b054707d934.html#gadd7d12f994e4868ca9998b054707d934":[0,2,0,0,7],
+"df/d28/group__single__blas__level1_gadd7d12f994e4868ca9998b054707d934.html#gadd7d12f994e4868ca9998b054707d934":[3,0,0,0,80,0],
 "df/d28/group__single__blas__level1_gaddc89585ced76065053abffb322c5a22.html#gaddc89585ced76065053abffb322c5a22":[0,2,0,0,11],
 "df/d28/group__single__blas__level1_gaddc89585ced76065053abffb322c5a22.html#gaddc89585ced76065053abffb322c5a22":[3,0,0,0,84,0],
-"df/d28/group__single__blas__level1_gaee5779d5d216a7cd8cf83488fb6bb175.html#gaee5779d5d216a7cd8cf83488fb6bb175":[0,2,0,0,8],
 "df/d28/group__single__blas__level1_gaee5779d5d216a7cd8cf83488fb6bb175.html#gaee5779d5d216a7cd8cf83488fb6bb175":[3,0,0,0,81,0],
+"df/d28/group__single__blas__level1_gaee5779d5d216a7cd8cf83488fb6bb175.html#gaee5779d5d216a7cd8cf83488fb6bb175":[0,2,0,0,8],
 "df/d28/group__single__blas__level1_gafc5e1e8d9f26907c0a7cf878107f08cf.html#gafc5e1e8d9f26907c0a7cf878107f08cf":[0,2,0,0,4],
 "df/d28/group__single__blas__level1_gafc5e1e8d9f26907c0a7cf878107f08cf.html#gafc5e1e8d9f26907c0a7cf878107f08cf":[3,0,0,0,77,0],
 "df/d29/dtbmv_8f.html":[3,0,0,0,62],
@@ -36,30 +39,30 @@ var NAVTREEINDEX119 =
 "df/d2d/lapacke__ctrttp__work_8c_a2b7b4526818140eceed4104482a87cac.html#a2b7b4526818140eceed4104482a87cac":[3,0,4,3,599,0],
 "df/d2d/lapacke__ctrttp__work_8c_source.html":[3,0,4,3,599],
 "df/d2e/group__complex16_p_tcomputational.html":[0,0,6,1,3],
-"df/d2e/group__complex16_p_tcomputational_ga08d07a22ba5f50a14d9caf644723b5c3.html#ga08d07a22ba5f50a14d9caf644723b5c3":[3,0,5,1879,0],
+"df/d2e/group__complex16_p_tcomputational_ga08d07a22ba5f50a14d9caf644723b5c3.html#ga08d07a22ba5f50a14d9caf644723b5c3":[3,0,5,1877,0],
 "df/d2e/group__complex16_p_tcomputational_ga08d07a22ba5f50a14d9caf644723b5c3.html#ga08d07a22ba5f50a14d9caf644723b5c3":[0,0,6,1,3,1],
 "df/d2e/group__complex16_p_tcomputational_ga216beeac0fe239f03d9b37f51e96d7c7.html#ga216beeac0fe239f03d9b37f51e96d7c7":[0,0,6,1,3,5],
-"df/d2e/group__complex16_p_tcomputational_ga216beeac0fe239f03d9b37f51e96d7c7.html#ga216beeac0fe239f03d9b37f51e96d7c7":[3,0,5,1885,0],
+"df/d2e/group__complex16_p_tcomputational_ga216beeac0fe239f03d9b37f51e96d7c7.html#ga216beeac0fe239f03d9b37f51e96d7c7":[3,0,5,1883,0],
+"df/d2e/group__complex16_p_tcomputational_ga7a91b8a69883b74c20c26aee3c537c55.html#ga7a91b8a69883b74c20c26aee3c537c55":[3,0,5,1882,0],
 "df/d2e/group__complex16_p_tcomputational_ga7a91b8a69883b74c20c26aee3c537c55.html#ga7a91b8a69883b74c20c26aee3c537c55":[0,0,6,1,3,4],
-"df/d2e/group__complex16_p_tcomputational_ga7a91b8a69883b74c20c26aee3c537c55.html#ga7a91b8a69883b74c20c26aee3c537c55":[3,0,5,1884,0],
-"df/d2e/group__complex16_p_tcomputational_ga93372dc1bb896550f56db40a44b3f202.html#ga93372dc1bb896550f56db40a44b3f202":[3,0,5,1880,0],
 "df/d2e/group__complex16_p_tcomputational_ga93372dc1bb896550f56db40a44b3f202.html#ga93372dc1bb896550f56db40a44b3f202":[0,0,6,1,3,2],
-"df/d2e/group__complex16_p_tcomputational_gac66038080132a6b116df577c91e3a39d.html#gac66038080132a6b116df577c91e3a39d":[3,0,5,1883,0],
+"df/d2e/group__complex16_p_tcomputational_ga93372dc1bb896550f56db40a44b3f202.html#ga93372dc1bb896550f56db40a44b3f202":[3,0,5,1878,0],
+"df/d2e/group__complex16_p_tcomputational_gac66038080132a6b116df577c91e3a39d.html#gac66038080132a6b116df577c91e3a39d":[3,0,5,1881,0],
 "df/d2e/group__complex16_p_tcomputational_gac66038080132a6b116df577c91e3a39d.html#gac66038080132a6b116df577c91e3a39d":[0,0,6,1,3,3],
-"df/d2e/group__complex16_p_tcomputational_gae93ce2977fc454e3b4362e894d8b54df.html#gae93ce2977fc454e3b4362e894d8b54df":[3,0,5,1878,0],
 "df/d2e/group__complex16_p_tcomputational_gae93ce2977fc454e3b4362e894d8b54df.html#gae93ce2977fc454e3b4362e894d8b54df":[0,0,6,1,3,0],
+"df/d2e/group__complex16_p_tcomputational_gae93ce2977fc454e3b4362e894d8b54df.html#gae93ce2977fc454e3b4362e894d8b54df":[3,0,5,1876,0],
 "df/d2f/cblas__zsymm_8c.html":[3,0,1,2,133],
 "df/d2f/cblas__zsymm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,133,2],
 "df/d2f/cblas__zsymm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,133,1],
-"df/d2f/cblas__zsymm_8c_a562aa7af3b9af5418e9b6f298ff27371.html#a562aa7af3b9af5418e9b6f298ff27371":[3,0,1,2,133,7],
 "df/d2f/cblas__zsymm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,133,4],
 "df/d2f/cblas__zsymm_8c_a8bc04ca7122be8af5c345be6464f102a.html#a8bc04ca7122be8af5c345be6464f102a":[3,0,1,2,133,5],
 "df/d2f/cblas__zsymm_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,133,0],
 "df/d2f/cblas__zsymm_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,133,6],
+"df/d2f/cblas__zsymm_8c_ac3b6cc91eb0c3009396094eab8b5d25f.html#ac3b6cc91eb0c3009396094eab8b5d25f":[3,0,1,2,133,7],
 "df/d2f/cblas__zsymm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,133,3],
 "df/d2f/cblas__zsymm_8c_source.html":[3,0,1,2,133],
-"df/d2f/zsysv__aa__2stage_8f.html":[3,0,5,1914],
-"df/d2f/zsysv__aa__2stage_8f_source.html":[3,0,5,1914],
+"df/d2f/zsysv__aa__2stage_8f.html":[3,0,5,1912],
+"df/d2f/zsysv__aa__2stage_8f_source.html":[3,0,5,1912],
 "df/d30/lapacke__stpcon__work_8c.html":[3,0,4,3,1791],
 "df/d30/lapacke__stpcon__work_8c_a840caa323001d102ea876c177c422237.html#a840caa323001d102ea876c177c422237":[3,0,4,3,1791,0],
 "df/d30/lapacke__stpcon__work_8c_source.html":[3,0,4,3,1791],
@@ -72,8 +75,8 @@ var NAVTREEINDEX119 =
 "df/d31/lapacke__ztpttf_8c.html":[3,0,4,3,2412],
 "df/d31/lapacke__ztpttf_8c_a5a78ed3f7d9d31b864b2b419315fb8c2.html#a5a78ed3f7d9d31b864b2b419315fb8c2":[3,0,4,3,2412,0],
 "df/d31/lapacke__ztpttf_8c_source.html":[3,0,4,3,2412],
-"df/d32/dgerfs_8f.html":[3,0,5,556],
-"df/d32/dgerfs_8f_source.html":[3,0,5,556],
+"df/d32/dgerfs_8f.html":[3,0,5,555],
+"df/d32/dgerfs_8f_source.html":[3,0,5,555],
 "df/d32/serrec_8f.html":[3,0,6,0,223],
 "df/d32/serrec_8f_source.html":[3,0,6,0,223],
 "df/d32/serrlqt_8f.html":[3,0,6,1,455],
@@ -81,14 +84,14 @@ var NAVTREEINDEX119 =
 "df/d34/lapacke__zpocon_8c.html":[3,0,4,3,2230],
 "df/d34/lapacke__zpocon_8c_afd6c8c4113aee74ae08e61cbf1c71a73.html#afd6c8c4113aee74ae08e61cbf1c71a73":[3,0,4,3,2230,0],
 "df/d34/lapacke__zpocon_8c_source.html":[3,0,4,3,2230],
-"df/d37/slamchf77_8f.html":[3,0,3,20],
-"df/d37/slamchf77_8f_a0259f906df485fc6fba360cb3ebef320.html#a0259f906df485fc6fba360cb3ebef320":[3,0,3,20,0],
-"df/d37/slamchf77_8f_a063f886475dbe005f58b9c37ced98b65.html#a063f886475dbe005f58b9c37ced98b65":[3,0,3,20,2],
-"df/d37/slamchf77_8f_a1b6914b771d6c2276fc60475c1d6e70b.html#a1b6914b771d6c2276fc60475c1d6e70b":[3,0,3,20,4],
-"df/d37/slamchf77_8f_a279f9f1e475af3a6e6101fbfd874f955.html#a279f9f1e475af3a6e6101fbfd874f955":[3,0,3,20,5],
-"df/d37/slamchf77_8f_a72e67de62733142ac7f456696018d1ef.html#a72e67de62733142ac7f456696018d1ef":[3,0,3,20,1],
-"df/d37/slamchf77_8f_a94c08689c8608b5ec74a6986fc752b64.html#a94c08689c8608b5ec74a6986fc752b64":[3,0,3,20,3],
-"df/d37/slamchf77_8f_source.html":[3,0,3,20],
+"df/d37/slamchf77_8f.html":[3,0,3,21],
+"df/d37/slamchf77_8f_a0259f906df485fc6fba360cb3ebef320.html#a0259f906df485fc6fba360cb3ebef320":[3,0,3,21,0],
+"df/d37/slamchf77_8f_a063f886475dbe005f58b9c37ced98b65.html#a063f886475dbe005f58b9c37ced98b65":[3,0,3,21,2],
+"df/d37/slamchf77_8f_a1b6914b771d6c2276fc60475c1d6e70b.html#a1b6914b771d6c2276fc60475c1d6e70b":[3,0,3,21,4],
+"df/d37/slamchf77_8f_a279f9f1e475af3a6e6101fbfd874f955.html#a279f9f1e475af3a6e6101fbfd874f955":[3,0,3,21,5],
+"df/d37/slamchf77_8f_a72e67de62733142ac7f456696018d1ef.html#a72e67de62733142ac7f456696018d1ef":[3,0,3,21,1],
+"df/d37/slamchf77_8f_a94c08689c8608b5ec74a6986fc752b64.html#a94c08689c8608b5ec74a6986fc752b64":[3,0,3,21,3],
+"df/d37/slamchf77_8f_source.html":[3,0,3,21],
 "df/d38/lapacke__chesvx_8c.html":[3,0,4,3,240],
 "df/d38/lapacke__chesvx_8c_aeb98840f6598288dcefceeda45a6228f.html#aeb98840f6598288dcefceeda45a6228f":[3,0,4,3,240,0],
 "df/d38/lapacke__chesvx_8c_source.html":[3,0,4,3,240],
@@ -101,15 +104,15 @@ var NAVTREEINDEX119 =
 "df/d38/lapacke__zhs__nancheck_8c.html":[3,0,4,4,124],
 "df/d38/lapacke__zhs__nancheck_8c_a8baccfd32360d2c8ab62232a23b2e80b.html#a8baccfd32360d2c8ab62232a23b2e80b":[3,0,4,4,124,0],
 "df/d38/lapacke__zhs__nancheck_8c_source.html":[3,0,4,4,124],
-"df/d38/zlahef__rook_8f.html":[3,0,5,1753],
-"df/d38/zlahef__rook_8f_source.html":[3,0,5,1753],
+"df/d38/zlahef__rook_8f.html":[3,0,5,1751],
+"df/d38/zlahef__rook_8f_source.html":[3,0,5,1751],
 "df/d3a/derrsyx_8f.html":[3,0,6,1,291],
 "df/d3a/derrsyx_8f_source.html":[3,0,6,1,291],
 "df/d3a/lapacke__claswp_8c.html":[3,0,4,3,364],
 "df/d3a/lapacke__claswp_8c_ab1a3893307d6c36eb53dbbaa176b4549.html#ab1a3893307d6c36eb53dbbaa176b4549":[3,0,4,3,364,0],
 "df/d3a/lapacke__claswp_8c_source.html":[3,0,4,3,364],
-"df/d3b/dsyevr_8f.html":[3,0,5,912],
-"df/d3b/dsyevr_8f_source.html":[3,0,5,912],
+"df/d3b/dsyevr_8f.html":[3,0,5,911],
+"df/d3b/dsyevr_8f_source.html":[3,0,5,911],
 "df/d3b/lapacke__cgemqrt_8c.html":[3,0,4,3,68],
 "df/d3b/lapacke__cgemqrt_8c_a76a3febd1cf8b4a7caaae5180b1cbcbf.html#a76a3febd1cf8b4a7caaae5180b1cbcbf":[3,0,4,3,68,0],
 "df/d3b/lapacke__cgemqrt_8c_source.html":[3,0,4,3,68],
@@ -118,20 +121,20 @@ var NAVTREEINDEX119 =
 "df/d3e/lapacke__dtbcon_8c.html":[3,0,4,3,1170],
 "df/d3e/lapacke__dtbcon_8c_a23ad689f8a402288053205537b51fea8.html#a23ad689f8a402288053205537b51fea8":[3,0,4,3,1170,0],
 "df/d3e/lapacke__dtbcon_8c_source.html":[3,0,4,3,1170],
-"df/d3e/slasq3_8f.html":[3,0,5,1275],
-"df/d3e/slasq3_8f_source.html":[3,0,5,1275],
-"df/d3e/zlarscl2_8f.html":[3,0,5,1814],
-"df/d3e/zlarscl2_8f_source.html":[3,0,5,1814],
+"df/d3e/slasq3_8f.html":[3,0,5,1273],
+"df/d3e/slasq3_8f_source.html":[3,0,5,1273],
+"df/d3e/zlarscl2_8f.html":[3,0,5,1812],
+"df/d3e/zlarscl2_8f_source.html":[3,0,5,1812],
 "df/d3f/cblas__zaxpy_8c.html":[3,0,1,2,111],
-"df/d3f/cblas__zaxpy_8c_a0f92ebc4f1fe1dc1c71a288be9804932.html#a0f92ebc4f1fe1dc1c71a288be9804932":[3,0,1,2,111,3],
 "df/d3f/cblas__zaxpy_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,111,0],
 "df/d3f/cblas__zaxpy_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,111,1],
 "df/d3f/cblas__zaxpy_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,111,2],
+"df/d3f/cblas__zaxpy_8c_aced2529914c2543e9c426999172d70ea.html#aced2529914c2543e9c426999172d70ea":[3,0,1,2,111,3],
 "df/d3f/cblas__zaxpy_8c_source.html":[3,0,1,2,111],
 "df/d40/ctgevc_8f.html":[3,0,5,426],
 "df/d40/ctgevc_8f_source.html":[3,0,5,426],
-"df/d41/dlags2_8f.html":[3,0,5,647],
-"df/d41/dlags2_8f_source.html":[3,0,5,647],
+"df/d41/dlags2_8f.html":[3,0,5,646],
+"df/d41/dlags2_8f_source.html":[3,0,5,646],
 "df/d42/zblat1_8f.html":[3,0,0,1,9],
 "df/d42/zblat1_8f_a077aa8449e1055cdecdebf7cb41738a5.html#a077aa8449e1055cdecdebf7cb41738a5":[3,0,0,1,9,6],
 "df/d42/zblat1_8f_a094d00ddd2399699d62da4f0f6f83834.html#a094d00ddd2399699d62da4f0f6f83834":[3,0,0,1,9,5],
@@ -148,35 +151,35 @@ var NAVTREEINDEX119 =
 "df/d43/lapacke__zgetsls__work_8c.html":[3,0,4,3,1961],
 "df/d43/lapacke__zgetsls__work_8c_aa2dcddab2fa70c9c2ae31af3c1db0533.html#aa2dcddab2fa70c9c2ae31af3c1db0533":[3,0,4,3,1961,0],
 "df/d43/lapacke__zgetsls__work_8c_source.html":[3,0,4,3,1961],
-"df/d43/zlacpy_8f.html":[3,0,5,1737],
-"df/d43/zlacpy_8f_source.html":[3,0,5,1737],
+"df/d43/zlacpy_8f.html":[3,0,5,1735],
+"df/d43/zlacpy_8f_source.html":[3,0,5,1735],
 "df/d44/lapacke__sgetrf2__work_8c.html":[3,0,4,3,1364],
 "df/d44/lapacke__sgetrf2__work_8c_ae34fbd55fc8549409d279e6cf1e3df38.html#ae34fbd55fc8549409d279e6cf1e3df38":[3,0,4,3,1364,0],
 "df/d44/lapacke__sgetrf2__work_8c_source.html":[3,0,4,3,1364],
-"df/d45/spocon_8f.html":[3,0,5,1350],
-"df/d45/spocon_8f_source.html":[3,0,5,1350],
+"df/d45/spocon_8f.html":[3,0,5,1348],
+"df/d45/spocon_8f_source.html":[3,0,5,1348],
 "df/d46/lapacke__dgtcon__work_8c.html":[3,0,4,3,813],
 "df/d46/lapacke__dgtcon__work_8c_a6f5463ef4981cbfd42fed6e4e56d575b.html#a6f5463ef4981cbfd42fed6e4e56d575b":[3,0,4,3,813,0],
 "df/d46/lapacke__dgtcon__work_8c_source.html":[3,0,4,3,813],
 "df/d46/lapacke__ztpqrt2__work_8c.html":[3,0,4,3,2402],
 "df/d46/lapacke__ztpqrt2__work_8c_a23c6bd173fed5b25194d4f8ecb8992eb.html#a23c6bd173fed5b25194d4f8ecb8992eb":[3,0,4,3,2402,0],
 "df/d46/lapacke__ztpqrt2__work_8c_source.html":[3,0,4,3,2402],
-"df/d46/slaorhr__col__getrfnp_8f.html":[3,0,5,1200],
-"df/d46/slaorhr__col__getrfnp_8f_source.html":[3,0,5,1200],
+"df/d46/slaorhr__col__getrfnp_8f.html":[3,0,5,1198],
+"df/d46/slaorhr__col__getrfnp_8f_source.html":[3,0,5,1198],
 "df/d46/zerrtsqr_8f.html":[3,0,6,1,668],
 "df/d46/zerrtsqr_8f_source.html":[3,0,6,1,668],
 "df/d47/ddrgev_8f.html":[3,0,6,0,113],
 "df/d47/ddrgev_8f_source.html":[3,0,6,0,113],
-"df/d47/zsytri__3_8f.html":[3,0,5,1931],
-"df/d47/zsytri__3_8f_source.html":[3,0,5,1931],
+"df/d47/zsytri__3_8f.html":[3,0,5,1929],
+"df/d47/zsytri__3_8f_source.html":[3,0,5,1929],
 "df/d48/derrqrtp_8f.html":[3,0,6,1,287],
 "df/d48/derrqrtp_8f_source.html":[3,0,6,1,287],
-"df/d48/dsbev__2stage_8f.html":[3,0,5,862],
-"df/d48/dsbev__2stage_8f_source.html":[3,0,5,862],
+"df/d48/dsbev__2stage_8f.html":[3,0,5,861],
+"df/d48/dsbev__2stage_8f_source.html":[3,0,5,861],
 "df/d4a/dbbcsd_8f.html":[3,0,5,500],
 "df/d4a/dbbcsd_8f_source.html":[3,0,5,500],
-"df/d4a/dgebd2_8f.html":[3,0,5,520],
-"df/d4a/dgebd2_8f_source.html":[3,0,5,520],
+"df/d4a/dgebd2_8f.html":[3,0,5,519],
+"df/d4a/dgebd2_8f_source.html":[3,0,5,519],
 "df/d4b/lapacke__zppsvx__work_8c.html":[3,0,4,3,2263],
 "df/d4b/lapacke__zppsvx__work_8c_a55b245c3e7756af5a4d2705b3d59e7a1.html#a55b245c3e7756af5a4d2705b3d59e7a1":[3,0,4,3,2263,0],
 "df/d4b/lapacke__zppsvx__work_8c_source.html":[3,0,4,3,2263],
@@ -187,17 +190,17 @@ var NAVTREEINDEX119 =
 "df/d4b/zppt03_8f_source.html":[3,0,6,1,727],
 "df/d4c/cpbsvx_8f.html":[3,0,5,326],
 "df/d4c/cpbsvx_8f_source.html":[3,0,5,326],
-"df/d4d/dpftri_8f.html":[3,0,5,826],
-"df/d4d/dpftri_8f_source.html":[3,0,5,826],
+"df/d4d/dpftri_8f.html":[3,0,5,825],
+"df/d4d/dpftri_8f_source.html":[3,0,5,825],
 "df/d4d/lapacke__dtpcon_8c.html":[3,0,4,3,1196],
 "df/d4d/lapacke__dtpcon_8c_a5c58194488bdc0a3cbc68e5e24d932f0.html#a5c58194488bdc0a3cbc68e5e24d932f0":[3,0,4,3,1196,0],
 "df/d4d/lapacke__dtpcon_8c_source.html":[3,0,4,3,1196],
 "df/d4d/sqrt17_8f.html":[3,0,6,1,543],
 "df/d4d/sqrt17_8f_source.html":[3,0,6,1,543],
-"df/d4d/zgeequ_8f.html":[3,0,5,1543],
-"df/d4d/zgeequ_8f_source.html":[3,0,5,1543],
-"df/d4e/dla__gbrfsx__extended_8f.html":[3,0,5,608],
-"df/d4e/dla__gbrfsx__extended_8f_source.html":[3,0,5,608],
+"df/d4d/zgeequ_8f.html":[3,0,5,1541],
+"df/d4d/zgeequ_8f_source.html":[3,0,5,1541],
+"df/d4e/dla__gbrfsx__extended_8f.html":[3,0,5,607],
+"df/d4e/dla__gbrfsx__extended_8f_source.html":[3,0,5,607],
 "df/d4f/clahef_8f.html":[3,0,5,229],
 "df/d4f/clahef_8f_source.html":[3,0,5,229],
 "df/d4f/lapacke__csyrfsx_8c.html":[3,0,4,3,484],
@@ -205,17 +208,17 @@ var NAVTREEINDEX119 =
 "df/d4f/lapacke__csyrfsx_8c_source.html":[3,0,4,3,484],
 "df/d4f/sslect_8f.html":[3,0,6,0,266],
 "df/d4f/sslect_8f_source.html":[3,0,6,0,266],
-"df/d4f/zgels_8f.html":[3,0,5,1557],
-"df/d4f/zgels_8f_source.html":[3,0,5,1557],
+"df/d4f/zgels_8f.html":[3,0,5,1555],
+"df/d4f/zgels_8f_source.html":[3,0,5,1555],
 "df/d51/zsymm_8f.html":[3,0,0,0,140],
 "df/d51/zsymm_8f_source.html":[3,0,0,0,140],
 "df/d52/lapacke__cunmrz__work_8c.html":[3,0,4,3,637],
 "df/d52/lapacke__cunmrz__work_8c_abbdf8a7a4be7be1d63c0817fe9fc0350.html#abbdf8a7a4be7be1d63c0817fe9fc0350":[3,0,4,3,637,0],
 "df/d52/lapacke__cunmrz__work_8c_source.html":[3,0,4,3,637],
-"df/d52/slasq4_8f.html":[3,0,5,1276],
-"df/d52/slasq4_8f_source.html":[3,0,5,1276],
-"df/d52/zhpgst_8f.html":[3,0,5,1693],
-"df/d52/zhpgst_8f_source.html":[3,0,5,1693],
+"df/d52/slasq4_8f.html":[3,0,5,1274],
+"df/d52/slasq4_8f_source.html":[3,0,5,1274],
+"df/d52/zhpgst_8f.html":[3,0,5,1691],
+"df/d52/zhpgst_8f_source.html":[3,0,5,1691],
 "df/d53/lapacke__zhbevx_8c.html":[3,0,4,3,2020],
 "df/d53/lapacke__zhbevx_8c_acbd1b7f946ad64b41f6fd6874ac910e4.html#acbd1b7f946ad64b41f6fd6874ac910e4":[3,0,4,3,2020,0],
 "df/d53/lapacke__zhbevx_8c_source.html":[3,0,4,3,2020],
@@ -238,16 +241,13 @@ var NAVTREEINDEX119 =
 "df/d58/csyconvf__rook_8f_source.html":[3,0,5,385],
 "df/d58/dchksb_8f.html":[3,0,6,0,101],
 "df/d58/dchksb_8f_source.html":[3,0,6,0,101],
-"df/d58/sla__gerfsx__extended_8f.html":[3,0,5,1135],
-"df/d58/sla__gerfsx__extended_8f_source.html":[3,0,5,1135],
+"df/d58/sla__gerfsx__extended_8f.html":[3,0,5,1133],
+"df/d58/sla__gerfsx__extended_8f_source.html":[3,0,5,1133],
 "df/d59/ctrsna_8f.html":[3,0,5,453],
 "df/d59/ctrsna_8f_source.html":[3,0,5,453],
 "df/d5a/claesy_8f.html":[3,0,5,224],
 "df/d5a/claesy_8f_source.html":[3,0,5,224],
 "df/d5a/lapacke__dpbstf__work_8c.html":[3,0,4,3,933],
 "df/d5a/lapacke__dpbstf__work_8c_a75001c7ad5376a7618a2e195c3bef2fc.html#a75001c7ad5376a7618a2e195c3bef2fc":[3,0,4,3,933,0],
-"df/d5a/lapacke__dpbstf__work_8c_source.html":[3,0,4,3,933],
-"df/d5a/lapacke__sstegr__work_8c.html":[3,0,4,3,1661],
-"df/d5a/lapacke__sstegr__work_8c_ab0552dacd24d22359ef18c737098e2bd.html#ab0552dacd24d22359ef18c737098e2bd":[3,0,4,3,1661,0],
-"df/d5a/lapacke__sstegr__work_8c_source.html":[3,0,4,3,1661]
+"df/d5a/lapacke__dpbstf__work_8c_source.html":[3,0,4,3,933]
 };
