@@ -1,24 +1,27 @@
 var NAVTREEINDEX121 =
 {
-"df/d9a/group__complex16_h_eeigen_ga60dd605c63d7183a4c289a4ab3df6df6.html#ga60dd605c63d7183a4c289a4ab3df6df6":[3,0,5,1642,0],
-"df/d9a/group__complex16_h_eeigen_ga74fdf9b5a16c90d8b7a589dec5ca058a.html#ga74fdf9b5a16c90d8b7a589dec5ca058a":[3,0,5,1650,0],
+"df/d9a/group__complex16_h_eeigen_ga59996f9a96d264d7eba3edef73e32c43.html#ga59996f9a96d264d7eba3edef73e32c43":[3,0,5,1639,0],
+"df/d9a/group__complex16_h_eeigen_ga59996f9a96d264d7eba3edef73e32c43.html#ga59996f9a96d264d7eba3edef73e32c43":[0,0,3,1,1,3],
+"df/d9a/group__complex16_h_eeigen_ga60dd605c63d7183a4c289a4ab3df6df6.html#ga60dd605c63d7183a4c289a4ab3df6df6":[3,0,5,1640,0],
+"df/d9a/group__complex16_h_eeigen_ga60dd605c63d7183a4c289a4ab3df6df6.html#ga60dd605c63d7183a4c289a4ab3df6df6":[0,0,3,1,1,4],
+"df/d9a/group__complex16_h_eeigen_ga74fdf9b5a16c90d8b7a589dec5ca058a.html#ga74fdf9b5a16c90d8b7a589dec5ca058a":[3,0,5,1648,0],
 "df/d9a/group__complex16_h_eeigen_ga74fdf9b5a16c90d8b7a589dec5ca058a.html#ga74fdf9b5a16c90d8b7a589dec5ca058a":[0,0,3,1,1,10],
+"df/d9a/group__complex16_h_eeigen_ga8ea76cbbb14edb5a22069e203fc8e8b2.html#ga8ea76cbbb14edb5a22069e203fc8e8b2":[3,0,5,1649,0],
 "df/d9a/group__complex16_h_eeigen_ga8ea76cbbb14edb5a22069e203fc8e8b2.html#ga8ea76cbbb14edb5a22069e203fc8e8b2":[0,0,3,1,1,11],
-"df/d9a/group__complex16_h_eeigen_ga8ea76cbbb14edb5a22069e203fc8e8b2.html#ga8ea76cbbb14edb5a22069e203fc8e8b2":[3,0,5,1651,0],
 "df/d9a/group__complex16_h_eeigen_ga9b3e110476166e66f2f62fa1fba6344a.html#ga9b3e110476166e66f2f62fa1fba6344a":[0,0,3,1,1,2],
-"df/d9a/group__complex16_h_eeigen_ga9b3e110476166e66f2f62fa1fba6344a.html#ga9b3e110476166e66f2f62fa1fba6344a":[3,0,5,1640,0],
+"df/d9a/group__complex16_h_eeigen_ga9b3e110476166e66f2f62fa1fba6344a.html#ga9b3e110476166e66f2f62fa1fba6344a":[3,0,5,1638,0],
 "df/d9a/group__complex16_h_eeigen_gaabef68a9c7b10df7aef8f4fec89fddbe.html#gaabef68a9c7b10df7aef8f4fec89fddbe":[0,0,3,1,1,6],
-"df/d9a/group__complex16_h_eeigen_gaabef68a9c7b10df7aef8f4fec89fddbe.html#gaabef68a9c7b10df7aef8f4fec89fddbe":[3,0,5,1644,0],
+"df/d9a/group__complex16_h_eeigen_gaabef68a9c7b10df7aef8f4fec89fddbe.html#gaabef68a9c7b10df7aef8f4fec89fddbe":[3,0,5,1642,0],
 "df/d9a/group__complex16_h_eeigen_gac77d6b27ad8afec6f975d71a329c6c98.html#gac77d6b27ad8afec6f975d71a329c6c98":[0,0,3,1,1,7],
-"df/d9a/group__complex16_h_eeigen_gac77d6b27ad8afec6f975d71a329c6c98.html#gac77d6b27ad8afec6f975d71a329c6c98":[3,0,5,1645,0],
+"df/d9a/group__complex16_h_eeigen_gac77d6b27ad8afec6f975d71a329c6c98.html#gac77d6b27ad8afec6f975d71a329c6c98":[3,0,5,1643,0],
+"df/d9a/group__complex16_h_eeigen_gacb5dc319f9656b8f390480115d83795c.html#gacb5dc319f9656b8f390480115d83795c":[3,0,5,1637,0],
 "df/d9a/group__complex16_h_eeigen_gacb5dc319f9656b8f390480115d83795c.html#gacb5dc319f9656b8f390480115d83795c":[0,0,3,1,1,1],
-"df/d9a/group__complex16_h_eeigen_gacb5dc319f9656b8f390480115d83795c.html#gacb5dc319f9656b8f390480115d83795c":[3,0,5,1639,0],
 "df/d9a/group__complex16_h_eeigen_gadc7c95ab10d3a0d34802aa94939d4ad1.html#gadc7c95ab10d3a0d34802aa94939d4ad1":[0,0,3,1,1,5],
-"df/d9a/group__complex16_h_eeigen_gadc7c95ab10d3a0d34802aa94939d4ad1.html#gadc7c95ab10d3a0d34802aa94939d4ad1":[3,0,5,1643,0],
-"df/d9a/group__complex16_h_eeigen_gaf23fb5b3ae38072ef4890ba43d5cfea2.html#gaf23fb5b3ae38072ef4890ba43d5cfea2":[3,0,5,1638,0],
+"df/d9a/group__complex16_h_eeigen_gadc7c95ab10d3a0d34802aa94939d4ad1.html#gadc7c95ab10d3a0d34802aa94939d4ad1":[3,0,5,1641,0],
 "df/d9a/group__complex16_h_eeigen_gaf23fb5b3ae38072ef4890ba43d5cfea2.html#gaf23fb5b3ae38072ef4890ba43d5cfea2":[0,0,3,1,1,0],
-"df/d9a/group__complex16_h_eeigen_gaf7b790b3b89de432a423c9006c1cc1ac.html#gaf7b790b3b89de432a423c9006c1cc1ac":[3,0,5,1648,0],
+"df/d9a/group__complex16_h_eeigen_gaf23fb5b3ae38072ef4890ba43d5cfea2.html#gaf23fb5b3ae38072ef4890ba43d5cfea2":[3,0,5,1636,0],
 "df/d9a/group__complex16_h_eeigen_gaf7b790b3b89de432a423c9006c1cc1ac.html#gaf7b790b3b89de432a423c9006c1cc1ac":[0,0,3,1,1,8],
+"df/d9a/group__complex16_h_eeigen_gaf7b790b3b89de432a423c9006c1cc1ac.html#gaf7b790b3b89de432a423c9006c1cc1ac":[3,0,5,1646,0],
 "df/d9a/lapacke__dorgtr_8c.html":[3,0,4,3,906],
 "df/d9a/lapacke__dorgtr_8c_a43e2e8b561bf8d7247be755a2ca40ebd.html#a43e2e8b561bf8d7247be755a2ca40ebd":[3,0,4,3,906,0],
 "df/d9a/lapacke__dorgtr_8c_source.html":[3,0,4,3,906],
@@ -28,24 +31,24 @@ var NAVTREEINDEX121 =
 "df/d9b/stpt01_8f_source.html":[3,0,6,1,559],
 "df/d9c/schksp_8f.html":[3,0,6,1,416],
 "df/d9c/schksp_8f_source.html":[3,0,6,1,416],
-"df/d9d/_s_r_c_2stplqt_8f.html":[3,0,5,1493],
-"df/d9d/_s_r_c_2stplqt_8f_source.html":[3,0,5,1493],
-"df/d9d/dptrfs_8f.html":[3,0,5,853],
-"df/d9d/dptrfs_8f_source.html":[3,0,5,853],
+"df/d9d/_s_r_c_2stplqt_8f.html":[3,0,5,1491],
+"df/d9d/_s_r_c_2stplqt_8f_source.html":[3,0,5,1491],
+"df/d9d/dptrfs_8f.html":[3,0,5,852],
+"df/d9d/dptrfs_8f_source.html":[3,0,5,852],
 "df/d9d/lapacke__dgg__nancheck_8c.html":[3,0,4,4,43],
 "df/d9d/lapacke__dgg__nancheck_8c_a3a9570dc4b713acd82d14cffff90e0a7.html#a3a9570dc4b713acd82d14cffff90e0a7":[3,0,4,4,43,0],
 "df/d9d/lapacke__dgg__nancheck_8c_source.html":[3,0,4,4,43],
 "df/d9f/ctzrzf_8f.html":[3,0,5,460],
 "df/d9f/ctzrzf_8f_source.html":[3,0,5,460],
-"df/da0/sgejsv_8f.html":[3,0,5,1054],
-"df/da0/sgejsv_8f_source.html":[3,0,5,1054],
-"df/da1/zgerq2_8f.html":[3,0,5,1578],
-"df/da1/zgerq2_8f_source.html":[3,0,5,1578],
+"df/da0/sgejsv_8f.html":[3,0,5,1052],
+"df/da0/sgejsv_8f_source.html":[3,0,5,1052],
+"df/da1/zgerq2_8f.html":[3,0,5,1576],
+"df/da1/zgerq2_8f_source.html":[3,0,5,1576],
 "df/da2/cblas__zhbmv_8c.html":[3,0,1,2,121],
-"df/da2/cblas__zhbmv_8c_a0fab29436fb783a411cd9ac8bb2cd6eb.html#a0fab29436fb783a411cd9ac8bb2cd6eb":[3,0,1,2,121,6],
 "df/da2/cblas__zhbmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,121,0],
 "df/da2/cblas__zhbmv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,121,1],
 "df/da2/cblas__zhbmv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,121,2],
+"df/da2/cblas__zhbmv_8c_a59c36b549c6654fc578e30585bb96ad7.html#a59c36b549c6654fc578e30585bb96ad7":[3,0,1,2,121,6],
 "df/da2/cblas__zhbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,121,4],
 "df/da2/cblas__zhbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,121,3],
 "df/da2/cblas__zhbmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,121,5],
@@ -55,41 +58,41 @@ var NAVTREEINDEX121 =
 "df/da3/cblas__dspmv_8c.html":[3,0,1,2,49],
 "df/da3/cblas__dspmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,49,0],
 "df/da3/cblas__dspmv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,49,1],
+"df/da3/cblas__dspmv_8c_a428e8631207355b404cdc759b10e5e26.html#a428e8631207355b404cdc759b10e5e26":[3,0,1,2,49,4],
 "df/da3/cblas__dspmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,49,2],
-"df/da3/cblas__dspmv_8c_a844048953176c334aac0cf79b7587e6b.html#a844048953176c334aac0cf79b7587e6b":[3,0,1,2,49,4],
 "df/da3/cblas__dspmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,49,3],
 "df/da3/cblas__dspmv_8c_source.html":[3,0,1,2,49],
-"df/da3/zgeqr2p_8f.html":[3,0,5,1570],
-"df/da3/zgeqr2p_8f_source.html":[3,0,5,1570],
+"df/da3/zgeqr2p_8f.html":[3,0,5,1568],
+"df/da3/zgeqr2p_8f_source.html":[3,0,5,1568],
 "df/da4/claqr0_8f.html":[3,0,5,266],
 "df/da4/claqr0_8f_source.html":[3,0,5,266],
-"df/da4/dgetri_8f.html":[3,0,5,573],
-"df/da4/dgetri_8f_source.html":[3,0,5,573],
+"df/da4/dgetri_8f.html":[3,0,5,572],
+"df/da4/dgetri_8f_source.html":[3,0,5,572],
 "df/da4/lapacke__cheevd__work_8c.html":[3,0,4,3,209],
 "df/da4/lapacke__cheevd__work_8c_ae2c90a1a097b0aad32d2d309c5cadf39.html#ae2c90a1a097b0aad32d2d309c5cadf39":[3,0,4,3,209,0],
 "df/da4/lapacke__cheevd__work_8c_source.html":[3,0,4,3,209],
-"df/da4/zggsvp3_8f.html":[3,0,5,1612],
-"df/da4/zggsvp3_8f_source.html":[3,0,5,1612],
+"df/da4/zggsvp3_8f.html":[3,0,5,1610],
+"df/da4/zggsvp3_8f_source.html":[3,0,5,1610],
 "df/da5/lapacke__stfttr__work_8c.html":[3,0,4,3,1777],
 "df/da5/lapacke__stfttr__work_8c_a450483395ecb9560b815dd1f7095a66e.html#a450483395ecb9560b815dd1f7095a66e":[3,0,4,3,1777,0],
 "df/da5/lapacke__stfttr__work_8c_source.html":[3,0,4,3,1777],
-"df/da6/disnan_8f.html":[3,0,5,605],
-"df/da6/disnan_8f_source.html":[3,0,5,605],
+"df/da6/disnan_8f.html":[3,0,5,604],
+"df/da6/disnan_8f_source.html":[3,0,5,604],
 "df/da6/lapacke__zgbtrf__work_8c.html":[3,0,4,3,1861],
 "df/da6/lapacke__zgbtrf__work_8c_a34ec63f4798b79dabd80bb54ea0bf936.html#a34ec63f4798b79dabd80bb54ea0bf936":[3,0,4,3,1861,0],
 "df/da6/lapacke__zgbtrf__work_8c_source.html":[3,0,4,3,1861],
 "df/da8/lapacke__cptsvx_8c.html":[3,0,4,3,442],
 "df/da8/lapacke__cptsvx_8c_aba13c9eccd8bb766578ba4b5832960cc.html#aba13c9eccd8bb766578ba4b5832960cc":[3,0,4,3,442,0],
 "df/da8/lapacke__cptsvx_8c_source.html":[3,0,4,3,442],
-"df/da9/dpbtrf_8f.html":[3,0,5,823],
-"df/da9/dpbtrf_8f_source.html":[3,0,5,823],
+"df/da9/dpbtrf_8f.html":[3,0,5,822],
+"df/da9/dpbtrf_8f_source.html":[3,0,5,822],
 "df/da9/zlatsy_8f.html":[3,0,6,1,702],
 "df/da9/zlatsy_8f_source.html":[3,0,6,1,702],
 "df/dac/cblas__zcopy_8c.html":[3,0,1,2,112],
 "df/dac/cblas__zcopy_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,112,0],
 "df/dac/cblas__zcopy_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,112,1],
+"df/dac/cblas__zcopy_8c_a59a9c17d7c00478d85743e23ea9b8f4d.html#a59a9c17d7c00478d85743e23ea9b8f4d":[3,0,1,2,112,3],
 "df/dac/cblas__zcopy_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,112,2],
-"df/dac/cblas__zcopy_8c_a9adf47d83ece1aa33a470634d5b869f2.html#a9adf47d83ece1aa33a470634d5b869f2":[3,0,1,2,112,3],
 "df/dac/cblas__zcopy_8c_source.html":[3,0,1,2,112],
 "df/dac/lapacke__sgemlq__work_8c.html":[3,0,4,3,1313],
 "df/dac/lapacke__sgemlq__work_8c_a4ef41f648a7a536d3362db11b8c066f2.html#a4ef41f648a7a536d3362db11b8c066f2":[3,0,4,3,1313,0],
@@ -108,14 +111,14 @@ var NAVTREEINDEX121 =
 "df/daf/lapacke__zgelsy__work_8c.html":[3,0,4,3,1901],
 "df/daf/lapacke__zgelsy__work_8c_adb64f861148fd6a5d0f410d4e84c58de.html#adb64f861148fd6a5d0f410d4e84c58de":[3,0,4,3,1901,0],
 "df/daf/lapacke__zgelsy__work_8c_source.html":[3,0,4,3,1901],
-"df/daf/zpotrs_8f.html":[3,0,5,1867],
-"df/daf/zpotrs_8f_source.html":[3,0,5,1867],
+"df/daf/zpotrs_8f.html":[3,0,5,1865],
+"df/daf/zpotrs_8f_source.html":[3,0,5,1865],
 "df/db1/claipd_8f.html":[3,0,6,1,126],
 "df/db1/claipd_8f_source.html":[3,0,6,1,126],
 "df/db2/cheev_8f.html":[3,0,5,116],
 "df/db2/cheev_8f_source.html":[3,0,5,116],
-"df/db2/dorg2r_8f.html":[3,0,5,789],
-"df/db2/dorg2r_8f_source.html":[3,0,5,789],
+"df/db2/dorg2r_8f.html":[3,0,5,788],
+"df/db2/dorg2r_8f_source.html":[3,0,5,788],
 "df/db2/zlatme_8f.html":[3,0,6,2,70],
 "df/db2/zlatme_8f_source.html":[3,0,6,2,70],
 "df/db3/_v_a_r_i_a_n_t_s_2lu_2_c_r_2cgetrf_8f.html":[3,0,5,1,1,0,0],
@@ -137,13 +140,13 @@ var NAVTREEINDEX121 =
 "df/db8/lapacke__sdisna__work_8c_source.html":[3,0,4,3,1251],
 "df/db8/sdrgev_8f.html":[3,0,6,0,209],
 "df/db8/sdrgev_8f_source.html":[3,0,6,0,209],
-"df/db8/zunbdb5_8f.html":[3,0,5,1987],
-"df/db8/zunbdb5_8f_source.html":[3,0,5,1987],
+"df/db8/zunbdb5_8f.html":[3,0,5,1985],
+"df/db8/zunbdb5_8f_source.html":[3,0,5,1985],
 "df/db9/lapacke__sgesvx__work_8c.html":[3,0,4,3,1357],
 "df/db9/lapacke__sgesvx__work_8c_a51efc4f62e8d5c7c061cbfa2005dd04d.html#a51efc4f62e8d5c7c061cbfa2005dd04d":[3,0,4,3,1357,0],
 "df/db9/lapacke__sgesvx__work_8c_source.html":[3,0,4,3,1357],
-"df/db9/ssyev__2stage_8f.html":[3,0,5,1429],
-"df/db9/ssyev__2stage_8f_source.html":[3,0,5,1429],
+"df/db9/ssyev__2stage_8f.html":[3,0,5,1427],
+"df/db9/ssyev__2stage_8f_source.html":[3,0,5,1427],
 "df/dba/dqrt15_8f.html":[3,0,6,1,364],
 "df/dba/dqrt15_8f_source.html":[3,0,6,1,364],
 "df/dba/lapacke__chegv__2stage__work_8c.html":[3,0,4,3,222],
@@ -152,60 +155,60 @@ var NAVTREEINDEX121 =
 "df/dba/lapacke__sggev3__work_8c.html":[3,0,4,3,1386],
 "df/dba/lapacke__sggev3__work_8c_a714b552f16b0feea01187563ea56b8cf.html#a714b552f16b0feea01187563ea56b8cf":[3,0,4,3,1386,0],
 "df/dba/lapacke__sggev3__work_8c_source.html":[3,0,4,3,1386],
-"df/dbb/la__constants_8f90.html":[3,0,5,1019],
-"df/dbb/la__constants_8f90.html#a0490d3fdb12dad4b573c18b3934af383":[3,0,5,1019,34],
-"df/dbb/la__constants_8f90.html#a04f63fb58d39f784836ba4b1e725b4fa":[3,0,5,1019,1],
-"df/dbb/la__constants_8f90.html#a0b5dca96afa6f18f1618b27e33e4125b":[3,0,5,1019,22],
-"df/dbb/la__constants_8f90.html#a1007acdb5dfd233c8b03935b0a079ef5":[3,0,5,1019,41],
-"df/dbb/la__constants_8f90.html#a178a8ab98826acab38a6e4842ca6e966":[3,0,5,1019,40],
-"df/dbb/la__constants_8f90.html#a1e6ffb5785d1f3687fc12af790b55dfd":[3,0,5,1019,31],
-"df/dbb/la__constants_8f90.html#a21a46f6b54758bb4add83f90107096c1":[3,0,5,1019,8],
-"df/dbb/la__constants_8f90.html#a25caf500867f8f8b3c9709d4fee83b72":[3,0,5,1019,28],
-"df/dbb/la__constants_8f90.html#a369bf7a69756c3022445760f1338cecb":[3,0,5,1019,46],
-"df/dbb/la__constants_8f90.html#a400fda8fe8fdf79f2e30a684173b20ba":[3,0,5,1019,20],
-"df/dbb/la__constants_8f90.html#a50cc15aba359a702d3b5e800d11037b0":[3,0,5,1019,39],
-"df/dbb/la__constants_8f90.html#a54da5d7e44717b0d0db11097983fd448":[3,0,5,1019,23],
-"df/dbb/la__constants_8f90.html#a55b01cf08a86ab2252493590c143a8e5":[3,0,5,1019,44],
-"df/dbb/la__constants_8f90.html#a55ec9989976ff6e0d9c8d904d9dd9bfa":[3,0,5,1019,6],
-"df/dbb/la__constants_8f90.html#a57d93b395b46a35967707d133b620042":[3,0,5,1019,30],
-"df/dbb/la__constants_8f90.html#a5c13d19c6503fb7f1b2675301a561841":[3,0,5,1019,50],
-"df/dbb/la__constants_8f90.html#a5f205287d5909c0a425aa37928b02583":[3,0,5,1019,25],
-"df/dbb/la__constants_8f90.html#a5f35a19c8c358fc82f7273780ef9c22c":[3,0,5,1019,26],
-"df/dbb/la__constants_8f90.html#a6039f15666a1d2373361bf5c79b26607":[3,0,5,1019,43],
-"df/dbb/la__constants_8f90.html#a6103083921bf44836809cb375de83e45":[3,0,5,1019,48],
-"df/dbb/la__constants_8f90.html#a6cf3a8fdc566459d78c82c71b0871c14":[3,0,5,1019,45],
-"df/dbb/la__constants_8f90.html#a6f0165529f661f95ba5f2b192fbbd26f":[3,0,5,1019,16],
-"df/dbb/la__constants_8f90.html#a6fd7a5042ca357d3cbf61ad70bf1759f":[3,0,5,1019,24],
-"df/dbb/la__constants_8f90.html#a710f46e19a271964cbc2dc7da5b3a419":[3,0,5,1019,4],
-"df/dbb/la__constants_8f90.html#a768621e04d2c860ca7f956b4745351ab":[3,0,5,1019,12],
-"df/dbb/la__constants_8f90.html#a7ae97fc519ab76a576db113b17312382":[3,0,5,1019,15],
-"df/dbb/la__constants_8f90.html#a81a871edc6f44403650775c5b3a50b52":[3,0,5,1019,10],
-"df/dbb/la__constants_8f90.html#a828ddbd0dca1da90e7d62d09ccdb2a53":[3,0,5,1019,13],
-"df/dbb/la__constants_8f90.html#a8ac0f58fa87531b26c2f0255b0e138d6":[3,0,5,1019,35],
-"df/dbb/la__constants_8f90.html#a8f76695e9985c42e93d8aa950d5cadc0":[3,0,5,1019,21],
-"df/dbb/la__constants_8f90.html#a910f958e48a94fca49df0912190df3f0":[3,0,5,1019,49],
-"df/dbb/la__constants_8f90.html#a91d612305c5bf7109935241b7f8ace97":[3,0,5,1019,5],
-"df/dbb/la__constants_8f90.html#a99b03bac60d2a416342cf54c668cb7a5":[3,0,5,1019,9],
-"df/dbb/la__constants_8f90.html#aa514778f9027ec97a02994e6456db81f":[3,0,5,1019,3],
-"df/dbb/la__constants_8f90.html#aa88cf42ff3ade2623d1739475b09a5f4":[3,0,5,1019,38],
-"df/dbb/la__constants_8f90.html#aa9251d5e1f28d03a7cd0dd3d2522e89f":[3,0,5,1019,11],
-"df/dbb/la__constants_8f90.html#aaa5fae659a9baf5889d27d0af583cd0d":[3,0,5,1019,32],
-"df/dbb/la__constants_8f90.html#ab1ad7249d0e7075315d60b58fcdd63ef":[3,0,5,1019,33],
-"df/dbb/la__constants_8f90.html#ab42ecef2cfb3ea41968cae9219892378":[3,0,5,1019,37],
-"df/dbb/la__constants_8f90.html#ac32a887bea9408253a5ede31dfaea1d0":[3,0,5,1019,36],
-"df/dbb/la__constants_8f90.html#ac34c435e9a04a0b3df2fd24fc982e364":[3,0,5,1019,51],
-"df/dbb/la__constants_8f90.html#ac5f9ae5335019ef7c017a6cad176a516":[3,0,5,1019,47],
-"df/dbb/la__constants_8f90.html#ae1f119aca476290396e30a7189132510":[3,0,5,1019,14],
-"df/dbb/la__constants_8f90.html#ae7f5050fefb3353398eeb93736cfed7c":[3,0,5,1019,19],
-"df/dbb/la__constants_8f90.html#aea2313eadc2df0780740b19d54058278":[3,0,5,1019,7],
-"df/dbb/la__constants_8f90.html#aeb4384c47544532b137b044f5323ab73":[3,0,5,1019,42],
-"df/dbb/la__constants_8f90.html#aebd1d42f8b096d4dc0c5cffd3c86cca6":[3,0,5,1019,2],
-"df/dbb/la__constants_8f90.html#aeea27d885c0887c809b27c4e260db13e":[3,0,5,1019,0],
-"df/dbb/la__constants_8f90.html#af1b7da73ba099a59d900962e0a624b34":[3,0,5,1019,27],
-"df/dbb/la__constants_8f90.html#af28cc44fdcb5a7a96ea2aea57b03ba55":[3,0,5,1019,17],
-"df/dbb/la__constants_8f90.html#af8ba7cf2dbd6100c61570d59be0d1b0c":[3,0,5,1019,18],
-"df/dbb/la__constants_8f90.html#afdd9ca326f9f9763542987785fe8381c":[3,0,5,1019,29],
-"df/dbb/la__constants_8f90_source.html":[3,0,5,1019],
+"df/dbb/la__constants_8f90.html":[3,0,5,1018],
+"df/dbb/la__constants_8f90.html#a0490d3fdb12dad4b573c18b3934af383":[3,0,5,1018,34],
+"df/dbb/la__constants_8f90.html#a04f63fb58d39f784836ba4b1e725b4fa":[3,0,5,1018,1],
+"df/dbb/la__constants_8f90.html#a0b5dca96afa6f18f1618b27e33e4125b":[3,0,5,1018,22],
+"df/dbb/la__constants_8f90.html#a1007acdb5dfd233c8b03935b0a079ef5":[3,0,5,1018,41],
+"df/dbb/la__constants_8f90.html#a178a8ab98826acab38a6e4842ca6e966":[3,0,5,1018,40],
+"df/dbb/la__constants_8f90.html#a1e6ffb5785d1f3687fc12af790b55dfd":[3,0,5,1018,31],
+"df/dbb/la__constants_8f90.html#a21a46f6b54758bb4add83f90107096c1":[3,0,5,1018,8],
+"df/dbb/la__constants_8f90.html#a25caf500867f8f8b3c9709d4fee83b72":[3,0,5,1018,28],
+"df/dbb/la__constants_8f90.html#a369bf7a69756c3022445760f1338cecb":[3,0,5,1018,46],
+"df/dbb/la__constants_8f90.html#a400fda8fe8fdf79f2e30a684173b20ba":[3,0,5,1018,20],
+"df/dbb/la__constants_8f90.html#a50cc15aba359a702d3b5e800d11037b0":[3,0,5,1018,39],
+"df/dbb/la__constants_8f90.html#a54da5d7e44717b0d0db11097983fd448":[3,0,5,1018,23],
+"df/dbb/la__constants_8f90.html#a55b01cf08a86ab2252493590c143a8e5":[3,0,5,1018,44],
+"df/dbb/la__constants_8f90.html#a55ec9989976ff6e0d9c8d904d9dd9bfa":[3,0,5,1018,6],
+"df/dbb/la__constants_8f90.html#a57d93b395b46a35967707d133b620042":[3,0,5,1018,30],
+"df/dbb/la__constants_8f90.html#a5c13d19c6503fb7f1b2675301a561841":[3,0,5,1018,50],
+"df/dbb/la__constants_8f90.html#a5f205287d5909c0a425aa37928b02583":[3,0,5,1018,25],
+"df/dbb/la__constants_8f90.html#a5f35a19c8c358fc82f7273780ef9c22c":[3,0,5,1018,26],
+"df/dbb/la__constants_8f90.html#a6039f15666a1d2373361bf5c79b26607":[3,0,5,1018,43],
+"df/dbb/la__constants_8f90.html#a6103083921bf44836809cb375de83e45":[3,0,5,1018,48],
+"df/dbb/la__constants_8f90.html#a6cf3a8fdc566459d78c82c71b0871c14":[3,0,5,1018,45],
+"df/dbb/la__constants_8f90.html#a6f0165529f661f95ba5f2b192fbbd26f":[3,0,5,1018,16],
+"df/dbb/la__constants_8f90.html#a6fd7a5042ca357d3cbf61ad70bf1759f":[3,0,5,1018,24],
+"df/dbb/la__constants_8f90.html#a710f46e19a271964cbc2dc7da5b3a419":[3,0,5,1018,4],
+"df/dbb/la__constants_8f90.html#a768621e04d2c860ca7f956b4745351ab":[3,0,5,1018,12],
+"df/dbb/la__constants_8f90.html#a7ae97fc519ab76a576db113b17312382":[3,0,5,1018,15],
+"df/dbb/la__constants_8f90.html#a81a871edc6f44403650775c5b3a50b52":[3,0,5,1018,10],
+"df/dbb/la__constants_8f90.html#a828ddbd0dca1da90e7d62d09ccdb2a53":[3,0,5,1018,13],
+"df/dbb/la__constants_8f90.html#a8ac0f58fa87531b26c2f0255b0e138d6":[3,0,5,1018,35],
+"df/dbb/la__constants_8f90.html#a8f76695e9985c42e93d8aa950d5cadc0":[3,0,5,1018,21],
+"df/dbb/la__constants_8f90.html#a910f958e48a94fca49df0912190df3f0":[3,0,5,1018,49],
+"df/dbb/la__constants_8f90.html#a91d612305c5bf7109935241b7f8ace97":[3,0,5,1018,5],
+"df/dbb/la__constants_8f90.html#a99b03bac60d2a416342cf54c668cb7a5":[3,0,5,1018,9],
+"df/dbb/la__constants_8f90.html#aa514778f9027ec97a02994e6456db81f":[3,0,5,1018,3],
+"df/dbb/la__constants_8f90.html#aa88cf42ff3ade2623d1739475b09a5f4":[3,0,5,1018,38],
+"df/dbb/la__constants_8f90.html#aa9251d5e1f28d03a7cd0dd3d2522e89f":[3,0,5,1018,11],
+"df/dbb/la__constants_8f90.html#aaa5fae659a9baf5889d27d0af583cd0d":[3,0,5,1018,32],
+"df/dbb/la__constants_8f90.html#ab1ad7249d0e7075315d60b58fcdd63ef":[3,0,5,1018,33],
+"df/dbb/la__constants_8f90.html#ab42ecef2cfb3ea41968cae9219892378":[3,0,5,1018,37],
+"df/dbb/la__constants_8f90.html#ac32a887bea9408253a5ede31dfaea1d0":[3,0,5,1018,36],
+"df/dbb/la__constants_8f90.html#ac34c435e9a04a0b3df2fd24fc982e364":[3,0,5,1018,51],
+"df/dbb/la__constants_8f90.html#ac5f9ae5335019ef7c017a6cad176a516":[3,0,5,1018,47],
+"df/dbb/la__constants_8f90.html#ae1f119aca476290396e30a7189132510":[3,0,5,1018,14],
+"df/dbb/la__constants_8f90.html#ae7f5050fefb3353398eeb93736cfed7c":[3,0,5,1018,19],
+"df/dbb/la__constants_8f90.html#aea2313eadc2df0780740b19d54058278":[3,0,5,1018,7],
+"df/dbb/la__constants_8f90.html#aeb4384c47544532b137b044f5323ab73":[3,0,5,1018,42],
+"df/dbb/la__constants_8f90.html#aebd1d42f8b096d4dc0c5cffd3c86cca6":[3,0,5,1018,2],
+"df/dbb/la__constants_8f90.html#aeea27d885c0887c809b27c4e260db13e":[3,0,5,1018,0],
+"df/dbb/la__constants_8f90.html#af1b7da73ba099a59d900962e0a624b34":[3,0,5,1018,27],
+"df/dbb/la__constants_8f90.html#af28cc44fdcb5a7a96ea2aea57b03ba55":[3,0,5,1018,17],
+"df/dbb/la__constants_8f90.html#af8ba7cf2dbd6100c61570d59be0d1b0c":[3,0,5,1018,18],
+"df/dbb/la__constants_8f90.html#afdd9ca326f9f9763542987785fe8381c":[3,0,5,1018,29],
+"df/dbb/la__constants_8f90_source.html":[3,0,5,1018],
 "df/dbb/lapacke__dpbequ__work_8c.html":[3,0,4,3,929],
 "df/dbb/lapacke__dpbequ__work_8c_a8186828018313c35ca76acf3be1c2bc5.html#a8186828018313c35ca76acf3be1c2bc5":[3,0,4,3,929,0],
 "df/dbb/lapacke__dpbequ__work_8c_source.html":[3,0,4,3,929],
@@ -218,8 +221,8 @@ var NAVTREEINDEX121 =
 "df/dbd/lapacke__chgeqz__work_8c.html":[3,0,4,3,281],
 "df/dbd/lapacke__chgeqz__work_8c_aceb3d06ea02f62fee41a5a73a86dfeb8.html#aceb3d06ea02f62fee41a5a73a86dfeb8":[3,0,4,3,281,0],
 "df/dbd/lapacke__chgeqz__work_8c_source.html":[3,0,4,3,281],
-"df/dbe/stbrfs_8f.html":[3,0,5,1478],
-"df/dbe/stbrfs_8f_source.html":[3,0,5,1478],
+"df/dbe/stbrfs_8f.html":[3,0,5,1476],
+"df/dbe/stbrfs_8f_source.html":[3,0,5,1476],
 "df/dbf/cggsvp3_8f.html":[3,0,5,90],
 "df/dbf/cggsvp3_8f_source.html":[3,0,5,90],
 "df/dbf/lapacke__zggbak_8c.html":[3,0,4,3,1964],
@@ -228,8 +231,8 @@ var NAVTREEINDEX121 =
 "df/dc1/lapacke__ctftri__work_8c.html":[3,0,4,3,541],
 "df/dc1/lapacke__ctftri__work_8c_a32edc885c2135bad65fbab9d3e960290.html#a32edc885c2135bad65fbab9d3e960290":[3,0,4,3,541,0],
 "df/dc1/lapacke__ctftri__work_8c_source.html":[3,0,4,3,541],
-"df/dc2/dlartgp_8f.html":[3,0,5,727],
-"df/dc2/dlartgp_8f_source.html":[3,0,5,727],
+"df/dc2/dlartgp_8f.html":[3,0,5,726],
+"df/dc2/dlartgp_8f_source.html":[3,0,5,726],
 "df/dc2/lapacke__chpgvd_8c.html":[3,0,4,3,294],
 "df/dc2/lapacke__chpgvd_8c_a7474a6abd43c23596af85ec5249ee37b.html#a7474a6abd43c23596af85ec5249ee37b":[3,0,4,3,294,0],
 "df/dc2/lapacke__chpgvd_8c_source.html":[3,0,4,3,294],
@@ -245,9 +248,6 @@ var NAVTREEINDEX121 =
 "df/dc4/chetrf__aa__2stage_8f.html":[3,0,5,150],
 "df/dc4/chetrf__aa__2stage_8f_source.html":[3,0,5,150],
 "df/dc5/group__variants_g_ecomputational.html":[0,0,0,4],
-"df/dc5/group__variants_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[3,0,5,1,1,1,1,0],
-"df/dc5/group__variants_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[3,0,5,1,1,2,1,0],
 "df/dc5/group__variants_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[3,0,5,1,1,0,1,0],
-"df/dc5/group__variants_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[0,0,0,4,3],
-"df/dc5/group__variants_g_ecomputational_ga333680795e2818318a1c6f6d1a503722.html#ga333680795e2818318a1c6f6d1a503722":[0,0,0,4,0]
+"df/dc5/group__variants_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[3,0,5,1,1,1,1,0]
 };
