@@ -7,8 +7,8 @@ var NAVTREEINDEX27 =
 "d3/de2/lapacke__zsysvxx_8c_source.html":[3,0,4,3,2336],
 "d3/de2/sdrvgex_8f.html":[3,0,6,1,430],
 "d3/de2/sdrvgex_8f_source.html":[3,0,6,1,430],
-"d3/de3/dlaed3_8f.html":[3,0,5,634],
-"d3/de3/dlaed3_8f_source.html":[3,0,5,634],
+"d3/de3/dlaed3_8f.html":[3,0,5,633],
+"d3/de3/dlaed3_8f_source.html":[3,0,5,633],
 "d3/de5/sget35_8f.html":[3,0,6,0,237],
 "d3/de5/sget35_8f_source.html":[3,0,6,0,237],
 "d3/de6/sget23_8f.html":[3,0,6,0,231],
@@ -16,12 +16,12 @@ var NAVTREEINDEX27 =
 "d3/de7/lapacke__zporfs__work_8c.html":[3,0,4,3,2237],
 "d3/de7/lapacke__zporfs__work_8c_a4ad94df18fc78de06f53788b991482da.html#a4ad94df18fc78de06f53788b991482da":[3,0,4,3,2237,0],
 "d3/de7/lapacke__zporfs__work_8c_source.html":[3,0,4,3,2237],
-"d3/de9/sgemlq_8f.html":[3,0,5,1064],
-"d3/de9/sgemlq_8f_a7a01f1e6ca7bce4a0ed87f2b3fde8092.html#a7a01f1e6ca7bce4a0ed87f2b3fde8092":[3,0,5,1064,0],
-"d3/de9/sgemlq_8f_source.html":[3,0,5,1064],
-"d3/de9/zlamswlq_8f.html":[3,0,5,1760],
-"d3/de9/zlamswlq_8f_a7fa1a07b7906c9c8b04513652e506cb8.html#a7fa1a07b7906c9c8b04513652e506cb8":[3,0,5,1760,0],
-"d3/de9/zlamswlq_8f_source.html":[3,0,5,1760],
+"d3/de9/sgemlq_8f.html":[3,0,5,1062],
+"d3/de9/sgemlq_8f_a7a01f1e6ca7bce4a0ed87f2b3fde8092.html#a7a01f1e6ca7bce4a0ed87f2b3fde8092":[3,0,5,1062,0],
+"d3/de9/sgemlq_8f_source.html":[3,0,5,1062],
+"d3/de9/zlamswlq_8f.html":[3,0,5,1758],
+"d3/de9/zlamswlq_8f_a7fa1a07b7906c9c8b04513652e506cb8.html#a7fa1a07b7906c9c8b04513652e506cb8":[3,0,5,1758,0],
+"d3/de9/zlamswlq_8f_source.html":[3,0,5,1758],
 "d3/dea/lapacke__zst__nancheck_8c.html":[3,0,4,4,137],
 "d3/dea/lapacke__zst__nancheck_8c_a9ebc448897be5ce0af4a71a12b6114cf.html#a9ebc448897be5ce0af4a71a12b6114cf":[3,0,4,4,137,0],
 "d3/dea/lapacke__zst__nancheck_8c_source.html":[3,0,4,4,137],
@@ -37,8 +37,8 @@ var NAVTREEINDEX27 =
 "d3/ded/lapacke__dsbtrd__work_8c.html":[3,0,4,3,1025],
 "d3/ded/lapacke__dsbtrd__work_8c_a83f4d551c69e220192d37af30c22a8a2.html#a83f4d551c69e220192d37af30c22a8a2":[3,0,4,3,1025,0],
 "d3/ded/lapacke__dsbtrd__work_8c_source.html":[3,0,4,3,1025],
-"d3/ded/sgbbrd_8f.html":[3,0,5,1029],
-"d3/ded/sgbbrd_8f_source.html":[3,0,5,1029],
+"d3/ded/sgbbrd_8f.html":[3,0,5,1027],
+"d3/ded/sgbbrd_8f_source.html":[3,0,5,1027],
 "d3/dee/cchkql_8f.html":[3,0,6,1,27],
 "d3/dee/cchkql_8f_source.html":[3,0,6,1,27],
 "d3/dee/cerrgt_8f.html":[3,0,6,1,78],
@@ -48,8 +48,8 @@ var NAVTREEINDEX27 =
 "d3/dee/lapacke__clarft_8c_source.html":[3,0,4,3,352],
 "d3/dee/zgeqpf_8f.html":[3,0,5,0,30],
 "d3/dee/zgeqpf_8f_source.html":[3,0,5,0,30],
-"d3/dee/zlasyf__aa_8f.html":[3,0,5,1828],
-"d3/dee/zlasyf__aa_8f_source.html":[3,0,5,1828],
+"d3/dee/zlasyf__aa_8f.html":[3,0,5,1826],
+"d3/dee/zlasyf__aa_8f_source.html":[3,0,5,1826],
 "d3/def/lapacke__dgbtrf_8c.html":[3,0,4,3,672],
 "d3/def/lapacke__dgbtrf_8c_aec18b5b3e871649dd59dd210630f065c.html#aec18b5b3e871649dd59dd210630f065c":[3,0,4,3,672,0],
 "d3/def/lapacke__dgbtrf_8c_source.html":[3,0,4,3,672],
@@ -66,8 +66,8 @@ var NAVTREEINDEX27 =
 "d3/df3/lapacke__dorghr_8c.html":[3,0,4,3,896],
 "d3/df3/lapacke__dorghr_8c_a43651194e9bbb7f78f359f862ed0c09a.html#a43651194e9bbb7f78f359f862ed0c09a":[3,0,4,3,896,0],
 "d3/df3/lapacke__dorghr_8c_source.html":[3,0,4,3,896],
-"d3/df4/dggglm_8f.html":[3,0,5,585],
-"d3/df4/dggglm_8f_source.html":[3,0,5,585],
+"d3/df4/dggglm_8f.html":[3,0,5,584],
+"d3/df4/dggglm_8f_source.html":[3,0,5,584],
 "d3/df5/lapacke__sspevd__work_8c.html":[3,0,4,3,1631],
 "d3/df5/lapacke__sspevd__work_8c_aba547bf8bdc90bdde0884db4b57b56b0.html#aba547bf8bdc90bdde0884db4b57b56b0":[3,0,4,3,1631,0],
 "d3/df5/lapacke__sspevd__work_8c_source.html":[3,0,4,3,1631],
@@ -79,41 +79,41 @@ var NAVTREEINDEX27 =
 "d3/dfa/lapacke__dstebz_8c_source.html":[3,0,4,3,1062],
 "d3/dfb/group__real_g_eeigen.html":[0,0,0,1,1],
 "d3/dfb/group__real_g_eeigen_ga0cd2fba843c9d04967c79a58f8d6e321.html#ga0cd2fba843c9d04967c79a58f8d6e321":[0,0,0,1,1,0],
-"d3/dfb/group__real_g_eeigen_ga0cd2fba843c9d04967c79a58f8d6e321.html#ga0cd2fba843c9d04967c79a58f8d6e321":[3,0,5,1048,0],
+"d3/dfb/group__real_g_eeigen_ga0cd2fba843c9d04967c79a58f8d6e321.html#ga0cd2fba843c9d04967c79a58f8d6e321":[3,0,5,1046,0],
 "d3/dfb/group__real_g_eeigen_ga104525b749278774f7b7f57195aa6798.html#ga104525b749278774f7b7f57195aa6798":[0,0,0,1,1,2],
-"d3/dfb/group__real_g_eeigen_ga104525b749278774f7b7f57195aa6798.html#ga104525b749278774f7b7f57195aa6798":[3,0,5,1050,0],
+"d3/dfb/group__real_g_eeigen_ga104525b749278774f7b7f57195aa6798.html#ga104525b749278774f7b7f57195aa6798":[3,0,5,1048,0],
 "d3/dfb/group__real_g_eeigen_ga47ddf03d427ec3f9346253132c26cf96.html#ga47ddf03d427ec3f9346253132c26cf96":[0,0,0,1,1,11],
-"d3/dfb/group__real_g_eeigen_ga47ddf03d427ec3f9346253132c26cf96.html#ga47ddf03d427ec3f9346253132c26cf96":[3,0,5,1107,0],
+"d3/dfb/group__real_g_eeigen_ga47ddf03d427ec3f9346253132c26cf96.html#ga47ddf03d427ec3f9346253132c26cf96":[3,0,5,1105,0],
 "d3/dfb/group__real_g_eeigen_ga6176eadcb5a027beb0b000fbf74f9e35.html#ga6176eadcb5a027beb0b000fbf74f9e35":[0,0,0,1,1,9],
-"d3/dfb/group__real_g_eeigen_ga6176eadcb5a027beb0b000fbf74f9e35.html#ga6176eadcb5a027beb0b000fbf74f9e35":[3,0,5,1105,0],
+"d3/dfb/group__real_g_eeigen_ga6176eadcb5a027beb0b000fbf74f9e35.html#ga6176eadcb5a027beb0b000fbf74f9e35":[3,0,5,1103,0],
 "d3/dfb/group__real_g_eeigen_ga6a36f16104f3f8ae8e499cc7efaa2195.html#ga6a36f16104f3f8ae8e499cc7efaa2195":[0,0,0,1,1,6],
-"d3/dfb/group__real_g_eeigen_ga6a36f16104f3f8ae8e499cc7efaa2195.html#ga6a36f16104f3f8ae8e499cc7efaa2195":[3,0,5,1102,0],
+"d3/dfb/group__real_g_eeigen_ga6a36f16104f3f8ae8e499cc7efaa2195.html#ga6a36f16104f3f8ae8e499cc7efaa2195":[3,0,5,1100,0],
 "d3/dfb/group__real_g_eeigen_ga7c33384acda01bd5c62e87213eb2f2f9.html#ga7c33384acda01bd5c62e87213eb2f2f9":[0,0,0,1,1,10],
-"d3/dfb/group__real_g_eeigen_ga7c33384acda01bd5c62e87213eb2f2f9.html#ga7c33384acda01bd5c62e87213eb2f2f9":[3,0,5,1106,0],
+"d3/dfb/group__real_g_eeigen_ga7c33384acda01bd5c62e87213eb2f2f9.html#ga7c33384acda01bd5c62e87213eb2f2f9":[3,0,5,1104,0],
 "d3/dfb/group__real_g_eeigen_ga80fd7fa3159b96cf467a9584f6464310.html#ga80fd7fa3159b96cf467a9584f6464310":[0,0,0,1,1,5],
 "d3/dfb/group__real_g_eeigen_ga80fd7fa3159b96cf467a9584f6464310.html#ga80fd7fa3159b96cf467a9584f6464310":[3,0,5,0,19,0],
 "d3/dfb/group__real_g_eeigen_gaa38a73620b45cbe5a9b1803351a28dbb.html#gaa38a73620b45cbe5a9b1803351a28dbb":[0,0,0,1,1,7],
-"d3/dfb/group__real_g_eeigen_gaa38a73620b45cbe5a9b1803351a28dbb.html#gaa38a73620b45cbe5a9b1803351a28dbb":[3,0,5,1103,0],
+"d3/dfb/group__real_g_eeigen_gaa38a73620b45cbe5a9b1803351a28dbb.html#gaa38a73620b45cbe5a9b1803351a28dbb":[3,0,5,1101,0],
 "d3/dfb/group__real_g_eeigen_gac04eec62b6a153d74e425961e9704fde.html#gac04eec62b6a153d74e425961e9704fde":[0,0,0,1,1,8],
-"d3/dfb/group__real_g_eeigen_gac04eec62b6a153d74e425961e9704fde.html#gac04eec62b6a153d74e425961e9704fde":[3,0,5,1104,0],
+"d3/dfb/group__real_g_eeigen_gac04eec62b6a153d74e425961e9704fde.html#gac04eec62b6a153d74e425961e9704fde":[3,0,5,1102,0],
 "d3/dfb/group__real_g_eeigen_gac8e46bbcd7e259cdacfccbcfb575a392.html#gac8e46bbcd7e259cdacfccbcfb575a392":[0,0,0,1,1,1],
-"d3/dfb/group__real_g_eeigen_gac8e46bbcd7e259cdacfccbcfb575a392.html#gac8e46bbcd7e259cdacfccbcfb575a392":[3,0,5,1049,0],
+"d3/dfb/group__real_g_eeigen_gac8e46bbcd7e259cdacfccbcfb575a392.html#gac8e46bbcd7e259cdacfccbcfb575a392":[3,0,5,1047,0],
 "d3/dfb/group__real_g_eeigen_gad6edd6ac01e4a249743c45803d9b37a2.html#gad6edd6ac01e4a249743c45803d9b37a2":[0,0,0,1,1,4],
 "d3/dfb/group__real_g_eeigen_gad6edd6ac01e4a249743c45803d9b37a2.html#gad6edd6ac01e4a249743c45803d9b37a2":[3,0,5,0,18,0],
 "d3/dfb/group__real_g_eeigen_gadf06d28b4793cbab21e898fcb713d5a5.html#gadf06d28b4793cbab21e898fcb713d5a5":[0,0,0,1,1,3],
-"d3/dfb/group__real_g_eeigen_gadf06d28b4793cbab21e898fcb713d5a5.html#gadf06d28b4793cbab21e898fcb713d5a5":[3,0,5,1051,0],
+"d3/dfb/group__real_g_eeigen_gadf06d28b4793cbab21e898fcb713d5a5.html#gadf06d28b4793cbab21e898fcb713d5a5":[3,0,5,1049,0],
 "d3/dfb/zlattr_8f.html":[3,0,6,1,705],
 "d3/dfb/zlattr_8f_source.html":[3,0,6,1,705],
-"d3/dfc/spstrf_8f.html":[3,0,5,1372],
-"d3/dfc/spstrf_8f_source.html":[3,0,5,1372],
+"d3/dfc/spstrf_8f.html":[3,0,5,1370],
+"d3/dfc/spstrf_8f_source.html":[3,0,5,1370],
 "d3/dfd/lapacke__spb__trans_8c.html":[3,0,4,4,86],
 "d3/dfd/lapacke__spb__trans_8c_a74dff816c65e1852a4647df1d1571874.html#a74dff816c65e1852a4647df1d1571874":[3,0,4,4,86,0],
 "d3/dfd/lapacke__spb__trans_8c_source.html":[3,0,4,4,86],
 "d3/dfd/lapacke__stptri__work_8c.html":[3,0,4,3,1803],
 "d3/dfd/lapacke__stptri__work_8c_a8bfda87a05d99fcbdecffc1097e8f497.html#a8bfda87a05d99fcbdecffc1097e8f497":[3,0,4,3,1803,0],
 "d3/dfd/lapacke__stptri__work_8c_source.html":[3,0,4,3,1803],
-"d3/dfe/dsyevr__2stage_8f.html":[3,0,5,913],
-"d3/dfe/dsyevr__2stage_8f_source.html":[3,0,5,913],
+"d3/dfe/dsyevr__2stage_8f.html":[3,0,5,912],
+"d3/dfe/dsyevr__2stage_8f_source.html":[3,0,5,912],
 "d3/dfe/lapacke__dstegr_8c.html":[3,0,4,3,1066],
 "d3/dfe/lapacke__dstegr_8c_a0a9c0545e1c6533ac382d48482cce94b.html#a0a9c0545e1c6533ac382d48482cce94b":[3,0,4,3,1066,0],
 "d3/dfe/lapacke__dstegr_8c_source.html":[3,0,4,3,1066],
@@ -124,10 +124,10 @@ var NAVTREEINDEX27 =
 "d3/dff/_l_i_n_2alasvm_8f_source.html":[3,0,6,1,6],
 "d3/dff/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2cpotrf_8f.html":[3,0,5,1,0,0,0],
 "d3/dff/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2cpotrf_8f_source.html":[3,0,5,1,0,0,0],
-"d3/dff/dtbrfs_8f.html":[3,0,5,958],
-"d3/dff/dtbrfs_8f_source.html":[3,0,5,958],
-"d3/dff/sgesvj_8f.html":[3,0,5,1089],
-"d3/dff/sgesvj_8f_source.html":[3,0,5,1089],
+"d3/dff/dtbrfs_8f.html":[3,0,5,957],
+"d3/dff/dtbrfs_8f_source.html":[3,0,5,957],
+"d3/dff/sgesvj_8f.html":[3,0,5,1087],
+"d3/dff/sgesvj_8f_source.html":[3,0,5,1087],
 "d4/d00/lapacke__ctrsyl_8c.html":[3,0,4,3,590],
 "d4/d00/lapacke__ctrsyl_8c_a96904d15d2b622314764c6a644950fb4.html#a96904d15d2b622314764c6a644950fb4":[3,0,4,3,590,0],
 "d4/d00/lapacke__ctrsyl_8c_source.html":[3,0,4,3,590],
@@ -155,9 +155,9 @@ var NAVTREEINDEX27 =
 "d4/d06/lapacke__zgemqrt__work_8c.html":[3,0,4,3,1907],
 "d4/d06/lapacke__zgemqrt__work_8c_a4e4e6774e3210f820cf2b7ecdc813c4f.html#a4e4e6774e3210f820cf2b7ecdc813c4f":[3,0,4,3,1907,0],
 "d4/d06/lapacke__zgemqrt__work_8c_source.html":[3,0,4,3,1907],
-"d4/d08/dsecnd___e_x_t___e_t_i_m_e___8f.html":[3,0,3,4],
-"d4/d08/dsecnd___e_x_t___e_t_i_m_e___8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,4,0],
-"d4/d08/dsecnd___e_x_t___e_t_i_m_e___8f_source.html":[3,0,3,4],
+"d4/d08/dsecnd___e_x_t___e_t_i_m_e___8f.html":[3,0,3,5],
+"d4/d08/dsecnd___e_x_t___e_t_i_m_e___8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,5,0],
+"d4/d08/dsecnd___e_x_t___e_t_i_m_e___8f_source.html":[3,0,3,5],
 "d4/d08/lapacke__dgetrs__work_8c.html":[3,0,4,3,771],
 "d4/d08/lapacke__dgetrs__work_8c_a279df774e424de914f97518998367bfc.html#a279df774e424de914f97518998367bfc":[3,0,4,3,771,0],
 "d4/d08/lapacke__dgetrs__work_8c_source.html":[3,0,4,3,771],
@@ -181,13 +181,13 @@ var NAVTREEINDEX27 =
 "d4/d0b/lapacke__dgees__work_8c.html":[3,0,4,3,689],
 "d4/d0b/lapacke__dgees__work_8c_aca01f55fe0efe6d5766ba96235376abd.html#aca01f55fe0efe6d5766ba96235376abd":[3,0,4,3,689,0],
 "d4/d0b/lapacke__dgees__work_8c_source.html":[3,0,4,3,689],
-"d4/d0d/dgelq_8f.html":[3,0,5,532],
-"d4/d0d/dgelq_8f_ac039f2ae906b9093e0c2f2ac08e66ef8.html#ac039f2ae906b9093e0c2f2ac08e66ef8":[3,0,5,532,0],
-"d4/d0d/dgelq_8f_source.html":[3,0,5,532],
+"d4/d0d/dgelq_8f.html":[3,0,5,531],
+"d4/d0d/dgelq_8f_ac039f2ae906b9093e0c2f2ac08e66ef8.html#ac039f2ae906b9093e0c2f2ac08e66ef8":[3,0,5,531,0],
+"d4/d0d/dgelq_8f_source.html":[3,0,5,531],
 "d4/d0e/dchktsqr_8f.html":[3,0,6,1,242],
 "d4/d0e/dchktsqr_8f_source.html":[3,0,6,1,242],
-"d4/d0f/dspev_8f.html":[3,0,5,875],
-"d4/d0f/dspev_8f_source.html":[3,0,5,875],
+"d4/d0f/dspev_8f.html":[3,0,5,874],
+"d4/d0f/dspev_8f_source.html":[3,0,5,874],
 "d4/d0f/lapacke__ssytrd__work_8c.html":[3,0,4,3,1733],
 "d4/d0f/lapacke__ssytrd__work_8c_a635f474b1505ba5338d08b99c27391f2.html#a635f474b1505ba5338d08b99c27391f2":[3,0,4,3,1733,0],
 "d4/d0f/lapacke__ssytrd__work_8c_source.html":[3,0,4,3,1733],
@@ -196,10 +196,8 @@ var NAVTREEINDEX27 =
 "d4/d10/lapacke__cpoequ__work_8c.html":[3,0,4,3,395],
 "d4/d10/lapacke__cpoequ__work_8c_ab5222ba15ee202a2443ba3c41390170e.html#ab5222ba15ee202a2443ba3c41390170e":[3,0,4,3,395,0],
 "d4/d10/lapacke__cpoequ__work_8c_source.html":[3,0,4,3,395],
-"d4/d10/scombssq_8f.html":[3,0,5,1026],
-"d4/d10/scombssq_8f_source.html":[3,0,5,1026],
-"d4/d11/dgeql2_8f.html":[3,0,5,545],
-"d4/d11/dgeql2_8f_source.html":[3,0,5,545],
+"d4/d11/dgeql2_8f.html":[3,0,5,544],
+"d4/d11/dgeql2_8f_source.html":[3,0,5,544],
 "d4/d11/lapacke__ssygv__2stage_8c.html":[3,0,4,3,1705],
 "d4/d11/lapacke__ssygv__2stage_8c_ab0aa9a03e34145409e83940ad6caa5a5.html#ab0aa9a03e34145409e83940ad6caa5a5":[3,0,4,3,1705,0],
 "d4/d11/lapacke__ssygv__2stage_8c_source.html":[3,0,4,3,1705],
@@ -214,15 +212,15 @@ var NAVTREEINDEX27 =
 "d4/d14/cblas__cgbmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,4,7],
 "d4/d14/cblas__cgbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,4,6],
 "d4/d14/cblas__cgbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,4,4],
+"d4/d14/cblas__cgbmv_8c_aa415c835c1dc9637037d8b88c6066dce.html#aa415c835c1dc9637037d8b88c6066dce":[3,0,1,2,4,8],
 "d4/d14/cblas__cgbmv_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,4,5],
 "d4/d14/cblas__cgbmv_8c_ae807ea950f545d041c6bcc92187e1f10.html#ae807ea950f545d041c6bcc92187e1f10":[3,0,1,2,4,2],
-"d4/d14/cblas__cgbmv_8c_aed393aad80d0ee9d1d5740dff2ebc7cf.html#aed393aad80d0ee9d1d5740dff2ebc7cf":[3,0,1,2,4,8],
 "d4/d14/cblas__cgbmv_8c_source.html":[3,0,1,2,4],
 "d4/d15/lapacke__zsytrs__aa__work_8c.html":[3,0,4,3,2366],
 "d4/d15/lapacke__zsytrs__aa__work_8c_a841cf62a24665f2c436bcf89b6cbfb05.html#a841cf62a24665f2c436bcf89b6cbfb05":[3,0,4,3,2366,0],
 "d4/d15/lapacke__zsytrs__aa__work_8c_source.html":[3,0,4,3,2366],
-"d4/d17/dla__porcond_8f.html":[3,0,5,615],
-"d4/d17/dla__porcond_8f_source.html":[3,0,5,615],
+"d4/d17/dla__porcond_8f.html":[3,0,5,614],
+"d4/d17/dla__porcond_8f_source.html":[3,0,5,614],
 "d4/d18/lapacke__zungtr__work_8c.html":[3,0,4,3,2459],
 "d4/d18/lapacke__zungtr__work_8c_a9b250a4a44209c04f37118ba8eac6a18.html#a9b250a4a44209c04f37118ba8eac6a18":[3,0,4,3,2459,0],
 "d4/d18/lapacke__zungtr__work_8c_source.html":[3,0,4,3,2459],
@@ -231,9 +229,9 @@ var NAVTREEINDEX27 =
 "d4/d19/cgemlq_8f_source.html":[3,0,5,39],
 "d4/d19/derrgex_8f.html":[3,0,6,1,273],
 "d4/d19/derrgex_8f_source.html":[3,0,6,1,273],
-"d4/d19/zgeqr_8f.html":[3,0,5,1568],
-"d4/d19/zgeqr_8f_a8ae88d8fdedeebfac10501b91406241b.html#a8ae88d8fdedeebfac10501b91406241b":[3,0,5,1568,0],
-"d4/d19/zgeqr_8f_source.html":[3,0,5,1568],
+"d4/d19/zgeqr_8f.html":[3,0,5,1566],
+"d4/d19/zgeqr_8f_a8ae88d8fdedeebfac10501b91406241b.html#a8ae88d8fdedeebfac10501b91406241b":[3,0,5,1566,0],
+"d4/d19/zgeqr_8f_source.html":[3,0,5,1566],
 "d4/d1b/cqrt11_8f.html":[3,0,6,1,172],
 "d4/d1b/cqrt11_8f_source.html":[3,0,6,1,172],
 "d4/d1b/lapacke__spocon__work_8c.html":[3,0,4,3,1547],
@@ -241,13 +239,15 @@ var NAVTREEINDEX27 =
 "d4/d1b/lapacke__spocon__work_8c_source.html":[3,0,4,3,1547],
 "d4/d1c/group__real_o_t_h_e_rsolve.html":[0,0,10,1],
 "d4/d1c/group__real_o_t_h_e_rsolve_ga173d044dadcc86da5e6f9e5c3dcee071.html#ga173d044dadcc86da5e6f9e5c3dcee071":[0,0,10,1,2],
-"d4/d1c/group__real_o_t_h_e_rsolve_ga173d044dadcc86da5e6f9e5c3dcee071.html#ga173d044dadcc86da5e6f9e5c3dcee071":[3,0,5,1343,0],
+"d4/d1c/group__real_o_t_h_e_rsolve_ga173d044dadcc86da5e6f9e5c3dcee071.html#ga173d044dadcc86da5e6f9e5c3dcee071":[3,0,5,1341,0],
 "d4/d1c/group__real_o_t_h_e_rsolve_ga52467870da59d888cefe37e1ca7960ed.html#ga52467870da59d888cefe37e1ca7960ed":[0,0,10,1,6],
-"d4/d1c/group__real_o_t_h_e_rsolve_ga52467870da59d888cefe37e1ca7960ed.html#ga52467870da59d888cefe37e1ca7960ed":[3,0,5,1405,0],
+"d4/d1c/group__real_o_t_h_e_rsolve_ga52467870da59d888cefe37e1ca7960ed.html#ga52467870da59d888cefe37e1ca7960ed":[3,0,5,1403,0],
 "d4/d1c/group__real_o_t_h_e_rsolve_ga5fedaae909ff6e16c917dcc5f19cb002.html#ga5fedaae909ff6e16c917dcc5f19cb002":[0,0,10,1,4],
-"d4/d1c/group__real_o_t_h_e_rsolve_ga5fedaae909ff6e16c917dcc5f19cb002.html#ga5fedaae909ff6e16c917dcc5f19cb002":[3,0,5,1367,0],
+"d4/d1c/group__real_o_t_h_e_rsolve_ga5fedaae909ff6e16c917dcc5f19cb002.html#ga5fedaae909ff6e16c917dcc5f19cb002":[3,0,5,1365,0],
 "d4/d1c/group__real_o_t_h_e_rsolve_ga63a2105abbfdbf4038e716059086d738.html#ga63a2105abbfdbf4038e716059086d738":[0,0,10,1,0],
-"d4/d1c/group__real_o_t_h_e_rsolve_ga63a2105abbfdbf4038e716059086d738.html#ga63a2105abbfdbf4038e716059086d738":[3,0,5,1111,0],
+"d4/d1c/group__real_o_t_h_e_rsolve_ga63a2105abbfdbf4038e716059086d738.html#ga63a2105abbfdbf4038e716059086d738":[3,0,5,1109,0],
 "d4/d1c/group__real_o_t_h_e_rsolve_ga74e2b958a5929ec4c81c872cc9177ecb.html#ga74e2b958a5929ec4c81c872cc9177ecb":[0,0,10,1,5],
-"d4/d1c/group__real_o_t_h_e_rsolve_ga74e2b958a5929ec4c81c872cc9177ecb.html#ga74e2b958a5929ec4c81c872cc9177ecb":[3,0,5,1404,0]
+"d4/d1c/group__real_o_t_h_e_rsolve_ga74e2b958a5929ec4c81c872cc9177ecb.html#ga74e2b958a5929ec4c81c872cc9177ecb":[3,0,5,1402,0],
+"d4/d1c/group__real_o_t_h_e_rsolve_gaa4fd8a9b07bed6c621210e5cfa7fe514.html#gaa4fd8a9b07bed6c621210e5cfa7fe514":[0,0,10,1,1],
+"d4/d1c/group__real_o_t_h_e_rsolve_gaa4fd8a9b07bed6c621210e5cfa7fe514.html#gaa4fd8a9b07bed6c621210e5cfa7fe514":[3,0,5,1340,0]
 };
