@@ -1,20 +1,18 @@
 var NAVTREEINDEX29 =
 {
-"d4/d54/cblas__ctbmv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,25,2],
-"d4/d54/cblas__ctbmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,25,5],
 "d4/d54/cblas__ctbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,25,4],
 "d4/d54/cblas__ctbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,25,3],
 "d4/d54/cblas__ctbmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,25,6],
 "d4/d54/cblas__ctbmv_8c_source.html":[3,0,1,2,25],
 "d4/d54/derrls_8f.html":[3,0,6,1,278],
 "d4/d54/derrls_8f_source.html":[3,0,6,1,278],
-"d4/d54/zhecon_8f.html":[3,0,5,1634],
-"d4/d54/zhecon_8f_source.html":[3,0,5,1634],
+"d4/d54/zhecon_8f.html":[3,0,5,1632],
+"d4/d54/zhecon_8f_source.html":[3,0,5,1632],
 "d4/d55/lapacke__dgeesx__work_8c.html":[3,0,4,3,691],
 "d4/d55/lapacke__dgeesx__work_8c_a184096e12d87b2a738fd8577f0c6b885.html#a184096e12d87b2a738fd8577f0c6b885":[3,0,4,3,691,0],
 "d4/d55/lapacke__dgeesx__work_8c_source.html":[3,0,4,3,691],
-"d4/d56/dorbdb4_8f.html":[3,0,5,783],
-"d4/d56/dorbdb4_8f_source.html":[3,0,5,783],
+"d4/d56/dorbdb4_8f.html":[3,0,5,782],
+"d4/d56/dorbdb4_8f_source.html":[3,0,5,782],
 "d4/d57/lapacke__cunmql__work_8c.html":[3,0,4,3,631],
 "d4/d57/lapacke__cunmql__work_8c_ac986be36ac4ed543b4d1c2ad04c8238a.html#ac986be36ac4ed543b4d1c2ad04c8238a":[3,0,4,3,631,0],
 "d4/d57/lapacke__cunmql__work_8c_source.html":[3,0,4,3,631],
@@ -27,10 +25,10 @@ var NAVTREEINDEX29 =
 "d4/d59/lapacke__ssytri__work_8c.html":[3,0,4,3,1751],
 "d4/d59/lapacke__ssytri__work_8c_a9f0e9adefbf5e0270a204176765cab9e.html#a9f0e9adefbf5e0270a204176765cab9e":[3,0,4,3,1751,0],
 "d4/d59/lapacke__ssytri__work_8c_source.html":[3,0,4,3,1751],
-"d4/d59/zsysv_8f.html":[3,0,5,1912],
-"d4/d59/zsysv_8f_source.html":[3,0,5,1912],
-"d4/d5a/dlaev2_8f.html":[3,0,5,643],
-"d4/d5a/dlaev2_8f_source.html":[3,0,5,643],
+"d4/d59/zsysv_8f.html":[3,0,5,1910],
+"d4/d59/zsysv_8f_source.html":[3,0,5,1910],
+"d4/d5a/dlaev2_8f.html":[3,0,5,642],
+"d4/d5a/dlaev2_8f_source.html":[3,0,5,642],
 "d4/d5a/lapacke__sspev_8c.html":[3,0,4,3,1628],
 "d4/d5a/lapacke__sspev_8c_aa2e2576a2cc5dce1c8933ad5db2f2e5b.html#aa2e2576a2cc5dce1c8933ad5db2f2e5b":[3,0,4,3,1628,0],
 "d4/d5a/lapacke__sspev_8c_source.html":[3,0,4,3,1628],
@@ -57,26 +55,26 @@ var NAVTREEINDEX29 =
 "d4/d5d/lapacke__zsyequb__work_8c.html":[3,0,4,3,2317],
 "d4/d5d/lapacke__zsyequb__work_8c_aa2dc8e2155766319c726141a940923b6.html#aa2dc8e2155766319c726141a940923b6":[3,0,4,3,2317,0],
 "d4/d5d/lapacke__zsyequb__work_8c_source.html":[3,0,4,3,2317],
-"d4/d5d/zungql_8f.html":[3,0,5,1997],
-"d4/d5d/zungql_8f_source.html":[3,0,5,1997],
+"d4/d5d/zungql_8f.html":[3,0,5,1995],
+"d4/d5d/zungql_8f_source.html":[3,0,5,1995],
 "d4/d5e/ctprfb_8f.html":[3,0,5,441],
 "d4/d5e/ctprfb_8f_source.html":[3,0,5,441],
-"d4/d5e/dlarz_8f.html":[3,0,5,731],
-"d4/d5e/dlarz_8f_source.html":[3,0,5,731],
+"d4/d5e/dlarz_8f.html":[3,0,5,730],
+"d4/d5e/dlarz_8f_source.html":[3,0,5,730],
 "d4/d60/cdrvgt_8f.html":[3,0,6,1,49],
 "d4/d60/cdrvgt_8f_source.html":[3,0,6,1,49],
 "d4/d61/chetrd_8f.html":[3,0,5,144],
 "d4/d61/chetrd_8f_source.html":[3,0,5,144],
 "d4/d61/derrtsqr_8f.html":[3,0,6,1,293],
 "d4/d61/derrtsqr_8f_source.html":[3,0,6,1,293],
-"d4/d61/dsfrk_8f.html":[3,0,5,872],
-"d4/d61/dsfrk_8f_source.html":[3,0,5,872],
-"d4/d61/dtprfb_8f.html":[3,0,5,979],
-"d4/d61/dtprfb_8f_source.html":[3,0,5,979],
+"d4/d61/dsfrk_8f.html":[3,0,5,871],
+"d4/d61/dsfrk_8f_source.html":[3,0,5,871],
+"d4/d61/dtprfb_8f.html":[3,0,5,978],
+"d4/d61/dtprfb_8f_source.html":[3,0,5,978],
 "d4/d62/group__double_g_tsolve.html":[0,0,5,0,0],
-"d4/d62/group__double_g_tsolve_ga2bf93f2ddefa5e671866eb2191dc19d4.html#ga2bf93f2ddefa5e671866eb2191dc19d4":[3,0,5,597,0],
+"d4/d62/group__double_g_tsolve_ga2bf93f2ddefa5e671866eb2191dc19d4.html#ga2bf93f2ddefa5e671866eb2191dc19d4":[3,0,5,596,0],
 "d4/d62/group__double_g_tsolve_ga2bf93f2ddefa5e671866eb2191dc19d4.html#ga2bf93f2ddefa5e671866eb2191dc19d4":[0,0,5,0,0,0],
-"d4/d62/group__double_g_tsolve_gaa9e938f737eedf395c4429393c769d07.html#gaa9e938f737eedf395c4429393c769d07":[3,0,5,598,0],
+"d4/d62/group__double_g_tsolve_gaa9e938f737eedf395c4429393c769d07.html#gaa9e938f737eedf395c4429393c769d07":[3,0,5,597,0],
 "d4/d62/group__double_g_tsolve_gaa9e938f737eedf395c4429393c769d07.html#gaa9e938f737eedf395c4429393c769d07":[0,0,5,0,0,1],
 "d4/d64/derrbd_8f.html":[3,0,6,0,126],
 "d4/d64/derrbd_8f_source.html":[3,0,6,0,126],
@@ -86,8 +84,8 @@ var NAVTREEINDEX29 =
 "d4/d65/cchkge_8f_source.html":[3,0,6,1,10],
 "d4/d65/clabrd_8f.html":[3,0,5,211],
 "d4/d65/clabrd_8f_source.html":[3,0,5,211],
-"d4/d66/dlaqp2_8f.html":[3,0,5,686],
-"d4/d66/dlaqp2_8f_source.html":[3,0,5,686],
+"d4/d66/dlaqp2_8f.html":[3,0,5,685],
+"d4/d66/dlaqp2_8f_source.html":[3,0,5,685],
 "d4/d66/lapacke__dptcon__work_8c.html":[3,0,4,3,991],
 "d4/d66/lapacke__dptcon__work_8c_af0145e5d459ac3ce7da2e1e441a0600d.html#af0145e5d459ac3ce7da2e1e441a0600d":[3,0,4,3,991,0],
 "d4/d66/lapacke__dptcon__work_8c_source.html":[3,0,4,3,991],
@@ -182,8 +180,8 @@ var NAVTREEINDEX29 =
 "d4/d6e/lapacke__sorgql_8c.html":[3,0,4,3,1498],
 "d4/d6e/lapacke__sorgql_8c_a3f150b8d6576f8cc17c2c3e2351ed485.html#a3f150b8d6576f8cc17c2c3e2351ed485":[3,0,4,3,1498,0],
 "d4/d6e/lapacke__sorgql_8c_source.html":[3,0,4,3,1498],
-"d4/d6f/dlasda_8f.html":[3,0,5,746],
-"d4/d6f/dlasda_8f_source.html":[3,0,5,746],
+"d4/d6f/dlasda_8f.html":[3,0,5,745],
+"d4/d6f/dlasda_8f_source.html":[3,0,5,745],
 "d4/d6f/dznrm2sub_8f.html":[3,0,1,2,151],
 "d4/d6f/dznrm2sub_8f_ad89b451c8a37a979908df17c3f6813bd.html#ad89b451c8a37a979908df17c3f6813bd":[3,0,1,2,151,0],
 "d4/d6f/dznrm2sub_8f_source.html":[3,0,1,2,151],
@@ -195,8 +193,8 @@ var NAVTREEINDEX29 =
 "d4/d71/lapacke__ztbrfs__work_8c.html":[3,0,4,3,2373],
 "d4/d71/lapacke__ztbrfs__work_8c_afa76cd94ae39796a6a6696ebab4fb93b.html#afa76cd94ae39796a6a6696ebab4fb93b":[3,0,4,3,2373,0],
 "d4/d71/lapacke__ztbrfs__work_8c_source.html":[3,0,4,3,2373],
-"d4/d71/zptsvx_8f.html":[3,0,5,1882],
-"d4/d71/zptsvx_8f_source.html":[3,0,5,1882],
+"d4/d71/zptsvx_8f.html":[3,0,5,1880],
+"d4/d71/zptsvx_8f_source.html":[3,0,5,1880],
 "d4/d73/alarqg_8f.html":[3,0,6,0,2],
 "d4/d73/alarqg_8f_source.html":[3,0,6,0,2],
 "d4/d73/lapacke__chptri_8c.html":[3,0,4,3,308],
@@ -249,5 +247,7 @@ var NAVTREEINDEX29 =
 "d4/d74/group__complex_h_ecomputational_gaa85276957e3e3dab2ae5104154384058.html#gaa85276957e3e3dab2ae5104154384058":[0,0,3,2,0,10],
 "d4/d74/group__complex_h_ecomputational_gaaa17e6b0561b20ce0353882d8964504c.html#gaaa17e6b0561b20ce0353882d8964504c":[3,0,5,160,0],
 "d4/d74/group__complex_h_ecomputational_gaaa17e6b0561b20ce0353882d8964504c.html#gaaa17e6b0561b20ce0353882d8964504c":[0,0,3,2,0,26],
-"d4/d74/group__complex_h_ecomputational_gab6ea0f6ab45a0d149570a866395a7cf1.html#gab6ea0f6ab45a0d149570a866395a7cf1":[3,0,5,231,0]
+"d4/d74/group__complex_h_ecomputational_gab6ea0f6ab45a0d149570a866395a7cf1.html#gab6ea0f6ab45a0d149570a866395a7cf1":[3,0,5,231,0],
+"d4/d74/group__complex_h_ecomputational_gab6ea0f6ab45a0d149570a866395a7cf1.html#gab6ea0f6ab45a0d149570a866395a7cf1":[0,0,3,2,0,36],
+"d4/d74/group__complex_h_ecomputational_gac8f382f5d0a3af27d8319c82cae7cbba.html#gac8f382f5d0a3af27d8319c82cae7cbba":[3,0,5,197,0]
 };
