@@ -1,7 +1,5 @@
 var NAVTREEINDEX30 =
 {
-"d4/d74/group__complex_h_ecomputational_gab6ea0f6ab45a0d149570a866395a7cf1.html#gab6ea0f6ab45a0d149570a866395a7cf1":[0,0,3,2,0,36],
-"d4/d74/group__complex_h_ecomputational_gac8f382f5d0a3af27d8319c82cae7cbba.html#gac8f382f5d0a3af27d8319c82cae7cbba":[3,0,5,197,0],
 "d4/d74/group__complex_h_ecomputational_gac8f382f5d0a3af27d8319c82cae7cbba.html#gac8f382f5d0a3af27d8319c82cae7cbba":[0,0,3,2,0,32],
 "d4/d74/group__complex_h_ecomputational_gacd355008da68592db4c2743fcea983cf.html#gacd355008da68592db4c2743fcea983cf":[3,0,5,198,0],
 "d4/d74/group__complex_h_ecomputational_gacd355008da68592db4c2743fcea983cf.html#gacd355008da68592db4c2743fcea983cf":[0,0,3,2,0,33],
@@ -34,8 +32,8 @@ var NAVTREEINDEX30 =
 "d4/d74/lapacke__zppsvx_8c.html":[3,0,4,3,2262],
 "d4/d74/lapacke__zppsvx_8c_af4f59af9a6a45715f656eef2cd7febc1.html#af4f59af9a6a45715f656eef2cd7febc1":[3,0,4,3,2262,0],
 "d4/d74/lapacke__zppsvx_8c_source.html":[3,0,4,3,2262],
-"d4/d76/dlaqr2_8f.html":[3,0,5,690],
-"d4/d76/dlaqr2_8f_source.html":[3,0,5,690],
+"d4/d76/dlaqr2_8f.html":[3,0,5,689],
+"d4/d76/dlaqr2_8f_source.html":[3,0,5,689],
 "d4/d76/lapacke__stpmqrt_8c.html":[3,0,4,3,1792],
 "d4/d76/lapacke__stpmqrt_8c_a54905744f7493f217d0c089370333bc7.html#a54905744f7493f217d0c089370333bc7":[3,0,4,3,1792,0],
 "d4/d76/lapacke__stpmqrt_8c_source.html":[3,0,4,3,1792],
@@ -45,15 +43,15 @@ var NAVTREEINDEX30 =
 "d4/d78/derrpox_8f_source.html":[3,0,6,1,281],
 "d4/d7a/clacpy_8f.html":[3,0,5,216],
 "d4/d7a/clacpy_8f_source.html":[3,0,5,216],
-"d4/d7a/dspcon_8f.html":[3,0,5,874],
-"d4/d7a/dspcon_8f_source.html":[3,0,5,874],
+"d4/d7a/dspcon_8f.html":[3,0,5,873],
+"d4/d7a/dspcon_8f_source.html":[3,0,5,873],
 "d4/d7a/group__eigen_g_e.html":[0,0,0,1],
 "d4/d7a/lapacke__zgesvdx__work_8c.html":[3,0,4,3,1943],
 "d4/d7a/lapacke__zgesvdx__work_8c_a9e912a909a49a53c7cd43b11a61c5cf3.html#a9e912a909a49a53c7cd43b11a61c5cf3":[3,0,4,3,1943,0],
 "d4/d7a/lapacke__zgesvdx__work_8c_source.html":[3,0,4,3,1943],
-"d4/d7a/ssytf2__rk_8f.html":[3,0,5,1454],
-"d4/d7a/ssytf2__rk_8f_a164970f4d77d668dbd51739a900acdda.html#a164970f4d77d668dbd51739a900acdda":[3,0,5,1454,0],
-"d4/d7a/ssytf2__rk_8f_source.html":[3,0,5,1454],
+"d4/d7a/ssytf2__rk_8f.html":[3,0,5,1452],
+"d4/d7a/ssytf2__rk_8f_a164970f4d77d668dbd51739a900acdda.html#a164970f4d77d668dbd51739a900acdda":[3,0,5,1452,0],
+"d4/d7a/ssytf2__rk_8f_source.html":[3,0,5,1452],
 "d4/d7b/lapacke__cheswapr__work_8c.html":[3,0,4,3,245],
 "d4/d7b/lapacke__cheswapr__work_8c_ac0e8b2363461bd79e3a398135d39e776.html#ac0e8b2363461bd79e3a398135d39e776":[3,0,4,3,245,0],
 "d4/d7b/lapacke__cheswapr__work_8c_source.html":[3,0,4,3,245],
@@ -65,10 +63,10 @@ var NAVTREEINDEX30 =
 "d4/d7c/lapacke__cgges3__work_8c.html":[3,0,4,3,132],
 "d4/d7c/lapacke__cgges3__work_8c_af71ee1cdee4a37eafe8b415df5fcbb62.html#af71ee1cdee4a37eafe8b415df5fcbb62":[3,0,4,3,132,0],
 "d4/d7c/lapacke__cgges3__work_8c_source.html":[3,0,4,3,132],
-"d4/d7d/strsyl_8f.html":[3,0,5,1512],
-"d4/d7d/strsyl_8f_source.html":[3,0,5,1512],
-"d4/d7d/zhegv__2stage_8f.html":[3,0,5,1649],
-"d4/d7d/zhegv__2stage_8f_source.html":[3,0,5,1649],
+"d4/d7d/strsyl_8f.html":[3,0,5,1510],
+"d4/d7d/strsyl_8f_source.html":[3,0,5,1510],
+"d4/d7d/zhegv__2stage_8f.html":[3,0,5,1647],
+"d4/d7d/zhegv__2stage_8f_source.html":[3,0,5,1647],
 "d4/d7e/group__complex_g_ecomputational.html":[0,0,0,3,2],
 "d4/d7e/group__complex_g_ecomputational_ga085bbc018c80dcb9db6bac7f1edb0d5e.html#ga085bbc018c80dcb9db6bac7f1edb0d5e":[3,0,5,44,0],
 "d4/d7e/group__complex_g_ecomputational_ga085bbc018c80dcb9db6bac7f1edb0d5e.html#ga085bbc018c80dcb9db6bac7f1edb0d5e":[0,0,0,3,2,13],
@@ -86,8 +84,8 @@ var NAVTREEINDEX30 =
 "d4/d7e/group__complex_g_ecomputational_ga2c07ec6e7b75b527987e381674bdd68b.html#ga2c07ec6e7b75b527987e381674bdd68b":[3,0,5,166,0],
 "d4/d7e/group__complex_g_ecomputational_ga2f7b64261525b754c678b722eb0e8785.html#ga2f7b64261525b754c678b722eb0e8785":[3,0,5,42,0],
 "d4/d7e/group__complex_g_ecomputational_ga2f7b64261525b754c678b722eb0e8785.html#ga2f7b64261525b754c678b722eb0e8785":[0,0,0,3,2,11],
-"d4/d7e/group__complex_g_ecomputational_ga3066386c9875ffe61cb0f8299012360a.html#ga3066386c9875ffe61cb0f8299012360a":[3,0,5,18,0],
 "d4/d7e/group__complex_g_ecomputational_ga3066386c9875ffe61cb0f8299012360a.html#ga3066386c9875ffe61cb0f8299012360a":[0,0,0,3,2,2],
+"d4/d7e/group__complex_g_ecomputational_ga3066386c9875ffe61cb0f8299012360a.html#ga3066386c9875ffe61cb0f8299012360a":[3,0,5,18,0],
 "d4/d7e/group__complex_g_ecomputational_ga30ebdf9137986a237c939500cbd46a41.html#ga30ebdf9137986a237c939500cbd46a41":[0,0,0,3,2,38],
 "d4/d7e/group__complex_g_ecomputational_ga30ebdf9137986a237c939500cbd46a41.html#ga30ebdf9137986a237c939500cbd46a41":[3,0,5,194,0],
 "d4/d7e/group__complex_g_ecomputational_ga333680795e2818318a1c6f6d1a503722.html#ga333680795e2818318a1c6f6d1a503722":[0,0,0,3,2,18],
@@ -167,8 +165,8 @@ var NAVTREEINDEX30 =
 "d4/d7e/lapacke__ssytrf__rk__work_8c.html":[3,0,4,3,1740],
 "d4/d7e/lapacke__ssytrf__rk__work_8c_ac7599adcbe47acf28835777f5bd4f32b.html#ac7599adcbe47acf28835777f5bd4f32b":[3,0,4,3,1740,0],
 "d4/d7e/lapacke__ssytrf__rk__work_8c_source.html":[3,0,4,3,1740],
-"d4/d7e/stprfb_8f.html":[3,0,5,1499],
-"d4/d7e/stprfb_8f_source.html":[3,0,5,1499],
+"d4/d7e/stprfb_8f.html":[3,0,5,1497],
+"d4/d7e/stprfb_8f_source.html":[3,0,5,1497],
 "d4/d7f/lapacke__cgbsvx__work_8c.html":[3,0,4,3,19],
 "d4/d7f/lapacke__cgbsvx__work_8c_afa0158a55e2306ca9dc81673349abdfa.html#afa0158a55e2306ca9dc81673349abdfa":[3,0,4,3,19,0],
 "d4/d7f/lapacke__cgbsvx__work_8c_source.html":[3,0,4,3,19],
@@ -249,5 +247,7 @@ var NAVTREEINDEX30 =
 "d4/d8a/group__complex_g_eeigen_ga791495feb4709cb91cf39a996a5e3f5a.html#ga791495feb4709cb91cf39a996a5e3f5a":[0,0,0,1,2,9],
 "d4/d8a/group__complex_g_eeigen_gad4e74f32b6e12e11517fc3884ffcc87d.html#gad4e74f32b6e12e11517fc3884ffcc87d":[3,0,5,79,0],
 "d4/d8a/group__complex_g_eeigen_gad4e74f32b6e12e11517fc3884ffcc87d.html#gad4e74f32b6e12e11517fc3884ffcc87d":[0,0,0,1,2,8],
-"d4/d8a/group__complex_g_eeigen_gad681a6edd407ef1e9ac9b6ee92ddbee3.html#gad681a6edd407ef1e9ac9b6ee92ddbee3":[3,0,5,82,0]
+"d4/d8a/group__complex_g_eeigen_gad681a6edd407ef1e9ac9b6ee92ddbee3.html#gad681a6edd407ef1e9ac9b6ee92ddbee3":[3,0,5,82,0],
+"d4/d8a/group__complex_g_eeigen_gad681a6edd407ef1e9ac9b6ee92ddbee3.html#gad681a6edd407ef1e9ac9b6ee92ddbee3":[0,0,0,1,2,11],
+"d4/d8a/group__complex_g_eeigen_gaead5d7a4df1e51d7f25d9540acc596e8.html#gaead5d7a4df1e51d7f25d9540acc596e8":[0,0,0,1,2,6]
 };
