@@ -1,12 +1,10 @@
 var NAVTREEINDEX32 =
 {
-"d4/db0/group__complex_o_t_h_e_rauxiliary_ga5faaf840490fa40a3a1e7e359d7fc216.html#ga5faaf840490fa40a3a1e7e359d7fc216":[3,0,5,288,0],
-"d4/db0/group__complex_o_t_h_e_rauxiliary_ga625578c63463d61350ee393cd3f9aeb6.html#ga625578c63463d61350ee393cd3f9aeb6":[0,0,8,2,46],
 "d4/db0/group__complex_o_t_h_e_rauxiliary_ga625578c63463d61350ee393cd3f9aeb6.html#ga625578c63463d61350ee393cd3f9aeb6":[3,0,5,283,0],
 "d4/db0/group__complex_o_t_h_e_rauxiliary_ga638b33f81ef91f4e3118a603807a5b32.html#ga638b33f81ef91f4e3118a603807a5b32":[0,0,8,2,10],
 "d4/db0/group__complex_o_t_h_e_rauxiliary_ga638b33f81ef91f4e3118a603807a5b32.html#ga638b33f81ef91f4e3118a603807a5b32":[3,0,5,225,0],
 "d4/db0/group__complex_o_t_h_e_rauxiliary_ga67758579a15100f1de380434f115a8e6.html#ga67758579a15100f1de380434f115a8e6":[0,0,8,2,77],
-"d4/db0/group__complex_o_t_h_e_rauxiliary_ga67758579a15100f1de380434f115a8e6.html#ga67758579a15100f1de380434f115a8e6":[3,0,5,1027,0],
+"d4/db0/group__complex_o_t_h_e_rauxiliary_ga67758579a15100f1de380434f115a8e6.html#ga67758579a15100f1de380434f115a8e6":[3,0,5,1025,0],
 "d4/db0/group__complex_o_t_h_e_rauxiliary_ga67f731c460d0fe02f7436fd76456671f.html#ga67f731c460d0fe02f7436fd76456671f":[0,0,8,2,17],
 "d4/db0/group__complex_o_t_h_e_rauxiliary_ga67f731c460d0fe02f7436fd76456671f.html#ga67f731c460d0fe02f7436fd76456671f":[3,0,5,243,0],
 "d4/db0/group__complex_o_t_h_e_rauxiliary_ga68a1ee847b10379867e914776e69e6de.html#ga68a1ee847b10379867e914776e69e6de":[0,0,8,2,53],
@@ -105,23 +103,23 @@ var NAVTREEINDEX32 =
 "d4/db0/lapacke__zlacn2__work_8c_source.html":[3,0,4,3,2157],
 "d4/db1/group__complex16_o_t_h_e_rsolve.html":[0,0,10,3],
 "d4/db1/group__complex16_o_t_h_e_rsolve_ga1eea80871f54b76db1b3af3a7ffd10fe.html#ga1eea80871f54b76db1b3af3a7ffd10fe":[0,0,10,3,4],
-"d4/db1/group__complex16_o_t_h_e_rsolve_ga1eea80871f54b76db1b3af3a7ffd10fe.html#ga1eea80871f54b76db1b3af3a7ffd10fe":[3,0,5,1848,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_ga1eea80871f54b76db1b3af3a7ffd10fe.html#ga1eea80871f54b76db1b3af3a7ffd10fe":[3,0,5,1846,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_ga403939a806cab9a6abae753b53ced33a.html#ga403939a806cab9a6abae753b53ced33a":[0,0,10,3,2],
-"d4/db1/group__complex16_o_t_h_e_rsolve_ga403939a806cab9a6abae753b53ced33a.html#ga403939a806cab9a6abae753b53ced33a":[3,0,5,1699,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_ga403939a806cab9a6abae753b53ced33a.html#ga403939a806cab9a6abae753b53ced33a":[3,0,5,1697,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_ga4267eb359aed7b9acf2b2613a7d9c66b.html#ga4267eb359aed7b9acf2b2613a7d9c66b":[0,0,10,3,8],
-"d4/db1/group__complex16_o_t_h_e_rsolve_ga4267eb359aed7b9acf2b2613a7d9c66b.html#ga4267eb359aed7b9acf2b2613a7d9c66b":[3,0,5,1892,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_ga4267eb359aed7b9acf2b2613a7d9c66b.html#ga4267eb359aed7b9acf2b2613a7d9c66b":[3,0,5,1890,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_ga4ebc9dd6e20aa11de94856e55d090ea2.html#ga4ebc9dd6e20aa11de94856e55d090ea2":[0,0,10,3,5],
-"d4/db1/group__complex16_o_t_h_e_rsolve_ga4ebc9dd6e20aa11de94856e55d090ea2.html#ga4ebc9dd6e20aa11de94856e55d090ea2":[3,0,5,1871,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_ga4ebc9dd6e20aa11de94856e55d090ea2.html#ga4ebc9dd6e20aa11de94856e55d090ea2":[3,0,5,1869,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_ga68024ddaa87dd52db7298afb9ba39492.html#ga68024ddaa87dd52db7298afb9ba39492":[0,0,10,3,0],
-"d4/db1/group__complex16_o_t_h_e_rsolve_ga68024ddaa87dd52db7298afb9ba39492.html#ga68024ddaa87dd52db7298afb9ba39492":[3,0,5,1608,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_ga68024ddaa87dd52db7298afb9ba39492.html#ga68024ddaa87dd52db7298afb9ba39492":[3,0,5,1606,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_ga73571ec97d7504db0bdcfe55243a7ce0.html#ga73571ec97d7504db0bdcfe55243a7ce0":[0,0,10,3,3],
-"d4/db1/group__complex16_o_t_h_e_rsolve_ga73571ec97d7504db0bdcfe55243a7ce0.html#ga73571ec97d7504db0bdcfe55243a7ce0":[3,0,5,1847,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_ga73571ec97d7504db0bdcfe55243a7ce0.html#ga73571ec97d7504db0bdcfe55243a7ce0":[3,0,5,1845,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_gac81582608790763de73f95699c765467.html#gac81582608790763de73f95699c765467":[0,0,10,3,7],
-"d4/db1/group__complex16_o_t_h_e_rsolve_gac81582608790763de73f95699c765467.html#gac81582608790763de73f95699c765467":[3,0,5,1891,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_gac81582608790763de73f95699c765467.html#gac81582608790763de73f95699c765467":[3,0,5,1889,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_gad4d497220a3966ba4c62c981df049b94.html#gad4d497220a3966ba4c62c981df049b94":[0,0,10,3,6],
-"d4/db1/group__complex16_o_t_h_e_rsolve_gad4d497220a3966ba4c62c981df049b94.html#gad4d497220a3966ba4c62c981df049b94":[3,0,5,1872,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_gad4d497220a3966ba4c62c981df049b94.html#gad4d497220a3966ba4c62c981df049b94":[3,0,5,1870,0],
 "d4/db1/group__complex16_o_t_h_e_rsolve_gaf72096024c278ba5b4e5d7f20841f0c5.html#gaf72096024c278ba5b4e5d7f20841f0c5":[0,0,10,3,1],
-"d4/db1/group__complex16_o_t_h_e_rsolve_gaf72096024c278ba5b4e5d7f20841f0c5.html#gaf72096024c278ba5b4e5d7f20841f0c5":[3,0,5,1698,0],
+"d4/db1/group__complex16_o_t_h_e_rsolve_gaf72096024c278ba5b4e5d7f20841f0c5.html#gaf72096024c278ba5b4e5d7f20841f0c5":[3,0,5,1696,0],
 "d4/db1/lapacke__dsbevx__work_8c.html":[3,0,4,3,1015],
 "d4/db1/lapacke__dsbevx__work_8c_a8c3e2e7e39533c6c8dccc1404645b68b.html#a8c3e2e7e39533c6c8dccc1404645b68b":[3,0,4,3,1015,0],
 "d4/db1/lapacke__dsbevx__work_8c_source.html":[3,0,4,3,1015],
@@ -131,8 +129,8 @@ var NAVTREEINDEX32 =
 "d4/db3/dqlt03_8f_source.html":[3,0,6,1,352],
 "d4/db3/sdrges_8f.html":[3,0,6,0,207],
 "d4/db3/sdrges_8f_source.html":[3,0,6,0,207],
-"d4/db3/slasdt_8f.html":[3,0,5,1271],
-"d4/db3/slasdt_8f_source.html":[3,0,5,1271],
+"d4/db3/slasdt_8f.html":[3,0,5,1269],
+"d4/db3/slasdt_8f_source.html":[3,0,5,1269],
 "d4/db4/lapacke__cppcon__work_8c.html":[3,0,4,3,417],
 "d4/db4/lapacke__cppcon__work_8c_a97881a169d5744bb0aab0312d85740c3.html#a97881a169d5744bb0aab0312d85740c3":[3,0,4,3,417,0],
 "d4/db4/lapacke__cppcon__work_8c_source.html":[3,0,4,3,417],
@@ -152,8 +150,8 @@ var NAVTREEINDEX32 =
 "d4/db7/lapacke__zposvx__work_8c.html":[3,0,4,3,2243],
 "d4/db7/lapacke__zposvx__work_8c_ab85105143030574add84a2a4a5440df0.html#ab85105143030574add84a2a4a5440df0":[3,0,4,3,2243,0],
 "d4/db7/lapacke__zposvx__work_8c_source.html":[3,0,4,3,2243],
-"d4/db8/dla__gbamv_8f.html":[3,0,5,606],
-"d4/db8/dla__gbamv_8f_source.html":[3,0,5,606],
+"d4/db8/dla__gbamv_8f.html":[3,0,5,605],
+"d4/db8/dla__gbamv_8f_source.html":[3,0,5,605],
 "d4/db8/lapacke__ssysv__work_8c.html":[3,0,4,3,1725],
 "d4/db8/lapacke__ssysv__work_8c_a755e18a97034e6a846ac64b007b20dc0.html#a755e18a97034e6a846ac64b007b20dc0":[3,0,4,3,1725,0],
 "d4/db8/lapacke__ssysv__work_8c_source.html":[3,0,4,3,1725],
@@ -162,8 +160,8 @@ var NAVTREEINDEX32 =
 "d4/db9/lapacke__zpbsv_8c.html":[3,0,4,3,2216],
 "d4/db9/lapacke__zpbsv_8c_a0e143e46a51ddcde53e81c92414eabe2.html#a0e143e46a51ddcde53e81c92414eabe2":[3,0,4,3,2216,0],
 "d4/db9/lapacke__zpbsv_8c_source.html":[3,0,4,3,2216],
-"d4/db9/sporfsx_8f.html":[3,0,5,1354],
-"d4/db9/sporfsx_8f_source.html":[3,0,5,1354],
+"d4/db9/sporfsx_8f.html":[3,0,5,1352],
+"d4/db9/sporfsx_8f_source.html":[3,0,5,1352],
 "d4/dba/chegvx_8f.html":[3,0,5,129],
 "d4/dba/chegvx_8f_source.html":[3,0,5,129],
 "d4/dba/chet22_8f.html":[3,0,6,0,69],
@@ -197,10 +195,10 @@ var NAVTREEINDEX32 =
 "d4/dbe/lapacke__sgeesx_8c_source.html":[3,0,4,3,1288],
 "d4/dbf/dsyt21_8f.html":[3,0,6,0,179],
 "d4/dbf/dsyt21_8f_source.html":[3,0,6,0,179],
-"d4/dbf/zgetf2_8f.html":[3,0,5,1590],
-"d4/dbf/zgetf2_8f_source.html":[3,0,5,1590],
-"d4/dc0/sorgbr_8f.html":[3,0,5,1312],
-"d4/dc0/sorgbr_8f_source.html":[3,0,5,1312],
+"d4/dbf/zgetf2_8f.html":[3,0,5,1588],
+"d4/dbf/zgetf2_8f_source.html":[3,0,5,1588],
+"d4/dc0/sorgbr_8f.html":[3,0,5,1310],
+"d4/dc0/sorgbr_8f_source.html":[3,0,5,1310],
 "d4/dc1/chesv__aa_8f.html":[3,0,5,133],
 "d4/dc1/chesv__aa_8f_source.html":[3,0,5,133],
 "d4/dc1/lapacke__dgebal__work_8c.html":[3,0,4,3,679],
@@ -208,9 +206,9 @@ var NAVTREEINDEX32 =
 "d4/dc1/lapacke__dgebal__work_8c_source.html":[3,0,4,3,679],
 "d4/dc2/cblas__zhpr_8c.html":[3,0,1,2,129],
 "d4/dc2/cblas__zhpr_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,129,0],
-"d4/dc2/cblas__zhpr_8c_a75705d01514b1823aa488bb4ae5174e1.html#a75705d01514b1823aa488bb4ae5174e1":[3,0,1,2,129,3],
 "d4/dc2/cblas__zhpr_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,129,1],
 "d4/dc2/cblas__zhpr_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,129,2],
+"d4/dc2/cblas__zhpr_8c_aa82cce55bffcab6cfd46f8eb8ba1efb7.html#aa82cce55bffcab6cfd46f8eb8ba1efb7":[3,0,1,2,129,3],
 "d4/dc2/cblas__zhpr_8c_source.html":[3,0,1,2,129],
 "d4/dc2/lapacke__zgerfsx__work_8c.html":[3,0,4,3,1931],
 "d4/dc2/lapacke__zgerfsx__work_8c_af53a0c4f60a28fe7b2fab670a1ed1404.html#af53a0c4f60a28fe7b2fab670a1ed1404":[3,0,4,3,1931,0],
@@ -239,15 +237,17 @@ var NAVTREEINDEX32 =
 "d4/dc6/lapacke__sgerfs__work_8c.html":[3,0,4,3,1339],
 "d4/dc6/lapacke__sgerfs__work_8c_a41c7bd503f2159a8c9ea80e96b598547.html#a41c7bd503f2159a8c9ea80e96b598547":[3,0,4,3,1339,0],
 "d4/dc6/lapacke__sgerfs__work_8c_source.html":[3,0,4,3,1339],
-"d4/dc6/lsametst_8f.html":[3,0,3,12],
-"d4/dc6/lsametst_8f_ac14a642d1c4ae2713896577ae288bb58.html#ac14a642d1c4ae2713896577ae288bb58":[3,0,3,12,0],
-"d4/dc6/lsametst_8f_source.html":[3,0,3,12],
+"d4/dc6/lsametst_8f.html":[3,0,3,13],
+"d4/dc6/lsametst_8f_ac14a642d1c4ae2713896577ae288bb58.html#ac14a642d1c4ae2713896577ae288bb58":[3,0,3,13,0],
+"d4/dc6/lsametst_8f_source.html":[3,0,3,13],
 "d4/dc7/cqrt14_8f.html":[3,0,6,1,175],
 "d4/dc7/cqrt14_8f_source.html":[3,0,6,1,175],
 "d4/dc7/zchksy__rook_8f.html":[3,0,6,1,604],
 "d4/dc7/zchksy__rook_8f_source.html":[3,0,6,1,604],
-"d4/dc7/zgbequb_8f.html":[3,0,5,1529],
-"d4/dc7/zgbequb_8f_source.html":[3,0,5,1529],
+"d4/dc7/zgbequb_8f.html":[3,0,5,1527],
+"d4/dc7/zgbequb_8f_source.html":[3,0,5,1527],
 "d4/dc8/cerrlqtp_8f.html":[3,0,6,1,83],
-"d4/dc8/cerrlqtp_8f_source.html":[3,0,6,1,83]
+"d4/dc8/cerrlqtp_8f_source.html":[3,0,6,1,83],
+"d4/dc8/ctrsv_8f.html":[3,0,0,0,34],
+"d4/dc8/ctrsv_8f_source.html":[3,0,0,0,34]
 };
