@@ -1,9 +1,7 @@
 var NAVTREEINDEX34 =
 {
-"d5/d04/cblas__stbsv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,103,2],
-"d5/d04/cblas__stbsv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,103,5],
-"d5/d04/cblas__stbsv_8c_a76920c06cd9f2be15c4578124ab38834.html#a76920c06cd9f2be15c4578124ab38834":[3,0,1,2,103,7],
 "d5/d04/cblas__stbsv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,103,4],
+"d5/d04/cblas__stbsv_8c_a8126daee2c3c538fcedb465939a7b2c5.html#a8126daee2c3c538fcedb465939a7b2c5":[3,0,1,2,103,7],
 "d5/d04/cblas__stbsv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,103,3],
 "d5/d04/cblas__stbsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,103,6],
 "d5/d04/cblas__stbsv_8c_source.html":[3,0,1,2,103],
@@ -15,10 +13,10 @@ var NAVTREEINDEX34 =
 "d5/d07/lapacke__cgecon__work_8c_source.html":[3,0,4,3,33],
 "d5/d07/sget36_8f.html":[3,0,6,0,238],
 "d5/d07/sget36_8f_source.html":[3,0,6,0,238],
-"d5/d07/slaed5_8f.html":[3,0,5,1159],
-"d5/d07/slaed5_8f_source.html":[3,0,5,1159],
-"d5/d07/sorglq_8f.html":[3,0,5,1315],
-"d5/d07/sorglq_8f_source.html":[3,0,5,1315],
+"d5/d07/slaed5_8f.html":[3,0,5,1157],
+"d5/d07/slaed5_8f_source.html":[3,0,5,1157],
+"d5/d07/sorglq_8f.html":[3,0,5,1313],
+"d5/d07/sorglq_8f_source.html":[3,0,5,1313],
 "d5/d08/clagge_8f.html":[3,0,6,2,0],
 "d5/d08/clagge_8f_source.html":[3,0,6,2,0],
 "d5/d09/cdrvrfp_8f.html":[3,0,6,1,67],
@@ -28,8 +26,8 @@ var NAVTREEINDEX34 =
 "d5/d09/lapacke__slamch_8c_source.html":[3,0,4,3,1438],
 "d5/d0a/cgeqls_8f.html":[3,0,6,1,108],
 "d5/d0a/cgeqls_8f_source.html":[3,0,6,1,108],
-"d5/d0a/dgeqr2_8f.html":[3,0,5,549],
-"d5/d0a/dgeqr2_8f_source.html":[3,0,5,549],
+"d5/d0a/dgeqr2_8f.html":[3,0,5,548],
+"d5/d0a/dgeqr2_8f_source.html":[3,0,5,548],
 "d5/d0a/lapacke__zgges3__work_8c.html":[3,0,4,3,1970],
 "d5/d0a/lapacke__zgges3__work_8c_a33b1d558244df8f98821c8a81b4499fa.html#a33b1d558244df8f98821c8a81b4499fa":[3,0,4,3,1970,0],
 "d5/d0a/lapacke__zgges3__work_8c_source.html":[3,0,4,3,1970],
@@ -44,10 +42,10 @@ var NAVTREEINDEX34 =
 "d5/d0d/lapacke__dptrfs__work_8c_source.html":[3,0,4,3,995],
 "d5/d0e/derred_8f.html":[3,0,6,0,128],
 "d5/d0e/derred_8f_source.html":[3,0,6,0,128],
-"d5/d0e/dggrqf_8f.html":[3,0,5,590],
-"d5/d0e/dggrqf_8f_source.html":[3,0,5,590],
-"d5/d0e/dtrevc3_8f.html":[3,0,5,987],
-"d5/d0e/dtrevc3_8f_source.html":[3,0,5,987],
+"d5/d0e/dggrqf_8f.html":[3,0,5,589],
+"d5/d0e/dggrqf_8f_source.html":[3,0,5,589],
+"d5/d0e/dtrevc3_8f.html":[3,0,5,986],
+"d5/d0e/dtrevc3_8f_source.html":[3,0,5,986],
 "d5/d10/zerrgex_8f.html":[3,0,6,1,647],
 "d5/d10/zerrgex_8f_source.html":[3,0,6,1,647],
 "d5/d11/lapacke__dorglq_8c.html":[3,0,4,3,898],
@@ -57,22 +55,22 @@ var NAVTREEINDEX34 =
 "d5/d13/lapacke__ctptrs__work_8c.html":[3,0,4,3,573],
 "d5/d13/lapacke__ctptrs__work_8c_a9e9dd25c37764046f18b3e9975764732.html#a9e9dd25c37764046f18b3e9975764732":[3,0,4,3,573,0],
 "d5/d13/lapacke__ctptrs__work_8c_source.html":[3,0,4,3,573],
-"d5/d13/zhetd2_8f.html":[3,0,5,1662],
-"d5/d13/zhetd2_8f_source.html":[3,0,5,1662],
+"d5/d13/zhetd2_8f.html":[3,0,5,1660],
+"d5/d13/zhetd2_8f_source.html":[3,0,5,1660],
 "d5/d14/zdrvsy__aa__2stage_8f.html":[3,0,6,1,639],
 "d5/d14/zdrvsy__aa__2stage_8f_source.html":[3,0,6,1,639],
 "d5/d15/cblas__dtpmv_8c.html":[3,0,1,2,61],
 "d5/d15/cblas__dtpmv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,61,0],
 "d5/d15/cblas__dtpmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,61,1],
-"d5/d15/cblas__dtpmv_8c_a27c3533d9977eecfa44f17c96ae4d861.html#a27c3533d9977eecfa44f17c96ae4d861":[3,0,1,2,61,5],
 "d5/d15/cblas__dtpmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,61,3],
 "d5/d15/cblas__dtpmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,61,2],
 "d5/d15/cblas__dtpmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,61,4],
+"d5/d15/cblas__dtpmv_8c_aec489e7eee0194cd2aeb4e9aa9ef35df.html#aec489e7eee0194cd2aeb4e9aa9ef35df":[3,0,1,2,61,5],
 "d5/d15/cblas__dtpmv_8c_source.html":[3,0,1,2,61],
 "d5/d15/zchkpt_8f.html":[3,0,6,1,591],
 "d5/d15/zchkpt_8f_source.html":[3,0,6,1,591],
-"d5/d16/dlarrf_8f.html":[3,0,5,720],
-"d5/d16/dlarrf_8f_source.html":[3,0,5,720],
+"d5/d16/dlarrf_8f.html":[3,0,5,719],
+"d5/d16/dlarrf_8f_source.html":[3,0,5,719],
 "d5/d16/lapacke__clascl__work_8c.html":[3,0,4,3,359],
 "d5/d16/lapacke__clascl__work_8c_a41ad6b55f799da1861576f7bb1dca40c.html#a41ad6b55f799da1861576f7bb1dca40c":[3,0,4,3,359,0],
 "d5/d16/lapacke__clascl__work_8c_source.html":[3,0,4,3,359],
@@ -81,8 +79,8 @@ var NAVTREEINDEX34 =
 "d5/d16/lapacke__sgesvdx_8c_source.html":[3,0,4,3,1352],
 "d5/d16/schkgk_8f.html":[3,0,6,0,194],
 "d5/d16/schkgk_8f_source.html":[3,0,6,0,194],
-"d5/d16/sspev_8f.html":[3,0,5,1396],
-"d5/d16/sspev_8f_source.html":[3,0,5,1396],
+"d5/d16/sspev_8f.html":[3,0,5,1394],
+"d5/d16/sspev_8f_source.html":[3,0,5,1394],
 "d5/d17/lapacke__cunmhr_8c.html":[3,0,4,3,626],
 "d5/d17/lapacke__cunmhr_8c_afcf359f5deedcc17771eea92c3e1fb54.html#afcf359f5deedcc17771eea92c3e1fb54":[3,0,4,3,626,0],
 "d5/d17/lapacke__cunmhr_8c_source.html":[3,0,4,3,626],
@@ -96,12 +94,11 @@ var NAVTREEINDEX34 =
 "d5/d1a/sqrt14_8f_source.html":[3,0,6,1,540],
 "d5/d1b/cchkhb2stg_8f.html":[3,0,6,0,20],
 "d5/d1b/cchkhb2stg_8f_source.html":[3,0,6,0,20],
-"d5/d1d/sptrfs_8f.html":[3,0,5,1375],
-"d5/d1d/sptrfs_8f_source.html":[3,0,5,1375],
+"d5/d1d/sptrfs_8f.html":[3,0,5,1373],
+"d5/d1d/sptrfs_8f_source.html":[3,0,5,1373],
 "d5/d1e/cla__geamv_8f.html":[3,0,5,190],
 "d5/d1e/cla__geamv_8f_source.html":[3,0,5,190],
 "d5/d1f/cblas__ssymm_8c.html":[3,0,1,2,96],
-"d5/d1f/cblas__ssymm_8c_a1159e2cf147def3f6614bcf9ad8e9a15.html#a1159e2cf147def3f6614bcf9ad8e9a15":[3,0,1,2,96,7],
 "d5/d1f/cblas__ssymm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,96,2],
 "d5/d1f/cblas__ssymm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,96,1],
 "d5/d1f/cblas__ssymm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,96,4],
@@ -109,6 +106,7 @@ var NAVTREEINDEX34 =
 "d5/d1f/cblas__ssymm_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,96,0],
 "d5/d1f/cblas__ssymm_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,96,6],
 "d5/d1f/cblas__ssymm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,96,3],
+"d5/d1f/cblas__ssymm_8c_ad855077f11472e8d1c85b56a33a2de7c.html#ad855077f11472e8d1c85b56a33a2de7c":[3,0,1,2,96,7],
 "d5/d1f/cblas__ssymm_8c_source.html":[3,0,1,2,96],
 "d5/d1f/cgesvd_8f.html":[3,0,5,61],
 "d5/d1f/cgesvd_8f_source.html":[3,0,5,61],
@@ -131,11 +129,11 @@ var NAVTREEINDEX34 =
 "d5/d22/cblas__drotg_8c_source.html":[3,0,1,2,43],
 "d5/d22/cblas__icamax_8c.html":[3,0,1,2,70],
 "d5/d22/cblas__icamax_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,70,0],
+"d5/d22/cblas__icamax_8c_a5eceecd9b10e06cc101b290f52f4520a.html#a5eceecd9b10e06cc101b290f52f4520a":[3,0,1,2,70,2],
 "d5/d22/cblas__icamax_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,70,1],
-"d5/d22/cblas__icamax_8c_a9e56332926a96fe58468e5927e951b5a.html#a9e56332926a96fe58468e5927e951b5a":[3,0,1,2,70,2],
 "d5/d22/cblas__icamax_8c_source.html":[3,0,1,2,70],
-"d5/d23/dpftrf_8f.html":[3,0,5,825],
-"d5/d23/dpftrf_8f_source.html":[3,0,5,825],
+"d5/d23/dpftrf_8f.html":[3,0,5,824],
+"d5/d23/dpftrf_8f_source.html":[3,0,5,824],
 "d5/d23/lapacke__clansy_8c.html":[3,0,4,3,338],
 "d5/d23/lapacke__clansy_8c_aa8164f3da3a829ca8a0f9879e4b2b30b.html#aa8164f3da3a829ca8a0f9879e4b2b30b":[3,0,4,3,338,0],
 "d5/d23/lapacke__clansy_8c_source.html":[3,0,4,3,338],
@@ -147,8 +145,8 @@ var NAVTREEINDEX34 =
 "d5/d24/lapacke__spbtrf_8c_source.html":[3,0,4,3,1536],
 "d5/d25/zdrvsy__rook_8f.html":[3,0,6,1,641],
 "d5/d25/zdrvsy__rook_8f_source.html":[3,0,6,1,641],
-"d5/d26/zdrscl_8f.html":[3,0,5,1525],
-"d5/d26/zdrscl_8f_source.html":[3,0,5,1525],
+"d5/d26/zdrscl_8f.html":[3,0,5,1523],
+"d5/d26/zdrscl_8f_source.html":[3,0,5,1523],
 "d5/d27/cchkhs_8f.html":[3,0,6,0,21],
 "d5/d27/cchkhs_8f_source.html":[3,0,6,0,21],
 "d5/d27/dchkbk_8f.html":[3,0,6,0,93],
@@ -156,8 +154,8 @@ var NAVTREEINDEX34 =
 "d5/d27/lapacke__ztrttp_8c.html":[3,0,4,3,2436],
 "d5/d27/lapacke__ztrttp_8c_a801ab5f64e4918c8dacd6c0d49532db8.html#a801ab5f64e4918c8dacd6c0d49532db8":[3,0,4,3,2436,0],
 "d5/d27/lapacke__ztrttp_8c_source.html":[3,0,4,3,2436],
-"d5/d27/stfttp_8f.html":[3,0,5,1482],
-"d5/d27/stfttp_8f_source.html":[3,0,5,1482],
+"d5/d27/stfttp_8f.html":[3,0,5,1480],
+"d5/d27/stfttp_8f_source.html":[3,0,5,1480],
 "d5/d28/clqt05_8f.html":[3,0,6,1,146],
 "d5/d28/clqt05_8f_source.html":[3,0,6,1,146],
 "d5/d29/lapacke__dtgsyl__work_8c.html":[3,0,4,3,1195],
@@ -184,8 +182,8 @@ var NAVTREEINDEX34 =
 "d5/d2c/lapacke__ztpttr_8c.html":[3,0,4,3,2414],
 "d5/d2c/lapacke__ztpttr_8c_a8e149f541b83fba3c498edf6a1a29638.html#a8e149f541b83fba3c498edf6a1a29638":[3,0,4,3,2414,0],
 "d5/d2c/lapacke__ztpttr_8c_source.html":[3,0,4,3,2414],
-"d5/d2e/dsygv_8f.html":[3,0,5,918],
-"d5/d2e/dsygv_8f_source.html":[3,0,5,918],
+"d5/d2e/dsygv_8f.html":[3,0,5,917],
+"d5/d2e/dsygv_8f_source.html":[3,0,5,917],
 "d5/d2f/dlattp_8f.html":[3,0,6,1,322],
 "d5/d2f/dlattp_8f_source.html":[3,0,6,1,322],
 "d5/d2f/lapacke__ztrsyl__work_8c.html":[3,0,4,3,2429],
@@ -196,8 +194,8 @@ var NAVTREEINDEX34 =
 "d5/d2f/sdotsub_8f_source.html":[3,0,1,2,159],
 "d5/d31/chetrs__3_8f.html":[3,0,5,161],
 "d5/d31/chetrs__3_8f_source.html":[3,0,5,161],
-"d5/d31/zlatdf_8f.html":[3,0,5,1833],
-"d5/d31/zlatdf_8f_source.html":[3,0,5,1833],
+"d5/d31/zlatdf_8f.html":[3,0,5,1831],
+"d5/d31/zlatdf_8f_source.html":[3,0,5,1831],
 "d5/d32/cchksy__aa_8f.html":[3,0,6,1,35],
 "d5/d32/cchksy__aa_8f_source.html":[3,0,6,1,35],
 "d5/d32/lapacke__cggbal_8c.html":[3,0,4,3,128],
@@ -208,18 +206,18 @@ var NAVTREEINDEX34 =
 "d5/d32/lapacke__zlantr_8c_source.html":[3,0,4,3,2178],
 "d5/d33/cchkgl_8f.html":[3,0,6,0,18],
 "d5/d33/cchkgl_8f_source.html":[3,0,6,0,18],
-"d5/d34/dlasq5_8f.html":[3,0,5,754],
-"d5/d34/dlasq5_8f_source.html":[3,0,5,754],
+"d5/d34/dlasq5_8f.html":[3,0,5,753],
+"d5/d34/dlasq5_8f_source.html":[3,0,5,753],
 "d5/d34/lapacke__zggesx__work_8c.html":[3,0,4,3,1973],
 "d5/d34/lapacke__zggesx__work_8c_a8f7968d6fc19a2b6f78987b9eacc379e.html#a8f7968d6fc19a2b6f78987b9eacc379e":[3,0,4,3,1973,0],
 "d5/d34/lapacke__zggesx__work_8c_source.html":[3,0,4,3,1973],
-"d5/d34/zlauu2_8f.html":[3,0,5,1841],
-"d5/d34/zlauu2_8f_source.html":[3,0,5,1841],
+"d5/d34/zlauu2_8f.html":[3,0,5,1839],
+"d5/d34/zlauu2_8f_source.html":[3,0,5,1839],
 "d5/d35/cblas__cdotc__sub_8c.html":[3,0,1,2,2],
 "d5/d35/cblas__cdotc__sub_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,2,0],
 "d5/d35/cblas__cdotc__sub_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,2,1],
 "d5/d35/cblas__cdotc__sub_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,2,2],
-"d5/d35/cblas__cdotc__sub_8c_aa37e1424b3c20ff27566ee3b28f4612d.html#aa37e1424b3c20ff27566ee3b28f4612d":[3,0,1,2,2,3],
+"d5/d35/cblas__cdotc__sub_8c_afa97df474038cbf18c7cb41a1cabe533.html#afa97df474038cbf18c7cb41a1cabe533":[3,0,1,2,2,3],
 "d5/d35/cblas__cdotc__sub_8c_source.html":[3,0,1,2,2],
 "d5/d35/lapacke__dgesvdq_8c.html":[3,0,4,3,752],
 "d5/d35/lapacke__dgesvdq_8c_a7e893490213530cf0b68c2affc7a3e9f.html#a7e893490213530cf0b68c2affc7a3e9f":[3,0,4,3,752,0],
@@ -234,7 +232,7 @@ var NAVTREEINDEX34 =
 "d5/d37/cblas__ssbmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,90,0],
 "d5/d37/cblas__ssbmv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,90,1],
 "d5/d37/cblas__ssbmv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,90,2],
-"d5/d37/cblas__ssbmv_8c_a67ee905c2a2e2a4c633ae93e61c3e327.html#a67ee905c2a2e2a4c633ae93e61c3e327":[3,0,1,2,90,6],
+"d5/d37/cblas__ssbmv_8c_a65f6cbd04a51511487951cfb53f8217c.html#a65f6cbd04a51511487951cfb53f8217c":[3,0,1,2,90,6],
 "d5/d37/cblas__ssbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,90,4],
 "d5/d37/cblas__ssbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,90,3],
 "d5/d37/cblas__ssbmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,90,5],
@@ -245,9 +243,11 @@ var NAVTREEINDEX34 =
 "d5/d38/lapacke__dggsvd3__work_8c.html":[3,0,4,3,806],
 "d5/d38/lapacke__dggsvd3__work_8c_ab9a02ce2ee5a6495a8194e4d8f41ce36.html#ab9a02ce2ee5a6495a8194e4d8f41ce36":[3,0,4,3,806,0],
 "d5/d38/lapacke__dggsvd3__work_8c_source.html":[3,0,4,3,806],
-"d5/d38/slarscl2_8f.html":[3,0,5,1248],
-"d5/d38/slarscl2_8f_source.html":[3,0,5,1248],
+"d5/d38/slarscl2_8f.html":[3,0,5,1246],
+"d5/d38/slarscl2_8f_source.html":[3,0,5,1246],
 "d5/d39/group__complex_g_bauxiliary.html":[0,0,1,2,2],
 "d5/d39/group__complex_g_bauxiliary_ga8bbfc1becb94399a6c92c37c94972587.html#ga8bbfc1becb94399a6c92c37c94972587":[3,0,5,241,0],
-"d5/d39/group__complex_g_bauxiliary_ga8bbfc1becb94399a6c92c37c94972587.html#ga8bbfc1becb94399a6c92c37c94972587":[0,0,1,2,2,0]
+"d5/d39/group__complex_g_bauxiliary_ga8bbfc1becb94399a6c92c37c94972587.html#ga8bbfc1becb94399a6c92c37c94972587":[0,0,1,2,2,0],
+"d5/d39/group__complex_g_bauxiliary_gace4fc1b659b18893679cc09dd8b5b998.html#gace4fc1b659b18893679cc09dd8b5b998":[3,0,5,259,0],
+"d5/d39/group__complex_g_bauxiliary_gace4fc1b659b18893679cc09dd8b5b998.html#gace4fc1b659b18893679cc09dd8b5b998":[0,0,1,2,2,1]
 };
