@@ -1,7 +1,5 @@
 var NAVTREEINDEX36 =
 {
-"d5/d7c/group__aux__lin_gad56ccbe8939c1230b917e03bf7b722b7.html#gad56ccbe8939c1230b917e03bf7b722b7":[0,1,1,4,5],
-"d5/d7c/group__aux__lin_gad56ccbe8939c1230b917e03bf7b722b7.html#gad56ccbe8939c1230b917e03bf7b722b7":[3,0,6,1,5,0],
 "d5/d7c/group__aux__lin_gae6f1eead77499e53bd640389a95288c4.html#gae6f1eead77499e53bd640389a95288c4":[0,1,1,4,9],
 "d5/d7c/group__aux__lin_gae6f1eead77499e53bd640389a95288c4.html#gae6f1eead77499e53bd640389a95288c4":[3,0,6,1,571,0],
 "d5/d7d/lapacke__dgtsvx_8c.html":[3,0,4,3,818],
@@ -15,8 +13,8 @@ var NAVTREEINDEX36 =
 "d5/d7e/lapacke__cgesvdx_8c_source.html":[3,0,4,3,104],
 "d5/d7f/sptt01_8f.html":[3,0,6,1,524],
 "d5/d7f/sptt01_8f_source.html":[3,0,6,1,524],
-"d5/d80/zla__syrcond__x_8f.html":[3,0,5,1728],
-"d5/d80/zla__syrcond__x_8f_source.html":[3,0,5,1728],
+"d5/d80/zla__syrcond__x_8f.html":[3,0,5,1726],
+"d5/d80/zla__syrcond__x_8f_source.html":[3,0,5,1726],
 "d5/d81/lapacke__cherfsx_8c.html":[3,0,4,3,230],
 "d5/d81/lapacke__cherfsx_8c_ac7d81f20b4a4b80430e6d03276141818.html#ac7d81f20b4a4b80430e6d03276141818":[3,0,4,3,230,0],
 "d5/d81/lapacke__cherfsx_8c_source.html":[3,0,4,3,230],
@@ -39,15 +37,15 @@ var NAVTREEINDEX36 =
 "d5/d86/cget24_8f_source.html":[3,0,6,0,55],
 "d5/d86/slqt01_8f.html":[3,0,6,1,505],
 "d5/d86/slqt01_8f_source.html":[3,0,6,1,505],
-"d5/d87/dsygs2_8f.html":[3,0,5,916],
-"d5/d87/dsygs2_8f_source.html":[3,0,5,916],
-"d5/d87/iladlr_8f.html":[3,0,5,1006],
-"d5/d87/iladlr_8f_source.html":[3,0,5,1006],
+"d5/d87/dsygs2_8f.html":[3,0,5,915],
+"d5/d87/dsygs2_8f_source.html":[3,0,5,915],
+"d5/d87/iladlr_8f.html":[3,0,5,1005],
+"d5/d87/iladlr_8f_source.html":[3,0,5,1005],
 "d5/d87/lapacke__zhbev__2stage_8c.html":[3,0,4,3,2013],
 "d5/d87/lapacke__zhbev__2stage_8c_a6c44b8d7a2f2dc4a28483876e9c01d49.html#a6c44b8d7a2f2dc4a28483876e9c01d49":[3,0,4,3,2013,0],
 "d5/d87/lapacke__zhbev__2stage_8c_source.html":[3,0,4,3,2013],
 "d5/d88/c__xerbla_8c.html":[3,0,1,3,25],
-"d5/d88/c__xerbla_8c_a257f71dabf79aafb8cb35c7f214bd071.html#a257f71dabf79aafb8cb35c7f214bd071":[3,0,1,3,25,0],
+"d5/d88/c__xerbla_8c_a7b83bc7177b7f191ca1ea657fe81a3c2.html#a7b83bc7177b7f191ca1ea657fe81a3c2":[3,0,1,3,25,0],
 "d5/d88/c__xerbla_8c_a9dba6501cb46384a8c483ecb5a916ed2.html#a9dba6501cb46384a8c483ecb5a916ed2":[3,0,1,3,25,1],
 "d5/d88/c__xerbla_8c_source.html":[3,0,1,3,25],
 "d5/d89/csyrfs_8f.html":[3,0,5,389],
@@ -56,61 +54,61 @@ var NAVTREEINDEX36 =
 "d5/d89/csytrs__aa__2stage_8f_source.html":[3,0,5,417],
 "d5/d89/sget32_8f.html":[3,0,6,0,234],
 "d5/d89/sget32_8f_source.html":[3,0,6,0,234],
-"d5/d8a/zla__gbrcond__x_8f.html":[3,0,5,1708],
-"d5/d8a/zla__gbrcond__x_8f_source.html":[3,0,5,1708],
+"d5/d8a/zla__gbrcond__x_8f.html":[3,0,5,1706],
+"d5/d8a/zla__gbrcond__x_8f_source.html":[3,0,5,1706],
 "d5/d8c/cblas__zher_8c.html":[3,0,1,2,124],
 "d5/d8c/cblas__zher_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,124,0],
 "d5/d8c/cblas__zher_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,124,2],
-"d5/d8c/cblas__zher_8c_a874ad1021fc106a7f6705f007452da59.html#a874ad1021fc106a7f6705f007452da59":[3,0,1,2,124,4],
 "d5/d8c/cblas__zher_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,124,1],
 "d5/d8c/cblas__zher_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,124,3],
+"d5/d8c/cblas__zher_8c_ab708ab00368ed17f5676d4a050a83908.html#ab708ab00368ed17f5676d4a050a83908":[3,0,1,2,124,4],
 "d5/d8c/cblas__zher_8c_source.html":[3,0,1,2,124],
 "d5/d8c/lapacke__sstemr__work_8c.html":[3,0,4,3,1665],
 "d5/d8c/lapacke__sstemr__work_8c_a8fadee97c4da0178f34b34d687b4aa83.html#a8fadee97c4da0178f34b34d687b4aa83":[3,0,4,3,1665,0],
 "d5/d8c/lapacke__sstemr__work_8c_source.html":[3,0,4,3,1665],
-"d5/d8d/ilaslr_8f.html":[3,0,5,1011],
-"d5/d8d/ilaslr_8f_source.html":[3,0,5,1011],
+"d5/d8d/ilaslr_8f.html":[3,0,5,1010],
+"d5/d8d/ilaslr_8f_source.html":[3,0,5,1010],
 "d5/d8e/lapacke__zhbevx__2stage_8c.html":[3,0,4,3,2021],
 "d5/d8e/lapacke__zhbevx__2stage_8c_a73ce01585fb2fa171a5384fd7ad22baa.html#a73ce01585fb2fa171a5384fd7ad22baa":[3,0,4,3,2021,0],
 "d5/d8e/lapacke__zhbevx__2stage_8c_source.html":[3,0,4,3,2021],
 "d5/d8e/ztrt05_8f.html":[3,0,6,1,777],
 "d5/d8e/ztrt05_8f_source.html":[3,0,6,1,777],
-"d5/d8f/dsytri_8f.html":[3,0,5,945],
-"d5/d8f/dsytri_8f_source.html":[3,0,5,945],
+"d5/d8f/dsytri_8f.html":[3,0,5,944],
+"d5/d8f/dsytri_8f_source.html":[3,0,5,944],
 "d5/d8f/lapacke__cheequb__work_8c.html":[3,0,4,3,201],
 "d5/d8f/lapacke__cheequb__work_8c_a10b6e650f0917c8f338c2b04aa4da05a.html#a10b6e650f0917c8f338c2b04aa4da05a":[3,0,4,3,201,0],
 "d5/d8f/lapacke__cheequb__work_8c_source.html":[3,0,4,3,201],
 "d5/d8f/lapacke__ssygvd__work_8c.html":[3,0,4,3,1709],
 "d5/d8f/lapacke__ssygvd__work_8c_a1f112f5cc95d1fb0c41a83b264d189e7.html#a1f112f5cc95d1fb0c41a83b264d189e7":[3,0,4,3,1709,0],
 "d5/d8f/lapacke__ssygvd__work_8c_source.html":[3,0,4,3,1709],
-"d5/d8f/zlange_8f.html":[3,0,5,1763],
-"d5/d8f/zlange_8f_source.html":[3,0,5,1763],
+"d5/d8f/zlange_8f.html":[3,0,5,1761],
+"d5/d8f/zlange_8f_source.html":[3,0,5,1761],
 "d5/d91/lapacke__zgbrfsx_8c.html":[3,0,4,3,1852],
 "d5/d91/lapacke__zgbrfsx_8c_a10aef2d4181aeeec835acfd72de14bd4.html#a10aef2d4181aeeec835acfd72de14bd4":[3,0,4,3,1852,0],
 "d5/d91/lapacke__zgbrfsx_8c_source.html":[3,0,4,3,1852],
-"d5/d91/stgsen_8f.html":[3,0,5,1487],
-"d5/d91/stgsen_8f_source.html":[3,0,5,1487],
+"d5/d91/stgsen_8f.html":[3,0,5,1485],
+"d5/d91/stgsen_8f_source.html":[3,0,5,1485],
 "d5/d92/lapacke__spbtrf__work_8c.html":[3,0,4,3,1537],
 "d5/d92/lapacke__spbtrf__work_8c_aa0a4779d058bfa9779d19fccd864edf0.html#aa0a4779d058bfa9779d19fccd864edf0":[3,0,4,3,1537,0],
 "d5/d92/lapacke__spbtrf__work_8c_source.html":[3,0,4,3,1537],
 "d5/d93/ctrcon_8f.html":[3,0,5,447],
 "d5/d93/ctrcon_8f_source.html":[3,0,5,447],
-"d5/d93/dsyev__2stage_8f.html":[3,0,5,909],
-"d5/d93/dsyev__2stage_8f_source.html":[3,0,5,909],
+"d5/d93/dsyev__2stage_8f.html":[3,0,5,908],
+"d5/d93/dsyev__2stage_8f_source.html":[3,0,5,908],
 "d5/d93/sget53_8f.html":[3,0,6,0,245],
 "d5/d93/sget53_8f_source.html":[3,0,6,0,245],
-"d5/d93/sgttrs_8f.html":[3,0,5,1123],
-"d5/d93/sgttrs_8f_source.html":[3,0,5,1123],
-"d5/d93/zlaswp_8f.html":[3,0,5,1826],
-"d5/d93/zlaswp_8f_source.html":[3,0,5,1826],
+"d5/d93/sgttrs_8f.html":[3,0,5,1121],
+"d5/d93/sgttrs_8f_source.html":[3,0,5,1121],
+"d5/d93/zlaswp_8f.html":[3,0,5,1824],
+"d5/d93/zlaswp_8f_source.html":[3,0,5,1824],
 "d5/d94/lapacke__spptrs_8c.html":[3,0,4,3,1584],
 "d5/d94/lapacke__spptrs_8c_af32701c32fcf2eb238a915d75d043faa.html#af32701c32fcf2eb238a915d75d043faa":[3,0,4,3,1584,0],
 "d5/d94/lapacke__spptrs_8c_source.html":[3,0,4,3,1584],
 "d5/d95/group__solve_h_e.html":[0,0,3,0],
 "d5/d96/dglmts_8f.html":[3,0,6,0,151],
 "d5/d96/dglmts_8f_source.html":[3,0,6,0,151],
-"d5/d96/sgeqrt2_8f.html":[3,0,5,1077],
-"d5/d96/sgeqrt2_8f_source.html":[3,0,5,1077],
+"d5/d96/sgeqrt2_8f.html":[3,0,5,1075],
+"d5/d96/sgeqrt2_8f_source.html":[3,0,5,1075],
 "d5/d98/lapacke__dhgeqz__work_8c.html":[3,0,4,3,825],
 "d5/d98/lapacke__dhgeqz__work_8c_ab0c538ed5fb4569572b7c426c3a3a3c8.html#ab0c538ed5fb4569572b7c426c3a3a3c8":[3,0,4,3,825,0],
 "d5/d98/lapacke__dhgeqz__work_8c_source.html":[3,0,4,3,825],
@@ -131,8 +129,8 @@ var NAVTREEINDEX36 =
 "d5/d99/group__single__eig_ga142bffda1c42659908f951ac51744638.html#ga142bffda1c42659908f951ac51744638":[3,0,6,0,238,0],
 "d5/d99/group__single__eig_ga15b379af6192edfd74986d7ef1b2e822.html#ga15b379af6192edfd74986d7ef1b2e822":[0,1,2,0,55],
 "d5/d99/group__single__eig_ga15b379af6192edfd74986d7ef1b2e822.html#ga15b379af6192edfd74986d7ef1b2e822":[3,0,6,0,240,0],
-"d5/d99/group__single__eig_ga1d66b6ef4236d0d0cf318e1c64930a38.html#ga1d66b6ef4236d0d0cf318e1c64930a38":[0,1,2,0,32],
 "d5/d99/group__single__eig_ga1d66b6ef4236d0d0cf318e1c64930a38.html#ga1d66b6ef4236d0d0cf318e1c64930a38":[3,0,6,0,216,0],
+"d5/d99/group__single__eig_ga1d66b6ef4236d0d0cf318e1c64930a38.html#ga1d66b6ef4236d0d0cf318e1c64930a38":[0,1,2,0,32],
 "d5/d99/group__single__eig_ga1f72bc4c21b1b37d449ec5911e36d7d1.html#ga1f72bc4c21b1b37d449ec5911e36d7d1":[0,1,2,0,82],
 "d5/d99/group__single__eig_ga1f72bc4c21b1b37d449ec5911e36d7d1.html#ga1f72bc4c21b1b37d449ec5911e36d7d1":[3,0,6,0,269,0],
 "d5/d99/group__single__eig_ga1f741a939ab68209bb2d6028538da0c1.html#ga1f741a939ab68209bb2d6028538da0c1":[0,1,2,0,30],
@@ -149,10 +147,10 @@ var NAVTREEINDEX36 =
 "d5/d99/group__single__eig_ga2a7d9603b3bd0ebb820f3a0ed88d760a.html#ga2a7d9603b3bd0ebb820f3a0ed88d760a":[3,0,6,0,230,0],
 "d5/d99/group__single__eig_ga2e1600d5ba10895a2ed94275d190b187.html#ga2e1600d5ba10895a2ed94275d190b187":[0,1,2,0,78],
 "d5/d99/group__single__eig_ga2e1600d5ba10895a2ed94275d190b187.html#ga2e1600d5ba10895a2ed94275d190b187":[3,0,6,0,265,0],
-"d5/d99/group__single__eig_ga30cf9f83367d540b803fbd2b264dde8f.html#ga30cf9f83367d540b803fbd2b264dde8f":[0,1,2,0,10],
 "d5/d99/group__single__eig_ga30cf9f83367d540b803fbd2b264dde8f.html#ga30cf9f83367d540b803fbd2b264dde8f":[3,0,6,0,194,0],
-"d5/d99/group__single__eig_ga35b38ff82fbc9f1d0f4e0eba2f7c497f.html#ga35b38ff82fbc9f1d0f4e0eba2f7c497f":[3,0,6,0,232,0],
+"d5/d99/group__single__eig_ga30cf9f83367d540b803fbd2b264dde8f.html#ga30cf9f83367d540b803fbd2b264dde8f":[0,1,2,0,10],
 "d5/d99/group__single__eig_ga35b38ff82fbc9f1d0f4e0eba2f7c497f.html#ga35b38ff82fbc9f1d0f4e0eba2f7c497f":[0,1,2,0,47],
+"d5/d99/group__single__eig_ga35b38ff82fbc9f1d0f4e0eba2f7c497f.html#ga35b38ff82fbc9f1d0f4e0eba2f7c497f":[3,0,6,0,232,0],
 "d5/d99/group__single__eig_ga375903897d1816ffdc66d54f50f80338.html#ga375903897d1816ffdc66d54f50f80338":[0,1,2,0,31],
 "d5/d99/group__single__eig_ga375903897d1816ffdc66d54f50f80338.html#ga375903897d1816ffdc66d54f50f80338":[3,0,6,0,215,0],
 "d5/d99/group__single__eig_ga38549b2e96321b31dceb6b549fba78dc.html#ga38549b2e96321b31dceb6b549fba78dc":[0,1,2,0,63],
@@ -173,8 +171,8 @@ var NAVTREEINDEX36 =
 "d5/d99/group__single__eig_ga4031914169fb1a0ddfd7dd67359c8b4f.html#ga4031914169fb1a0ddfd7dd67359c8b4f":[3,0,6,0,276,0],
 "d5/d99/group__single__eig_ga411333994f433776dd07049fe3973a66.html#ga411333994f433776dd07049fe3973a66":[0,1,2,0,35],
 "d5/d99/group__single__eig_ga411333994f433776dd07049fe3973a66.html#ga411333994f433776dd07049fe3973a66":[3,0,6,0,220,0],
-"d5/d99/group__single__eig_ga412f58b485b08b55197171f8c070dcee.html#ga412f58b485b08b55197171f8c070dcee":[3,0,6,0,248,0],
 "d5/d99/group__single__eig_ga412f58b485b08b55197171f8c070dcee.html#ga412f58b485b08b55197171f8c070dcee":[0,1,2,0,62],
+"d5/d99/group__single__eig_ga412f58b485b08b55197171f8c070dcee.html#ga412f58b485b08b55197171f8c070dcee":[3,0,6,0,248,0],
 "d5/d99/group__single__eig_ga41b0a1a7d888674eac14ad251c2d94ec.html#ga41b0a1a7d888674eac14ad251c2d94ec":[0,1,2,0,17],
 "d5/d99/group__single__eig_ga41b0a1a7d888674eac14ad251c2d94ec.html#ga41b0a1a7d888674eac14ad251c2d94ec":[3,0,6,0,201,0],
 "d5/d99/group__single__eig_ga445a7d10a693e781798a410681ab92a6.html#ga445a7d10a693e781798a410681ab92a6":[0,1,2,0,60],
@@ -223,8 +221,8 @@ var NAVTREEINDEX36 =
 "d5/d99/group__single__eig_ga9051201041524e344b189e8504011c6f.html#ga9051201041524e344b189e8504011c6f":[3,0,6,0,266,0],
 "d5/d99/group__single__eig_ga91d3493bce6a97430fded1ad19b1bead.html#ga91d3493bce6a97430fded1ad19b1bead":[0,1,2,0,36],
 "d5/d99/group__single__eig_ga91d3493bce6a97430fded1ad19b1bead.html#ga91d3493bce6a97430fded1ad19b1bead":[3,0,6,0,221,0],
-"d5/d99/group__single__eig_ga939255a845788e786a4a5b786f878a22.html#ga939255a845788e786a4a5b786f878a22":[0,1,2,0,84],
 "d5/d99/group__single__eig_ga939255a845788e786a4a5b786f878a22.html#ga939255a845788e786a4a5b786f878a22":[3,0,6,0,271,0],
+"d5/d99/group__single__eig_ga939255a845788e786a4a5b786f878a22.html#ga939255a845788e786a4a5b786f878a22":[0,1,2,0,84],
 "d5/d99/group__single__eig_ga9540564c76aed17bc8b26a879ee5ca46.html#ga9540564c76aed17bc8b26a879ee5ca46":[0,1,2,0,70],
 "d5/d99/group__single__eig_ga9540564c76aed17bc8b26a879ee5ca46.html#ga9540564c76aed17bc8b26a879ee5ca46":[3,0,6,0,257,0],
 "d5/d99/group__single__eig_ga982b1b2bcfb91803ffe5fe2c9ed62a19.html#ga982b1b2bcfb91803ffe5fe2c9ed62a19":[0,1,2,0,51],
@@ -249,5 +247,7 @@ var NAVTREEINDEX36 =
 "d5/d99/group__single__eig_gac812301fb70fec79ae94eb13b0fa1466.html#gac812301fb70fec79ae94eb13b0fa1466":[3,0,6,0,239,0],
 "d5/d99/group__single__eig_gac817155b9a60030bdc313807c2a10f76.html#gac817155b9a60030bdc313807c2a10f76":[0,1,2,0,57],
 "d5/d99/group__single__eig_gac817155b9a60030bdc313807c2a10f76.html#gac817155b9a60030bdc313807c2a10f76":[3,0,6,0,243,0],
-"d5/d99/group__single__eig_gaccd03e1eb309d22da705f8bd9a6b0b61.html#gaccd03e1eb309d22da705f8bd9a6b0b61":[0,1,2,0,58]
+"d5/d99/group__single__eig_gaccd03e1eb309d22da705f8bd9a6b0b61.html#gaccd03e1eb309d22da705f8bd9a6b0b61":[0,1,2,0,58],
+"d5/d99/group__single__eig_gaccd03e1eb309d22da705f8bd9a6b0b61.html#gaccd03e1eb309d22da705f8bd9a6b0b61":[3,0,6,0,244,0],
+"d5/d99/group__single__eig_gacd0abbe15d93a0180c975f8b2af5f801.html#gacd0abbe15d93a0180c975f8b2af5f801":[0,1,2,0,88]
 };
