@@ -1,7 +1,5 @@
 var NAVTREEINDEX37 =
 {
-"d5/d99/group__single__eig_gaccd03e1eb309d22da705f8bd9a6b0b61.html#gaccd03e1eb309d22da705f8bd9a6b0b61":[3,0,6,0,244,0],
-"d5/d99/group__single__eig_gacd0abbe15d93a0180c975f8b2af5f801.html#gacd0abbe15d93a0180c975f8b2af5f801":[0,1,2,0,88],
 "d5/d99/group__single__eig_gacd0abbe15d93a0180c975f8b2af5f801.html#gacd0abbe15d93a0180c975f8b2af5f801":[3,0,6,0,275,0],
 "d5/d99/group__single__eig_gacdb40a265d764f2ce962040de230c2f1.html#gacdb40a265d764f2ce962040de230c2f1":[0,1,2,0,76],
 "d5/d99/group__single__eig_gacdb40a265d764f2ce962040de230c2f1.html#gacdb40a265d764f2ce962040de230c2f1":[3,0,6,0,263,0],
@@ -56,13 +54,13 @@ var NAVTREEINDEX37 =
 "d5/d99/lapacke__zgtsv__work_8c_source.html":[3,0,4,3,2005],
 "d5/d9a/cpotrf2_8f.html":[3,0,5,343],
 "d5/d9a/cpotrf2_8f_source.html":[3,0,5,343],
-"d5/d9a/dlasyf_8f.html":[3,0,5,763],
-"d5/d9a/dlasyf_8f_source.html":[3,0,5,763],
+"d5/d9a/dlasyf_8f.html":[3,0,5,762],
+"d5/d9a/dlasyf_8f_source.html":[3,0,5,762],
 "d5/d9a/lapacke__ztbrfs_8c.html":[3,0,4,3,2372],
 "d5/d9a/lapacke__ztbrfs_8c_a6c6583032889c119432fc0b115ae7548.html#a6c6583032889c119432fc0b115ae7548":[3,0,4,3,2372,0],
 "d5/d9a/lapacke__ztbrfs_8c_source.html":[3,0,4,3,2372],
-"d5/d9b/dsygvx_8f.html":[3,0,5,921],
-"d5/d9b/dsygvx_8f_source.html":[3,0,5,921],
+"d5/d9b/dsygvx_8f.html":[3,0,5,920],
+"d5/d9b/dsygvx_8f_source.html":[3,0,5,920],
 "d5/d9b/lapacke__clagsy__work_8c.html":[3,0,4,3,333],
 "d5/d9b/lapacke__clagsy__work_8c_adb2a7858f8db46dc2912889d55b4b98d.html#adb2a7858f8db46dc2912889d55b4b98d":[3,0,4,3,333,0],
 "d5/d9b/lapacke__clagsy__work_8c_source.html":[3,0,4,3,333],
@@ -74,14 +72,14 @@ var NAVTREEINDEX37 =
 "d5/d9d/lapacke__dgeqrf__work_8c.html":[3,0,4,3,731],
 "d5/d9d/lapacke__dgeqrf__work_8c_a72f2c7cfebec81a75e695900243821ae.html#a72f2c7cfebec81a75e695900243821ae":[3,0,4,3,731,0],
 "d5/d9d/lapacke__dgeqrf__work_8c_source.html":[3,0,4,3,731],
-"d5/d9d/sorgrq_8f.html":[3,0,5,1319],
-"d5/d9d/sorgrq_8f_source.html":[3,0,5,1319],
-"d5/d9d/zppsv_8f.html":[3,0,5,1871],
-"d5/d9d/zppsv_8f_source.html":[3,0,5,1871],
+"d5/d9d/sorgrq_8f.html":[3,0,5,1317],
+"d5/d9d/sorgrq_8f_source.html":[3,0,5,1317],
+"d5/d9d/zppsv_8f.html":[3,0,5,1869],
+"d5/d9d/zppsv_8f_source.html":[3,0,5,1869],
 "d5/d9e/sdrvpt_8f.html":[3,0,6,1,437],
 "d5/d9e/sdrvpt_8f_source.html":[3,0,6,1,437],
-"d5/d9f/zsytrs__aa_8f.html":[3,0,5,1937],
-"d5/d9f/zsytrs__aa_8f_source.html":[3,0,5,1937],
+"d5/d9f/zsytrs__aa_8f.html":[3,0,5,1935],
+"d5/d9f/zsytrs__aa_8f_source.html":[3,0,5,1935],
 "d5/da0/dqrt17_8f.html":[3,0,6,1,366],
 "d5/da0/dqrt17_8f_source.html":[3,0,6,1,366],
 "d5/da1/_m_a_t_g_e_n_2zlahilb_8f.html":[3,0,6,2,59],
@@ -106,13 +104,13 @@ var NAVTREEINDEX37 =
 "d5/da3/lapacke__zsytrf__work_8c.html":[3,0,4,3,2349],
 "d5/da3/lapacke__zsytrf__work_8c_aa539a17e4ee67a7909c03b3e9c1a786c.html#aa539a17e4ee67a7909c03b3e9c1a786c":[3,0,4,3,2349,0],
 "d5/da3/lapacke__zsytrf__work_8c_source.html":[3,0,4,3,2349],
-"d5/da3/ssbevd_8f.html":[3,0,5,1385],
-"d5/da3/ssbevd_8f_source.html":[3,0,5,1385],
+"d5/da3/ssbevd_8f.html":[3,0,5,1383],
+"d5/da3/ssbevd_8f_source.html":[3,0,5,1383],
 "d5/da5/lapacke__dgeesx_8c.html":[3,0,4,3,690],
 "d5/da5/lapacke__dgeesx_8c_a98e5813f7c93eccb61fd41d751675d23.html#a98e5813f7c93eccb61fd41d751675d23":[3,0,4,3,690,0],
 "d5/da5/lapacke__dgeesx_8c_source.html":[3,0,4,3,690],
-"d5/da5/slarzb_8f.html":[3,0,5,1255],
-"d5/da5/slarzb_8f_source.html":[3,0,5,1255],
+"d5/da5/slarzb_8f.html":[3,0,5,1253],
+"d5/da5/slarzb_8f_source.html":[3,0,5,1253],
 "d5/da6/lapacke__cgeqr_8c.html":[3,0,4,3,76],
 "d5/da6/lapacke__cgeqr_8c_a003f725d707ae6b0ab8223eaaa70ed26.html#a003f725d707ae6b0ab8223eaaa70ed26":[3,0,4,3,76,0],
 "d5/da6/lapacke__cgeqr_8c_source.html":[3,0,4,3,76],
@@ -120,15 +118,15 @@ var NAVTREEINDEX37 =
 "d5/da6/lapacke__cpotri_8c_a2c47f0c201a8cc5c41b06012084c1b4d.html#a2c47f0c201a8cc5c41b06012084c1b4d":[3,0,4,3,412,0],
 "d5/da6/lapacke__cpotri_8c_source.html":[3,0,4,3,412],
 "d5/da7/group__real_g_tcomputational.html":[0,0,5,1,1],
-"d5/da7/group__real_g_tcomputational_ga0cd464cdbfc79c87c6b3fa3d1e139abf.html#ga0cd464cdbfc79c87c6b3fa3d1e139abf":[3,0,5,1122,0],
+"d5/da7/group__real_g_tcomputational_ga0cd464cdbfc79c87c6b3fa3d1e139abf.html#ga0cd464cdbfc79c87c6b3fa3d1e139abf":[3,0,5,1120,0],
 "d5/da7/group__real_g_tcomputational_ga0cd464cdbfc79c87c6b3fa3d1e139abf.html#ga0cd464cdbfc79c87c6b3fa3d1e139abf":[0,0,5,1,1,2],
-"d5/da7/group__real_g_tcomputational_ga4c1f4f3382563a295c36917d658befb3.html#ga4c1f4f3382563a295c36917d658befb3":[3,0,5,1123,0],
+"d5/da7/group__real_g_tcomputational_ga4c1f4f3382563a295c36917d658befb3.html#ga4c1f4f3382563a295c36917d658befb3":[3,0,5,1121,0],
 "d5/da7/group__real_g_tcomputational_ga4c1f4f3382563a295c36917d658befb3.html#ga4c1f4f3382563a295c36917d658befb3":[0,0,5,1,1,3],
-"d5/da7/group__real_g_tcomputational_ga913327540f64843e724055d28babf247.html#ga913327540f64843e724055d28babf247":[3,0,5,1124,0],
+"d5/da7/group__real_g_tcomputational_ga913327540f64843e724055d28babf247.html#ga913327540f64843e724055d28babf247":[3,0,5,1122,0],
 "d5/da7/group__real_g_tcomputational_ga913327540f64843e724055d28babf247.html#ga913327540f64843e724055d28babf247":[0,0,5,1,1,4],
-"d5/da7/group__real_g_tcomputational_ga9474585c30f5420fc243d0bd0e0e9c12.html#ga9474585c30f5420fc243d0bd0e0e9c12":[3,0,5,1118,0],
+"d5/da7/group__real_g_tcomputational_ga9474585c30f5420fc243d0bd0e0e9c12.html#ga9474585c30f5420fc243d0bd0e0e9c12":[3,0,5,1116,0],
 "d5/da7/group__real_g_tcomputational_ga9474585c30f5420fc243d0bd0e0e9c12.html#ga9474585c30f5420fc243d0bd0e0e9c12":[0,0,5,1,1,0],
-"d5/da7/group__real_g_tcomputational_gaa83bbd4b0fcb6e3dffaa4ea7c08b2f08.html#gaa83bbd4b0fcb6e3dffaa4ea7c08b2f08":[3,0,5,1119,0],
+"d5/da7/group__real_g_tcomputational_gaa83bbd4b0fcb6e3dffaa4ea7c08b2f08.html#gaa83bbd4b0fcb6e3dffaa4ea7c08b2f08":[3,0,5,1117,0],
 "d5/da7/group__real_g_tcomputational_gaa83bbd4b0fcb6e3dffaa4ea7c08b2f08.html#gaa83bbd4b0fcb6e3dffaa4ea7c08b2f08":[0,0,5,1,1,1],
 "d5/da8/cdrvsy__aa__2stage_8f.html":[3,0,6,1,71],
 "d5/da8/cdrvsy__aa__2stage_8f_source.html":[3,0,6,1,71],
@@ -146,10 +144,10 @@ var NAVTREEINDEX37 =
 "d5/da9/lapacke__slartgs__work_8c.html":[3,0,4,3,1467],
 "d5/da9/lapacke__slartgs__work_8c_a1b9a6e2dbacbf49b9771db33d6366c56.html#a1b9a6e2dbacbf49b9771db33d6366c56":[3,0,4,3,1467,0],
 "d5/da9/lapacke__slartgs__work_8c_source.html":[3,0,4,3,1467],
-"d5/da9/sorm2r_8f.html":[3,0,5,1326],
-"d5/da9/sorm2r_8f_source.html":[3,0,5,1326],
-"d5/da9/zlaqz2_8f.html":[3,0,5,1798],
-"d5/da9/zlaqz2_8f_source.html":[3,0,5,1798],
+"d5/da9/sorm2r_8f.html":[3,0,5,1324],
+"d5/da9/sorm2r_8f_source.html":[3,0,5,1324],
+"d5/da9/zlaqz2_8f.html":[3,0,5,1796],
+"d5/da9/zlaqz2_8f_source.html":[3,0,5,1796],
 "d5/daa/cerrec_8f.html":[3,0,6,0,46],
 "d5/daa/cerrec_8f_source.html":[3,0,6,0,46],
 "d5/daa/csyt01__aa_8f.html":[3,0,6,1,190],
@@ -163,14 +161,14 @@ var NAVTREEINDEX37 =
 "d5/dac/cblas__caxpy_8c.html":[3,0,1,2,0],
 "d5/dac/cblas__caxpy_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,0,0],
 "d5/dac/cblas__caxpy_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,0,1],
+"d5/dac/cblas__caxpy_8c_a66809705e90491912160b318ab0099fc.html#a66809705e90491912160b318ab0099fc":[3,0,1,2,0,3],
 "d5/dac/cblas__caxpy_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,0,2],
-"d5/dac/cblas__caxpy_8c_ad8be262cd3a0fe6b04e90a42bb1b2134.html#ad8be262cd3a0fe6b04e90a42bb1b2134":[3,0,1,2,0,3],
 "d5/dac/cblas__caxpy_8c_source.html":[3,0,1,2,0],
 "d5/dac/lapacke__zggev3_8c.html":[3,0,4,3,1975],
 "d5/dac/lapacke__zggev3_8c_ad51fdf57c865964e97661f92d3e22a04.html#ad51fdf57c865964e97661f92d3e22a04":[3,0,4,3,1975,0],
 "d5/dac/lapacke__zggev3_8c_source.html":[3,0,4,3,1975],
-"d5/dac/spbtf2_8f.html":[3,0,5,1344],
-"d5/dac/spbtf2_8f_source.html":[3,0,5,1344],
+"d5/dac/spbtf2_8f.html":[3,0,5,1342],
+"d5/dac/spbtf2_8f_source.html":[3,0,5,1342],
 "d5/dad/lapacke__cpstrf_8c.html":[3,0,4,3,432],
 "d5/dad/lapacke__cpstrf_8c_aa40df29f5239424a4ef17be1308c6189.html#aa40df29f5239424a4ef17be1308c6189":[3,0,4,3,432,0],
 "d5/dad/lapacke__cpstrf_8c_source.html":[3,0,4,3,432],
@@ -179,8 +177,8 @@ var NAVTREEINDEX37 =
 "d5/dae/lapacke__ctptri_8c_source.html":[3,0,4,3,570],
 "d5/db0/cblas__dtrmm_8c.html":[3,0,1,2,63],
 "d5/db0/cblas__dtrmm_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,63,0],
-"d5/db0/cblas__dtrmm_8c_a289ca7ac0bf28e430fb02873ce7e23f6.html#a289ca7ac0bf28e430fb02873ce7e23f6":[3,0,1,2,63,8],
 "d5/db0/cblas__dtrmm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,63,2],
+"d5/db0/cblas__dtrmm_8c_a5f9ebfe6804f40135ec8208471ab62cd.html#a5f9ebfe6804f40135ec8208471ab62cd":[3,0,1,2,63,8],
 "d5/db0/cblas__dtrmm_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,63,6],
 "d5/db0/cblas__dtrmm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,63,4],
 "d5/db0/cblas__dtrmm_8c_a8bc04ca7122be8af5c345be6464f102a.html#a8bc04ca7122be8af5c345be6464f102a":[3,0,1,2,63,5],
@@ -211,8 +209,8 @@ var NAVTREEINDEX37 =
 "d5/db2/c__cblas1_8c_source.html":[3,0,1,3,3],
 "d5/db2/chseqr_8f.html":[3,0,5,184],
 "d5/db2/chseqr_8f_source.html":[3,0,5,184],
-"d5/db2/ztfttr_8f.html":[3,0,5,1946],
-"d5/db2/ztfttr_8f_source.html":[3,0,5,1946],
+"d5/db2/ztfttr_8f.html":[3,0,5,1944],
+"d5/db2/ztfttr_8f_source.html":[3,0,5,1944],
 "d5/db3/lapacke__zposvxx__work_8c.html":[3,0,4,3,2245],
 "d5/db3/lapacke__zposvxx__work_8c_a173f7d9afc9b5ee814c84aaf222cafde.html#a173f7d9afc9b5ee814c84aaf222cafde":[3,0,4,3,2245,0],
 "d5/db3/lapacke__zposvxx__work_8c_source.html":[3,0,4,3,2245],
@@ -224,8 +222,8 @@ var NAVTREEINDEX37 =
 "d5/db5/lapacke__ztbcon__work_8c.html":[3,0,4,3,2371],
 "d5/db5/lapacke__ztbcon__work_8c_a6d4a6590dc834a7ccb9831b1c864e2d8.html#a6d4a6590dc834a7ccb9831b1c864e2d8":[3,0,4,3,2371,0],
 "d5/db5/lapacke__ztbcon__work_8c_source.html":[3,0,4,3,2371],
-"d5/db5/zgbsvxx_8f.html":[3,0,5,1534],
-"d5/db5/zgbsvxx_8f_source.html":[3,0,5,1534],
+"d5/db5/zgbsvxx_8f.html":[3,0,5,1532],
+"d5/db5/zgbsvxx_8f_source.html":[3,0,5,1532],
 "d5/db6/lapacke__zgetsqrhrt_8c.html":[3,0,4,3,1962],
 "d5/db6/lapacke__zgetsqrhrt_8c_ad74ec6882dd5f5cc99fa23cdb1371bc6.html#ad74ec6882dd5f5cc99fa23cdb1371bc6":[3,0,4,3,1962,0],
 "d5/db6/lapacke__zgetsqrhrt_8c_source.html":[3,0,4,3,1962],
@@ -239,15 +237,17 @@ var NAVTREEINDEX37 =
 "d5/db7/lapacke__zunmhr_8c_source.html":[3,0,4,3,2464],
 "d5/db8/chbevd_8f.html":[3,0,5,103],
 "d5/db8/chbevd_8f_source.html":[3,0,5,103],
-"d5/db8/dlarra_8f.html":[3,0,5,715],
-"d5/db8/dlarra_8f_source.html":[3,0,5,715],
+"d5/db8/dlarra_8f.html":[3,0,5,714],
+"d5/db8/dlarra_8f_source.html":[3,0,5,714],
 "d5/db8/lapacke__slantr__work_8c.html":[3,0,4,3,1445],
 "d5/db8/lapacke__slantr__work_8c_ad10361e78aa703729f8a1d0da7b62fe5.html#ad10361e78aa703729f8a1d0da7b62fe5":[3,0,4,3,1445,0],
 "d5/db8/lapacke__slantr__work_8c_source.html":[3,0,4,3,1445],
-"d5/db9/sla__geamv_8f.html":[3,0,5,1133],
-"d5/db9/sla__geamv_8f_source.html":[3,0,5,1133],
+"d5/db9/sla__geamv_8f.html":[3,0,5,1131],
+"d5/db9/sla__geamv_8f_source.html":[3,0,5,1131],
 "d5/db9/zpot06_8f.html":[3,0,6,1,724],
 "d5/db9/zpot06_8f_source.html":[3,0,6,1,724],
-"d5/dba/dtrtri_8f.html":[3,0,5,994],
-"d5/dba/dtrtri_8f_source.html":[3,0,5,994]
+"d5/dba/dtrtri_8f.html":[3,0,5,993],
+"d5/dba/dtrtri_8f_source.html":[3,0,5,993],
+"d5/dba/lapacke__slarfx_8c.html":[3,0,4,3,1460],
+"d5/dba/lapacke__slarfx_8c_a500538960c20cb37d5312ef93bfbe355.html#a500538960c20cb37d5312ef93bfbe355":[3,0,4,3,1460,0]
 };
