@@ -1,7 +1,5 @@
 var NAVTREEINDEX38 =
 {
-"d5/dba/lapacke__slarfx_8c.html":[3,0,4,3,1460],
-"d5/dba/lapacke__slarfx_8c_a500538960c20cb37d5312ef93bfbe355.html#a500538960c20cb37d5312ef93bfbe355":[3,0,4,3,1460,0],
 "d5/dba/lapacke__slarfx_8c_source.html":[3,0,4,3,1460],
 "d5/dbb/lapacke__cgebrd_8c.html":[3,0,4,3,30],
 "d5/dbb/lapacke__cgebrd_8c_aaf08635f9f12d30f15c091c44b6f98d4.html#aaf08635f9f12d30f15c091c44b6f98d4":[3,0,4,3,30,0],
@@ -20,35 +18,35 @@ var NAVTREEINDEX38 =
 "d5/dbe/cgebal_8f_source.html":[3,0,5,17],
 "d5/dbf/derrtr_8f.html":[3,0,6,1,292],
 "d5/dbf/derrtr_8f_source.html":[3,0,6,1,292],
-"d5/dc0/zgeqrfp_8f.html":[3,0,5,1572],
-"d5/dc0/zgeqrfp_8f_source.html":[3,0,5,1572],
+"d5/dc0/zgeqrfp_8f.html":[3,0,5,1570],
+"d5/dc0/zgeqrfp_8f_source.html":[3,0,5,1570],
 "d5/dc1/chetd2_8f.html":[3,0,5,140],
 "d5/dc1/chetd2_8f_source.html":[3,0,5,140],
 "d5/dc1/lapacke__cgesvdx__work_8c.html":[3,0,4,3,105],
 "d5/dc1/lapacke__cgesvdx__work_8c_a7b511a8d471a7148e255671cf77fc552.html#a7b511a8d471a7148e255671cf77fc552":[3,0,4,3,105,0],
 "d5/dc1/lapacke__cgesvdx__work_8c_source.html":[3,0,4,3,105],
 "d5/dc2/group__complex16_g_tsolve.html":[0,0,5,0,3],
-"d5/dc2/group__complex16_g_tsolve_ga0f8fa2a56d81bf3db97572afda73b61a.html#ga0f8fa2a56d81bf3db97572afda73b61a":[3,0,5,1618,0],
+"d5/dc2/group__complex16_g_tsolve_ga0f8fa2a56d81bf3db97572afda73b61a.html#ga0f8fa2a56d81bf3db97572afda73b61a":[3,0,5,1616,0],
 "d5/dc2/group__complex16_g_tsolve_ga0f8fa2a56d81bf3db97572afda73b61a.html#ga0f8fa2a56d81bf3db97572afda73b61a":[0,0,5,0,3,1],
-"d5/dc2/group__complex16_g_tsolve_gafa718af2b9ce6eca26d8dd1cbfc3cedf.html#gafa718af2b9ce6eca26d8dd1cbfc3cedf":[3,0,5,1617,0],
+"d5/dc2/group__complex16_g_tsolve_gafa718af2b9ce6eca26d8dd1cbfc3cedf.html#gafa718af2b9ce6eca26d8dd1cbfc3cedf":[3,0,5,1615,0],
 "d5/dc2/group__complex16_g_tsolve_gafa718af2b9ce6eca26d8dd1cbfc3cedf.html#gafa718af2b9ce6eca26d8dd1cbfc3cedf":[0,0,5,0,3,0],
-"d5/dc3/zpptri_8f.html":[3,0,5,1874],
-"d5/dc3/zpptri_8f_source.html":[3,0,5,1874],
+"d5/dc3/zpptri_8f.html":[3,0,5,1872],
+"d5/dc3/zpptri_8f_source.html":[3,0,5,1872],
 "d5/dc4/lapacke__cgesvd__work_8c.html":[3,0,4,3,101],
 "d5/dc4/lapacke__cgesvd__work_8c_a31759bd20426743ff608530894c417fb.html#a31759bd20426743ff608530894c417fb":[3,0,4,3,101,0],
 "d5/dc4/lapacke__cgesvd__work_8c_source.html":[3,0,4,3,101],
 "d5/dc5/cgelsy_8f.html":[3,0,5,38],
 "d5/dc5/cgelsy_8f_source.html":[3,0,5,38],
 "d5/dc5/group__complex16_g_tcomputational.html":[0,0,5,1,3],
-"d5/dc5/group__complex16_g_tcomputational_ga11d60b5dc29a0f78c56fea7e602ae5b7.html#ga11d60b5dc29a0f78c56fea7e602ae5b7":[3,0,5,1621,0],
+"d5/dc5/group__complex16_g_tcomputational_ga11d60b5dc29a0f78c56fea7e602ae5b7.html#ga11d60b5dc29a0f78c56fea7e602ae5b7":[3,0,5,1619,0],
 "d5/dc5/group__complex16_g_tcomputational_ga11d60b5dc29a0f78c56fea7e602ae5b7.html#ga11d60b5dc29a0f78c56fea7e602ae5b7":[0,0,5,1,3,4],
-"d5/dc5/group__complex16_g_tcomputational_ga148e6aee5b49528c292d9425e415c8ab.html#ga148e6aee5b49528c292d9425e415c8ab":[3,0,5,1619,0],
+"d5/dc5/group__complex16_g_tcomputational_ga148e6aee5b49528c292d9425e415c8ab.html#ga148e6aee5b49528c292d9425e415c8ab":[3,0,5,1617,0],
 "d5/dc5/group__complex16_g_tcomputational_ga148e6aee5b49528c292d9425e415c8ab.html#ga148e6aee5b49528c292d9425e415c8ab":[0,0,5,1,3,2],
-"d5/dc5/group__complex16_g_tcomputational_ga245a808bba47aa88b0a67f9e518363bb.html#ga245a808bba47aa88b0a67f9e518363bb":[3,0,5,1615,0],
+"d5/dc5/group__complex16_g_tcomputational_ga245a808bba47aa88b0a67f9e518363bb.html#ga245a808bba47aa88b0a67f9e518363bb":[3,0,5,1613,0],
 "d5/dc5/group__complex16_g_tcomputational_ga245a808bba47aa88b0a67f9e518363bb.html#ga245a808bba47aa88b0a67f9e518363bb":[0,0,5,1,3,0],
-"d5/dc5/group__complex16_g_tcomputational_ga5435936793916e289edd3a7322e770de.html#ga5435936793916e289edd3a7322e770de":[3,0,5,1620,0],
+"d5/dc5/group__complex16_g_tcomputational_ga5435936793916e289edd3a7322e770de.html#ga5435936793916e289edd3a7322e770de":[3,0,5,1618,0],
 "d5/dc5/group__complex16_g_tcomputational_ga5435936793916e289edd3a7322e770de.html#ga5435936793916e289edd3a7322e770de":[0,0,5,1,3,3],
-"d5/dc5/group__complex16_g_tcomputational_gaef94b3e5def942900d60d274131ddf7e.html#gaef94b3e5def942900d60d274131ddf7e":[3,0,5,1616,0],
+"d5/dc5/group__complex16_g_tcomputational_gaef94b3e5def942900d60d274131ddf7e.html#gaef94b3e5def942900d60d274131ddf7e":[3,0,5,1614,0],
 "d5/dc5/group__complex16_g_tcomputational_gaef94b3e5def942900d60d274131ddf7e.html#gaef94b3e5def942900d60d274131ddf7e":[0,0,5,1,3,1],
 "d5/dc5/lapacke__slag2d__work_8c.html":[3,0,4,3,1433],
 "d5/dc5/lapacke__slag2d__work_8c_a94a49fa961b6f897c0d8a0011cfb3295.html#a94a49fa961b6f897c0d8a0011cfb3295":[3,0,4,3,1433,0],
@@ -56,13 +54,13 @@ var NAVTREEINDEX38 =
 "d5/dc6/lapacke__zhpsvx__work_8c.html":[3,0,4,3,2141],
 "d5/dc6/lapacke__zhpsvx__work_8c_a04da14222a5603f46a0a8ec9727f0a4b.html#a04da14222a5603f46a0a8ec9727f0a4b":[3,0,4,3,2141,0],
 "d5/dc6/lapacke__zhpsvx__work_8c_source.html":[3,0,4,3,2141],
-"d5/dc7/sla__porpvgrw_8f.html":[3,0,5,1140],
-"d5/dc7/sla__porpvgrw_8f_source.html":[3,0,5,1140],
+"d5/dc7/sla__porpvgrw_8f.html":[3,0,5,1138],
+"d5/dc7/sla__porpvgrw_8f_source.html":[3,0,5,1138],
 "d5/dc8/lapacke__ssytrf__rook__work_8c.html":[3,0,4,3,1742],
 "d5/dc8/lapacke__ssytrf__rook__work_8c_a8312f23f7a9222326556c83427b24998.html#a8312f23f7a9222326556c83427b24998":[3,0,4,3,1742,0],
 "d5/dc8/lapacke__ssytrf__rook__work_8c_source.html":[3,0,4,3,1742],
-"d5/dc9/ssyconv_8f.html":[3,0,5,1424],
-"d5/dc9/ssyconv_8f_source.html":[3,0,5,1424],
+"d5/dc9/ssyconv_8f.html":[3,0,5,1422],
+"d5/dc9/ssyconv_8f_source.html":[3,0,5,1422],
 "d5/dcc/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2zpotrf_8f.html":[3,0,5,1,0,1,3],
 "d5/dcc/_v_a_r_i_a_n_t_s_2cholesky_2_t_o_p_2zpotrf_8f_source.html":[3,0,5,1,0,1,3],
 "d5/dcc/dchkqrt_8f.html":[3,0,6,1,229],
@@ -95,8 +93,8 @@ var NAVTREEINDEX38 =
 "d5/dd4/lapacke__dppequ_8c.html":[3,0,4,3,974],
 "d5/dd4/lapacke__dppequ_8c_a65aae91a4d63adbecf59b663712687e4.html#a65aae91a4d63adbecf59b663712687e4":[3,0,4,3,974,0],
 "d5/dd4/lapacke__dppequ_8c_source.html":[3,0,4,3,974],
-"d5/dd4/zherfsx_8f.html":[3,0,5,1653],
-"d5/dd4/zherfsx_8f_source.html":[3,0,5,1653],
+"d5/dd4/zherfsx_8f.html":[3,0,5,1651],
+"d5/dd4/zherfsx_8f_source.html":[3,0,5,1651],
 "d5/dd6/lapacke__dggsvp__work_8c.html":[3,0,4,3,811],
 "d5/dd6/lapacke__dggsvp__work_8c_a7dfe446365e4d0e0242ac42c9466dddd.html#a7dfe446365e4d0e0242ac42c9466dddd":[3,0,4,3,811,0],
 "d5/dd6/lapacke__dggsvp__work_8c_source.html":[3,0,4,3,811],
@@ -119,19 +117,19 @@ var NAVTREEINDEX38 =
 "d5/ddb/lapacke__chpevx__work_8c.html":[3,0,4,3,289],
 "d5/ddb/lapacke__chpevx__work_8c_a516612d5aee6f7b395367e5bf5aaa03b.html#a516612d5aee6f7b395367e5bf5aaa03b":[3,0,4,3,289,0],
 "d5/ddb/lapacke__chpevx__work_8c_source.html":[3,0,4,3,289],
-"d5/ddb/zlaed0_8f.html":[3,0,5,1741],
-"d5/ddb/zlaed0_8f_source.html":[3,0,5,1741],
+"d5/ddb/zlaed0_8f.html":[3,0,5,1739],
+"d5/ddb/zlaed0_8f_source.html":[3,0,5,1739],
 "d5/ddc/claset_8f.html":[3,0,5,301],
 "d5/ddc/claset_8f_source.html":[3,0,5,301],
-"d5/ddc/icmax1_8f.html":[3,0,5,1000],
-"d5/ddc/icmax1_8f_source.html":[3,0,5,1000],
+"d5/ddc/icmax1_8f.html":[3,0,5,999],
+"d5/ddc/icmax1_8f_source.html":[3,0,5,999],
 "d5/ddc/lapacke__chpgvd__work_8c.html":[3,0,4,3,295],
 "d5/ddc/lapacke__chpgvd__work_8c_aea69c9310bb3c2b57f27b251c945433c.html#aea69c9310bb3c2b57f27b251c945433c":[3,0,4,3,295,0],
 "d5/ddc/lapacke__chpgvd__work_8c_source.html":[3,0,4,3,295],
-"d5/ddd/sorgql_8f.html":[3,0,5,1316],
-"d5/ddd/sorgql_8f_source.html":[3,0,5,1316],
-"d5/ddd/zlarzb_8f.html":[3,0,5,1818],
-"d5/ddd/zlarzb_8f_source.html":[3,0,5,1818],
+"d5/ddd/sorgql_8f.html":[3,0,5,1314],
+"d5/ddd/sorgql_8f_source.html":[3,0,5,1314],
+"d5/ddd/zlarzb_8f.html":[3,0,5,1816],
+"d5/ddd/zlarzb_8f_source.html":[3,0,5,1816],
 "d5/dde/lapacke__dgbequ__work_8c.html":[3,0,4,3,659],
 "d5/dde/lapacke__dgbequ__work_8c_aa2ad6130a3db9299168ee8b6b315a029.html#aa2ad6130a3db9299168ee8b6b315a029":[3,0,4,3,659,0],
 "d5/dde/lapacke__dgbequ__work_8c_source.html":[3,0,4,3,659],
@@ -150,17 +148,17 @@ var NAVTREEINDEX38 =
 "d5/de4/ddrvsx_8f_source.html":[3,0,6,0,124],
 "d5/de4/zdrvpt_8f.html":[3,0,6,1,630],
 "d5/de4/zdrvpt_8f_source.html":[3,0,6,1,630],
-"d5/de4/zhbevd__2stage_8f.html":[3,0,5,1626],
-"d5/de4/zhbevd__2stage_8f_source.html":[3,0,5,1626],
+"d5/de4/zhbevd__2stage_8f.html":[3,0,5,1624],
+"d5/de4/zhbevd__2stage_8f_source.html":[3,0,5,1624],
 "d5/de5/lapacke__chbevx__work_8c.html":[3,0,4,3,185],
 "d5/de5/lapacke__chbevx__work_8c_a5a8c1f84ad3e7fd9a8dc9aa15475fab4.html#a5a8c1f84ad3e7fd9a8dc9aa15475fab4":[3,0,4,3,185,0],
 "d5/de5/lapacke__chbevx__work_8c_source.html":[3,0,4,3,185],
 "d5/de6/dgegs_8f.html":[3,0,5,0,9],
 "d5/de6/dgegs_8f_source.html":[3,0,5,0,9],
-"d5/de6/stptri_8f.html":[3,0,5,1501],
-"d5/de6/stptri_8f_source.html":[3,0,5,1501],
-"d5/de7/slaneg_8f.html":[3,0,5,1186],
-"d5/de7/slaneg_8f_source.html":[3,0,5,1186],
+"d5/de6/stptri_8f.html":[3,0,5,1499],
+"d5/de6/stptri_8f_source.html":[3,0,5,1499],
+"d5/de7/slaneg_8f.html":[3,0,5,1184],
+"d5/de7/slaneg_8f_source.html":[3,0,5,1184],
 "d5/de8/lapacke__cgbrfs_8c.html":[3,0,4,3,12],
 "d5/de8/lapacke__cgbrfs_8c_aa39670a60a7f6a217c4d5606a330e77c.html#aa39670a60a7f6a217c4d5606a330e77c":[3,0,4,3,12,0],
 "d5/de8/lapacke__cgbrfs_8c_source.html":[3,0,4,3,12],
@@ -175,39 +173,39 @@ var NAVTREEINDEX38 =
 "d5/ded/lapacke__d__nancheck_8c_source.html":[3,0,4,4,38],
 "d5/dee/cblas__strmm_8c.html":[3,0,1,2,106],
 "d5/dee/cblas__strmm_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,106,0],
-"d5/dee/cblas__strmm_8c_a309421a4a267f3a3f8461b2d1c5db311.html#a309421a4a267f3a3f8461b2d1c5db311":[3,0,1,2,106,8],
 "d5/dee/cblas__strmm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,106,2],
 "d5/dee/cblas__strmm_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,106,6],
 "d5/dee/cblas__strmm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,106,4],
 "d5/dee/cblas__strmm_8c_a8bc04ca7122be8af5c345be6464f102a.html#a8bc04ca7122be8af5c345be6464f102a":[3,0,1,2,106,5],
 "d5/dee/cblas__strmm_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,106,1],
 "d5/dee/cblas__strmm_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,106,7],
+"d5/dee/cblas__strmm_8c_aa7b0ca27812cbafb41b9bbd7d359a357.html#aa7b0ca27812cbafb41b9bbd7d359a357":[3,0,1,2,106,8],
 "d5/dee/cblas__strmm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,106,3],
 "d5/dee/cblas__strmm_8c_source.html":[3,0,1,2,106],
 "d5/dee/schkqrtp_8f.html":[3,0,6,1,413],
 "d5/dee/schkqrtp_8f_source.html":[3,0,6,1,413],
-"d5/def/zpotf2_8f.html":[3,0,5,1863],
-"d5/def/zpotf2_8f_source.html":[3,0,5,1863],
+"d5/def/zpotf2_8f.html":[3,0,5,1861],
+"d5/def/zpotf2_8f_source.html":[3,0,5,1861],
 "d5/df0/clals0_8f.html":[3,0,5,236],
 "d5/df0/clals0_8f_source.html":[3,0,5,236],
 "d5/df0/dlafts_8f.html":[3,0,6,0,156],
 "d5/df0/dlafts_8f_source.html":[3,0,6,0,156],
 "d5/df1/cblas__sgemv_8c.html":[3,0,1,2,83],
 "d5/df1/cblas__sgemv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,83,0],
+"d5/df1/cblas__sgemv_8c_a1862b91312ac6c449960c4c0b9d497ae.html#a1862b91312ac6c449960c4c0b9d497ae":[3,0,1,2,83,6],
 "d5/df1/cblas__sgemv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,83,1],
-"d5/df1/cblas__sgemv_8c_a635a0f4176618975d4176d443aa20c69.html#a635a0f4176618975d4176d443aa20c69":[3,0,1,2,83,6],
 "d5/df1/cblas__sgemv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,83,5],
 "d5/df1/cblas__sgemv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,83,4],
 "d5/df1/cblas__sgemv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,83,2],
 "d5/df1/cblas__sgemv_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,83,3],
 "d5/df1/cblas__sgemv_8c_source.html":[3,0,1,2,83],
-"d5/df2/dgeevx_8f.html":[3,0,5,528],
-"d5/df2/dgeevx_8f_source.html":[3,0,5,528],
+"d5/df2/dgeevx_8f.html":[3,0,5,527],
+"d5/df2/dgeevx_8f_source.html":[3,0,5,527],
 "d5/df2/lapacke__sorcsd__work_8c.html":[3,0,4,3,1491],
 "d5/df2/lapacke__sorcsd__work_8c_a5576e7da34f75094d328b6b50f7fb316.html#a5576e7da34f75094d328b6b50f7fb316":[3,0,4,3,1491,0],
 "d5/df2/lapacke__sorcsd__work_8c_source.html":[3,0,4,3,1491],
-"d5/df2/ztpmlqt_8f.html":[3,0,5,1958],
-"d5/df2/ztpmlqt_8f_source.html":[3,0,5,1958],
+"d5/df2/ztpmlqt_8f.html":[3,0,5,1956],
+"d5/df2/ztpmlqt_8f_source.html":[3,0,5,1956],
 "d5/df3/lapacke__zhesvx_8c.html":[3,0,4,3,2078],
 "d5/df3/lapacke__zhesvx_8c_abb24f4745d1e64f573f6e5cf08aa9330.html#abb24f4745d1e64f573f6e5cf08aa9330":[3,0,4,3,2078,0],
 "d5/df3/lapacke__zhesvx_8c_source.html":[3,0,4,3,2078],
@@ -249,5 +247,7 @@ var NAVTREEINDEX38 =
 "d5/df8/lapacke__clantr_8c.html":[3,0,4,3,340],
 "d5/df8/lapacke__clantr_8c_a0df9fda5a264d49068a6828a49764519.html#a0df9fda5a264d49068a6828a49764519":[3,0,4,3,340,0],
 "d5/df8/lapacke__clantr_8c_source.html":[3,0,4,3,340],
-"d5/df9/lapacke__dpbrfs__work_8c.html":[3,0,4,3,931]
+"d5/df9/lapacke__dpbrfs__work_8c.html":[3,0,4,3,931],
+"d5/df9/lapacke__dpbrfs__work_8c_a93cb760258f3f0f4e4c661e265f4f1dd.html#a93cb760258f3f0f4e4c661e265f4f1dd":[3,0,4,3,931,0],
+"d5/df9/lapacke__dpbrfs__work_8c_source.html":[3,0,4,3,931]
 };
