@@ -1,51 +1,49 @@
 var NAVTREEINDEX39 =
 {
-"d5/df9/lapacke__dpbrfs__work_8c_a93cb760258f3f0f4e4c661e265f4f1dd.html#a93cb760258f3f0f4e4c661e265f4f1dd":[3,0,4,3,931,0],
-"d5/df9/lapacke__dpbrfs__work_8c_source.html":[3,0,4,3,931],
 "d5/dfa/cblas__ctbsv_8c.html":[3,0,1,2,26],
 "d5/dfa/cblas__ctbsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,26,0],
 "d5/dfa/cblas__ctbsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,26,1],
 "d5/dfa/cblas__ctbsv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,26,2],
-"d5/dfa/cblas__ctbsv_8c_a52925e88668b2d1e7b8d43cc5590b3f2.html#a52925e88668b2d1e7b8d43cc5590b3f2":[3,0,1,2,26,7],
 "d5/dfa/cblas__ctbsv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,26,5],
 "d5/dfa/cblas__ctbsv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,26,4],
 "d5/dfa/cblas__ctbsv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,26,3],
+"d5/dfa/cblas__ctbsv_8c_a9a26c0d1af9f3fc1249ef44217131b41.html#a9a26c0d1af9f3fc1249ef44217131b41":[3,0,1,2,26,7],
 "d5/dfa/cblas__ctbsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,26,6],
 "d5/dfa/cblas__ctbsv_8c_source.html":[3,0,1,2,26],
 "d5/dfb/group__complex16_g_bcomputational.html":[0,0,1,1,3],
-"d5/dfb/group__complex16_g_bcomputational_ga00a48689a70d8648e27d282870bd58bf.html#ga00a48689a70d8648e27d282870bd58bf":[3,0,5,1526,0],
+"d5/dfb/group__complex16_g_bcomputational_ga00a48689a70d8648e27d282870bd58bf.html#ga00a48689a70d8648e27d282870bd58bf":[3,0,5,1524,0],
 "d5/dfb/group__complex16_g_bcomputational_ga00a48689a70d8648e27d282870bd58bf.html#ga00a48689a70d8648e27d282870bd58bf":[0,0,1,1,3,0],
-"d5/dfb/group__complex16_g_bcomputational_ga06753b5d5c8432fbb7009909d321cdd0.html#ga06753b5d5c8432fbb7009909d321cdd0":[3,0,5,1535,0],
+"d5/dfb/group__complex16_g_bcomputational_ga06753b5d5c8432fbb7009909d321cdd0.html#ga06753b5d5c8432fbb7009909d321cdd0":[3,0,5,1533,0],
 "d5/dfb/group__complex16_g_bcomputational_ga06753b5d5c8432fbb7009909d321cdd0.html#ga06753b5d5c8432fbb7009909d321cdd0":[0,0,1,1,3,6],
-"d5/dfb/group__complex16_g_bcomputational_ga4b75373735df92b29116cf3bc549e363.html#ga4b75373735df92b29116cf3bc549e363":[3,0,5,1598,0],
+"d5/dfb/group__complex16_g_bcomputational_ga4b75373735df92b29116cf3bc549e363.html#ga4b75373735df92b29116cf3bc549e363":[3,0,5,1596,0],
 "d5/dfb/group__complex16_g_bcomputational_ga4b75373735df92b29116cf3bc549e363.html#ga4b75373735df92b29116cf3bc549e363":[0,0,1,1,3,10],
-"d5/dfb/group__complex16_g_bcomputational_ga5451de5ad5b709619fd4f45f3d7c425b.html#ga5451de5ad5b709619fd4f45f3d7c425b":[3,0,5,1530,0],
+"d5/dfb/group__complex16_g_bcomputational_ga5451de5ad5b709619fd4f45f3d7c425b.html#ga5451de5ad5b709619fd4f45f3d7c425b":[3,0,5,1528,0],
 "d5/dfb/group__complex16_g_bcomputational_ga5451de5ad5b709619fd4f45f3d7c425b.html#ga5451de5ad5b709619fd4f45f3d7c425b":[0,0,1,1,3,4],
-"d5/dfb/group__complex16_g_bcomputational_ga5cb4b9d353cfd24bd8862e8f2a845edb.html#ga5cb4b9d353cfd24bd8862e8f2a845edb":[3,0,5,1993,0],
+"d5/dfb/group__complex16_g_bcomputational_ga5cb4b9d353cfd24bd8862e8f2a845edb.html#ga5cb4b9d353cfd24bd8862e8f2a845edb":[3,0,5,1991,0],
 "d5/dfb/group__complex16_g_bcomputational_ga5cb4b9d353cfd24bd8862e8f2a845edb.html#ga5cb4b9d353cfd24bd8862e8f2a845edb":[0,0,1,1,3,16],
-"d5/dfb/group__complex16_g_bcomputational_ga70ef3ec53bb3d6704ccf2f9d0add0eda.html#ga70ef3ec53bb3d6704ccf2f9d0add0eda":[3,0,5,1707,0],
+"d5/dfb/group__complex16_g_bcomputational_ga70ef3ec53bb3d6704ccf2f9d0add0eda.html#ga70ef3ec53bb3d6704ccf2f9d0add0eda":[3,0,5,1705,0],
 "d5/dfb/group__complex16_g_bcomputational_ga70ef3ec53bb3d6704ccf2f9d0add0eda.html#ga70ef3ec53bb3d6704ccf2f9d0add0eda":[0,0,1,1,3,12],
-"d5/dfb/group__complex16_g_bcomputational_ga7c97209b521bc4c556f7aac044adba00.html#ga7c97209b521bc4c556f7aac044adba00":[3,0,5,1529,0],
+"d5/dfb/group__complex16_g_bcomputational_ga7c97209b521bc4c556f7aac044adba00.html#ga7c97209b521bc4c556f7aac044adba00":[3,0,5,1527,0],
 "d5/dfb/group__complex16_g_bcomputational_ga7c97209b521bc4c556f7aac044adba00.html#ga7c97209b521bc4c556f7aac044adba00":[0,0,1,1,3,3],
-"d5/dfb/group__complex16_g_bcomputational_ga8738f3a065af06737854349ab50a3015.html#ga8738f3a065af06737854349ab50a3015":[3,0,5,1527,0],
+"d5/dfb/group__complex16_g_bcomputational_ga8738f3a065af06737854349ab50a3015.html#ga8738f3a065af06737854349ab50a3015":[3,0,5,1525,0],
 "d5/dfb/group__complex16_g_bcomputational_ga8738f3a065af06737854349ab50a3015.html#ga8738f3a065af06737854349ab50a3015":[0,0,1,1,3,1],
-"d5/dfb/group__complex16_g_bcomputational_ga8c57793eab444ac626d6bf86a8d0a5d6.html#ga8c57793eab444ac626d6bf86a8d0a5d6":[3,0,5,1708,0],
+"d5/dfb/group__complex16_g_bcomputational_ga8c57793eab444ac626d6bf86a8d0a5d6.html#ga8c57793eab444ac626d6bf86a8d0a5d6":[3,0,5,1706,0],
 "d5/dfb/group__complex16_g_bcomputational_ga8c57793eab444ac626d6bf86a8d0a5d6.html#ga8c57793eab444ac626d6bf86a8d0a5d6":[0,0,1,1,3,13],
-"d5/dfb/group__complex16_g_bcomputational_ga943a0999e5e3fa707305ece7505e1757.html#ga943a0999e5e3fa707305ece7505e1757":[3,0,5,1709,0],
+"d5/dfb/group__complex16_g_bcomputational_ga943a0999e5e3fa707305ece7505e1757.html#ga943a0999e5e3fa707305ece7505e1757":[3,0,5,1707,0],
 "d5/dfb/group__complex16_g_bcomputational_ga943a0999e5e3fa707305ece7505e1757.html#ga943a0999e5e3fa707305ece7505e1757":[0,0,1,1,3,14],
-"d5/dfb/group__complex16_g_bcomputational_ga9b98a0ba02d0dc89be7ac6319a29755d.html#ga9b98a0ba02d0dc89be7ac6319a29755d":[3,0,5,1536,0],
+"d5/dfb/group__complex16_g_bcomputational_ga9b98a0ba02d0dc89be7ac6319a29755d.html#ga9b98a0ba02d0dc89be7ac6319a29755d":[3,0,5,1534,0],
 "d5/dfb/group__complex16_g_bcomputational_ga9b98a0ba02d0dc89be7ac6319a29755d.html#ga9b98a0ba02d0dc89be7ac6319a29755d":[0,0,1,1,3,7],
-"d5/dfb/group__complex16_g_bcomputational_gaa2680ba9e0dc10bfbc62319acf1ff067.html#gaa2680ba9e0dc10bfbc62319acf1ff067":[3,0,5,1710,0],
+"d5/dfb/group__complex16_g_bcomputational_gaa2680ba9e0dc10bfbc62319acf1ff067.html#gaa2680ba9e0dc10bfbc62319acf1ff067":[3,0,5,1708,0],
 "d5/dfb/group__complex16_g_bcomputational_gaa2680ba9e0dc10bfbc62319acf1ff067.html#gaa2680ba9e0dc10bfbc62319acf1ff067":[0,0,1,1,3,15],
-"d5/dfb/group__complex16_g_bcomputational_gaa379093bafefd601c50d4017add97bcc.html#gaa379093bafefd601c50d4017add97bcc":[3,0,5,1597,0],
+"d5/dfb/group__complex16_g_bcomputational_gaa379093bafefd601c50d4017add97bcc.html#gaa379093bafefd601c50d4017add97bcc":[3,0,5,1595,0],
 "d5/dfb/group__complex16_g_bcomputational_gaa379093bafefd601c50d4017add97bcc.html#gaa379093bafefd601c50d4017add97bcc":[0,0,1,1,3,9],
+"d5/dfb/group__complex16_g_bcomputational_gadc499be042b41eb62757b62dce1aa6d7.html#gadc499be042b41eb62757b62dce1aa6d7":[3,0,5,1526,0],
 "d5/dfb/group__complex16_g_bcomputational_gadc499be042b41eb62757b62dce1aa6d7.html#gadc499be042b41eb62757b62dce1aa6d7":[0,0,1,1,3,2],
-"d5/dfb/group__complex16_g_bcomputational_gadc499be042b41eb62757b62dce1aa6d7.html#gadc499be042b41eb62757b62dce1aa6d7":[3,0,5,1528,0],
-"d5/dfb/group__complex16_g_bcomputational_gaec856046d887af43e47d8468805b1c19.html#gaec856046d887af43e47d8468805b1c19":[3,0,5,1531,0],
 "d5/dfb/group__complex16_g_bcomputational_gaec856046d887af43e47d8468805b1c19.html#gaec856046d887af43e47d8468805b1c19":[0,0,1,1,3,5],
-"d5/dfb/group__complex16_g_bcomputational_gaf0580d30a1bd07214f6068317a467e34.html#gaf0580d30a1bd07214f6068317a467e34":[3,0,5,1706,0],
+"d5/dfb/group__complex16_g_bcomputational_gaec856046d887af43e47d8468805b1c19.html#gaec856046d887af43e47d8468805b1c19":[3,0,5,1529,0],
+"d5/dfb/group__complex16_g_bcomputational_gaf0580d30a1bd07214f6068317a467e34.html#gaf0580d30a1bd07214f6068317a467e34":[3,0,5,1704,0],
 "d5/dfb/group__complex16_g_bcomputational_gaf0580d30a1bd07214f6068317a467e34.html#gaf0580d30a1bd07214f6068317a467e34":[0,0,1,1,3,11],
-"d5/dfb/group__complex16_g_bcomputational_gaf3a96e7f621f139aa2750ae380e83700.html#gaf3a96e7f621f139aa2750ae380e83700":[3,0,5,1537,0],
+"d5/dfb/group__complex16_g_bcomputational_gaf3a96e7f621f139aa2750ae380e83700.html#gaf3a96e7f621f139aa2750ae380e83700":[3,0,5,1535,0],
 "d5/dfb/group__complex16_g_bcomputational_gaf3a96e7f621f139aa2750ae380e83700.html#gaf3a96e7f621f139aa2750ae380e83700":[0,0,1,1,3,8],
 "d5/dfb/zchkst_8f.html":[3,0,6,0,295],
 "d5/dfb/zchkst_8f_source.html":[3,0,6,0,295],
@@ -58,8 +56,8 @@ var NAVTREEINDEX39 =
 "d5/dfc/lapacke__zlarfb_8c.html":[3,0,4,3,2186],
 "d5/dfc/lapacke__zlarfb_8c_a6b2b1f4ed6a6d4a5585ae1276eee289a.html#a6b2b1f4ed6a6d4a5585ae1276eee289a":[3,0,4,3,2186,0],
 "d5/dfc/lapacke__zlarfb_8c_source.html":[3,0,4,3,2186],
-"d5/dfd/ilaslc_8f.html":[3,0,5,1010],
-"d5/dfd/ilaslc_8f_source.html":[3,0,5,1010],
+"d5/dfd/ilaslc_8f.html":[3,0,5,1009],
+"d5/dfd/ilaslc_8f_source.html":[3,0,5,1009],
 "d5/dfe/lapacke__zsyequb_8c.html":[3,0,4,3,2316],
 "d5/dfe/lapacke__zsyequb_8c_ab98aae684117ea349a22784116952a3a.html#ab98aae684117ea349a22784116952a3a":[3,0,4,3,2316,0],
 "d5/dfe/lapacke__zsyequb_8c_source.html":[3,0,4,3,2316],
@@ -76,8 +74,8 @@ var NAVTREEINDEX39 =
 "d6/d02/cblas__dspr_8c.html":[3,0,1,2,50],
 "d6/d02/cblas__dspr_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,50,0],
 "d6/d02/cblas__dspr_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,50,1],
+"d6/d02/cblas__dspr_8c_a9b2b23829afc42f557233a65a36077e3.html#a9b2b23829afc42f557233a65a36077e3":[3,0,1,2,50,3],
 "d6/d02/cblas__dspr_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,50,2],
-"d6/d02/cblas__dspr_8c_ae0b3d0d3a0e56a816b5d431ed93ec6c5.html#ae0b3d0d3a0e56a816b5d431ed93ec6c5":[3,0,1,2,50,3],
 "d6/d02/cblas__dspr_8c_source.html":[3,0,1,2,50],
 "d6/d02/lapacke__chpsv__work_8c.html":[3,0,4,3,301],
 "d6/d02/lapacke__chpsv__work_8c_aa67b93909d02db50aef55c2acda5f8b9.html#aa67b93909d02db50aef55c2acda5f8b9":[3,0,4,3,301,0],
@@ -87,8 +85,8 @@ var NAVTREEINDEX39 =
 "d6/d03/lapacke__sgghrd_8c.html":[3,0,4,3,1394],
 "d6/d03/lapacke__sgghrd_8c_a29f0b738eead4e960ae80dd241b4a769.html#a29f0b738eead4e960ae80dd241b4a769":[3,0,4,3,1394,0],
 "d6/d03/lapacke__sgghrd_8c_source.html":[3,0,4,3,1394],
-"d6/d04/zlanhb_8f.html":[3,0,5,1765],
-"d6/d04/zlanhb_8f_source.html":[3,0,5,1765],
+"d6/d04/zlanhb_8f.html":[3,0,5,1763],
+"d6/d04/zlanhb_8f_source.html":[3,0,5,1763],
 "d6/d05/zlavhe_8f.html":[3,0,6,1,706],
 "d6/d05/zlavhe_8f_source.html":[3,0,6,1,706],
 "d6/d06/example___d_g_e_s_v__rowmajor_8c.html":[3,0,4,0,3],
@@ -100,8 +98,8 @@ var NAVTREEINDEX39 =
 "d6/d08/lapacke__sgelq_8c.html":[3,0,4,3,1298],
 "d6/d08/lapacke__sgelq_8c_ae470c90071af6666698be801ee1a563b.html#ae470c90071af6666698be801ee1a563b":[3,0,4,3,1298,0],
 "d6/d08/lapacke__sgelq_8c_source.html":[3,0,4,3,1298],
-"d6/d08/sggbak_8f.html":[3,0,5,1100],
-"d6/d08/sggbak_8f_source.html":[3,0,5,1100],
+"d6/d08/sggbak_8f.html":[3,0,5,1098],
+"d6/d08/sggbak_8f_source.html":[3,0,5,1098],
 "d6/d09/cdrvsg_8f.html":[3,0,6,0,39],
 "d6/d09/cdrvsg_8f_source.html":[3,0,6,0,39],
 "d6/d0a/lapacke__cheequb_8c.html":[3,0,4,3,200],
@@ -110,49 +108,49 @@ var NAVTREEINDEX39 =
 "d6/d0a/lapacke__sgg__trans_8c.html":[3,0,4,4,81],
 "d6/d0a/lapacke__sgg__trans_8c_aa57eae52cacf7613e3b29cb8ce153bf4.html#aa57eae52cacf7613e3b29cb8ce153bf4":[3,0,4,4,81,0],
 "d6/d0a/lapacke__sgg__trans_8c_source.html":[3,0,4,4,81],
-"d6/d0a/zsytri2x_8f.html":[3,0,5,1930],
-"d6/d0a/zsytri2x_8f_source.html":[3,0,5,1930],
+"d6/d0a/zsytri2x_8f.html":[3,0,5,1928],
+"d6/d0a/zsytri2x_8f_source.html":[3,0,5,1928],
 "d6/d0b/cppt02_8f.html":[3,0,6,1,155],
 "d6/d0b/cppt02_8f_source.html":[3,0,6,1,155],
 "d6/d0b/lapacke__claswp__work_8c.html":[3,0,4,3,365],
 "d6/d0b/lapacke__claswp__work_8c_a9e3078587ae34f48fec64ec934af8e55.html#a9e3078587ae34f48fec64ec934af8e55":[3,0,4,3,365,0],
 "d6/d0b/lapacke__claswp__work_8c_source.html":[3,0,4,3,365],
-"d6/d0b/ssyswapr_8f.html":[3,0,5,1451],
-"d6/d0b/ssyswapr_8f_source.html":[3,0,5,1451],
+"d6/d0b/ssyswapr_8f.html":[3,0,5,1449],
+"d6/d0b/ssyswapr_8f_source.html":[3,0,5,1449],
 "d6/d0c/lapacke__sgerqf_8c.html":[3,0,4,3,1342],
 "d6/d0c/lapacke__sgerqf_8c_a1c198962019c8875f16211874079793e.html#a1c198962019c8875f16211874079793e":[3,0,4,3,1342,0],
 "d6/d0c/lapacke__sgerqf_8c_source.html":[3,0,4,3,1342],
-"d6/d0c/slasv2_8f.html":[3,0,5,1282],
-"d6/d0c/slasv2_8f_source.html":[3,0,5,1282],
-"d6/d0c/zlaein_8f.html":[3,0,5,1744],
-"d6/d0c/zlaein_8f_source.html":[3,0,5,1744],
+"d6/d0c/slasv2_8f.html":[3,0,5,1280],
+"d6/d0c/slasv2_8f_source.html":[3,0,5,1280],
+"d6/d0c/zlaein_8f.html":[3,0,5,1742],
+"d6/d0c/zlaein_8f_source.html":[3,0,5,1742],
 "d6/d0d/group__double_p_oauxiliary.html":[0,0,4,3,0],
 "d6/d0e/group__double_s_ysolve.html":[0,0,2,0,0],
-"d6/d0e/group__double_s_ysolve_ga183787a5a4cb471abe442815b0e44b35.html#ga183787a5a4cb471abe442815b0e44b35":[3,0,5,929,0],
+"d6/d0e/group__double_s_ysolve_ga183787a5a4cb471abe442815b0e44b35.html#ga183787a5a4cb471abe442815b0e44b35":[3,0,5,928,0],
 "d6/d0e/group__double_s_ysolve_ga183787a5a4cb471abe442815b0e44b35.html#ga183787a5a4cb471abe442815b0e44b35":[0,0,2,0,0,5],
-"d6/d0e/group__double_s_ysolve_ga1891fac0c928034e0c0396aa3d30f8f3.html#ga1891fac0c928034e0c0396aa3d30f8f3":[3,0,5,930,0],
+"d6/d0e/group__double_s_ysolve_ga1891fac0c928034e0c0396aa3d30f8f3.html#ga1891fac0c928034e0c0396aa3d30f8f3":[3,0,5,929,0],
 "d6/d0e/group__double_s_ysolve_ga1891fac0c928034e0c0396aa3d30f8f3.html#ga1891fac0c928034e0c0396aa3d30f8f3":[0,0,2,0,0,6],
-"d6/d0e/group__double_s_ysolve_ga1b3fcf55f485dd01efeb8435dccf9215.html#ga1b3fcf55f485dd01efeb8435dccf9215":[3,0,5,928,0],
+"d6/d0e/group__double_s_ysolve_ga1b3fcf55f485dd01efeb8435dccf9215.html#ga1b3fcf55f485dd01efeb8435dccf9215":[3,0,5,927,0],
 "d6/d0e/group__double_s_ysolve_ga1b3fcf55f485dd01efeb8435dccf9215.html#ga1b3fcf55f485dd01efeb8435dccf9215":[0,0,2,0,0,4],
-"d6/d0e/group__double_s_ysolve_ga590164a7509bc601db1950b9a45da83c.html#ga590164a7509bc601db1950b9a45da83c":[3,0,5,927,0],
+"d6/d0e/group__double_s_ysolve_ga590164a7509bc601db1950b9a45da83c.html#ga590164a7509bc601db1950b9a45da83c":[3,0,5,926,0],
 "d6/d0e/group__double_s_ysolve_ga590164a7509bc601db1950b9a45da83c.html#ga590164a7509bc601db1950b9a45da83c":[0,0,2,0,0,3],
-"d6/d0e/group__double_s_ysolve_ga9995c47692c9885ed5d6a6b431686f41.html#ga9995c47692c9885ed5d6a6b431686f41":[3,0,5,924,0],
+"d6/d0e/group__double_s_ysolve_ga9995c47692c9885ed5d6a6b431686f41.html#ga9995c47692c9885ed5d6a6b431686f41":[3,0,5,923,0],
 "d6/d0e/group__double_s_ysolve_ga9995c47692c9885ed5d6a6b431686f41.html#ga9995c47692c9885ed5d6a6b431686f41":[0,0,2,0,0,0],
-"d6/d0e/group__double_s_ysolve_ga9f78d49e5b2de9987bbc1b75f9564013.html#ga9f78d49e5b2de9987bbc1b75f9564013":[3,0,5,926,0],
+"d6/d0e/group__double_s_ysolve_ga9f78d49e5b2de9987bbc1b75f9564013.html#ga9f78d49e5b2de9987bbc1b75f9564013":[3,0,5,925,0],
 "d6/d0e/group__double_s_ysolve_ga9f78d49e5b2de9987bbc1b75f9564013.html#ga9f78d49e5b2de9987bbc1b75f9564013":[0,0,2,0,0,2],
-"d6/d0e/group__double_s_ysolve_gaa540b8322a0a6745799e1587aab188ca.html#gaa540b8322a0a6745799e1587aab188ca":[3,0,5,925,0],
+"d6/d0e/group__double_s_ysolve_gaa540b8322a0a6745799e1587aab188ca.html#gaa540b8322a0a6745799e1587aab188ca":[3,0,5,924,0],
 "d6/d0e/group__double_s_ysolve_gaa540b8322a0a6745799e1587aab188ca.html#gaa540b8322a0a6745799e1587aab188ca":[0,0,2,0,0,1],
 "d6/d0e/lapacke__chetri__work_8c.html":[3,0,4,3,265],
 "d6/d0e/lapacke__chetri__work_8c_a03962be5edc8982622a802079dbe2d45.html#a03962be5edc8982622a802079dbe2d45":[3,0,4,3,265,0],
 "d6/d0e/lapacke__chetri__work_8c_source.html":[3,0,4,3,265],
 "d6/d0e/sgbt02_8f.html":[3,0,6,1,477],
 "d6/d0e/sgbt02_8f_source.html":[3,0,6,1,477],
-"d6/d0e/sstegr_8f.html":[3,0,5,1412],
-"d6/d0e/sstegr_8f_source.html":[3,0,5,1412],
+"d6/d0e/sstegr_8f.html":[3,0,5,1410],
+"d6/d0e/sstegr_8f_source.html":[3,0,5,1410],
 "d6/d0e/zdrvsy_8f.html":[3,0,6,1,637],
 "d6/d0e/zdrvsy_8f_source.html":[3,0,6,1,637],
-"d6/d0e/zlasr_8f.html":[3,0,5,1823],
-"d6/d0e/zlasr_8f_source.html":[3,0,5,1823],
+"d6/d0e/zlasr_8f.html":[3,0,5,1821],
+"d6/d0e/zlasr_8f_source.html":[3,0,5,1821],
 "d6/d0f/lapacke__sgges3__work_8c.html":[3,0,4,3,1380],
 "d6/d0f/lapacke__sgges3__work_8c_a2125f032fa507fd2dd1e7c5cb5c810e7.html#a2125f032fa507fd2dd1e7c5cb5c810e7":[3,0,4,3,1380,0],
 "d6/d0f/lapacke__sgges3__work_8c_source.html":[3,0,4,3,1380],
@@ -162,25 +160,25 @@ var NAVTREEINDEX39 =
 "d6/d0f/srotm_8f_source.html":[3,0,0,0,92],
 "d6/d10/group__complex16_g_esolve.html":[0,0,0,0,3],
 "d6/d10/group__complex16_g_esolve_ga1d8089ba1e1538eb3d1ab0ebe97596c7.html#ga1d8089ba1e1538eb3d1ab0ebe97596c7":[0,0,0,0,3,1],
-"d6/d10/group__complex16_g_esolve_ga1d8089ba1e1538eb3d1ab0ebe97596c7.html#ga1d8089ba1e1538eb3d1ab0ebe97596c7":[3,0,5,1557,0],
+"d6/d10/group__complex16_g_esolve_ga1d8089ba1e1538eb3d1ab0ebe97596c7.html#ga1d8089ba1e1538eb3d1ab0ebe97596c7":[3,0,5,1555,0],
 "d6/d10/group__complex16_g_esolve_ga2f5a7b554bd143d8588b9ba5d6a8985c.html#ga2f5a7b554bd143d8588b9ba5d6a8985c":[3,0,5,0,29,0],
 "d6/d10/group__complex16_g_esolve_ga2f5a7b554bd143d8588b9ba5d6a8985c.html#ga2f5a7b554bd143d8588b9ba5d6a8985c":[0,0,0,0,3,4],
 "d6/d10/group__complex16_g_esolve_ga3fdbfbbdf63edec20151f08aa68985e4.html#ga3fdbfbbdf63edec20151f08aa68985e4":[0,0,0,0,3,9],
-"d6/d10/group__complex16_g_esolve_ga3fdbfbbdf63edec20151f08aa68985e4.html#ga3fdbfbbdf63edec20151f08aa68985e4":[3,0,5,1595,0],
+"d6/d10/group__complex16_g_esolve_ga3fdbfbbdf63edec20151f08aa68985e4.html#ga3fdbfbbdf63edec20151f08aa68985e4":[3,0,5,1593,0],
 "d6/d10/group__complex16_g_esolve_ga531713dfc62bc5df387b7bb486a9deeb.html#ga531713dfc62bc5df387b7bb486a9deeb":[0,0,0,0,3,6],
-"d6/d10/group__complex16_g_esolve_ga531713dfc62bc5df387b7bb486a9deeb.html#ga531713dfc62bc5df387b7bb486a9deeb":[3,0,5,1582,0],
+"d6/d10/group__complex16_g_esolve_ga531713dfc62bc5df387b7bb486a9deeb.html#ga531713dfc62bc5df387b7bb486a9deeb":[3,0,5,1580,0],
 "d6/d10/group__complex16_g_esolve_ga61e68db68886c3f80753fac87ca35a6e.html#ga61e68db68886c3f80753fac87ca35a6e":[0,0,0,0,3,3],
-"d6/d10/group__complex16_g_esolve_ga61e68db68886c3f80753fac87ca35a6e.html#ga61e68db68886c3f80753fac87ca35a6e":[3,0,5,1559,0],
+"d6/d10/group__complex16_g_esolve_ga61e68db68886c3f80753fac87ca35a6e.html#ga61e68db68886c3f80753fac87ca35a6e":[3,0,5,1557,0],
 "d6/d10/group__complex16_g_esolve_ga892cb7992dc737797a8b8043dfc81a48.html#ga892cb7992dc737797a8b8043dfc81a48":[0,0,0,0,3,0],
-"d6/d10/group__complex16_g_esolve_ga892cb7992dc737797a8b8043dfc81a48.html#ga892cb7992dc737797a8b8043dfc81a48":[3,0,5,1523,0],
+"d6/d10/group__complex16_g_esolve_ga892cb7992dc737797a8b8043dfc81a48.html#ga892cb7992dc737797a8b8043dfc81a48":[3,0,5,1521,0],
 "d6/d10/group__complex16_g_esolve_gab538c5c13af357a23b3b7433a3971354.html#gab538c5c13af357a23b3b7433a3971354":[0,0,0,0,3,5],
-"d6/d10/group__complex16_g_esolve_gab538c5c13af357a23b3b7433a3971354.html#gab538c5c13af357a23b3b7433a3971354":[3,0,5,1560,0],
+"d6/d10/group__complex16_g_esolve_gab538c5c13af357a23b3b7433a3971354.html#gab538c5c13af357a23b3b7433a3971354":[3,0,5,1558,0],
 "d6/d10/group__complex16_g_esolve_gabe3ae17895d46aeb7c9e5a076eaeeb69.html#gabe3ae17895d46aeb7c9e5a076eaeeb69":[0,0,0,0,3,7],
-"d6/d10/group__complex16_g_esolve_gabe3ae17895d46aeb7c9e5a076eaeeb69.html#gabe3ae17895d46aeb7c9e5a076eaeeb69":[3,0,5,1587,0],
+"d6/d10/group__complex16_g_esolve_gabe3ae17895d46aeb7c9e5a076eaeeb69.html#gabe3ae17895d46aeb7c9e5a076eaeeb69":[3,0,5,1585,0],
 "d6/d10/group__complex16_g_esolve_gae06e94cada1d406119efa6251a4eb308.html#gae06e94cada1d406119efa6251a4eb308":[0,0,0,0,3,2],
-"d6/d10/group__complex16_g_esolve_gae06e94cada1d406119efa6251a4eb308.html#gae06e94cada1d406119efa6251a4eb308":[3,0,5,1558,0],
+"d6/d10/group__complex16_g_esolve_gae06e94cada1d406119efa6251a4eb308.html#gae06e94cada1d406119efa6251a4eb308":[3,0,5,1556,0],
 "d6/d10/group__complex16_g_esolve_gaff43ace945f982f6612eeace3c1b4f3b.html#gaff43ace945f982f6612eeace3c1b4f3b":[0,0,0,0,3,8],
-"d6/d10/group__complex16_g_esolve_gaff43ace945f982f6612eeace3c1b4f3b.html#gaff43ace945f982f6612eeace3c1b4f3b":[3,0,5,1588,0],
+"d6/d10/group__complex16_g_esolve_gaff43ace945f982f6612eeace3c1b4f3b.html#gaff43ace945f982f6612eeace3c1b4f3b":[3,0,5,1586,0],
 "d6/d10/lapacke__zunmrq__work_8c.html":[3,0,4,3,2473],
 "d6/d10/lapacke__zunmrq__work_8c_a6e98bf8b7a81dd82da0bd7f06d8319c1.html#a6e98bf8b7a81dd82da0bd7f06d8319c1":[3,0,4,3,2473,0],
 "d6/d10/lapacke__zunmrq__work_8c_source.html":[3,0,4,3,2473],
@@ -189,8 +187,8 @@ var NAVTREEINDEX39 =
 "d6/d12/lapacke__dsyequb__work_8c_source.html":[3,0,4,3,1091],
 "d6/d12/snrm2_8f90.html":[3,0,0,0,89],
 "d6/d12/snrm2_8f90_source.html":[3,0,0,0,89],
-"d6/d12/ssbgv_8f.html":[3,0,5,1390],
-"d6/d12/ssbgv_8f_source.html":[3,0,5,1390],
+"d6/d12/ssbgv_8f.html":[3,0,5,1388],
+"d6/d12/ssbgv_8f_source.html":[3,0,5,1388],
 "d6/d13/lapacke__dsptrs_8c.html":[3,0,4,3,1060],
 "d6/d13/lapacke__dsptrs_8c_a70bd9f0a9d3967092d7c76b36e384073.html#a70bd9f0a9d3967092d7c76b36e384073":[3,0,4,3,1060,0],
 "d6/d13/lapacke__dsptrs_8c_source.html":[3,0,4,3,1060],
@@ -247,7 +245,9 @@ var NAVTREEINDEX39 =
 "d6/d19/lapacke__sggev3_8c.html":[3,0,4,3,1385],
 "d6/d19/lapacke__sggev3_8c_ac825b2cda47360a9959b9fc6228c10e7.html#ac825b2cda47360a9959b9fc6228c10e7":[3,0,4,3,1385,0],
 "d6/d19/lapacke__sggev3_8c_source.html":[3,0,4,3,1385],
-"d6/d1a/zunbdb4_8f.html":[3,0,5,1986],
-"d6/d1a/zunbdb4_8f_source.html":[3,0,5,1986],
-"d6/d1b/cdrves_8f.html":[3,0,6,0,37]
+"d6/d1a/zunbdb4_8f.html":[3,0,5,1984],
+"d6/d1a/zunbdb4_8f_source.html":[3,0,5,1984],
+"d6/d1b/cdrves_8f.html":[3,0,6,0,37],
+"d6/d1b/cdrves_8f_source.html":[3,0,6,0,37],
+"d6/d1c/clatps_8f.html":[3,0,5,312]
 };
