@@ -1,24 +1,22 @@
 var NAVTREEINDEX40 =
 {
-"d6/d1b/cdrves_8f_source.html":[3,0,6,0,37],
-"d6/d1c/clatps_8f.html":[3,0,5,312],
 "d6/d1c/clatps_8f_source.html":[3,0,5,312],
 "d6/d1c/dsyt22_8f.html":[3,0,6,0,180],
 "d6/d1c/dsyt22_8f_source.html":[3,0,6,0,180],
 "d6/d1c/lapacke__dormhr_8c.html":[3,0,4,3,912],
 "d6/d1c/lapacke__dormhr_8c_adeacd792ffa275097e445408163da41c.html#adeacd792ffa275097e445408163da41c":[3,0,4,3,912,0],
 "d6/d1c/lapacke__dormhr_8c_source.html":[3,0,4,3,912],
-"d6/d1d/zlassq_8f90.html":[3,0,5,1824],
-"d6/d1d/zlassq_8f90_source.html":[3,0,5,1824],
-"d6/d1f/slasd8_8f.html":[3,0,5,1268],
-"d6/d1f/slasd8_8f_source.html":[3,0,5,1268],
+"d6/d1d/zlassq_8f90.html":[3,0,5,1822],
+"d6/d1d/zlassq_8f90_source.html":[3,0,5,1822],
+"d6/d1f/slasd8_8f.html":[3,0,5,1266],
+"d6/d1f/slasd8_8f_source.html":[3,0,5,1266],
 "d6/d20/lapacke__slacpy_8c.html":[3,0,4,3,1430],
 "d6/d20/lapacke__slacpy_8c_a5a535e86b322f4f7674440da57152ac0.html#a5a535e86b322f4f7674440da57152ac0":[3,0,4,3,1430,0],
 "d6/d20/lapacke__slacpy_8c_source.html":[3,0,4,3,1430],
-"d6/d22/dgejsv_8f.html":[3,0,5,531],
-"d6/d22/dgejsv_8f_source.html":[3,0,5,531],
-"d6/d23/dtrttf_8f.html":[3,0,5,996],
-"d6/d23/dtrttf_8f_source.html":[3,0,5,996],
+"d6/d22/dgejsv_8f.html":[3,0,5,530],
+"d6/d22/dgejsv_8f_source.html":[3,0,5,530],
+"d6/d23/dtrttf_8f.html":[3,0,5,995],
+"d6/d23/dtrttf_8f_source.html":[3,0,5,995],
 "d6/d23/lapacke__dtpcon__work_8c.html":[3,0,4,3,1197],
 "d6/d23/lapacke__dtpcon__work_8c_a64fe6c355c352d45fd433ec1571a826f.html#a64fe6c355c352d45fd433ec1571a826f":[3,0,4,3,1197,0],
 "d6/d23/lapacke__dtpcon__work_8c_source.html":[3,0,4,3,1197],
@@ -37,21 +35,21 @@ var NAVTREEINDEX40 =
 "d6/d24/lapacke__zsy__trans_8c.html":[3,0,4,4,139],
 "d6/d24/lapacke__zsy__trans_8c_aaf42cba97c52a20a277d26cb2a396507.html#aaf42cba97c52a20a277d26cb2a396507":[3,0,4,4,139,0],
 "d6/d24/lapacke__zsy__trans_8c_source.html":[3,0,4,4,139],
-"d6/d24/zgges_8f.html":[3,0,5,1599],
-"d6/d24/zgges_8f_source.html":[3,0,5,1599],
+"d6/d24/zgges_8f.html":[3,0,5,1597],
+"d6/d24/zgges_8f_source.html":[3,0,5,1597],
 "d6/d25/cpbsv_8f.html":[3,0,5,325],
 "d6/d25/cpbsv_8f_source.html":[3,0,5,325],
-"d6/d25/dpoequb_8f.html":[3,0,5,830],
-"d6/d25/dpoequb_8f_source.html":[3,0,5,830],
-"d6/d26/dgeqrt2_8f.html":[3,0,5,554],
-"d6/d26/dgeqrt2_8f_source.html":[3,0,5,554],
+"d6/d25/dpoequb_8f.html":[3,0,5,829],
+"d6/d25/dpoequb_8f_source.html":[3,0,5,829],
+"d6/d26/dgeqrt2_8f.html":[3,0,5,553],
+"d6/d26/dgeqrt2_8f_source.html":[3,0,5,553],
 "d6/d26/lapacke__cpotrf2_8c.html":[3,0,4,3,409],
 "d6/d26/lapacke__cpotrf2_8c_a53b490f0c2fb6ea540c8042037bed7c9.html#a53b490f0c2fb6ea540c8042037bed7c9":[3,0,4,3,409,0],
 "d6/d26/lapacke__cpotrf2_8c_source.html":[3,0,4,3,409],
 "d6/d26/serred_8f.html":[3,0,6,0,224],
 "d6/d26/serred_8f_source.html":[3,0,6,0,224],
-"d6/d27/zlag2c_8f.html":[3,0,5,1747],
-"d6/d27/zlag2c_8f_source.html":[3,0,5,1747],
+"d6/d27/zlag2c_8f.html":[3,0,5,1745],
+"d6/d27/zlag2c_8f_source.html":[3,0,5,1745],
 "d6/d28/lapacke__dpbcon_8c.html":[3,0,4,3,926],
 "d6/d28/lapacke__dpbcon_8c_a32b6c6920bfa78aa3138997ad02628d7.html#a32b6c6920bfa78aa3138997ad02628d7":[3,0,4,3,926,0],
 "d6/d28/lapacke__dpbcon_8c_source.html":[3,0,4,3,926],
@@ -69,8 +67,8 @@ var NAVTREEINDEX40 =
 "d6/d2a/lapacke__zsysv__aa__work_8c.html":[3,0,4,3,2328],
 "d6/d2a/lapacke__zsysv__aa__work_8c_a5624695a9703df781d6d0402c5d7bbd0.html#a5624695a9703df781d6d0402c5d7bbd0":[3,0,4,3,2328,0],
 "d6/d2a/lapacke__zsysv__aa__work_8c_source.html":[3,0,4,3,2328],
-"d6/d2b/dgeqrt3_8f.html":[3,0,5,555],
-"d6/d2b/dgeqrt3_8f_source.html":[3,0,5,555],
+"d6/d2b/dgeqrt3_8f.html":[3,0,5,554],
+"d6/d2b/dgeqrt3_8f_source.html":[3,0,5,554],
 "d6/d2c/lapacke__sgetrs_8c.html":[3,0,4,3,1368],
 "d6/d2c/lapacke__sgetrs_8c_a10cfceda9ea0b0e2b7495eb8999da585.html#a10cfceda9ea0b0e2b7495eb8999da585":[3,0,4,3,1368,0],
 "d6/d2c/lapacke__sgetrs_8c_source.html":[3,0,4,3,1368],
@@ -119,13 +117,13 @@ var NAVTREEINDEX40 =
 "d6/d30/group__single__blas__level2_gafc92361b74c6d41c7e5afa0aa5d13ec9.html#gafc92361b74c6d41c7e5afa0aa5d13ec9":[3,0,0,0,87,0],
 "d6/d30/group__single__blas__level2_gafeb94d36b0bb94a6f87a0576e339434d.html#gafeb94d36b0bb94a6f87a0576e339434d":[0,2,1,0,9],
 "d6/d30/group__single__blas__level2_gafeb94d36b0bb94a6f87a0576e339434d.html#gafeb94d36b0bb94a6f87a0576e339434d":[3,0,0,0,103,0],
-"d6/d30/sgeqr2p_8f.html":[3,0,5,1073],
-"d6/d30/sgeqr2p_8f_source.html":[3,0,5,1073],
+"d6/d30/sgeqr2p_8f.html":[3,0,5,1071],
+"d6/d30/sgeqr2p_8f_source.html":[3,0,5,1071],
 "d6/d31/lapacke__zheevx__2stage_8c.html":[3,0,4,3,2053],
 "d6/d31/lapacke__zheevx__2stage_8c_a179a6436c263ca8793cd2703c0d0f232.html#a179a6436c263ca8793cd2703c0d0f232":[3,0,4,3,2053,0],
 "d6/d31/lapacke__zheevx__2stage_8c_source.html":[3,0,4,3,2053],
-"d6/d32/dlals0_8f.html":[3,0,5,657],
-"d6/d32/dlals0_8f_source.html":[3,0,5,657],
+"d6/d32/dlals0_8f.html":[3,0,5,656],
+"d6/d32/dlals0_8f_source.html":[3,0,5,656],
 "d6/d32/lapacke__cgelq2__work_8c.html":[3,0,4,3,52],
 "d6/d32/lapacke__cgelq2__work_8c_a30341bfec4c641e787c37462bf1df2ec.html#a30341bfec4c641e787c37462bf1df2ec":[3,0,4,3,52,0],
 "d6/d32/lapacke__cgelq2__work_8c_source.html":[3,0,4,3,52],
@@ -154,8 +152,8 @@ var NAVTREEINDEX40 =
 "d6/d39/lapacke__dgetf2__work_8c_source.html":[3,0,4,3,763],
 "d6/d3a/dchksy_8f.html":[3,0,6,1,234],
 "d6/d3a/dchksy_8f_source.html":[3,0,6,1,234],
-"d6/d3a/dlaqsp_8f.html":[3,0,5,695],
-"d6/d3a/dlaqsp_8f_source.html":[3,0,5,695],
+"d6/d3a/dlaqsp_8f.html":[3,0,5,694],
+"d6/d3a/dlaqsp_8f_source.html":[3,0,5,694],
 "d6/d3a/lapacke__dsprfs__work_8c.html":[3,0,4,3,1049],
 "d6/d3a/lapacke__dsprfs__work_8c_a37eaf5bc4b908bd0cb62b846c497ab83.html#a37eaf5bc4b908bd0cb62b846c497ab83":[3,0,4,3,1049,0],
 "d6/d3a/lapacke__dsprfs__work_8c_source.html":[3,0,4,3,1049],
@@ -172,8 +170,8 @@ var NAVTREEINDEX40 =
 "d6/d3c/lapacke__strcon_8c.html":[3,0,4,3,1810],
 "d6/d3c/lapacke__strcon_8c_a223550009e96a9e49f213ceaa9ae9178.html#a223550009e96a9e49f213ceaa9ae9178":[3,0,4,3,1810,0],
 "d6/d3c/lapacke__strcon_8c_source.html":[3,0,4,3,1810],
-"d6/d3c/stbtrs_8f.html":[3,0,5,1479],
-"d6/d3c/stbtrs_8f_source.html":[3,0,5,1479],
+"d6/d3c/stbtrs_8f.html":[3,0,5,1477],
+"d6/d3c/stbtrs_8f_source.html":[3,0,5,1477],
 "d6/d3d/lapacke__zpftri__work_8c.html":[3,0,4,3,2227],
 "d6/d3d/lapacke__zpftri__work_8c_a7cbd63b1fedeef969ac4823c7fafbc9d.html#a7cbd63b1fedeef969ac4823c7fafbc9d":[3,0,4,3,2227,0],
 "d6/d3d/lapacke__zpftri__work_8c_source.html":[3,0,4,3,2227],
@@ -182,58 +180,58 @@ var NAVTREEINDEX40 =
 "d6/d3e/lapacke__ztrrfs__work_8c_source.html":[3,0,4,3,2423],
 "d6/d3e/zhemm_8f.html":[3,0,0,0,128],
 "d6/d3e/zhemm_8f_source.html":[3,0,0,0,128],
-"d6/d40/ssytrf__aa__2stage_8f.html":[3,0,5,1462],
-"d6/d40/ssytrf__aa__2stage_8f_source.html":[3,0,5,1462],
+"d6/d40/ssytrf__aa__2stage_8f.html":[3,0,5,1460],
+"d6/d40/ssytrf__aa__2stage_8f_source.html":[3,0,5,1460],
 "d6/d41/zget52_8f.html":[3,0,6,0,334],
 "d6/d41/zget52_8f_source.html":[3,0,6,0,334],
 "d6/d42/lapacke__ssytri2x__work_8c.html":[3,0,4,3,1748],
 "d6/d42/lapacke__ssytri2x__work_8c_a94c09dc696646859f96392a0a33c72bd.html#a94c09dc696646859f96392a0a33c72bd":[3,0,4,3,1748,0],
 "d6/d42/lapacke__ssytri2x__work_8c_source.html":[3,0,4,3,1748],
-"d6/d42/zgesvd_8f.html":[3,0,5,1583],
-"d6/d42/zgesvd_8f_source.html":[3,0,5,1583],
-"d6/d43/dtrsyl_8f.html":[3,0,5,992],
-"d6/d43/dtrsyl_8f_source.html":[3,0,5,992],
+"d6/d42/zgesvd_8f.html":[3,0,5,1581],
+"d6/d42/zgesvd_8f_source.html":[3,0,5,1581],
+"d6/d43/dtrsyl_8f.html":[3,0,5,991],
+"d6/d43/dtrsyl_8f_source.html":[3,0,5,991],
 "d6/d43/lapacke__sporfsx__work_8c.html":[3,0,4,3,1555],
 "d6/d43/lapacke__sporfsx__work_8c_a74a47a46108403ca3ef994f64bc18971.html#a74a47a46108403ca3ef994f64bc18971":[3,0,4,3,1555,0],
 "d6/d43/lapacke__sporfsx__work_8c_source.html":[3,0,4,3,1555],
-"d6/d43/zpteqr_8f.html":[3,0,5,1879],
-"d6/d43/zpteqr_8f_source.html":[3,0,5,1879],
+"d6/d43/zpteqr_8f.html":[3,0,5,1877],
+"d6/d43/zpteqr_8f_source.html":[3,0,5,1877],
 "d6/d44/chpr2_8f.html":[3,0,0,0,18],
 "d6/d44/chpr2_8f_source.html":[3,0,0,0,18],
 "d6/d44/isamax_8f.html":[3,0,0,0,74],
 "d6/d44/isamax_8f_source.html":[3,0,0,0,74],
 "d6/d44/slattb_8f.html":[3,0,6,1,499],
 "d6/d44/slattb_8f_source.html":[3,0,6,1,499],
-"d6/d44/zlarnv_8f.html":[3,0,5,1812],
-"d6/d44/zlarnv_8f_source.html":[3,0,5,1812],
-"d6/d46/dggsvp3_8f.html":[3,0,5,592],
-"d6/d46/dggsvp3_8f_source.html":[3,0,5,592],
+"d6/d44/zlarnv_8f.html":[3,0,5,1810],
+"d6/d44/zlarnv_8f_source.html":[3,0,5,1810],
+"d6/d46/dggsvp3_8f.html":[3,0,5,591],
+"d6/d46/dggsvp3_8f_source.html":[3,0,5,591],
 "d6/d46/lapacke__zhptrd__work_8c.html":[3,0,4,3,2143],
 "d6/d46/lapacke__zhptrd__work_8c_a1d930f003ae9fd701a6405c1a193893b.html#a1d930f003ae9fd701a6405c1a193893b":[3,0,4,3,2143,0],
 "d6/d46/lapacke__zhptrd__work_8c_source.html":[3,0,4,3,2143],
 "d6/d46/sgbmv_8f.html":[3,0,0,0,85],
 "d6/d46/sgbmv_8f_source.html":[3,0,0,0,85],
-"d6/d46/slatbs_8f.html":[3,0,5,1290],
-"d6/d46/slatbs_8f_source.html":[3,0,5,1290],
-"d6/d47/zpbcon_8f.html":[3,0,5,1843],
-"d6/d47/zpbcon_8f_source.html":[3,0,5,1843],
+"d6/d46/slatbs_8f.html":[3,0,5,1288],
+"d6/d46/slatbs_8f_source.html":[3,0,5,1288],
+"d6/d47/zpbcon_8f.html":[3,0,5,1841],
+"d6/d47/zpbcon_8f_source.html":[3,0,5,1841],
 "d6/d49/clahr2_8f.html":[3,0,5,234],
 "d6/d49/clahr2_8f_source.html":[3,0,5,234],
-"d6/d49/dgetrs_8f.html":[3,0,5,574],
-"d6/d49/dgetrs_8f_source.html":[3,0,5,574],
+"d6/d49/dgetrs_8f.html":[3,0,5,573],
+"d6/d49/dgetrs_8f_source.html":[3,0,5,573],
 "d6/d49/zdrvrf1_8f.html":[3,0,6,1,631],
 "d6/d49/zdrvrf1_8f_source.html":[3,0,6,1,631],
 "d6/d4a/lapacke__zcgesv_8c.html":[3,0,4,3,1838],
 "d6/d4a/lapacke__zcgesv_8c_ac709b30a1e58d75db7729534601be382.html#ac709b30a1e58d75db7729534601be382":[3,0,4,3,1838,0],
 "d6/d4a/lapacke__zcgesv_8c_source.html":[3,0,4,3,1838],
-"d6/d4a/zgehrd_8f.html":[3,0,5,1550],
-"d6/d4a/zgehrd_8f_source.html":[3,0,5,1550],
+"d6/d4a/zgehrd_8f.html":[3,0,5,1548],
+"d6/d4a/zgehrd_8f_source.html":[3,0,5,1548],
 "d6/d4b/csysv__rook_8f.html":[3,0,5,395],
 "d6/d4b/csysv__rook_8f_source.html":[3,0,5,395],
-"d6/d4b/dgelsy_8f.html":[3,0,5,540],
-"d6/d4b/dgelsy_8f_source.html":[3,0,5,540],
-"d6/d4c/dlarrb_8f.html":[3,0,5,716],
-"d6/d4c/dlarrb_8f_source.html":[3,0,5,716],
+"d6/d4b/dgelsy_8f.html":[3,0,5,539],
+"d6/d4b/dgelsy_8f_source.html":[3,0,5,539],
+"d6/d4c/dlarrb_8f.html":[3,0,5,715],
+"d6/d4c/dlarrb_8f_source.html":[3,0,5,715],
 "d6/d4f/dlqt04_8f.html":[3,0,6,1,330],
 "d6/d4f/dlqt04_8f_source.html":[3,0,6,1,330],
 "d6/d50/sdrvrf3_8f.html":[3,0,6,1,440],
@@ -249,5 +247,7 @@ var NAVTREEINDEX40 =
 "d6/d52/csgt01_8f_source.html":[3,0,6,0,80],
 "d6/d52/dbdt04_8f.html":[3,0,6,0,89],
 "d6/d52/dbdt04_8f_source.html":[3,0,6,0,89],
-"d6/d52/lapacke__cgetrf__work_8c.html":[3,0,4,3,117]
+"d6/d52/lapacke__cgetrf__work_8c.html":[3,0,4,3,117],
+"d6/d52/lapacke__cgetrf__work_8c_a289dd8ce852ba4df4ccdcde60ee6086d.html#a289dd8ce852ba4df4ccdcde60ee6086d":[3,0,4,3,117,0],
+"d6/d52/lapacke__cgetrf__work_8c_source.html":[3,0,4,3,117]
 };
