@@ -1,9 +1,7 @@
 var NAVTREEINDEX41 =
 {
-"d6/d52/lapacke__cgetrf__work_8c_a289dd8ce852ba4df4ccdcde60ee6086d.html#a289dd8ce852ba4df4ccdcde60ee6086d":[3,0,4,3,117,0],
-"d6/d52/lapacke__cgetrf__work_8c_source.html":[3,0,4,3,117],
-"d6/d52/slag2_8f.html":[3,0,5,1168],
-"d6/d52/slag2_8f_source.html":[3,0,5,1168],
+"d6/d52/slag2_8f.html":[3,0,5,1166],
+"d6/d52/slag2_8f_source.html":[3,0,5,1166],
 "d6/d53/dchkql_8f.html":[3,0,6,1,227],
 "d6/d53/dchkql_8f_source.html":[3,0,6,1,227],
 "d6/d53/lapacke__dpbtrs__work_8c.html":[3,0,4,3,941],
@@ -27,8 +25,8 @@ var NAVTREEINDEX41 =
 "d6/d55/lapacke__zgerfs__work_8c_source.html":[3,0,4,3,1929],
 "d6/d55/zdrvab_8f.html":[3,0,6,1,611],
 "d6/d55/zdrvab_8f_source.html":[3,0,6,1,611],
-"d6/d56/zgbtrs_8f.html":[3,0,5,1537],
-"d6/d56/zgbtrs_8f_source.html":[3,0,5,1537],
+"d6/d56/zgbtrs_8f.html":[3,0,5,1535],
+"d6/d56/zgbtrs_8f_source.html":[3,0,5,1535],
 "d6/d58/dget31_8f.html":[3,0,6,0,137],
 "d6/d58/dget31_8f_source.html":[3,0,6,0,137],
 "d6/d58/lapacke__ssytrs__3__work_8c.html":[3,0,4,3,1756],
@@ -55,12 +53,15 @@ var NAVTREEINDEX41 =
 "d6/d5a/group__complex_o_t_h_e_rsolve_gab6eacad249a7dcb36a0fae555742c656.html#gab6eacad249a7dcb36a0fae555742c656":[3,0,5,326,0],
 "d6/d5a/group__complex_o_t_h_e_rsolve_gae79199f531e34e35f3a2939d14fe5455.html#gae79199f531e34e35f3a2939d14fe5455":[0,0,10,2,1],
 "d6/d5a/group__complex_o_t_h_e_rsolve_gae79199f531e34e35f3a2939d14fe5455.html#gae79199f531e34e35f3a2939d14fe5455":[3,0,5,177,0],
-"d6/d5a/slatdf_8f.html":[3,0,5,1291],
-"d6/d5a/slatdf_8f_source.html":[3,0,5,1291],
+"d6/d5a/slatdf_8f.html":[3,0,5,1289],
+"d6/d5a/slatdf_8f_source.html":[3,0,5,1289],
 "d6/d5b/cgemm_8f.html":[3,0,0,0,5],
 "d6/d5b/cgemm_8f_source.html":[3,0,0,0,5],
-"d6/d5b/sspsv_8f.html":[3,0,5,1404],
-"d6/d5b/sspsv_8f_source.html":[3,0,5,1404],
+"d6/d5b/sspsv_8f.html":[3,0,5,1402],
+"d6/d5b/sspsv_8f_source.html":[3,0,5,1402],
+"d6/d5c/droundup__lwork_8f.html":[3,0,3,3],
+"d6/d5c/droundup__lwork_8f_ad90a3af6d4f2e0745500103604b49480.html#ad90a3af6d4f2e0745500103604b49480":[3,0,3,3,0],
+"d6/d5c/droundup__lwork_8f_source.html":[3,0,3,3],
 "d6/d5c/lapacke__spptri__work_8c.html":[3,0,4,3,1583],
 "d6/d5c/lapacke__spptri__work_8c_aa6f974e678425061ecd1016484979cf7.html#aa6f974e678425061ecd1016484979cf7":[3,0,4,3,1583,0],
 "d6/d5c/lapacke__spptri__work_8c_source.html":[3,0,4,3,1583],
@@ -78,11 +79,11 @@ var NAVTREEINDEX41 =
 "d6/d61/cblas__sger_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,84,4],
 "d6/d61/cblas__sger_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,84,2],
 "d6/d61/cblas__sger_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,84,3],
-"d6/d61/cblas__sger_8c_af339e20680f50d6d72005c3b7e163e32.html#af339e20680f50d6d72005c3b7e163e32":[3,0,1,2,84,5],
+"d6/d61/cblas__sger_8c_af58442b7ce3f0259b5f918e841128435.html#af58442b7ce3f0259b5f918e841128435":[3,0,1,2,84,5],
 "d6/d61/cblas__sger_8c_source.html":[3,0,1,2,84],
-"d6/d61/dgeqr_8f.html":[3,0,5,548],
-"d6/d61/dgeqr_8f_ab20e537c689b3d58da800847243310d0.html#ab20e537c689b3d58da800847243310d0":[3,0,5,548,0],
-"d6/d61/dgeqr_8f_source.html":[3,0,5,548],
+"d6/d61/dgeqr_8f.html":[3,0,5,547],
+"d6/d61/dgeqr_8f_ab20e537c689b3d58da800847243310d0.html#ab20e537c689b3d58da800847243310d0":[3,0,5,547,0],
+"d6/d61/dgeqr_8f_source.html":[3,0,5,547],
 "d6/d61/lapacke__stp__nancheck_8c.html":[3,0,4,4,105],
 "d6/d61/lapacke__stp__nancheck_8c_a31639cbfcf91e691be7866900ab9e666.html#a31639cbfcf91e691be7866900ab9e666":[3,0,4,4,105,0],
 "d6/d61/lapacke__stp__nancheck_8c_source.html":[3,0,4,4,105],
@@ -112,8 +113,8 @@ var NAVTREEINDEX41 =
 "d6/d66/lapacke__spptri_8c.html":[3,0,4,3,1582],
 "d6/d66/lapacke__spptri_8c_a43f45fa5663e3cb2d70e21b16b37e12a.html#a43f45fa5663e3cb2d70e21b16b37e12a":[3,0,4,3,1582,0],
 "d6/d66/lapacke__spptri_8c_source.html":[3,0,4,3,1582],
-"d6/d66/slacon_8f.html":[3,0,5,1149],
-"d6/d66/slacon_8f_source.html":[3,0,5,1149],
+"d6/d66/slacon_8f.html":[3,0,5,1147],
+"d6/d66/slacon_8f_source.html":[3,0,5,1147],
 "d6/d67/cgetri_8f.html":[3,0,5,71],
 "d6/d67/cgetri_8f_source.html":[3,0,5,71],
 "d6/d68/lapacke__cstedc_8c.html":[3,0,4,3,462],
@@ -124,10 +125,10 @@ var NAVTREEINDEX41 =
 "d6/d6b/lapacke__dsytri__work_8c.html":[3,0,4,3,1157],
 "d6/d6b/lapacke__dsytri__work_8c_a86c28b3aa0c293072fe26d33baf84197.html#a86c28b3aa0c293072fe26d33baf84197":[3,0,4,3,1157,0],
 "d6/d6b/lapacke__dsytri__work_8c_source.html":[3,0,4,3,1157],
-"d6/d6b/ssbgvd_8f.html":[3,0,5,1391],
-"d6/d6b/ssbgvd_8f_source.html":[3,0,5,1391],
-"d6/d6b/stplqt2_8f.html":[3,0,5,1494],
-"d6/d6b/stplqt2_8f_source.html":[3,0,5,1494],
+"d6/d6b/ssbgvd_8f.html":[3,0,5,1389],
+"d6/d6b/ssbgvd_8f_source.html":[3,0,5,1389],
+"d6/d6b/stplqt2_8f.html":[3,0,5,1492],
+"d6/d6b/stplqt2_8f_source.html":[3,0,5,1492],
 "d6/d6c/lapacke__dsbtrd_8c.html":[3,0,4,3,1024],
 "d6/d6c/lapacke__dsbtrd_8c_afd7f964883b2ab8ac39d9efb9504444a.html#afd7f964883b2ab8ac39d9efb9504444a":[3,0,4,3,1024,0],
 "d6/d6c/lapacke__dsbtrd_8c_source.html":[3,0,4,3,1024],
@@ -136,12 +137,12 @@ var NAVTREEINDEX41 =
 "d6/d6d/lapacke__zlange__work_8c.html":[3,0,4,3,2173],
 "d6/d6d/lapacke__zlange__work_8c_a97d31e666ab194c9c3063afbc558db8d.html#a97d31e666ab194c9c3063afbc558db8d":[3,0,4,3,2173,0],
 "d6/d6d/lapacke__zlange__work_8c_source.html":[3,0,4,3,2173],
-"d6/d6d/ssysvx_8f.html":[3,0,5,1449],
-"d6/d6d/ssysvx_8f_source.html":[3,0,5,1449],
-"d6/d6e/zsytrf__rook_8f.html":[3,0,5,1927],
-"d6/d6e/zsytrf__rook_8f_source.html":[3,0,5,1927],
-"d6/d6f/dtrtrs_8f.html":[3,0,5,995],
-"d6/d6f/dtrtrs_8f_source.html":[3,0,5,995],
+"d6/d6d/ssysvx_8f.html":[3,0,5,1447],
+"d6/d6d/ssysvx_8f_source.html":[3,0,5,1447],
+"d6/d6e/zsytrf__rook_8f.html":[3,0,5,1925],
+"d6/d6e/zsytrf__rook_8f_source.html":[3,0,5,1925],
+"d6/d6f/dtrtrs_8f.html":[3,0,5,994],
+"d6/d6f/dtrtrs_8f_source.html":[3,0,5,994],
 "d6/d6f/group__double__blas__testing.html":[0,2,4,1],
 "d6/d6f/group__double__blas__testing_ga39e559692fad240e74460f5a8b42a3e0.html#ga39e559692fad240e74460f5a8b42a3e0":[3,0,0,1,3,4],
 "d6/d6f/group__double__blas__testing_ga39e559692fad240e74460f5a8b42a3e0.html#ga39e559692fad240e74460f5a8b42a3e0":[0,2,4,1,0],
@@ -152,8 +153,8 @@ var NAVTREEINDEX41 =
 "d6/d6f/lapacke__sgejsv_8c.html":[3,0,4,3,1296],
 "d6/d6f/lapacke__sgejsv_8c_aadd9f34457f108e91539133eb6beb1e5.html#aadd9f34457f108e91539133eb6beb1e5":[3,0,4,3,1296,0],
 "d6/d6f/lapacke__sgejsv_8c_source.html":[3,0,4,3,1296],
-"d6/d6f/zhetrf__rook_8f.html":[3,0,5,1674],
-"d6/d6f/zhetrf__rook_8f_source.html":[3,0,5,1674],
+"d6/d6f/zhetrf__rook_8f.html":[3,0,5,1672],
+"d6/d6f/zhetrf__rook_8f_source.html":[3,0,5,1672],
 "d6/d70/zhet01_8f.html":[3,0,6,1,690],
 "d6/d70/zhet01_8f_source.html":[3,0,6,1,690],
 "d6/d71/clalsd_8f.html":[3,0,5,238],
@@ -165,11 +166,11 @@ var NAVTREEINDEX41 =
 "d6/d71/lapacke__ztzrzf__work_8c.html":[3,0,4,3,2439],
 "d6/d71/lapacke__ztzrzf__work_8c_a2ca13f58516698cd55190699d66e5f22.html#a2ca13f58516698cd55190699d66e5f22":[3,0,4,3,2439,0],
 "d6/d71/lapacke__ztzrzf__work_8c_source.html":[3,0,4,3,2439],
-"d6/d72/dsecnd___i_n_t___e_t_i_m_e_8f.html":[3,0,3,6],
-"d6/d72/dsecnd___i_n_t___e_t_i_m_e_8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,6,0],
-"d6/d72/dsecnd___i_n_t___e_t_i_m_e_8f_source.html":[3,0,3,6],
-"d6/d72/sla__gercond_8f.html":[3,0,5,1134],
-"d6/d72/sla__gercond_8f_source.html":[3,0,5,1134],
+"d6/d72/dsecnd___i_n_t___e_t_i_m_e_8f.html":[3,0,3,7],
+"d6/d72/dsecnd___i_n_t___e_t_i_m_e_8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,7,0],
+"d6/d72/dsecnd___i_n_t___e_t_i_m_e_8f_source.html":[3,0,3,7],
+"d6/d72/sla__gercond_8f.html":[3,0,5,1132],
+"d6/d72/sla__gercond_8f_source.html":[3,0,5,1132],
 "d6/d73/dlatm5_8f.html":[3,0,6,2,30],
 "d6/d73/dlatm5_8f_source.html":[3,0,6,2,30],
 "d6/d73/lapacke__cggsvp3_8c.html":[3,0,4,3,159],
@@ -185,10 +186,10 @@ var NAVTREEINDEX41 =
 "d6/d76/lapacke__ztrexc_8c_source.html":[3,0,4,3,2420],
 "d6/d76/zlctsx_8f.html":[3,0,6,0,349],
 "d6/d76/zlctsx_8f_source.html":[3,0,6,0,349],
-"d6/d77/dla__syamv_8f.html":[3,0,5,618],
-"d6/d77/dla__syamv_8f_source.html":[3,0,5,618],
-"d6/d78/dorgql_8f.html":[3,0,5,794],
-"d6/d78/dorgql_8f_source.html":[3,0,5,794],
+"d6/d77/dla__syamv_8f.html":[3,0,5,617],
+"d6/d77/dla__syamv_8f_source.html":[3,0,5,617],
+"d6/d78/dorgql_8f.html":[3,0,5,793],
+"d6/d78/dorgql_8f_source.html":[3,0,5,793],
 "d6/d78/lapacke__zgghrd__work_8c.html":[3,0,4,3,1985],
 "d6/d78/lapacke__zgghrd__work_8c_ab6c519f56e65bae957d5dcfd522241a7.html#ab6c519f56e65bae957d5dcfd522241a7":[3,0,4,3,1985,0],
 "d6/d78/lapacke__zgghrd__work_8c_source.html":[3,0,4,3,1985],
@@ -198,8 +199,8 @@ var NAVTREEINDEX41 =
 "d6/d7c/chbevd__2stage_8f.html":[3,0,5,104],
 "d6/d7c/chbevd__2stage_8f_source.html":[3,0,5,104],
 "d6/d7c/group__complex__eig.html":[0,1,2,2],
-"d6/d7c/group__complex__eig_ga00458f67544e6b941bb4b947d54e239f.html#ga00458f67544e6b941bb4b947d54e239f":[0,1,2,2,32],
 "d6/d7c/group__complex__eig_ga00458f67544e6b941bb4b947d54e239f.html#ga00458f67544e6b941bb4b947d54e239f":[3,0,6,0,39,0],
+"d6/d7c/group__complex__eig_ga00458f67544e6b941bb4b947d54e239f.html#ga00458f67544e6b941bb4b947d54e239f":[0,1,2,2,32],
 "d6/d7c/group__complex__eig_ga02f888d1e47ac0a876793161ada51c49.html#ga02f888d1e47ac0a876793161ada51c49":[0,1,2,2,18],
 "d6/d7c/group__complex__eig_ga02f888d1e47ac0a876793161ada51c49.html#ga02f888d1e47ac0a876793161ada51c49":[3,0,6,0,25,0],
 "d6/d7c/group__complex__eig_ga05eff262113cc6cd7a9142ae1269dac0.html#ga05eff262113cc6cd7a9142ae1269dac0":[0,1,2,2,35],
@@ -214,14 +215,14 @@ var NAVTREEINDEX41 =
 "d6/d7c/group__complex__eig_ga1bad51cd5228d6748888b32aaa29b8e4.html#ga1bad51cd5228d6748888b32aaa29b8e4":[3,0,6,0,82,0],
 "d6/d7c/group__complex__eig_ga21eb09898bd5e7259abc7e07868c3687.html#ga21eb09898bd5e7259abc7e07868c3687":[0,1,2,2,27],
 "d6/d7c/group__complex__eig_ga21eb09898bd5e7259abc7e07868c3687.html#ga21eb09898bd5e7259abc7e07868c3687":[3,0,6,0,34,0],
-"d6/d7c/group__complex__eig_ga25f6db849fd0d68eaa2e68917e36a38e.html#ga25f6db849fd0d68eaa2e68917e36a38e":[3,0,6,0,68,0],
 "d6/d7c/group__complex__eig_ga25f6db849fd0d68eaa2e68917e36a38e.html#ga25f6db849fd0d68eaa2e68917e36a38e":[0,1,2,2,61],
+"d6/d7c/group__complex__eig_ga25f6db849fd0d68eaa2e68917e36a38e.html#ga25f6db849fd0d68eaa2e68917e36a38e":[3,0,6,0,68,0],
 "d6/d7c/group__complex__eig_ga26e28ed198349b9824bd5809a4b72b8f.html#ga26e28ed198349b9824bd5809a4b72b8f":[0,1,2,2,76],
 "d6/d7c/group__complex__eig_ga26e28ed198349b9824bd5809a4b72b8f.html#ga26e28ed198349b9824bd5809a4b72b8f":[3,0,6,0,83,0],
 "d6/d7c/group__complex__eig_ga275bf58dfd5af715eea76b14ff5f6023.html#ga275bf58dfd5af715eea76b14ff5f6023":[0,1,2,2,67],
 "d6/d7c/group__complex__eig_ga275bf58dfd5af715eea76b14ff5f6023.html#ga275bf58dfd5af715eea76b14ff5f6023":[3,0,6,0,74,0],
-"d6/d7c/group__complex__eig_ga28909ffc04948989e0c6bf3dedaed598.html#ga28909ffc04948989e0c6bf3dedaed598":[3,0,6,0,64,0],
 "d6/d7c/group__complex__eig_ga28909ffc04948989e0c6bf3dedaed598.html#ga28909ffc04948989e0c6bf3dedaed598":[0,1,2,2,57],
+"d6/d7c/group__complex__eig_ga28909ffc04948989e0c6bf3dedaed598.html#ga28909ffc04948989e0c6bf3dedaed598":[3,0,6,0,64,0],
 "d6/d7c/group__complex__eig_ga2b82bbab7031b4a887831d1cf3d3ac42.html#ga2b82bbab7031b4a887831d1cf3d3ac42":[0,1,2,2,29],
 "d6/d7c/group__complex__eig_ga2b82bbab7031b4a887831d1cf3d3ac42.html#ga2b82bbab7031b4a887831d1cf3d3ac42":[3,0,6,0,36,0],
 "d6/d7c/group__complex__eig_ga2de5d5cdd79b4ab56fd984ac860f1b36.html#ga2de5d5cdd79b4ab56fd984ac860f1b36":[0,1,2,2,37],
@@ -236,8 +237,8 @@ var NAVTREEINDEX41 =
 "d6/d7c/group__complex__eig_ga33af268bb77b50a691195ec96919e2f4.html#ga33af268bb77b50a691195ec96919e2f4":[3,0,6,0,14,0],
 "d6/d7c/group__complex__eig_ga348eb5544a2d2680f42ba665fcd5b81c.html#ga348eb5544a2d2680f42ba665fcd5b81c":[0,1,2,2,47],
 "d6/d7c/group__complex__eig_ga348eb5544a2d2680f42ba665fcd5b81c.html#ga348eb5544a2d2680f42ba665fcd5b81c":[3,0,6,0,54,0],
-"d6/d7c/group__complex__eig_ga38ae0be71db106e536d22d0982164f3e.html#ga38ae0be71db106e536d22d0982164f3e":[0,1,2,2,11],
 "d6/d7c/group__complex__eig_ga38ae0be71db106e536d22d0982164f3e.html#ga38ae0be71db106e536d22d0982164f3e":[3,0,6,0,18,0],
+"d6/d7c/group__complex__eig_ga38ae0be71db106e536d22d0982164f3e.html#ga38ae0be71db106e536d22d0982164f3e":[0,1,2,2,11],
 "d6/d7c/group__complex__eig_ga38c55aad209e2f68c34d7959912ee253.html#ga38c55aad209e2f68c34d7959912ee253":[3,0,6,0,17,0],
 "d6/d7c/group__complex__eig_ga38c55aad209e2f68c34d7959912ee253.html#ga38c55aad209e2f68c34d7959912ee253":[0,1,2,2,10],
 "d6/d7c/group__complex__eig_ga392b1b165355ea949383c3c5f701b0e1.html#ga392b1b165355ea949383c3c5f701b0e1":[0,1,2,2,12],
@@ -248,6 +249,5 @@ var NAVTREEINDEX41 =
 "d6/d7c/group__complex__eig_ga3ca7ddf2fd131cc637d9678a346bd445.html#ga3ca7ddf2fd131cc637d9678a346bd445":[3,0,6,0,10,0],
 "d6/d7c/group__complex__eig_ga3dbf4135e14f662ed4f3486c218d7132.html#ga3dbf4135e14f662ed4f3486c218d7132":[0,1,2,2,45],
 "d6/d7c/group__complex__eig_ga3dbf4135e14f662ed4f3486c218d7132.html#ga3dbf4135e14f662ed4f3486c218d7132":[3,0,6,0,52,0],
-"d6/d7c/group__complex__eig_ga4283cb04f906b24363d97745e2ce10bd.html#ga4283cb04f906b24363d97745e2ce10bd":[0,1,2,2,56],
-"d6/d7c/group__complex__eig_ga4283cb04f906b24363d97745e2ce10bd.html#ga4283cb04f906b24363d97745e2ce10bd":[3,0,6,0,63,0]
+"d6/d7c/group__complex__eig_ga4283cb04f906b24363d97745e2ce10bd.html#ga4283cb04f906b24363d97745e2ce10bd":[0,1,2,2,56]
 };
