@@ -1,13 +1,14 @@
 var NAVTREEINDEX43 =
 {
+"d6/da2/cblas__dgemv_8c_a74249ed25c31a797dd3d579ecd1780d1.html#a74249ed25c31a797dd3d579ecd1780d1":[3,0,1,2,39,6],
+"d6/da2/cblas__dgemv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,39,4],
 "d6/da2/cblas__dgemv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,39,2],
 "d6/da2/cblas__dgemv_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,39,3],
-"d6/da2/cblas__dgemv_8c_af52363a502fe42d51a8eb24ff5a4a21f.html#af52363a502fe42d51a8eb24ff5a4a21f":[3,0,1,2,39,6],
 "d6/da2/cblas__dgemv_8c_source.html":[3,0,1,2,39],
 "d6/da2/sqrt03_8f.html":[3,0,6,1,534],
 "d6/da2/sqrt03_8f_source.html":[3,0,6,1,534],
-"d6/da2/zhetrd__he2hb_8f.html":[3,0,5,1669],
-"d6/da2/zhetrd__he2hb_8f_source.html":[3,0,5,1669],
+"d6/da2/zhetrd__he2hb_8f.html":[3,0,5,1667],
+"d6/da2/zhetrd__he2hb_8f_source.html":[3,0,5,1667],
 "d6/da3/cptsvx_8f.html":[3,0,5,360],
 "d6/da3/cptsvx_8f_source.html":[3,0,5,360],
 "d6/da5/dget34_8f.html":[3,0,6,0,140],
@@ -30,8 +31,8 @@ var NAVTREEINDEX43 =
 "d6/da6/cblas__sswap_8c.html":[3,0,1,2,95],
 "d6/da6/cblas__sswap_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,95,0],
 "d6/da6/cblas__sswap_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,95,1],
-"d6/da6/cblas__sswap_8c_a7a2140bfc7c4d93af27b4baf69ada57e.html#a7a2140bfc7c4d93af27b4baf69ada57e":[3,0,1,2,95,3],
 "d6/da6/cblas__sswap_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,95,2],
+"d6/da6/cblas__sswap_8c_ace5548a9e1ec8153d63dede2484b82a7.html#ace5548a9e1ec8153d63dede2484b82a7":[3,0,1,2,95,3],
 "d6/da6/cblas__sswap_8c_source.html":[3,0,1,2,95],
 "d6/da6/serrps_8f.html":[3,0,6,1,461],
 "d6/da6/serrps_8f_source.html":[3,0,6,1,461],
@@ -43,8 +44,8 @@ var NAVTREEINDEX43 =
 "d6/da8/lapacke__zungql_8c.html":[3,0,4,3,2452],
 "d6/da8/lapacke__zungql_8c_a9a63ea1698c7474a6a94c636be6cb86d.html#a9a63ea1698c7474a6a94c636be6cb86d":[3,0,4,3,2452,0],
 "d6/da8/lapacke__zungql_8c_source.html":[3,0,4,3,2452],
-"d6/daa/dlaed2_8f.html":[3,0,5,633],
-"d6/daa/dlaed2_8f_source.html":[3,0,5,633],
+"d6/daa/dlaed2_8f.html":[3,0,5,632],
+"d6/daa/dlaed2_8f_source.html":[3,0,5,632],
 "d6/dab/cdrvls_8f.html":[3,0,6,1,57],
 "d6/dab/cdrvls_8f_source.html":[3,0,6,1,57],
 "d6/dab/dsvdch_8f.html":[3,0,6,0,176],
@@ -60,12 +61,12 @@ var NAVTREEINDEX43 =
 "d6/dad/lapacke__dlartgp__work_8c.html":[3,0,4,3,867],
 "d6/dad/lapacke__dlartgp__work_8c_a10e19fe74f2e50700838b8666facee06.html#a10e19fe74f2e50700838b8666facee06":[3,0,4,3,867,0],
 "d6/dad/lapacke__dlartgp__work_8c_source.html":[3,0,4,3,867],
-"d6/dae/zheevd_8f.html":[3,0,5,1640],
-"d6/dae/zheevd_8f_source.html":[3,0,5,1640],
+"d6/dae/zheevd_8f.html":[3,0,5,1638],
+"d6/dae/zheevd_8f_source.html":[3,0,5,1638],
 "d6/daf/derrgg_8f.html":[3,0,6,0,129],
 "d6/daf/derrgg_8f_source.html":[3,0,6,0,129],
-"d6/daf/ssytrs__aa__2stage_8f.html":[3,0,5,1475],
-"d6/daf/ssytrs__aa__2stage_8f_source.html":[3,0,5,1475],
+"d6/daf/ssytrs__aa__2stage_8f.html":[3,0,5,1473],
+"d6/daf/ssytrs__aa__2stage_8f_source.html":[3,0,5,1473],
 "d6/db0/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2dpotrf_8f.html":[3,0,5,1,0,0,1],
 "d6/db0/_v_a_r_i_a_n_t_s_2cholesky_2_r_l_2dpotrf_8f_source.html":[3,0,5,1,0,0,1],
 "d6/db0/lapacke__zhbtrd_8c.html":[3,0,4,3,2032],
@@ -83,18 +84,18 @@ var NAVTREEINDEX43 =
 "d6/db2/lapacke__zheequb_8c.html":[3,0,4,3,2038],
 "d6/db2/lapacke__zheequb_8c_a986c7d9cdb504e875d830202e3778460.html#a986c7d9cdb504e875d830202e3778460":[3,0,4,3,2038,0],
 "d6/db2/lapacke__zheequb_8c_source.html":[3,0,4,3,2038],
-"d6/db3/dggsvd3_8f.html":[3,0,5,591],
-"d6/db3/dggsvd3_8f_source.html":[3,0,5,591],
-"d6/db3/ssytrf__rk_8f.html":[3,0,5,1463],
-"d6/db3/ssytrf__rk_8f_a0afb5815527e91e5e4f48a2aa4066bcf.html#a0afb5815527e91e5e4f48a2aa4066bcf":[3,0,5,1463,0],
-"d6/db3/ssytrf__rk_8f_source.html":[3,0,5,1463],
+"d6/db3/dggsvd3_8f.html":[3,0,5,590],
+"d6/db3/dggsvd3_8f_source.html":[3,0,5,590],
+"d6/db3/ssytrf__rk_8f.html":[3,0,5,1461],
+"d6/db3/ssytrf__rk_8f_a0afb5815527e91e5e4f48a2aa4066bcf.html#a0afb5815527e91e5e4f48a2aa4066bcf":[3,0,5,1461,0],
+"d6/db3/ssytrf__rk_8f_source.html":[3,0,5,1461],
 "d6/db4/lapacke__zgels_8c.html":[3,0,4,3,1894],
 "d6/db4/lapacke__zgels_8c_a39cea8e8cd3c25946352ad4fe03e32df.html#a39cea8e8cd3c25946352ad4fe03e32df":[3,0,4,3,1894,0],
 "d6/db4/lapacke__zgels_8c_source.html":[3,0,4,3,1894],
 "d6/db5/cla__gercond__c_8f.html":[3,0,5,191],
 "d6/db5/cla__gercond__c_8f_source.html":[3,0,5,191],
-"d6/db5/dlaeda_8f.html":[3,0,5,641],
-"d6/db5/dlaeda_8f_source.html":[3,0,5,641],
+"d6/db5/dlaeda_8f.html":[3,0,5,640],
+"d6/db5/dlaeda_8f_source.html":[3,0,5,640],
 "d6/db5/lapacke__chetrd__work_8c.html":[3,0,4,3,247],
 "d6/db5/lapacke__chetrd__work_8c_a9b4f0bb975bf330f65f01b7df62ddddf.html#a9b4f0bb975bf330f65f01b7df62ddddf":[3,0,4,3,247,0],
 "d6/db5/lapacke__chetrd__work_8c_source.html":[3,0,4,3,247],
@@ -143,10 +144,10 @@ var NAVTREEINDEX43 =
 "d6/dba/lapacke__sgeqpf__work_8c.html":[3,0,4,3,1323],
 "d6/dba/lapacke__sgeqpf__work_8c_a0fbf918be20e5e086239e700475ce8df.html#a0fbf918be20e5e086239e700475ce8df":[3,0,4,3,1323,0],
 "d6/dba/lapacke__sgeqpf__work_8c_source.html":[3,0,4,3,1323],
-"d6/dba/zlapll_8f.html":[3,0,5,1777],
-"d6/dba/zlapll_8f_source.html":[3,0,5,1777],
-"d6/dbc/ztpttr_8f.html":[3,0,5,1967],
-"d6/dbc/ztpttr_8f_source.html":[3,0,5,1967],
+"d6/dba/zlapll_8f.html":[3,0,5,1775],
+"d6/dba/zlapll_8f_source.html":[3,0,5,1775],
+"d6/dbc/ztpttr_8f.html":[3,0,5,1965],
+"d6/dbc/ztpttr_8f_source.html":[3,0,5,1965],
 "d6/dbd/lapacke__dggsvp_8c.html":[3,0,4,3,808],
 "d6/dbd/lapacke__dggsvp_8c_a5ba17008b29f21564bad22368023a0a0.html#a5ba17008b29f21564bad22368023a0a0":[3,0,4,3,808,0],
 "d6/dbd/lapacke__dggsvp_8c_source.html":[3,0,4,3,808],
@@ -159,10 +160,10 @@ var NAVTREEINDEX43 =
 "d6/dc0/lapacke__zgtsvx__work_8c.html":[3,0,4,3,2007],
 "d6/dc0/lapacke__zgtsvx__work_8c_aac61593ddaf9eed5f73906fcccda47ee.html#aac61593ddaf9eed5f73906fcccda47ee":[3,0,4,3,2007,0],
 "d6/dc0/lapacke__zgtsvx__work_8c_source.html":[3,0,4,3,2007],
-"d6/dc0/ssysv__aa_8f.html":[3,0,5,1445],
-"d6/dc0/ssysv__aa_8f_source.html":[3,0,5,1445],
-"d6/dc1/zlarfb__gett_8f.html":[3,0,5,1805],
-"d6/dc1/zlarfb__gett_8f_source.html":[3,0,5,1805],
+"d6/dc0/ssysv__aa_8f.html":[3,0,5,1443],
+"d6/dc0/ssysv__aa_8f_source.html":[3,0,5,1443],
+"d6/dc1/zlarfb__gett_8f.html":[3,0,5,1803],
+"d6/dc1/zlarfb__gett_8f_source.html":[3,0,5,1803],
 "d6/dc3/crqt02_8f.html":[3,0,6,1,180],
 "d6/dc3/crqt02_8f_source.html":[3,0,6,1,180],
 "d6/dc3/lapacke__sgelss__work_8c.html":[3,0,4,3,1309],
@@ -183,12 +184,12 @@ var NAVTREEINDEX43 =
 "d6/dc6/lapacke__stftri__work_8c.html":[3,0,4,3,1773],
 "d6/dc6/lapacke__stftri__work_8c_a15d08b6b57d002990bab9c59a384686d.html#a15d08b6b57d002990bab9c59a384686d":[3,0,4,3,1773,0],
 "d6/dc6/lapacke__stftri__work_8c_source.html":[3,0,4,3,1773],
-"d6/dc6/zla__gbamv_8f.html":[3,0,5,1706],
-"d6/dc6/zla__gbamv_8f_source.html":[3,0,5,1706],
+"d6/dc6/zla__gbamv_8f.html":[3,0,5,1704],
+"d6/dc6/zla__gbamv_8f_source.html":[3,0,5,1704],
 "d6/dc7/group__double_g_bauxiliary.html":[0,0,1,2,0],
-"d6/dc7/group__double_g_bauxiliary_gad33336cd27dd6f289effc58cf9e88673.html#gad33336cd27dd6f289effc58cf9e88673":[3,0,5,684,0],
+"d6/dc7/group__double_g_bauxiliary_gad33336cd27dd6f289effc58cf9e88673.html#gad33336cd27dd6f289effc58cf9e88673":[3,0,5,683,0],
 "d6/dc7/group__double_g_bauxiliary_gad33336cd27dd6f289effc58cf9e88673.html#gad33336cd27dd6f289effc58cf9e88673":[0,0,1,2,0,1],
-"d6/dc7/group__double_g_bauxiliary_gaef2185b66fc7b07324cb1dcb622ea238.html#gaef2185b66fc7b07324cb1dcb622ea238":[3,0,5,664,0],
+"d6/dc7/group__double_g_bauxiliary_gaef2185b66fc7b07324cb1dcb622ea238.html#gaef2185b66fc7b07324cb1dcb622ea238":[3,0,5,663,0],
 "d6/dc7/group__double_g_bauxiliary_gaef2185b66fc7b07324cb1dcb622ea238.html#gaef2185b66fc7b07324cb1dcb622ea238":[0,0,1,2,0,0],
 "d6/dc7/lapacke__clauum__work_8c.html":[3,0,4,3,369],
 "d6/dc7/lapacke__clauum__work_8c_a7d8a9f00a30ee42bb110fa7fc676cdf6.html#a7d8a9f00a30ee42bb110fa7fc676cdf6":[3,0,4,3,369,0],
@@ -200,19 +201,19 @@ var NAVTREEINDEX43 =
 "d6/dc8/lapacke__sgemqr__work_8c.html":[3,0,4,3,1315],
 "d6/dc8/lapacke__sgemqr__work_8c_aa0dfd8e69f7c1f2dc99ea72ef5fe057a.html#aa0dfd8e69f7c1f2dc99ea72ef5fe057a":[3,0,4,3,1315,0],
 "d6/dc8/lapacke__sgemqr__work_8c_source.html":[3,0,4,3,1315],
-"d6/dc8/slaqsy_8f.html":[3,0,5,1219],
-"d6/dc8/slaqsy_8f_source.html":[3,0,5,1219],
+"d6/dc8/slaqsy_8f.html":[3,0,5,1217],
+"d6/dc8/slaqsy_8f_source.html":[3,0,5,1217],
 "d6/dc9/cungbr_8f.html":[3,0,5,472],
 "d6/dc9/cungbr_8f_source.html":[3,0,5,472],
 "d6/dca/lapacke__chetrs__rook_8c.html":[3,0,4,3,275],
 "d6/dca/lapacke__chetrs__rook_8c_a8ab88b59b1994b99daf655cdf6b735c9.html#a8ab88b59b1994b99daf655cdf6b735c9":[3,0,4,3,275,0],
 "d6/dca/lapacke__chetrs__rook_8c_source.html":[3,0,4,3,275],
-"d6/dca/slasd0_8f.html":[3,0,5,1260],
-"d6/dca/slasd0_8f_source.html":[3,0,5,1260],
-"d6/dcb/sorm2l_8f.html":[3,0,5,1325],
-"d6/dcb/sorm2l_8f_source.html":[3,0,5,1325],
-"d6/dcc/dpbstf_8f.html":[3,0,5,819],
-"d6/dcc/dpbstf_8f_source.html":[3,0,5,819],
+"d6/dca/slasd0_8f.html":[3,0,5,1258],
+"d6/dca/slasd0_8f_source.html":[3,0,5,1258],
+"d6/dcb/sorm2l_8f.html":[3,0,5,1323],
+"d6/dcb/sorm2l_8f_source.html":[3,0,5,1323],
+"d6/dcc/dpbstf_8f.html":[3,0,5,818],
+"d6/dcc/dpbstf_8f_source.html":[3,0,5,818],
 "d6/dcd/lapacke__cgetsqrhrt__work_8c.html":[3,0,4,3,125],
 "d6/dcd/lapacke__cgetsqrhrt__work_8c_a3abd4b0a7b59f726727bd6fda62a061c.html#a3abd4b0a7b59f726727bd6fda62a061c":[3,0,4,3,125,0],
 "d6/dcd/lapacke__cgetsqrhrt__work_8c_source.html":[3,0,4,3,125],
@@ -242,12 +243,11 @@ var NAVTREEINDEX43 =
 "d6/dd3/lapacke__dgetf2_8c.html":[3,0,4,3,762],
 "d6/dd3/lapacke__dgetf2_8c_ab89228ca3dc57ca3c5be1cd7793b716e.html#ab89228ca3dc57ca3c5be1cd7793b716e":[3,0,4,3,762,0],
 "d6/dd3/lapacke__dgetf2_8c_source.html":[3,0,4,3,762],
-"d6/dd3/sormlq_8f.html":[3,0,5,1330],
-"d6/dd3/sormlq_8f_source.html":[3,0,5,1330],
-"d6/dd3/spbsvx_8f.html":[3,0,5,1343],
-"d6/dd3/spbsvx_8f_source.html":[3,0,5,1343],
-"d6/dd3/zhetrf_8f.html":[3,0,5,1670],
-"d6/dd3/zhetrf_8f_source.html":[3,0,5,1670],
-"d6/dd3/ztrtrs_8f.html":[3,0,5,1978],
-"d6/dd3/ztrtrs_8f_source.html":[3,0,5,1978]
+"d6/dd3/sormlq_8f.html":[3,0,5,1328],
+"d6/dd3/sormlq_8f_source.html":[3,0,5,1328],
+"d6/dd3/spbsvx_8f.html":[3,0,5,1341],
+"d6/dd3/spbsvx_8f_source.html":[3,0,5,1341],
+"d6/dd3/zhetrf_8f.html":[3,0,5,1668],
+"d6/dd3/zhetrf_8f_source.html":[3,0,5,1668],
+"d6/dd3/ztrtrs_8f.html":[3,0,5,1976]
 };
