@@ -1,14 +1,15 @@
 var NAVTREEINDEX44 =
 {
+"d6/dd3/ztrtrs_8f_source.html":[3,0,5,1976],
 "d6/dd7/lapacke__ssteqr__work_8c.html":[3,0,4,3,1667],
 "d6/dd7/lapacke__ssteqr__work_8c_a99e1af8511b3dd5d7d7cd2d08b1bd133.html#a99e1af8511b3dd5d7d7cd2d08b1bd133":[3,0,4,3,1667,0],
 "d6/dd7/lapacke__ssteqr__work_8c_source.html":[3,0,4,3,1667],
-"d6/dd7/ssyevd__2stage_8f.html":[3,0,5,1431],
-"d6/dd7/ssyevd__2stage_8f_source.html":[3,0,5,1431],
+"d6/dd7/ssyevd__2stage_8f.html":[3,0,5,1429],
+"d6/dd7/ssyevd__2stage_8f_source.html":[3,0,5,1429],
 "d6/dd7/stpt02_8f.html":[3,0,6,1,560],
 "d6/dd7/stpt02_8f_source.html":[3,0,6,1,560],
-"d6/dd7/zlaed8_8f.html":[3,0,5,1743],
-"d6/dd7/zlaed8_8f_source.html":[3,0,5,1743],
+"d6/dd7/zlaed8_8f.html":[3,0,5,1741],
+"d6/dd7/zlaed8_8f_source.html":[3,0,5,1741],
 "d6/dd8/lapacke__dgelq_8c.html":[3,0,4,3,700],
 "d6/dd8/lapacke__dgelq_8c_ae11fa7410c8812c4aa6a2f0e32dcab8b.html#ae11fa7410c8812c4aa6a2f0e32dcab8b":[3,0,4,3,700,0],
 "d6/dd8/lapacke__dgelq_8c_source.html":[3,0,4,3,700],
@@ -31,8 +32,8 @@ var NAVTREEINDEX44 =
 "d6/de1/lapacke__dlapmt__work_8c.html":[3,0,4,3,851],
 "d6/de1/lapacke__dlapmt__work_8c_a48a5da83bb0ef0b3af8fe73fb5c82dd0.html#a48a5da83bb0ef0b3af8fe73fb5c82dd0":[3,0,4,3,851,0],
 "d6/de1/lapacke__dlapmt__work_8c_source.html":[3,0,4,3,851],
-"d6/de1/zlahef__aa_8f.html":[3,0,5,1751],
-"d6/de1/zlahef__aa_8f_source.html":[3,0,5,1751],
+"d6/de1/zlahef__aa_8f.html":[3,0,5,1749],
+"d6/de1/zlahef__aa_8f_source.html":[3,0,5,1749],
 "d6/de2/lapacke__dst__nancheck_8c.html":[3,0,4,4,61],
 "d6/de2/lapacke__dst__nancheck_8c_a7f97513ea64e78cde7aa6fff4172307a.html#a7f97513ea64e78cde7aa6fff4172307a":[3,0,4,4,61,0],
 "d6/de2/lapacke__dst__nancheck_8c_source.html":[3,0,4,4,61],
@@ -42,8 +43,8 @@ var NAVTREEINDEX44 =
 "d6/de3/lapacke__dsysv__aa__work_8c.html":[3,0,4,3,1126],
 "d6/de3/lapacke__dsysv__aa__work_8c_a289ac784a3b89b71871fa435fefa6e4c.html#a289ac784a3b89b71871fa435fefa6e4c":[3,0,4,3,1126,0],
 "d6/de3/lapacke__dsysv__aa__work_8c_source.html":[3,0,4,3,1126],
-"d6/de3/zla__herfsx__extended_8f.html":[3,0,5,1719],
-"d6/de3/zla__herfsx__extended_8f_source.html":[3,0,5,1719],
+"d6/de3/zla__herfsx__extended_8f.html":[3,0,5,1717],
+"d6/de3/zla__herfsx__extended_8f_source.html":[3,0,5,1717],
 "d6/de4/lapacke__chptrf_8c.html":[3,0,4,3,306],
 "d6/de4/lapacke__chptrf_8c_a79a452c2b11bdc862ee3e307a360a487.html#a79a452c2b11bdc862ee3e307a360a487":[3,0,4,3,306,0],
 "d6/de4/lapacke__chptrf_8c_source.html":[3,0,4,3,306],
@@ -52,15 +53,15 @@ var NAVTREEINDEX44 =
 "d6/de5/lapacke__dlauum__work_8c_source.html":[3,0,4,3,883],
 "d6/de6/ddrvsg2stg_8f.html":[3,0,6,0,121],
 "d6/de6/ddrvsg2stg_8f_source.html":[3,0,6,0,121],
-"d6/de6/sgetrf2_8f.html":[3,0,5,1095],
-"d6/de6/sgetrf2_8f_source.html":[3,0,5,1095],
-"d6/de6/sgglse_8f.html":[3,0,5,1111],
-"d6/de6/sgglse_8f_source.html":[3,0,5,1111],
+"d6/de6/sgetrf2_8f.html":[3,0,5,1093],
+"d6/de6/sgetrf2_8f_source.html":[3,0,5,1093],
+"d6/de6/sgglse_8f.html":[3,0,5,1109],
+"d6/de6/sgglse_8f_source.html":[3,0,5,1109],
 "d6/de8/lapacke__dgesv_8c.html":[3,0,4,3,748],
 "d6/de8/lapacke__dgesv_8c_a3ff136210c1293cb1b015979b9a57d96.html#a3ff136210c1293cb1b015979b9a57d96":[3,0,4,3,748,0],
 "d6/de8/lapacke__dgesv_8c_source.html":[3,0,4,3,748],
-"d6/de8/sormr3_8f.html":[3,0,5,1334],
-"d6/de8/sormr3_8f_source.html":[3,0,5,1334],
+"d6/de8/sormr3_8f.html":[3,0,5,1332],
+"d6/de8/sormr3_8f_source.html":[3,0,5,1332],
 "d6/dea/ctsqr01_8f.html":[3,0,6,1,208],
 "d6/dea/ctsqr01_8f_a5d746df5d34ef26583788a536a988d28.html#a5d746df5d34ef26583788a536a988d28":[3,0,6,1,208,0],
 "d6/dea/ctsqr01_8f_source.html":[3,0,6,1,208],
@@ -79,12 +80,12 @@ var NAVTREEINDEX44 =
 "d6/ded/lapacke__cgeqrfp_8c.html":[3,0,4,3,82],
 "d6/ded/lapacke__cgeqrfp_8c_a7e3683ddebb3313ebd6aa98a779dce35.html#a7e3683ddebb3313ebd6aa98a779dce35":[3,0,4,3,82,0],
 "d6/ded/lapacke__cgeqrfp_8c_source.html":[3,0,4,3,82],
-"d6/ded/second___e_x_t___e_t_i_m_e___8f.html":[3,0,3,14],
-"d6/ded/second___e_x_t___e_t_i_m_e___8f_ae9f971a8b343bd2fcb85c3b16da97f10.html#ae9f971a8b343bd2fcb85c3b16da97f10":[3,0,3,14,0],
-"d6/ded/second___e_x_t___e_t_i_m_e___8f_source.html":[3,0,3,14],
+"d6/ded/second___e_x_t___e_t_i_m_e___8f.html":[3,0,3,15],
+"d6/ded/second___e_x_t___e_t_i_m_e___8f_ae9f971a8b343bd2fcb85c3b16da97f10.html#ae9f971a8b343bd2fcb85c3b16da97f10":[3,0,3,15,0],
+"d6/ded/second___e_x_t___e_t_i_m_e___8f_source.html":[3,0,3,15],
 "d6/dee/group__complex__blas__level2.html":[0,2,1,2],
-"d6/dee/group__complex__blas__level2_ga0983da08821bec7701e90fb1e65c8cd7.html#ga0983da08821bec7701e90fb1e65c8cd7":[3,0,0,0,6,0],
 "d6/dee/group__complex__blas__level2_ga0983da08821bec7701e90fb1e65c8cd7.html#ga0983da08821bec7701e90fb1e65c8cd7":[0,2,1,2,1],
+"d6/dee/group__complex__blas__level2_ga0983da08821bec7701e90fb1e65c8cd7.html#ga0983da08821bec7701e90fb1e65c8cd7":[3,0,0,0,6,0],
 "d6/dee/group__complex__blas__level2_ga1afdec04246cf2d0cb650ec237296ef3.html#ga1afdec04246cf2d0cb650ec237296ef3":[0,2,1,2,14],
 "d6/dee/group__complex__blas__level2_ga1afdec04246cf2d0cb650ec237296ef3.html#ga1afdec04246cf2d0cb650ec237296ef3":[3,0,0,0,30,0],
 "d6/dee/group__complex__blas__level2_ga2483c6533c8a24ff715137629f939074.html#ga2483c6533c8a24ff715137629f939074":[0,2,1,2,11],
@@ -95,48 +96,48 @@ var NAVTREEINDEX44 =
 "d6/dee/group__complex__blas__level2_ga38ae7f5a40e16fd315011faddf4412cc.html#ga38ae7f5a40e16fd315011faddf4412cc":[3,0,0,0,34,0],
 "d6/dee/group__complex__blas__level2_ga426c198e1c8863d9ecbdbe16efa0f6cf.html#ga426c198e1c8863d9ecbdbe16efa0f6cf":[0,2,1,2,4],
 "d6/dee/group__complex__blas__level2_ga426c198e1c8863d9ecbdbe16efa0f6cf.html#ga426c198e1c8863d9ecbdbe16efa0f6cf":[3,0,0,0,9,0],
-"d6/dee/group__complex__blas__level2_ga47f0128bb830b67b37b285af34eaad5f.html#ga47f0128bb830b67b37b285af34eaad5f":[3,0,0,0,28,0],
 "d6/dee/group__complex__blas__level2_ga47f0128bb830b67b37b285af34eaad5f.html#ga47f0128bb830b67b37b285af34eaad5f":[0,2,1,2,12],
+"d6/dee/group__complex__blas__level2_ga47f0128bb830b67b37b285af34eaad5f.html#ga47f0128bb830b67b37b285af34eaad5f":[3,0,0,0,28,0],
 "d6/dee/group__complex__blas__level2_ga50fe7a70e7ae8f9ede50acd6747510d7.html#ga50fe7a70e7ae8f9ede50acd6747510d7":[0,2,1,2,0],
 "d6/dee/group__complex__blas__level2_ga50fe7a70e7ae8f9ede50acd6747510d7.html#ga50fe7a70e7ae8f9ede50acd6747510d7":[3,0,0,0,4,0],
 "d6/dee/group__complex__blas__level2_ga537b8bcd05cbe626ebce0fbc8d66a2d6.html#ga537b8bcd05cbe626ebce0fbc8d66a2d6":[0,2,1,2,10],
 "d6/dee/group__complex__blas__level2_ga537b8bcd05cbe626ebce0fbc8d66a2d6.html#ga537b8bcd05cbe626ebce0fbc8d66a2d6":[3,0,0,0,18,0],
 "d6/dee/group__complex__blas__level2_ga62930e76219d094e424db1712a5356cb.html#ga62930e76219d094e424db1712a5356cb":[0,2,1,2,15],
 "d6/dee/group__complex__blas__level2_ga62930e76219d094e424db1712a5356cb.html#ga62930e76219d094e424db1712a5356cb":[3,0,0,0,32,0],
-"d6/dee/group__complex__blas__level2_gaa59d93fbbd8d0b1be4a51634cb437cc1.html#gaa59d93fbbd8d0b1be4a51634cb437cc1":[3,0,0,0,13,0],
 "d6/dee/group__complex__blas__level2_gaa59d93fbbd8d0b1be4a51634cb437cc1.html#gaa59d93fbbd8d0b1be4a51634cb437cc1":[0,2,1,2,7],
+"d6/dee/group__complex__blas__level2_gaa59d93fbbd8d0b1be4a51634cb437cc1.html#gaa59d93fbbd8d0b1be4a51634cb437cc1":[3,0,0,0,13,0],
 "d6/dee/group__complex__blas__level2_gab21c402efadfa2023cfbc06911506e42.html#gab21c402efadfa2023cfbc06911506e42":[0,2,1,2,3],
 "d6/dee/group__complex__blas__level2_gab21c402efadfa2023cfbc06911506e42.html#gab21c402efadfa2023cfbc06911506e42":[3,0,0,0,8,0],
-"d6/dee/group__complex__blas__level2_gac23d51cad7f51484371119bb6e3fb1f3.html#gac23d51cad7f51484371119bb6e3fb1f3":[3,0,0,0,11,0],
 "d6/dee/group__complex__blas__level2_gac23d51cad7f51484371119bb6e3fb1f3.html#gac23d51cad7f51484371119bb6e3fb1f3":[0,2,1,2,5],
-"d6/dee/group__complex__blas__level2_gac98100eee08124fb7a5d55effbb85a65.html#gac98100eee08124fb7a5d55effbb85a65":[0,2,1,2,9],
+"d6/dee/group__complex__blas__level2_gac23d51cad7f51484371119bb6e3fb1f3.html#gac23d51cad7f51484371119bb6e3fb1f3":[3,0,0,0,11,0],
 "d6/dee/group__complex__blas__level2_gac98100eee08124fb7a5d55effbb85a65.html#gac98100eee08124fb7a5d55effbb85a65":[3,0,0,0,17,0],
-"d6/dee/group__complex__blas__level2_gad1dc14308bf0c1c8d9ba6ee068ac4d60.html#gad1dc14308bf0c1c8d9ba6ee068ac4d60":[0,2,1,2,8],
+"d6/dee/group__complex__blas__level2_gac98100eee08124fb7a5d55effbb85a65.html#gac98100eee08124fb7a5d55effbb85a65":[0,2,1,2,9],
 "d6/dee/group__complex__blas__level2_gad1dc14308bf0c1c8d9ba6ee068ac4d60.html#gad1dc14308bf0c1c8d9ba6ee068ac4d60":[3,0,0,0,16,0],
-"d6/dee/group__complex__blas__level2_gafa73370c613ec8f157771992010809ac.html#gafa73370c613ec8f157771992010809ac":[0,2,1,2,6],
+"d6/dee/group__complex__blas__level2_gad1dc14308bf0c1c8d9ba6ee068ac4d60.html#gad1dc14308bf0c1c8d9ba6ee068ac4d60":[0,2,1,2,8],
 "d6/dee/group__complex__blas__level2_gafa73370c613ec8f157771992010809ac.html#gafa73370c613ec8f157771992010809ac":[3,0,0,0,12,0],
+"d6/dee/group__complex__blas__level2_gafa73370c613ec8f157771992010809ac.html#gafa73370c613ec8f157771992010809ac":[0,2,1,2,6],
 "d6/dee/group__complex__blas__level2_gafb7324ce48931e58b392dd6eef9a286c.html#gafb7324ce48931e58b392dd6eef9a286c":[0,2,1,2,13],
 "d6/dee/group__complex__blas__level2_gafb7324ce48931e58b392dd6eef9a286c.html#gafb7324ce48931e58b392dd6eef9a286c":[3,0,0,0,29,0],
-"d6/dee/zheev_8f.html":[3,0,5,1638],
-"d6/dee/zheev_8f_source.html":[3,0,5,1638],
+"d6/dee/zheev_8f.html":[3,0,5,1636],
+"d6/dee/zheev_8f_source.html":[3,0,5,1636],
 "d6/def/lapacke__dpstrf_8c.html":[3,0,4,3,988],
 "d6/def/lapacke__dpstrf_8c_a2b650cddf82818423fe53c664392a6c9.html#a2b650cddf82818423fe53c664392a6c9":[3,0,4,3,988,0],
 "d6/def/lapacke__dpstrf_8c_source.html":[3,0,4,3,988],
-"d6/df0/dlaqr1_8f.html":[3,0,5,689],
-"d6/df0/dlaqr1_8f_source.html":[3,0,5,689],
-"d6/df0/ssygv_8f.html":[3,0,5,1438],
-"d6/df0/ssygv_8f_source.html":[3,0,5,1438],
+"d6/df0/dlaqr1_8f.html":[3,0,5,688],
+"d6/df0/dlaqr1_8f_source.html":[3,0,5,688],
+"d6/df0/ssygv_8f.html":[3,0,5,1436],
+"d6/df0/ssygv_8f_source.html":[3,0,5,1436],
 "d6/df1/cdrgvx_8f.html":[3,0,6,0,35],
 "d6/df1/cdrgvx_8f_source.html":[3,0,6,0,35],
 "d6/df1/lapacke__cgbcon_8c.html":[3,0,4,3,6],
 "d6/df1/lapacke__cgbcon_8c_a005993b6d9cf5510f6267820a48a7e32.html#a005993b6d9cf5510f6267820a48a7e32":[3,0,4,3,6,0],
 "d6/df1/lapacke__cgbcon_8c_source.html":[3,0,4,3,6],
-"d6/df1/zlanhs_8f.html":[3,0,5,1769],
-"d6/df1/zlanhs_8f_source.html":[3,0,5,1769],
+"d6/df1/zlanhs_8f.html":[3,0,5,1767],
+"d6/df1/zlanhs_8f_source.html":[3,0,5,1767],
 "d6/df2/cblas__ztpsv_8c.html":[3,0,1,2,139],
 "d6/df2/cblas__ztpsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,139,0],
 "d6/df2/cblas__ztpsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,139,1],
-"d6/df2/cblas__ztpsv_8c_a58c95c385c6a6f64f54172063fd14c9d.html#a58c95c385c6a6f64f54172063fd14c9d":[3,0,1,2,139,5],
+"d6/df2/cblas__ztpsv_8c_a20ec63f5822f3fcb87c566d977718528.html#a20ec63f5822f3fcb87c566d977718528":[3,0,1,2,139,5],
 "d6/df2/cblas__ztpsv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,139,3],
 "d6/df2/cblas__ztpsv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,139,2],
 "d6/df2/cblas__ztpsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,139,4],
@@ -147,8 +148,8 @@ var NAVTREEINDEX44 =
 "d6/df2/lapacke__dgeqrfp__work_8c.html":[3,0,4,3,733],
 "d6/df2/lapacke__dgeqrfp__work_8c_a146f2c599b0bda43981468a615050f9c.html#a146f2c599b0bda43981468a615050f9c":[3,0,4,3,733,0],
 "d6/df2/lapacke__dgeqrfp__work_8c_source.html":[3,0,4,3,733],
-"d6/df3/dgetsqrhrt_8f.html":[3,0,5,576],
-"d6/df3/dgetsqrhrt_8f_source.html":[3,0,5,576],
+"d6/df3/dgetsqrhrt_8f.html":[3,0,5,575],
+"d6/df3/dgetsqrhrt_8f_source.html":[3,0,5,575],
 "d6/df3/lapacke__dlacpy_8c.html":[3,0,4,3,832],
 "d6/df3/lapacke__dlacpy_8c_a199e5c646edf25bdbad687cd62727c86.html#a199e5c646edf25bdbad687cd62727c86":[3,0,4,3,832,0],
 "d6/df3/lapacke__dlacpy_8c_source.html":[3,0,4,3,832],
@@ -184,43 +185,43 @@ var NAVTREEINDEX44 =
 "d6/df6/group__complex_p_ocomputational_gad3d34aea85ff135afe5692ec73649249.html#gad3d34aea85ff135afe5692ec73649249":[0,0,4,1,2,8],
 "d6/df6/group__complex_p_ocomputational_gad9052b4b70569dfd6e8943971c9b38b2.html#gad9052b4b70569dfd6e8943971c9b38b2":[3,0,5,345,0],
 "d6/df6/group__complex_p_ocomputational_gad9052b4b70569dfd6e8943971c9b38b2.html#gad9052b4b70569dfd6e8943971c9b38b2":[0,0,4,1,2,13],
-"d6/df6/group__complex_p_ocomputational_gae3d6f3635d5674e86148d50639cf2675.html#gae3d6f3635d5674e86148d50639cf2675":[0,0,4,1,2,2],
 "d6/df6/group__complex_p_ocomputational_gae3d6f3635d5674e86148d50639cf2675.html#gae3d6f3635d5674e86148d50639cf2675":[3,0,5,203,0],
+"d6/df6/group__complex_p_ocomputational_gae3d6f3635d5674e86148d50639cf2675.html#gae3d6f3635d5674e86148d50639cf2675":[0,0,4,1,2,2],
 "d6/df6/schksy__aa__2stage_8f.html":[3,0,6,1,419],
 "d6/df6/schksy__aa__2stage_8f_a8e7cb21379542d2429b007a8748850b6.html#a8e7cb21379542d2429b007a8748850b6":[3,0,6,1,419,0],
 "d6/df6/schksy__aa__2stage_8f_source.html":[3,0,6,1,419],
 "d6/df7/cblas__ctrsv_8c.html":[3,0,1,2,32],
 "d6/df7/cblas__ctrsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,32,0],
 "d6/df7/cblas__ctrsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,32,1],
-"d6/df7/cblas__ctrsv_8c_a55011687e213b7cb332013a260a0c426.html#a55011687e213b7cb332013a260a0c426":[3,0,1,2,32,6],
 "d6/df7/cblas__ctrsv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,32,4],
 "d6/df7/cblas__ctrsv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,32,3],
 "d6/df7/cblas__ctrsv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,32,2],
 "d6/df7/cblas__ctrsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,32,5],
+"d6/df7/cblas__ctrsv_8c_af730adc8996c696306fb77a8db502632.html#af730adc8996c696306fb77a8db502632":[3,0,1,2,32,6],
 "d6/df7/cblas__ctrsv_8c_source.html":[3,0,1,2,32],
 "d6/df7/lapacke__cunmrz_8c.html":[3,0,4,3,636],
 "d6/df7/lapacke__cunmrz_8c_aadf0dd9df89e13af85512db8a4aa1c59.html#aadf0dd9df89e13af85512db8a4aa1c59":[3,0,4,3,636,0],
 "d6/df7/lapacke__cunmrz_8c_source.html":[3,0,4,3,636],
-"d6/df8/ssytrs__rook_8f.html":[3,0,5,1476],
-"d6/df8/ssytrs__rook_8f_source.html":[3,0,5,1476],
+"d6/df8/ssytrs__rook_8f.html":[3,0,5,1474],
+"d6/df8/ssytrs__rook_8f_source.html":[3,0,5,1474],
 "d6/df9/group__complex_s_yeigen.html":[0,0,2,1,2],
 "d6/df9/lapacke__csycon_8c.html":[3,0,4,3,472],
 "d6/df9/lapacke__csycon_8c_a205e6f48f7849ecb44683f6c2de3c8cb.html#a205e6f48f7849ecb44683f6c2de3c8cb":[3,0,4,3,472,0],
 "d6/df9/lapacke__csycon_8c_source.html":[3,0,4,3,472],
-"d6/df9/zgesvxx_8f.html":[3,0,5,1588],
-"d6/df9/zgesvxx_8f_source.html":[3,0,5,1588],
-"d6/dfa/zspcon_8f.html":[3,0,5,1887],
-"d6/dfa/zspcon_8f_source.html":[3,0,5,1887],
-"d6/dfb/dgehd2_8f.html":[3,0,5,529],
-"d6/dfb/dgehd2_8f_source.html":[3,0,5,529],
+"d6/df9/zgesvxx_8f.html":[3,0,5,1586],
+"d6/df9/zgesvxx_8f_source.html":[3,0,5,1586],
+"d6/dfa/zspcon_8f.html":[3,0,5,1885],
+"d6/dfa/zspcon_8f_source.html":[3,0,5,1885],
+"d6/dfb/dgehd2_8f.html":[3,0,5,528],
+"d6/dfb/dgehd2_8f_source.html":[3,0,5,528],
 "d6/dfc/clatrz_8f.html":[3,0,5,315],
 "d6/dfc/clatrz_8f_source.html":[3,0,5,315],
-"d6/dfd/dgges3_8f.html":[3,0,5,580],
-"d6/dfd/dgges3_8f_source.html":[3,0,5,580],
-"d6/dfd/dlasdq_8f.html":[3,0,5,747],
-"d6/dfd/dlasdq_8f_source.html":[3,0,5,747],
-"d6/dfd/sgeqr2_8f.html":[3,0,5,1072],
-"d6/dfd/sgeqr2_8f_source.html":[3,0,5,1072],
+"d6/dfd/dgges3_8f.html":[3,0,5,579],
+"d6/dfd/dgges3_8f_source.html":[3,0,5,579],
+"d6/dfd/dlasdq_8f.html":[3,0,5,746],
+"d6/dfd/dlasdq_8f_source.html":[3,0,5,746],
+"d6/dfd/sgeqr2_8f.html":[3,0,5,1070],
+"d6/dfd/sgeqr2_8f_source.html":[3,0,5,1070],
 "d6/dff/c__sblas1_8c.html":[3,0,1,3,19],
 "d6/dff/c__sblas1_8c_a25178981ec0049866cca30fae0a16680.html#a25178981ec0049866cca30fae0a16680":[3,0,1,3,19,4],
 "d6/dff/c__sblas1_8c_a562a35c8d9ab27742e28409b3a2b404d.html#a562a35c8d9ab27742e28409b3a2b404d":[3,0,1,3,19,6],
@@ -235,8 +236,8 @@ var NAVTREEINDEX44 =
 "d6/dff/c__sblas1_8c_ac872e13c7b9436e66fc8ba9b0e881465.html#ac872e13c7b9436e66fc8ba9b0e881465":[3,0,1,3,19,9],
 "d6/dff/c__sblas1_8c_aee03268abc78dfcaf897c9b30473dbf2.html#aee03268abc78dfcaf897c9b30473dbf2":[3,0,1,3,19,0],
 "d6/dff/c__sblas1_8c_source.html":[3,0,1,3,19],
-"d6/dff/zlat2c_8f.html":[3,0,5,1831],
-"d6/dff/zlat2c_8f_source.html":[3,0,5,1831],
+"d6/dff/zlat2c_8f.html":[3,0,5,1829],
+"d6/dff/zlat2c_8f_source.html":[3,0,5,1829],
 "d7/d01/lapacke__csytri_8c.html":[3,0,4,3,512],
 "d7/d01/lapacke__csytri_8c_a5ff73ed90aa4e4f131703543c727e549.html#a5ff73ed90aa4e4f131703543c727e549":[3,0,4,3,512,0],
 "d7/d01/lapacke__csytri_8c_source.html":[3,0,4,3,512],
@@ -245,9 +246,8 @@ var NAVTREEINDEX44 =
 "d7/d01/lapacke__dtptri__work_8c_source.html":[3,0,4,3,1209],
 "d7/d01/zdrvgbx_8f.html":[3,0,6,1,614],
 "d7/d01/zdrvgbx_8f_source.html":[3,0,6,1,614],
-"d7/d01/zpbtrs_8f.html":[3,0,5,1851],
-"d7/d01/zpbtrs_8f_source.html":[3,0,5,1851],
+"d7/d01/zpbtrs_8f.html":[3,0,5,1849],
+"d7/d01/zpbtrs_8f_source.html":[3,0,5,1849],
 "d7/d02/lapacke__sgetf2__work_8c.html":[3,0,4,3,1361],
-"d7/d02/lapacke__sgetf2__work_8c_ad724233980145ef9378380229e348f76.html#ad724233980145ef9378380229e348f76":[3,0,4,3,1361,0],
-"d7/d02/lapacke__sgetf2__work_8c_source.html":[3,0,4,3,1361]
+"d7/d02/lapacke__sgetf2__work_8c_ad724233980145ef9378380229e348f76.html#ad724233980145ef9378380229e348f76":[3,0,4,3,1361,0]
 };
