@@ -1,10 +1,11 @@
 var NAVTREEINDEX47 =
 {
+"d7/d73/clahrd_8f.html":[3,0,5,0,6],
 "d7/d73/clahrd_8f_source.html":[3,0,5,0,6],
 "d7/d75/cbdt01_8f.html":[3,0,6,0,6],
 "d7/d75/cbdt01_8f_source.html":[3,0,6,0,6],
-"d7/d75/dopgtr_8f.html":[3,0,5,777],
-"d7/d75/dopgtr_8f_source.html":[3,0,5,777],
+"d7/d75/dopgtr_8f.html":[3,0,5,776],
+"d7/d75/dopgtr_8f_source.html":[3,0,5,776],
 "d7/d75/lapacke__slartgp__work_8c.html":[3,0,4,3,1465],
 "d7/d75/lapacke__slartgp__work_8c_ae692f0f914d5656916a9f63db688fae9.html#ae692f0f914d5656916a9f63db688fae9":[3,0,4,3,1465,0],
 "d7/d75/lapacke__slartgp__work_8c_source.html":[3,0,4,3,1465],
@@ -16,12 +17,12 @@ var NAVTREEINDEX47 =
 "d7/d76/lapacke__zungtsqr__row__work_8c.html":[3,0,4,3,2461],
 "d7/d76/lapacke__zungtsqr__row__work_8c_a3e3f5a5dcde2b7125260a390557316b9.html#a3e3f5a5dcde2b7125260a390557316b9":[3,0,4,3,2461,0],
 "d7/d76/lapacke__zungtsqr__row__work_8c_source.html":[3,0,4,3,2461],
-"d7/d76/sorm22_8f.html":[3,0,5,1324],
-"d7/d76/sorm22_8f_source.html":[3,0,5,1324],
+"d7/d76/sorm22_8f.html":[3,0,5,1322],
+"d7/d76/sorm22_8f_source.html":[3,0,5,1322],
 "d7/d76/zgemm_8f.html":[3,0,0,0,123],
 "d7/d76/zgemm_8f_source.html":[3,0,0,0,123],
-"d7/d77/dpttrs_8f.html":[3,0,5,857],
-"d7/d77/dpttrs_8f_source.html":[3,0,5,857],
+"d7/d77/dpttrs_8f.html":[3,0,5,856],
+"d7/d77/dpttrs_8f_source.html":[3,0,5,856],
 "d7/d77/lapacke__dorcsd2by1__work_8c.html":[3,0,4,3,892],
 "d7/d77/lapacke__dorcsd2by1__work_8c_a6fed1ef0054fd7ffa7cda6967e014ccc.html#a6fed1ef0054fd7ffa7cda6967e014ccc":[3,0,4,3,892,0],
 "d7/d77/lapacke__dorcsd2by1__work_8c_source.html":[3,0,4,3,892],
@@ -35,8 +36,8 @@ var NAVTREEINDEX47 =
 "d7/d79/lapacke__sormrz_8c_source.html":[3,0,4,3,1520],
 "d7/d7b/cdotu_8f.html":[3,0,0,0,3],
 "d7/d7b/cdotu_8f_source.html":[3,0,0,0,3],
-"d7/d7b/dorcsd2by1_8f.html":[3,0,5,787],
-"d7/d7b/dorcsd2by1_8f_source.html":[3,0,5,787],
+"d7/d7b/dorcsd2by1_8f.html":[3,0,5,786],
+"d7/d7b/dorcsd2by1_8f_source.html":[3,0,5,786],
 "d7/d7b/lapacke__cgeqrf_8c.html":[3,0,4,3,80],
 "d7/d7b/lapacke__cgeqrf_8c_acb40a027cddd18793e4718f220cc0a82.html#acb40a027cddd18793e4718f220cc0a82":[3,0,4,3,80,0],
 "d7/d7b/lapacke__cgeqrf_8c_source.html":[3,0,4,3,80],
@@ -66,8 +67,8 @@ var NAVTREEINDEX47 =
 "d7/d80/lapacke__dsy__trans_8c.html":[3,0,4,4,63],
 "d7/d80/lapacke__dsy__trans_8c_aef8c308a8f1bcce98598849dc06bccff.html#aef8c308a8f1bcce98598849dc06bccff":[3,0,4,4,63,0],
 "d7/d80/lapacke__dsy__trans_8c_source.html":[3,0,4,4,63],
-"d7/d82/dstedc_8f.html":[3,0,5,891],
-"d7/d82/dstedc_8f_source.html":[3,0,5,891],
+"d7/d82/dstedc_8f.html":[3,0,5,890],
+"d7/d82/dstedc_8f_source.html":[3,0,5,890],
 "d7/d82/lapacke__ssycon__3_8c.html":[3,0,4,3,1679],
 "d7/d82/lapacke__ssycon__3_8c_a88b3c501e62840a8eacca36bcf920eb8.html#a88b3c501e62840a8eacca36bcf920eb8":[3,0,4,3,1679,0],
 "d7/d82/lapacke__ssycon__3_8c_source.html":[3,0,4,3,1679],
@@ -84,17 +85,17 @@ var NAVTREEINDEX47 =
 "d7/d84/lapacke__sspevx__work_8c.html":[3,0,4,3,1633],
 "d7/d84/lapacke__sspevx__work_8c_ae59af3d297589aa6f47784a1f63a36e5.html#ae59af3d297589aa6f47784a1f63a36e5":[3,0,4,3,1633,0],
 "d7/d84/lapacke__sspevx__work_8c_source.html":[3,0,4,3,1633],
-"d7/d84/slacpy_8f.html":[3,0,5,1150],
-"d7/d84/slacpy_8f_source.html":[3,0,5,1150],
+"d7/d84/slacpy_8f.html":[3,0,5,1148],
+"d7/d84/slacpy_8f_source.html":[3,0,5,1148],
 "d7/d86/lapacke__zhseqr__work_8c.html":[3,0,4,3,2153],
 "d7/d86/lapacke__zhseqr__work_8c_a43103c35659ae89d06b806c8ad95876a.html#a43103c35659ae89d06b806c8ad95876a":[3,0,4,3,2153,0],
 "d7/d86/lapacke__zhseqr__work_8c_source.html":[3,0,4,3,2153],
 "d7/d87/cblas__dsyr_8c.html":[3,0,1,2,55],
 "d7/d87/cblas__dsyr_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,55,0],
-"d7/d87/cblas__dsyr_8c_a179d6b24c85defbff9fdec49789b7cbc.html#a179d6b24c85defbff9fdec49789b7cbc":[3,0,1,2,55,4],
 "d7/d87/cblas__dsyr_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,55,2],
 "d7/d87/cblas__dsyr_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,55,1],
 "d7/d87/cblas__dsyr_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,55,3],
+"d7/d87/cblas__dsyr_8c_afafa85591c94d1a195a03b197d1f9357.html#afafa85591c94d1a195a03b197d1f9357":[3,0,1,2,55,4],
 "d7/d87/cblas__dsyr_8c_source.html":[3,0,1,2,55],
 "d7/d87/cerrtz_8f.html":[3,0,6,1,99],
 "d7/d87/cerrtz_8f_source.html":[3,0,6,1,99],
@@ -107,7 +108,7 @@ var NAVTREEINDEX47 =
 "d7/d8b/cblas__dswap_8c.html":[3,0,1,2,52],
 "d7/d8b/cblas__dswap_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,52,0],
 "d7/d8b/cblas__dswap_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,52,1],
-"d7/d8b/cblas__dswap_8c_a7685f88c9d5cfa34d5b5d4f01cbce79b.html#a7685f88c9d5cfa34d5b5d4f01cbce79b":[3,0,1,2,52,3],
+"d7/d8b/cblas__dswap_8c_a6f36c71d07c4b5de621d1967ea6bca33.html#a6f36c71d07c4b5de621d1967ea6bca33":[3,0,1,2,52,3],
 "d7/d8b/cblas__dswap_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,52,2],
 "d7/d8b/cblas__dswap_8c_source.html":[3,0,1,2,52],
 "d7/d8b/lapacke__dggbak__work_8c.html":[3,0,4,3,777],
@@ -115,16 +116,16 @@ var NAVTREEINDEX47 =
 "d7/d8b/lapacke__dggbak__work_8c_source.html":[3,0,4,3,777],
 "d7/d8c/dgeqpf_8f.html":[3,0,5,0,12],
 "d7/d8c/dgeqpf_8f_source.html":[3,0,5,0,12],
-"d7/d8d/dsptrs_8f.html":[3,0,5,889],
-"d7/d8d/dsptrs_8f_source.html":[3,0,5,889],
+"d7/d8d/dsptrs_8f.html":[3,0,5,888],
+"d7/d8d/dsptrs_8f_source.html":[3,0,5,888],
 "d7/d8e/lapacke__sgerfsx__work_8c.html":[3,0,4,3,1341],
 "d7/d8e/lapacke__sgerfsx__work_8c_a1a46de2067b0207ea03d37a1d254468b.html#a1a46de2067b0207ea03d37a1d254468b":[3,0,4,3,1341,0],
 "d7/d8e/lapacke__sgerfsx__work_8c_source.html":[3,0,4,3,1341],
 "d7/d8e/lapacke__zgelss__work_8c.html":[3,0,4,3,1899],
 "d7/d8e/lapacke__zgelss__work_8c_a6c1b278b91af733dbe0502e83f6ae97f.html#a6c1b278b91af733dbe0502e83f6ae97f":[3,0,4,3,1899,0],
 "d7/d8e/lapacke__zgelss__work_8c_source.html":[3,0,4,3,1899],
-"d7/d8f/ztfsm_8f.html":[3,0,5,1943],
-"d7/d8f/ztfsm_8f_source.html":[3,0,5,1943],
+"d7/d8f/ztfsm_8f.html":[3,0,5,1941],
+"d7/d8f/ztfsm_8f_source.html":[3,0,5,1941],
 "d7/d90/claqhe_8f.html":[3,0,5,262],
 "d7/d90/claqhe_8f_source.html":[3,0,5,262],
 "d7/d91/lapacke__dspcon__work_8c.html":[3,0,4,3,1031],
@@ -142,7 +143,7 @@ var NAVTREEINDEX47 =
 "d7/d92/cblas__ztrmv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,141,0],
 "d7/d92/cblas__ztrmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,141,1],
 "d7/d92/cblas__ztrmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,141,4],
-"d7/d92/cblas__ztrmv_8c_a6a48a2aeb97fc5a9b3cc2cfdda53a699.html#a6a48a2aeb97fc5a9b3cc2cfdda53a699":[3,0,1,2,141,6],
+"d7/d92/cblas__ztrmv_8c_a71afd5cfa1e160227f9b72f35e3032af.html#a71afd5cfa1e160227f9b72f35e3032af":[3,0,1,2,141,6],
 "d7/d92/cblas__ztrmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,141,3],
 "d7/d92/cblas__ztrmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,141,2],
 "d7/d92/cblas__ztrmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,141,5],
@@ -155,76 +156,76 @@ var NAVTREEINDEX47 =
 "d7/d92/lapacke__sggglm_8c_source.html":[3,0,4,3,1390],
 "d7/d93/group__real_o_t_h_e_reigen.html":[0,0,7,1],
 "d7/d93/group__real_o_t_h_e_reigen_ga11129006080a6ea11a4102843b1ee623.html#ga11129006080a6ea11a4102843b1ee623":[0,0,7,1,2],
-"d7/d93/group__real_o_t_h_e_reigen_ga11129006080a6ea11a4102843b1ee623.html#ga11129006080a6ea11a4102843b1ee623":[3,0,5,1383,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga11129006080a6ea11a4102843b1ee623.html#ga11129006080a6ea11a4102843b1ee623":[3,0,5,1381,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga12db0b30afb433ab6b4fe18a9ee0234f.html#ga12db0b30afb433ab6b4fe18a9ee0234f":[0,0,7,1,7],
-"d7/d93/group__real_o_t_h_e_reigen_ga12db0b30afb433ab6b4fe18a9ee0234f.html#ga12db0b30afb433ab6b4fe18a9ee0234f":[3,0,5,1388,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga12db0b30afb433ab6b4fe18a9ee0234f.html#ga12db0b30afb433ab6b4fe18a9ee0234f":[3,0,5,1386,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga1db1fd0c060db1450df5955922555099.html#ga1db1fd0c060db1450df5955922555099":[0,0,7,1,9],
-"d7/d93/group__real_o_t_h_e_reigen_ga1db1fd0c060db1450df5955922555099.html#ga1db1fd0c060db1450df5955922555099":[3,0,5,1391,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga1db1fd0c060db1450df5955922555099.html#ga1db1fd0c060db1450df5955922555099":[3,0,5,1389,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga2165cdadb45a55b88e71baceea213c3a.html#ga2165cdadb45a55b88e71baceea213c3a":[0,0,7,1,3],
-"d7/d93/group__real_o_t_h_e_reigen_ga2165cdadb45a55b88e71baceea213c3a.html#ga2165cdadb45a55b88e71baceea213c3a":[3,0,5,1384,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga2165cdadb45a55b88e71baceea213c3a.html#ga2165cdadb45a55b88e71baceea213c3a":[3,0,5,1382,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga3396020c326155bf403103d9eef2552d.html#ga3396020c326155bf403103d9eef2552d":[0,0,7,1,1],
-"d7/d93/group__real_o_t_h_e_reigen_ga3396020c326155bf403103d9eef2552d.html#ga3396020c326155bf403103d9eef2552d":[3,0,5,1108,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga3396020c326155bf403103d9eef2552d.html#ga3396020c326155bf403103d9eef2552d":[3,0,5,1106,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga36282d988538ba9e8906875420e2b567.html#ga36282d988538ba9e8906875420e2b567":[0,0,7,1,20],
-"d7/d93/group__real_o_t_h_e_reigen_ga36282d988538ba9e8906875420e2b567.html#ga36282d988538ba9e8906875420e2b567":[3,0,5,1420,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga36282d988538ba9e8906875420e2b567.html#ga36282d988538ba9e8906875420e2b567":[3,0,5,1418,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga40e8f9c2d9853f400715b94a9c5225ab.html#ga40e8f9c2d9853f400715b94a9c5225ab":[0,0,7,1,4],
-"d7/d93/group__real_o_t_h_e_reigen_ga40e8f9c2d9853f400715b94a9c5225ab.html#ga40e8f9c2d9853f400715b94a9c5225ab":[3,0,5,1385,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga40e8f9c2d9853f400715b94a9c5225ab.html#ga40e8f9c2d9853f400715b94a9c5225ab":[3,0,5,1383,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga5566995387fefaa091f1c44cdfff6440.html#ga5566995387fefaa091f1c44cdfff6440":[0,0,7,1,6],
-"d7/d93/group__real_o_t_h_e_reigen_ga5566995387fefaa091f1c44cdfff6440.html#ga5566995387fefaa091f1c44cdfff6440":[3,0,5,1387,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga5566995387fefaa091f1c44cdfff6440.html#ga5566995387fefaa091f1c44cdfff6440":[3,0,5,1385,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga62165ec681f491ea6067a0ab9f532ad4.html#ga62165ec681f491ea6067a0ab9f532ad4":[0,0,7,1,0],
-"d7/d93/group__real_o_t_h_e_reigen_ga62165ec681f491ea6067a0ab9f532ad4.html#ga62165ec681f491ea6067a0ab9f532ad4":[3,0,5,1025,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga62165ec681f491ea6067a0ab9f532ad4.html#ga62165ec681f491ea6067a0ab9f532ad4":[3,0,5,1024,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga68f61567a0a76acea2eac1923e9851a4.html#ga68f61567a0a76acea2eac1923e9851a4":[0,0,7,1,8],
-"d7/d93/group__real_o_t_h_e_reigen_ga68f61567a0a76acea2eac1923e9851a4.html#ga68f61567a0a76acea2eac1923e9851a4":[3,0,5,1390,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga68f61567a0a76acea2eac1923e9851a4.html#ga68f61567a0a76acea2eac1923e9851a4":[3,0,5,1388,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga6958826aa7f37b7d1d4c6f27329dabc0.html#ga6958826aa7f37b7d1d4c6f27329dabc0":[0,0,7,1,17],
-"d7/d93/group__real_o_t_h_e_reigen_ga6958826aa7f37b7d1d4c6f27329dabc0.html#ga6958826aa7f37b7d1d4c6f27329dabc0":[3,0,5,1417,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga6958826aa7f37b7d1d4c6f27329dabc0.html#ga6958826aa7f37b7d1d4c6f27329dabc0":[3,0,5,1415,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga698be9aea5406ea6cb19fe47378e2233.html#ga698be9aea5406ea6cb19fe47378e2233":[0,0,7,1,10],
-"d7/d93/group__real_o_t_h_e_reigen_ga698be9aea5406ea6cb19fe47378e2233.html#ga698be9aea5406ea6cb19fe47378e2233":[3,0,5,1392,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga698be9aea5406ea6cb19fe47378e2233.html#ga698be9aea5406ea6cb19fe47378e2233":[3,0,5,1390,0],
 "d7/d93/group__real_o_t_h_e_reigen_ga6d78c13e0472349e920ec49cc79337fb.html#ga6d78c13e0472349e920ec49cc79337fb":[0,0,7,1,16],
-"d7/d93/group__real_o_t_h_e_reigen_ga6d78c13e0472349e920ec49cc79337fb.html#ga6d78c13e0472349e920ec49cc79337fb":[3,0,5,1402,0],
+"d7/d93/group__real_o_t_h_e_reigen_ga6d78c13e0472349e920ec49cc79337fb.html#ga6d78c13e0472349e920ec49cc79337fb":[3,0,5,1400,0],
 "d7/d93/group__real_o_t_h_e_reigen_gaaa149618cc74cd907218f33d30825109.html#gaaa149618cc74cd907218f33d30825109":[0,0,7,1,13],
-"d7/d93/group__real_o_t_h_e_reigen_gaaa149618cc74cd907218f33d30825109.html#gaaa149618cc74cd907218f33d30825109":[3,0,5,1398,0],
+"d7/d93/group__real_o_t_h_e_reigen_gaaa149618cc74cd907218f33d30825109.html#gaaa149618cc74cd907218f33d30825109":[3,0,5,1396,0],
 "d7/d93/group__real_o_t_h_e_reigen_gab12d98c1a742020839416cf5c086905b.html#gab12d98c1a742020839416cf5c086905b":[0,0,7,1,12],
-"d7/d93/group__real_o_t_h_e_reigen_gab12d98c1a742020839416cf5c086905b.html#gab12d98c1a742020839416cf5c086905b":[3,0,5,1397,0],
+"d7/d93/group__real_o_t_h_e_reigen_gab12d98c1a742020839416cf5c086905b.html#gab12d98c1a742020839416cf5c086905b":[3,0,5,1395,0],
 "d7/d93/group__real_o_t_h_e_reigen_gabe4f11f3ba16bc8f1bf087ef0f6897f1.html#gabe4f11f3ba16bc8f1bf087ef0f6897f1":[0,0,7,1,15],
-"d7/d93/group__real_o_t_h_e_reigen_gabe4f11f3ba16bc8f1bf087ef0f6897f1.html#gabe4f11f3ba16bc8f1bf087ef0f6897f1":[3,0,5,1401,0],
+"d7/d93/group__real_o_t_h_e_reigen_gabe4f11f3ba16bc8f1bf087ef0f6897f1.html#gabe4f11f3ba16bc8f1bf087ef0f6897f1":[3,0,5,1399,0],
 "d7/d93/group__real_o_t_h_e_reigen_gac844e5b72330b46b806ca01856b8078a.html#gac844e5b72330b46b806ca01856b8078a":[0,0,7,1,5],
-"d7/d93/group__real_o_t_h_e_reigen_gac844e5b72330b46b806ca01856b8078a.html#gac844e5b72330b46b806ca01856b8078a":[3,0,5,1386,0],
+"d7/d93/group__real_o_t_h_e_reigen_gac844e5b72330b46b806ca01856b8078a.html#gac844e5b72330b46b806ca01856b8078a":[3,0,5,1384,0],
 "d7/d93/group__real_o_t_h_e_reigen_gad3d127183140e2efdc4dc1016f8f49ce.html#gad3d127183140e2efdc4dc1016f8f49ce":[0,0,7,1,18],
-"d7/d93/group__real_o_t_h_e_reigen_gad3d127183140e2efdc4dc1016f8f49ce.html#gad3d127183140e2efdc4dc1016f8f49ce":[3,0,5,1418,0],
+"d7/d93/group__real_o_t_h_e_reigen_gad3d127183140e2efdc4dc1016f8f49ce.html#gad3d127183140e2efdc4dc1016f8f49ce":[3,0,5,1416,0],
 "d7/d93/group__real_o_t_h_e_reigen_gaee30ff1f2a1f001a8c75a1d233985bb5.html#gaee30ff1f2a1f001a8c75a1d233985bb5":[0,0,7,1,11],
-"d7/d93/group__real_o_t_h_e_reigen_gaee30ff1f2a1f001a8c75a1d233985bb5.html#gaee30ff1f2a1f001a8c75a1d233985bb5":[3,0,5,1396,0],
+"d7/d93/group__real_o_t_h_e_reigen_gaee30ff1f2a1f001a8c75a1d233985bb5.html#gaee30ff1f2a1f001a8c75a1d233985bb5":[3,0,5,1394,0],
 "d7/d93/group__real_o_t_h_e_reigen_gaee807b6868003c11b1b1741576c0f06b.html#gaee807b6868003c11b1b1741576c0f06b":[0,0,7,1,19],
-"d7/d93/group__real_o_t_h_e_reigen_gaee807b6868003c11b1b1741576c0f06b.html#gaee807b6868003c11b1b1741576c0f06b":[3,0,5,1419,0],
+"d7/d93/group__real_o_t_h_e_reigen_gaee807b6868003c11b1b1741576c0f06b.html#gaee807b6868003c11b1b1741576c0f06b":[3,0,5,1417,0],
 "d7/d93/group__real_o_t_h_e_reigen_gaf356f346cac338069786ba63042527a6.html#gaf356f346cac338069786ba63042527a6":[0,0,7,1,14],
-"d7/d93/group__real_o_t_h_e_reigen_gaf356f346cac338069786ba63042527a6.html#gaf356f346cac338069786ba63042527a6":[3,0,5,1400,0],
+"d7/d93/group__real_o_t_h_e_reigen_gaf356f346cac338069786ba63042527a6.html#gaf356f346cac338069786ba63042527a6":[3,0,5,1398,0],
 "d7/d93/lapacke__slarfg_8c.html":[3,0,4,3,1456],
 "d7/d93/lapacke__slarfg_8c_a71d0efe2cab5cc31747eceff3eb62625.html#a71d0efe2cab5cc31747eceff3eb62625":[3,0,4,3,1456,0],
 "d7/d93/lapacke__slarfg_8c_source.html":[3,0,4,3,1456],
-"d7/d93/zla__gercond__c_8f.html":[3,0,5,1712],
-"d7/d93/zla__gercond__c_8f_source.html":[3,0,5,1712],
+"d7/d93/zla__gercond__c_8f.html":[3,0,5,1710],
+"d7/d93/zla__gercond__c_8f_source.html":[3,0,5,1710],
 "d7/d94/lapacke__sggevx__work_8c.html":[3,0,4,3,1389],
 "d7/d94/lapacke__sggevx__work_8c_a4de722361ab8a15341e502b8119eae79.html#a4de722361ab8a15341e502b8119eae79":[3,0,4,3,1389,0],
 "d7/d94/lapacke__sggevx__work_8c_source.html":[3,0,4,3,1389],
 "d7/d95/lapacke__zgesvdq__work_8c.html":[3,0,4,3,1941],
 "d7/d95/lapacke__zgesvdq__work_8c_a823d368479fb9851065bb06e65dc6955.html#a823d368479fb9851065bb06e65dc6955":[3,0,4,3,1941,0],
 "d7/d95/lapacke__zgesvdq__work_8c_source.html":[3,0,4,3,1941],
-"d7/d95/slaed9_8f.html":[3,0,5,1163],
-"d7/d95/slaed9_8f_source.html":[3,0,5,1163],
-"d7/d96/ztgexc_8f.html":[3,0,5,1949],
-"d7/d96/ztgexc_8f_source.html":[3,0,5,1949],
+"d7/d95/slaed9_8f.html":[3,0,5,1161],
+"d7/d95/slaed9_8f_source.html":[3,0,5,1161],
+"d7/d96/ztgexc_8f.html":[3,0,5,1947],
+"d7/d96/ztgexc_8f_source.html":[3,0,5,1947],
 "d7/d97/lapacke__cgetrf2__work_8c.html":[3,0,4,3,116],
 "d7/d97/lapacke__cgetrf2__work_8c_a52225d839c0dcbeced98910d3f84f193.html#a52225d839c0dcbeced98910d3f84f193":[3,0,4,3,116,0],
 "d7/d97/lapacke__cgetrf2__work_8c_source.html":[3,0,4,3,116],
 "d7/d98/lapacke__zunghr_8c.html":[3,0,4,3,2448],
 "d7/d98/lapacke__zunghr_8c_a9dfdf985c3693820ee266e75bb2b464b.html#a9dfdf985c3693820ee266e75bb2b464b":[3,0,4,3,2448,0],
 "d7/d98/lapacke__zunghr_8c_source.html":[3,0,4,3,2448],
-"d7/d98/sggrqf_8f.html":[3,0,5,1113],
-"d7/d98/sggrqf_8f_source.html":[3,0,5,1113],
+"d7/d98/sggrqf_8f.html":[3,0,5,1111],
+"d7/d98/sggrqf_8f_source.html":[3,0,5,1111],
 "d7/d99/_v_a_r_i_a_n_t_s_2lu_2_c_r_2zgetrf_8f.html":[3,0,5,1,1,0,3],
 "d7/d99/_v_a_r_i_a_n_t_s_2lu_2_c_r_2zgetrf_8f_source.html":[3,0,5,1,1,0,3],
 "d7/d99/sceil_8f.html":[3,0,5,1,2,0,2],
 "d7/d99/sceil_8f_source.html":[3,0,5,1,2,0,2],
-"d7/d99/ssysv__aa__2stage_8f.html":[3,0,5,1446],
-"d7/d99/ssysv__aa__2stage_8f_source.html":[3,0,5,1446],
+"d7/d99/ssysv__aa__2stage_8f.html":[3,0,5,1444],
+"d7/d99/ssysv__aa__2stage_8f_source.html":[3,0,5,1444],
 "d7/d9a/dchkec_8f.html":[3,0,6,0,95],
 "d7/d9a/dchkec_8f_source.html":[3,0,6,0,95],
 "d7/d9a/lapacke__dlarnv__work_8c.html":[3,0,4,3,865],
@@ -248,6 +249,5 @@ var NAVTREEINDEX47 =
 "d7/d9d/lapacke__cuncsd__work_8c.html":[3,0,4,3,607],
 "d7/d9d/lapacke__cuncsd__work_8c_a1d1f95d55f86d78fb8f2c32eea114f7c.html#a1d1f95d55f86d78fb8f2c32eea114f7c":[3,0,4,3,607,0],
 "d7/d9d/lapacke__cuncsd__work_8c_source.html":[3,0,4,3,607],
-"d7/d9d/lapacke__zsytrf__rook_8c.html":[3,0,4,3,2347],
-"d7/d9d/lapacke__zsytrf__rook_8c_a5851ea333270c1d5b2ffff5af86fec90.html#a5851ea333270c1d5b2ffff5af86fec90":[3,0,4,3,2347,0]
+"d7/d9d/lapacke__zsytrf__rook_8c.html":[3,0,4,3,2347]
 };
