@@ -1,5 +1,6 @@
 var NAVTREEINDEX48 =
 {
+"d7/d9d/lapacke__zsytrf__rook_8c_a5851ea333270c1d5b2ffff5af86fec90.html#a5851ea333270c1d5b2ffff5af86fec90":[3,0,4,3,2347,0],
 "d7/d9d/lapacke__zsytrf__rook_8c_source.html":[3,0,4,3,2347],
 "d7/d9e/lapacke__cgbtrf__work_8c.html":[3,0,4,3,23],
 "d7/d9e/lapacke__cgbtrf__work_8c_af209a6be488737fba7514b940cf6116e.html#af209a6be488737fba7514b940cf6116e":[3,0,4,3,23,0],
@@ -18,12 +19,12 @@ var NAVTREEINDEX48 =
 "d7/da0/lapacke__slapmt_8c.html":[3,0,4,3,1448],
 "d7/da0/lapacke__slapmt_8c_a8ec2f1b9830b02778931c5e42460be40.html#a8ec2f1b9830b02778931c5e42460be40":[3,0,4,3,1448,0],
 "d7/da0/lapacke__slapmt_8c_source.html":[3,0,4,3,1448],
-"d7/da1/zhetrs__aa_8f.html":[3,0,5,1684],
-"d7/da1/zhetrs__aa_8f_source.html":[3,0,5,1684],
+"d7/da1/zhetrs__aa_8f.html":[3,0,5,1682],
+"d7/da1/zhetrs__aa_8f_source.html":[3,0,5,1682],
 "d7/da2/cpot03_8f.html":[3,0,6,1,152],
 "d7/da2/cpot03_8f_source.html":[3,0,6,1,152],
-"d7/da2/zunmhr_8f.html":[3,0,5,2009],
-"d7/da2/zunmhr_8f_source.html":[3,0,5,2009],
+"d7/da2/zunmhr_8f.html":[3,0,5,2007],
+"d7/da2/zunmhr_8f_source.html":[3,0,5,2007],
 "d7/da3/cgbbrd_8f.html":[3,0,5,4],
 "d7/da3/cgbbrd_8f_source.html":[3,0,5,4],
 "d7/da3/clarscl2_8f.html":[3,0,5,293],
@@ -36,33 +37,33 @@ var NAVTREEINDEX48 =
 "d7/da4/lapacke__sggesx_8c.html":[3,0,4,3,1382],
 "d7/da4/lapacke__sggesx_8c_a6384803b64f897ba6396688afaec0102.html#a6384803b64f897ba6396688afaec0102":[3,0,4,3,1382,0],
 "d7/da4/lapacke__sggesx_8c_source.html":[3,0,4,3,1382],
-"d7/da4/ssyconvf__rook_8f.html":[3,0,5,1426],
-"d7/da4/ssyconvf__rook_8f_a2acbfeaccb575707cbf786f750938770.html#a2acbfeaccb575707cbf786f750938770":[3,0,5,1426,0],
-"d7/da4/ssyconvf__rook_8f_source.html":[3,0,5,1426],
-"d7/da6/zptts2_8f.html":[3,0,5,1885],
-"d7/da6/zptts2_8f_source.html":[3,0,5,1885],
+"d7/da4/ssyconvf__rook_8f.html":[3,0,5,1424],
+"d7/da4/ssyconvf__rook_8f_a2acbfeaccb575707cbf786f750938770.html#a2acbfeaccb575707cbf786f750938770":[3,0,5,1424,0],
+"d7/da4/ssyconvf__rook_8f_source.html":[3,0,5,1424],
+"d7/da6/zptts2_8f.html":[3,0,5,1883],
+"d7/da6/zptts2_8f_source.html":[3,0,5,1883],
 "d7/da7/dlaptm_8f.html":[3,0,6,1,317],
 "d7/da7/dlaptm_8f_source.html":[3,0,6,1,317],
 "d7/da8/cblas__zgemv_8c.html":[3,0,1,2,118],
 "d7/da8/cblas__zgemv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,118,0],
 "d7/da8/cblas__zgemv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,118,1],
-"d7/da8/cblas__zgemv_8c_a524f74e46313ef1c63c852e80ecbd437.html#a524f74e46313ef1c63c852e80ecbd437":[3,0,1,2,118,6],
 "d7/da8/cblas__zgemv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,118,5],
 "d7/da8/cblas__zgemv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,118,4],
 "d7/da8/cblas__zgemv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,118,2],
+"d7/da8/cblas__zgemv_8c_aa083a103e5ed2cb801157b0a7673ba88.html#aa083a103e5ed2cb801157b0a7673ba88":[3,0,1,2,118,6],
 "d7/da8/cblas__zgemv_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,118,3],
 "d7/da8/cblas__zgemv_8c_source.html":[3,0,1,2,118],
 "d7/da8/lapacke__zhetri__3_8c.html":[3,0,4,3,2101],
 "d7/da8/lapacke__zhetri__3_8c_a941b62fd27bd825f6bed4471d38fb4a6.html#a941b62fd27bd825f6bed4471d38fb4a6":[3,0,4,3,2101,0],
 "d7/da8/lapacke__zhetri__3_8c_source.html":[3,0,4,3,2101],
-"d7/da9/dlarfg_8f.html":[3,0,5,708],
-"d7/da9/dlarfg_8f_source.html":[3,0,5,708],
-"d7/daa/slarrf_8f.html":[3,0,5,1243],
-"d7/daa/slarrf_8f_source.html":[3,0,5,1243],
+"d7/da9/dlarfg_8f.html":[3,0,5,707],
+"d7/da9/dlarfg_8f_source.html":[3,0,5,707],
+"d7/daa/slarrf_8f.html":[3,0,5,1241],
+"d7/daa/slarrf_8f_source.html":[3,0,5,1241],
 "d7/daa/ssgt01_8f.html":[3,0,6,0,265],
 "d7/daa/ssgt01_8f_source.html":[3,0,6,0,265],
-"d7/dab/zlapmr_8f.html":[3,0,5,1778],
-"d7/dab/zlapmr_8f_source.html":[3,0,5,1778],
+"d7/dab/zlapmr_8f.html":[3,0,5,1776],
+"d7/dab/zlapmr_8f_source.html":[3,0,5,1776],
 "d7/dad/cblas__drotmg_8c.html":[3,0,1,2,45],
 "d7/dad/cblas__drotmg_8c_afedab778ebc48e6cd1ddaafdbc589ff1.html#afedab778ebc48e6cd1ddaafdbc589ff1":[3,0,1,2,45,0],
 "d7/dad/cblas__drotmg_8c_source.html":[3,0,1,2,45],
@@ -78,12 +79,12 @@ var NAVTREEINDEX48 =
 "d7/db0/chpev_8f_source.html":[3,0,5,169],
 "d7/db0/dgegv_8f.html":[3,0,5,0,10],
 "d7/db0/dgegv_8f_source.html":[3,0,5,0,10],
-"d7/db1/dlasq4_8f.html":[3,0,5,753],
-"d7/db1/dlasq4_8f_source.html":[3,0,5,753],
+"d7/db1/dlasq4_8f.html":[3,0,5,752],
+"d7/db1/dlasq4_8f_source.html":[3,0,5,752],
 "d7/db2/zaxpy_8f.html":[3,0,0,0,116],
 "d7/db2/zaxpy_8f_source.html":[3,0,0,0,116],
-"d7/db2/zgebd2_8f.html":[3,0,5,1540],
-"d7/db2/zgebd2_8f_source.html":[3,0,5,1540],
+"d7/db2/zgebd2_8f.html":[3,0,5,1538],
+"d7/db2/zgebd2_8f_source.html":[3,0,5,1538],
 "d7/db3/lapacke__dgeqrt2__work_8c.html":[3,0,4,3,736],
 "d7/db3/lapacke__dgeqrt2__work_8c_a1f3319b557243ef93eb2adf62a09b502.html#a1f3319b557243ef93eb2adf62a09b502":[3,0,4,3,736,0],
 "d7/db3/lapacke__dgeqrt2__work_8c_source.html":[3,0,4,3,736],
@@ -92,11 +93,11 @@ var NAVTREEINDEX48 =
 "d7/db3/lapacke__zgeqr_8c_source.html":[3,0,4,3,1914],
 "d7/db4/cblas__dtbsv_8c.html":[3,0,1,2,60],
 "d7/db4/cblas__dtbsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,60,0],
-"d7/db4/cblas__dtbsv_8c_a0d292ef38fcf01b8dd92c51d52923c8b.html#a0d292ef38fcf01b8dd92c51d52923c8b":[3,0,1,2,60,7],
 "d7/db4/cblas__dtbsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,60,1],
 "d7/db4/cblas__dtbsv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,60,2],
 "d7/db4/cblas__dtbsv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,60,5],
 "d7/db4/cblas__dtbsv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,60,4],
+"d7/db4/cblas__dtbsv_8c_a881a12c22f30a45076b05b80d5b32777.html#a881a12c22f30a45076b05b80d5b32777":[3,0,1,2,60,7],
 "d7/db4/cblas__dtbsv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,60,3],
 "d7/db4/cblas__dtbsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,60,6],
 "d7/db4/cblas__dtbsv_8c_source.html":[3,0,1,2,60],
@@ -106,8 +107,8 @@ var NAVTREEINDEX48 =
 "d7/db4/lapacke__zstedc__work_8c.html":[3,0,4,3,2301],
 "d7/db4/lapacke__zstedc__work_8c_aae7c906959575aec0851e7634f04676e.html#aae7c906959575aec0851e7634f04676e":[3,0,4,3,2301,0],
 "d7/db4/lapacke__zstedc__work_8c_source.html":[3,0,4,3,2301],
-"d7/db4/slasq1_8f.html":[3,0,5,1273],
-"d7/db4/slasq1_8f_source.html":[3,0,5,1273],
+"d7/db4/slasq1_8f.html":[3,0,5,1271],
+"d7/db4/slasq1_8f_source.html":[3,0,5,1271],
 "d7/db5/dget54_8f.html":[3,0,6,0,150],
 "d7/db5/dget54_8f_source.html":[3,0,6,0,150],
 "d7/db5/lapacke__dgecon_8c.html":[3,0,4,3,682],
@@ -120,13 +121,13 @@ var NAVTREEINDEX48 =
 "d7/db6/lapacke__sorgbr__work_8c_source.html":[3,0,4,3,1493],
 "d7/db6/slqt05_8f.html":[3,0,6,1,509],
 "d7/db6/slqt05_8f_source.html":[3,0,6,1,509],
-"d7/db8/sgemqr_8f.html":[3,0,5,1066],
-"d7/db8/sgemqr_8f_a706c4dc68b7e14f4869ceaec7a262ec0.html#a706c4dc68b7e14f4869ceaec7a262ec0":[3,0,5,1066,0],
-"d7/db8/sgemqr_8f_source.html":[3,0,5,1066],
+"d7/db8/sgemqr_8f.html":[3,0,5,1064],
+"d7/db8/sgemqr_8f_a706c4dc68b7e14f4869ceaec7a262ec0.html#a706c4dc68b7e14f4869ceaec7a262ec0":[3,0,5,1064,0],
+"d7/db8/sgemqr_8f_source.html":[3,0,5,1064],
 "d7/dbc/cblas__cgemm_8c.html":[3,0,1,2,5],
 "d7/dbc/cblas__cgemm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,5,3],
+"d7/dbc/cblas__cgemm_8c_a158b1031ef0d58ced6acb556feeae92d.html#a158b1031ef0d58ced6acb556feeae92d":[3,0,1,2,5,8],
 "d7/dbc/cblas__cgemm_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,5,0],
-"d7/dbc/cblas__cgemm_8c_a552842a427053cdcadc6e403d4b8bd23.html#a552842a427053cdcadc6e403d4b8bd23":[3,0,1,2,5,8],
 "d7/dbc/cblas__cgemm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,5,2],
 "d7/dbc/cblas__cgemm_8c_a5e21023e217bd5a6db0984f3164ba6fc.html#a5e21023e217bd5a6db0984f3164ba6fc":[3,0,1,2,5,7],
 "d7/dbc/cblas__cgemm_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,5,6],
@@ -144,14 +145,14 @@ var NAVTREEINDEX48 =
 "d7/dbd/lapacke__dlamch__work_8c.html":[3,0,4,3,841],
 "d7/dbd/lapacke__dlamch__work_8c_a79b7a2a2153d46da2e4a3cc7da11a607.html#a79b7a2a2153d46da2e4a3cc7da11a607":[3,0,4,3,841,0],
 "d7/dbd/lapacke__dlamch__work_8c_source.html":[3,0,4,3,841],
-"d7/dbf/zsytrf__aa_8f.html":[3,0,5,1924],
-"d7/dbf/zsytrf__aa_8f_source.html":[3,0,5,1924],
-"d7/dc0/iladlc_8f.html":[3,0,5,1005],
-"d7/dc0/iladlc_8f_source.html":[3,0,5,1005],
-"d7/dc0/zsytri2_8f.html":[3,0,5,1929],
-"d7/dc0/zsytri2_8f_source.html":[3,0,5,1929],
-"d7/dc1/zsytrs__3_8f.html":[3,0,5,1936],
-"d7/dc1/zsytrs__3_8f_source.html":[3,0,5,1936],
+"d7/dbf/zsytrf__aa_8f.html":[3,0,5,1922],
+"d7/dbf/zsytrf__aa_8f_source.html":[3,0,5,1922],
+"d7/dc0/iladlc_8f.html":[3,0,5,1004],
+"d7/dc0/iladlc_8f_source.html":[3,0,5,1004],
+"d7/dc0/zsytri2_8f.html":[3,0,5,1927],
+"d7/dc0/zsytri2_8f_source.html":[3,0,5,1927],
+"d7/dc1/zsytrs__3_8f.html":[3,0,5,1934],
+"d7/dc1/zsytrs__3_8f_source.html":[3,0,5,1934],
 "d7/dc2/clacn2_8f.html":[3,0,5,213],
 "d7/dc2/clacn2_8f_source.html":[3,0,5,213],
 "d7/dc3/group__double__lin.html":[0,1,1,1],
@@ -191,12 +192,12 @@ var NAVTREEINDEX48 =
 "d7/dc3/group__double__lin_ga1ec1e1fad10aa87bde3576487239c5e1.html#ga1ec1e1fad10aa87bde3576487239c5e1":[3,0,6,1,225,0],
 "d7/dc3/group__double__lin_ga208912d7f06dd04653e8261b24fa62af.html#ga208912d7f06dd04653e8261b24fa62af":[0,1,1,1,125],
 "d7/dc3/group__double__lin_ga208912d7f06dd04653e8261b24fa62af.html#ga208912d7f06dd04653e8261b24fa62af":[3,0,6,1,336,0],
-"d7/dc3/group__double__lin_ga22be349893f9397ea12efa368fa75407.html#ga22be349893f9397ea12efa368fa75407":[3,0,6,1,353,0],
 "d7/dc3/group__double__lin_ga22be349893f9397ea12efa368fa75407.html#ga22be349893f9397ea12efa368fa75407":[0,1,1,1,142],
+"d7/dc3/group__double__lin_ga22be349893f9397ea12efa368fa75407.html#ga22be349893f9397ea12efa368fa75407":[3,0,6,1,353,0],
 "d7/dc3/group__double__lin_ga232d99672dedb88a49b1abd4b77191ec.html#ga232d99672dedb88a49b1abd4b77191ec":[0,1,1,1,116],
 "d7/dc3/group__double__lin_ga232d99672dedb88a49b1abd4b77191ec.html#ga232d99672dedb88a49b1abd4b77191ec":[3,0,6,1,327,0],
-"d7/dc3/group__double__lin_ga2507f2787f18c8fbaa5dd348b265f6bf.html#ga2507f2787f18c8fbaa5dd348b265f6bf":[0,1,1,1,165],
 "d7/dc3/group__double__lin_ga2507f2787f18c8fbaa5dd348b265f6bf.html#ga2507f2787f18c8fbaa5dd348b265f6bf":[3,0,6,1,376,0],
+"d7/dc3/group__double__lin_ga2507f2787f18c8fbaa5dd348b265f6bf.html#ga2507f2787f18c8fbaa5dd348b265f6bf":[0,1,1,1,165],
 "d7/dc3/group__double__lin_ga2531f677f628d30acf84634929d904e5.html#ga2531f677f628d30acf84634929d904e5":[0,1,1,1,106],
 "d7/dc3/group__double__lin_ga2531f677f628d30acf84634929d904e5.html#ga2531f677f628d30acf84634929d904e5":[3,0,6,1,317,0],
 "d7/dc3/group__double__lin_ga2553cadb5535be38dad9a91a709d971c.html#ga2553cadb5535be38dad9a91a709d971c":[0,1,1,1,91],
@@ -215,8 +216,8 @@ var NAVTREEINDEX48 =
 "d7/dc3/group__double__lin_ga2b2e3ad97569e899c170e6f18f7a8776.html#ga2b2e3ad97569e899c170e6f18f7a8776":[3,0,6,1,364,0],
 "d7/dc3/group__double__lin_ga2bc6375c0d6210d16ae808ac0950bd28.html#ga2bc6375c0d6210d16ae808ac0950bd28":[0,1,1,1,15],
 "d7/dc3/group__double__lin_ga2bc6375c0d6210d16ae808ac0950bd28.html#ga2bc6375c0d6210d16ae808ac0950bd28":[3,0,6,1,218,0],
-"d7/dc3/group__double__lin_ga2daab75a77e46e708098a240ca24bc77.html#ga2daab75a77e46e708098a240ca24bc77":[0,1,1,1,4],
 "d7/dc3/group__double__lin_ga2daab75a77e46e708098a240ca24bc77.html#ga2daab75a77e46e708098a240ca24bc77":[3,0,6,1,83,0],
+"d7/dc3/group__double__lin_ga2daab75a77e46e708098a240ca24bc77.html#ga2daab75a77e46e708098a240ca24bc77":[0,1,1,1,4],
 "d7/dc3/group__double__lin_ga30758da2bab16da4b0b5c925bc869022.html#ga30758da2bab16da4b0b5c925bc869022":[0,1,1,1,115],
 "d7/dc3/group__double__lin_ga30758da2bab16da4b0b5c925bc869022.html#ga30758da2bab16da4b0b5c925bc869022":[3,0,6,1,326,0],
 "d7/dc3/group__double__lin_ga323e6436b0b10537c96eb7ac3e871285.html#ga323e6436b0b10537c96eb7ac3e871285":[0,1,1,1,73],
@@ -225,16 +226,16 @@ var NAVTREEINDEX48 =
 "d7/dc3/group__double__lin_ga3285163d1ca50de8fdce2fc4b3e92114.html#ga3285163d1ca50de8fdce2fc4b3e92114":[3,0,6,1,265,0],
 "d7/dc3/group__double__lin_ga34a38ca3e7e4c5fc00c39a32af0d576f.html#ga34a38ca3e7e4c5fc00c39a32af0d576f":[0,1,1,1,132],
 "d7/dc3/group__double__lin_ga34a38ca3e7e4c5fc00c39a32af0d576f.html#ga34a38ca3e7e4c5fc00c39a32af0d576f":[3,0,6,1,343,0],
-"d7/dc3/group__double__lin_ga364f84b5f8cf146b97e24e52e718b2ec.html#ga364f84b5f8cf146b97e24e52e718b2ec":[3,0,6,1,354,0],
 "d7/dc3/group__double__lin_ga364f84b5f8cf146b97e24e52e718b2ec.html#ga364f84b5f8cf146b97e24e52e718b2ec":[0,1,1,1,143],
+"d7/dc3/group__double__lin_ga364f84b5f8cf146b97e24e52e718b2ec.html#ga364f84b5f8cf146b97e24e52e718b2ec":[3,0,6,1,354,0],
 "d7/dc3/group__double__lin_ga3aa1db881073cfec78bb0eec939fa0da.html#ga3aa1db881073cfec78bb0eec939fa0da":[0,1,1,1,189],
 "d7/dc3/group__double__lin_ga3aa1db881073cfec78bb0eec939fa0da.html#ga3aa1db881073cfec78bb0eec939fa0da":[3,0,6,1,508,0],
 "d7/dc3/group__double__lin_ga3ac2ab6cb24e60294c3cb3d772dfc168.html#ga3ac2ab6cb24e60294c3cb3d772dfc168":[0,1,1,1,46],
 "d7/dc3/group__double__lin_ga3ac2ab6cb24e60294c3cb3d772dfc168.html#ga3ac2ab6cb24e60294c3cb3d772dfc168":[3,0,6,1,251,0],
 "d7/dc3/group__double__lin_ga3ae486b31506e972a9cb3a9c2d03348c.html#ga3ae486b31506e972a9cb3a9c2d03348c":[0,1,1,1,163],
 "d7/dc3/group__double__lin_ga3ae486b31506e972a9cb3a9c2d03348c.html#ga3ae486b31506e972a9cb3a9c2d03348c":[3,0,6,1,374,0],
-"d7/dc3/group__double__lin_ga3b4ab9461495d638095380868fa97049.html#ga3b4ab9461495d638095380868fa97049":[0,1,1,1,26],
 "d7/dc3/group__double__lin_ga3b4ab9461495d638095380868fa97049.html#ga3b4ab9461495d638095380868fa97049":[3,0,6,1,229,0],
+"d7/dc3/group__double__lin_ga3b4ab9461495d638095380868fa97049.html#ga3b4ab9461495d638095380868fa97049":[0,1,1,1,26],
 "d7/dc3/group__double__lin_ga3e26bcfdcaad86790cffa8f7b4258de5.html#ga3e26bcfdcaad86790cffa8f7b4258de5":[0,1,1,1,186],
 "d7/dc3/group__double__lin_ga3e26bcfdcaad86790cffa8f7b4258de5.html#ga3e26bcfdcaad86790cffa8f7b4258de5":[3,0,6,1,455,0],
 "d7/dc3/group__double__lin_ga3eae501df53eca1113cb9703e237acd3.html#ga3eae501df53eca1113cb9703e237acd3":[0,1,1,1,114],
@@ -248,6 +249,5 @@ var NAVTREEINDEX48 =
 "d7/dc3/group__double__lin_ga478c1d53fc9e88ddbeea5f74423560be.html#ga478c1d53fc9e88ddbeea5f74423560be":[0,1,1,1,69],
 "d7/dc3/group__double__lin_ga478c1d53fc9e88ddbeea5f74423560be.html#ga478c1d53fc9e88ddbeea5f74423560be":[3,0,6,1,277,0],
 "d7/dc3/group__double__lin_ga4815f05c6b1e6e46dc4d6066b4663d01.html#ga4815f05c6b1e6e46dc4d6066b4663d01":[0,1,1,1,97],
-"d7/dc3/group__double__lin_ga4815f05c6b1e6e46dc4d6066b4663d01.html#ga4815f05c6b1e6e46dc4d6066b4663d01":[3,0,6,1,308,0],
-"d7/dc3/group__double__lin_ga4e33e0b2206bf1c76520333b8982df24.html#ga4e33e0b2206bf1c76520333b8982df24":[0,1,1,1,20]
+"d7/dc3/group__double__lin_ga4815f05c6b1e6e46dc4d6066b4663d01.html#ga4815f05c6b1e6e46dc4d6066b4663d01":[3,0,6,1,308,0]
 };
