@@ -1,5 +1,6 @@
 var NAVTREEINDEX50 =
 {
+"d7/dc3/group__double__lin_gad76ee5dabf34bd9837af78686f074744.html#gad76ee5dabf34bd9837af78686f074744":[0,1,1,1,113],
 "d7/dc3/group__double__lin_gad76ee5dabf34bd9837af78686f074744.html#gad76ee5dabf34bd9837af78686f074744":[3,0,6,1,324,0],
 "d7/dc3/group__double__lin_gad8c416848c97df5476bcbe960e743c78.html#gad8c416848c97df5476bcbe960e743c78":[0,1,1,1,124],
 "d7/dc3/group__double__lin_gad8c416848c97df5476bcbe960e743c78.html#gad8c416848c97df5476bcbe960e743c78":[3,0,6,1,335,0],
@@ -22,20 +23,20 @@ var NAVTREEINDEX50 =
 "d7/dc3/group__double__lin_gadfec0f472fd2ce54edf26dfa27fee25b.html#gadfec0f472fd2ce54edf26dfa27fee25b":[3,0,6,1,258,0],
 "d7/dc3/group__double__lin_gae0e141a4d9e70990a118f31558c06079.html#gae0e141a4d9e70990a118f31558c06079":[0,1,1,1,27],
 "d7/dc3/group__double__lin_gae0e141a4d9e70990a118f31558c06079.html#gae0e141a4d9e70990a118f31558c06079":[3,0,6,1,230,0],
-"d7/dc3/group__double__lin_gae303210d150bc53b7009535a9350312b.html#gae303210d150bc53b7009535a9350312b":[0,1,1,1,193],
 "d7/dc3/group__double__lin_gae303210d150bc53b7009535a9350312b.html#gae303210d150bc53b7009535a9350312b":[3,0,6,1,586,0],
+"d7/dc3/group__double__lin_gae303210d150bc53b7009535a9350312b.html#gae303210d150bc53b7009535a9350312b":[0,1,1,1,193],
 "d7/dc3/group__double__lin_gae485e6ded732a7296ba1291c3ca4cd43.html#gae485e6ded732a7296ba1291c3ca4cd43":[0,1,1,1,129],
 "d7/dc3/group__double__lin_gae485e6ded732a7296ba1291c3ca4cd43.html#gae485e6ded732a7296ba1291c3ca4cd43":[3,0,6,1,340,0],
-"d7/dc3/group__double__lin_gae5935ffc21a0bcaf46bda6cc406368f6.html#gae5935ffc21a0bcaf46bda6cc406368f6":[3,0,6,1,373,0],
 "d7/dc3/group__double__lin_gae5935ffc21a0bcaf46bda6cc406368f6.html#gae5935ffc21a0bcaf46bda6cc406368f6":[0,1,1,1,162],
+"d7/dc3/group__double__lin_gae5935ffc21a0bcaf46bda6cc406368f6.html#gae5935ffc21a0bcaf46bda6cc406368f6":[3,0,6,1,373,0],
 "d7/dc3/group__double__lin_gae835dfa51943b6cddd0d991c0525737a.html#gae835dfa51943b6cddd0d991c0525737a":[0,1,1,1,76],
 "d7/dc3/group__double__lin_gae835dfa51943b6cddd0d991c0525737a.html#gae835dfa51943b6cddd0d991c0525737a":[3,0,6,1,285,0],
 "d7/dc3/group__double__lin_gae8bcacf5aff31505da444b9df968151c.html#gae8bcacf5aff31505da444b9df968151c":[0,1,1,1,101],
 "d7/dc3/group__double__lin_gae8bcacf5aff31505da444b9df968151c.html#gae8bcacf5aff31505da444b9df968151c":[3,0,6,1,312,0],
 "d7/dc3/group__double__lin_gaed20cca74e55e9252051d91f329a8bc3.html#gaed20cca74e55e9252051d91f329a8bc3":[0,1,1,1,31],
 "d7/dc3/group__double__lin_gaed20cca74e55e9252051d91f329a8bc3.html#gaed20cca74e55e9252051d91f329a8bc3":[3,0,6,1,234,0],
-"d7/dc3/group__double__lin_gaed33a09e8bc0c43d32c67f83e1673630.html#gaed33a09e8bc0c43d32c67f83e1673630":[3,0,6,1,306,0],
 "d7/dc3/group__double__lin_gaed33a09e8bc0c43d32c67f83e1673630.html#gaed33a09e8bc0c43d32c67f83e1673630":[0,1,1,1,95],
+"d7/dc3/group__double__lin_gaed33a09e8bc0c43d32c67f83e1673630.html#gaed33a09e8bc0c43d32c67f83e1673630":[3,0,6,1,306,0],
 "d7/dc3/group__double__lin_gaef20b8ac00287c0f935b061ebe2c9fdf.html#gaef20b8ac00287c0f935b061ebe2c9fdf":[0,1,1,1,110],
 "d7/dc3/group__double__lin_gaef20b8ac00287c0f935b061ebe2c9fdf.html#gaef20b8ac00287c0f935b061ebe2c9fdf":[3,0,6,1,321,0],
 "d7/dc3/group__double__lin_gaf0285d60d2ab48e4f2c676c7d93318bb.html#gaf0285d60d2ab48e4f2c676c7d93318bb":[0,1,1,1,89],
@@ -69,10 +70,10 @@ var NAVTREEINDEX50 =
 "d7/dc4/lapacke__cgelq_8c.html":[3,0,4,3,50],
 "d7/dc4/lapacke__cgelq_8c_aadac41d4c1ab14b0f1dac6de2216f453.html#aadac41d4c1ab14b0f1dac6de2216f453":[3,0,4,3,50,0],
 "d7/dc4/lapacke__cgelq_8c_source.html":[3,0,4,3,50],
-"d7/dc4/zhecon__3_8f.html":[3,0,5,1635],
-"d7/dc4/zhecon__3_8f_source.html":[3,0,5,1635],
-"d7/dc4/zsytri__3x_8f.html":[3,0,5,1932],
-"d7/dc4/zsytri__3x_8f_source.html":[3,0,5,1932],
+"d7/dc4/zhecon__3_8f.html":[3,0,5,1633],
+"d7/dc4/zhecon__3_8f_source.html":[3,0,5,1633],
+"d7/dc4/zsytri__3x_8f.html":[3,0,5,1930],
+"d7/dc4/zsytri__3x_8f_source.html":[3,0,5,1930],
 "d7/dc5/dget10_8f.html":[3,0,6,0,133],
 "d7/dc5/dget10_8f_source.html":[3,0,6,0,133],
 "d7/dc9/lapacke__dsytrs_8c.html":[3,0,4,3,1158],
@@ -88,41 +89,41 @@ var NAVTREEINDEX50 =
 "d7/dca/lapacke__zgeqrt2_8c_source.html":[3,0,4,3,1923],
 "d7/dcb/dtrt03_8f.html":[3,0,6,1,389],
 "d7/dcb/dtrt03_8f_source.html":[3,0,6,1,389],
-"d7/dcb/sla__porfsx__extended_8f.html":[3,0,5,1139],
-"d7/dcb/sla__porfsx__extended_8f_source.html":[3,0,5,1139],
+"d7/dcb/sla__porfsx__extended_8f.html":[3,0,5,1137],
+"d7/dcb/sla__porfsx__extended_8f_source.html":[3,0,5,1137],
 "d7/dcc/cblas__stpsv_8c.html":[3,0,1,2,105],
 "d7/dcc/cblas__stpsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,105,0],
 "d7/dcc/cblas__stpsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,105,1],
 "d7/dcc/cblas__stpsv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,105,3],
 "d7/dcc/cblas__stpsv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,105,2],
-"d7/dcc/cblas__stpsv_8c_a7c06083086962fbe22cf3ad09131f4d9.html#a7c06083086962fbe22cf3ad09131f4d9":[3,0,1,2,105,5],
 "d7/dcc/cblas__stpsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,105,4],
+"d7/dcc/cblas__stpsv_8c_acc7cf88cb9ff49ca3d919e0d611e0729.html#acc7cf88cb9ff49ca3d919e0d611e0729":[3,0,1,2,105,5],
 "d7/dcc/cblas__stpsv_8c_source.html":[3,0,1,2,105],
 "d7/dcc/cgehrd_8f.html":[3,0,5,28],
 "d7/dcc/cgehrd_8f_source.html":[3,0,5,28],
 "d7/dce/ctpmlqt_8f.html":[3,0,5,437],
 "d7/dce/ctpmlqt_8f_source.html":[3,0,5,437],
-"d7/dce/dla__gercond_8f.html":[3,0,5,611],
-"d7/dce/dla__gercond_8f_source.html":[3,0,5,611],
+"d7/dce/dla__gercond_8f.html":[3,0,5,610],
+"d7/dce/dla__gercond_8f_source.html":[3,0,5,610],
 "d7/dcf/cblas__ssyr2_8c.html":[3,0,1,2,99],
+"d7/dcf/cblas__ssyr2_8c_a1229af6348e1549a74f255e742d6df42.html#a1229af6348e1549a74f255e742d6df42":[3,0,1,2,99,5],
 "d7/dcf/cblas__ssyr2_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,99,0],
 "d7/dcf/cblas__ssyr2_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,99,1],
 "d7/dcf/cblas__ssyr2_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,99,3],
 "d7/dcf/cblas__ssyr2_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,99,2],
 "d7/dcf/cblas__ssyr2_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,99,4],
-"d7/dcf/cblas__ssyr2_8c_af36a445b2261e4a38d64d4961758ba89.html#af36a445b2261e4a38d64d4961758ba89":[3,0,1,2,99,5],
 "d7/dcf/cblas__ssyr2_8c_source.html":[3,0,1,2,99],
 "d7/dd0/dlatm1_8f.html":[3,0,6,2,27],
 "d7/dd0/dlatm1_8f_source.html":[3,0,6,2,27],
 "d7/dd0/lapacke__zgges3_8c.html":[3,0,4,3,1969],
 "d7/dd0/lapacke__zgges3_8c_a966552ea05b5505bbf9acbc2efcf582b.html#a966552ea05b5505bbf9acbc2efcf582b":[3,0,4,3,1969,0],
 "d7/dd0/lapacke__zgges3_8c_source.html":[3,0,4,3,1969],
-"d7/dd1/slarrk_8f.html":[3,0,5,1245],
-"d7/dd1/slarrk_8f_source.html":[3,0,5,1245],
-"d7/dd1/slasdq_8f.html":[3,0,5,1270],
-"d7/dd1/slasdq_8f_source.html":[3,0,5,1270],
-"d7/dd1/zhpgvd_8f.html":[3,0,5,1695],
-"d7/dd1/zhpgvd_8f_source.html":[3,0,5,1695],
+"d7/dd1/slarrk_8f.html":[3,0,5,1243],
+"d7/dd1/slarrk_8f_source.html":[3,0,5,1243],
+"d7/dd1/slasdq_8f.html":[3,0,5,1268],
+"d7/dd1/slasdq_8f_source.html":[3,0,5,1268],
+"d7/dd1/zhpgvd_8f.html":[3,0,5,1693],
+"d7/dd1/zhpgvd_8f_source.html":[3,0,5,1693],
 "d7/dd2/clagsy_8f.html":[3,0,6,2,2],
 "d7/dd2/clagsy_8f_source.html":[3,0,6,2,2],
 "d7/dd2/lapacke__ztptrs__work_8c.html":[3,0,4,3,2411],
@@ -161,8 +162,8 @@ var NAVTREEINDEX50 =
 "d7/dd7/group__complex__matgen_ga591e57991ad92ea8cc4ffd534c682bf9.html#ga591e57991ad92ea8cc4ffd534c682bf9":[3,0,6,2,5,0],
 "d7/dd7/group__complex__matgen_ga6b05f57659c673fb19b320ad9737810b.html#ga6b05f57659c673fb19b320ad9737810b":[0,1,0,2,12],
 "d7/dd7/group__complex__matgen_ga6b05f57659c673fb19b320ad9737810b.html#ga6b05f57659c673fb19b320ad9737810b":[3,0,6,2,12,0],
-"d7/dd7/group__complex__matgen_ga6b623095dea5337d8a8cc4e32c7990e0.html#ga6b623095dea5337d8a8cc4e32c7990e0":[3,0,6,2,14,0],
 "d7/dd7/group__complex__matgen_ga6b623095dea5337d8a8cc4e32c7990e0.html#ga6b623095dea5337d8a8cc4e32c7990e0":[0,1,0,2,14],
+"d7/dd7/group__complex__matgen_ga6b623095dea5337d8a8cc4e32c7990e0.html#ga6b623095dea5337d8a8cc4e32c7990e0":[3,0,6,2,14,0],
 "d7/dd7/group__complex__matgen_ga7a28051d16bc46beecf83a6cacad4b37.html#ga7a28051d16bc46beecf83a6cacad4b37":[0,1,0,2,4],
 "d7/dd7/group__complex__matgen_ga7a28051d16bc46beecf83a6cacad4b37.html#ga7a28051d16bc46beecf83a6cacad4b37":[3,0,6,2,4,0],
 "d7/dd7/group__complex__matgen_ga7b4d68bedb34b4e82b4a7cb32be76d24.html#ga7b4d68bedb34b4e82b4a7cb32be76d24":[0,1,0,2,1],
@@ -185,24 +186,24 @@ var NAVTREEINDEX50 =
 "d7/dd7/group__complex__matgen_gae43d0be5e9d0999d6a512e6842a6d65f.html#gae43d0be5e9d0999d6a512e6842a6d65f":[3,0,6,2,2,0],
 "d7/dd7/group__complex__matgen_gae9d75b31c19f718d006ac8059071b253.html#gae9d75b31c19f718d006ac8059071b253":[0,1,0,2,13],
 "d7/dd7/group__complex__matgen_gae9d75b31c19f718d006ac8059071b253.html#gae9d75b31c19f718d006ac8059071b253":[3,0,6,2,13,0],
-"d7/dd8/dlascl2_8f.html":[3,0,5,736],
-"d7/dd8/dlascl2_8f_source.html":[3,0,5,736],
+"d7/dd8/dlascl2_8f.html":[3,0,5,735],
+"d7/dd8/dlascl2_8f_source.html":[3,0,5,735],
 "d7/dd8/lapacke__slagsy_8c.html":[3,0,4,3,1436],
 "d7/dd8/lapacke__slagsy_8c_a4d8fdc269f351b1e7056e23275443c1b.html#a4d8fdc269f351b1e7056e23275443c1b":[3,0,4,3,1436,0],
 "d7/dd8/lapacke__slagsy_8c_source.html":[3,0,4,3,1436],
 "d7/dd9/lapacke__dgesv__work_8c.html":[3,0,4,3,749],
 "d7/dd9/lapacke__dgesv__work_8c_a6e4e6f43f3ea01a131316aabc0f2c10a.html#a6e4e6f43f3ea01a131316aabc0f2c10a":[3,0,4,3,749,0],
 "d7/dd9/lapacke__dgesv__work_8c_source.html":[3,0,4,3,749],
-"d7/dd9/ssytrs_8f.html":[3,0,5,1471],
-"d7/dd9/ssytrs_8f_source.html":[3,0,5,1471],
-"d7/dd9/zlags2_8f.html":[3,0,5,1748],
-"d7/dd9/zlags2_8f_source.html":[3,0,5,1748],
-"d7/dda/slaed7_8f.html":[3,0,5,1161],
-"d7/dda/slaed7_8f_source.html":[3,0,5,1161],
-"d7/ddb/dlarrr_8f.html":[3,0,5,723],
-"d7/ddb/dlarrr_8f_source.html":[3,0,5,723],
-"d7/ddb/dorgtsqr_8f.html":[3,0,5,799],
-"d7/ddb/dorgtsqr_8f_source.html":[3,0,5,799],
+"d7/dd9/ssytrs_8f.html":[3,0,5,1469],
+"d7/dd9/ssytrs_8f_source.html":[3,0,5,1469],
+"d7/dd9/zlags2_8f.html":[3,0,5,1746],
+"d7/dd9/zlags2_8f_source.html":[3,0,5,1746],
+"d7/dda/slaed7_8f.html":[3,0,5,1159],
+"d7/dda/slaed7_8f_source.html":[3,0,5,1159],
+"d7/ddb/dlarrr_8f.html":[3,0,5,722],
+"d7/ddb/dlarrr_8f_source.html":[3,0,5,722],
+"d7/ddb/dorgtsqr_8f.html":[3,0,5,798],
+"d7/ddb/dorgtsqr_8f_source.html":[3,0,5,798],
 "d7/dde/lapacke__sptcon__work_8c.html":[3,0,4,3,1589],
 "d7/dde/lapacke__sptcon__work_8c_a8e40abbfbbfad9f03d53c71fb4e0b93d.html#a8e40abbfbbfad9f03d53c71fb4e0b93d":[3,0,4,3,1589,0],
 "d7/dde/lapacke__sptcon__work_8c_source.html":[3,0,4,3,1589],
@@ -211,8 +212,8 @@ var NAVTREEINDEX50 =
 "d7/ddf/lapacke__sgbrfs__work_8c_source.html":[3,0,4,3,1261],
 "d7/de0/chetrs__aa__2stage_8f.html":[3,0,5,163],
 "d7/de0/chetrs__aa__2stage_8f_source.html":[3,0,5,163],
-"d7/de0/zlatrd_8f.html":[3,0,5,1835],
-"d7/de0/zlatrd_8f_source.html":[3,0,5,1835],
+"d7/de0/zlatrd_8f.html":[3,0,5,1833],
+"d7/de0/zlatrd_8f_source.html":[3,0,5,1833],
 "d7/de2/lapacke__zlacp2_8c.html":[3,0,4,3,2158],
 "d7/de2/lapacke__zlacp2_8c_af501e307ad2e3ced2e0d4f5b1f632fb2.html#af501e307ad2e3ced2e0d4f5b1f632fb2":[3,0,4,3,2158,0],
 "d7/de2/lapacke__zlacp2_8c_source.html":[3,0,4,3,2158],
@@ -222,18 +223,18 @@ var NAVTREEINDEX50 =
 "d7/de5/cblas__zswap_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,132,0],
 "d7/de5/cblas__zswap_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,132,1],
 "d7/de5/cblas__zswap_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,132,2],
-"d7/de5/cblas__zswap_8c_a941cf9f95d66a8ca0c22e4e3b1ca0b46.html#a941cf9f95d66a8ca0c22e4e3b1ca0b46":[3,0,1,2,132,3],
+"d7/de5/cblas__zswap_8c_afd0fd19718e55f4ee203082d6c24bf4d.html#afd0fd19718e55f4ee203082d6c24bf4d":[3,0,1,2,132,3],
 "d7/de5/cblas__zswap_8c_source.html":[3,0,1,2,132],
 "d7/de5/lapacke__sgetsqrhrt__work_8c.html":[3,0,4,3,1373],
 "d7/de5/lapacke__sgetsqrhrt__work_8c_a1071e963f31ff93f84932852a0bccc84.html#a1071e963f31ff93f84932852a0bccc84":[3,0,4,3,1373,0],
 "d7/de5/lapacke__sgetsqrhrt__work_8c_source.html":[3,0,4,3,1373],
-"d7/de6/dtpmqrt_8f.html":[3,0,5,976],
-"d7/de6/dtpmqrt_8f_source.html":[3,0,5,976],
+"d7/de6/dtpmqrt_8f.html":[3,0,5,975],
+"d7/de6/dtpmqrt_8f_source.html":[3,0,5,975],
 "d7/de6/lapacke__dsyevr__work_8c.html":[3,0,4,3,1103],
 "d7/de6/lapacke__dsyevr__work_8c_a5542586fdcc41b2bb42f38a1ab4fd566.html#a5542586fdcc41b2bb42f38a1ab4fd566":[3,0,4,3,1103,0],
 "d7/de6/lapacke__dsyevr__work_8c_source.html":[3,0,4,3,1103],
-"d7/de6/ssbgst_8f.html":[3,0,5,1389],
-"d7/de6/ssbgst_8f_source.html":[3,0,5,1389],
+"d7/de6/ssbgst_8f.html":[3,0,5,1387],
+"d7/de6/ssbgst_8f_source.html":[3,0,5,1387],
 "d7/de7/ctgsyl_8f.html":[3,0,5,433],
 "d7/de7/ctgsyl_8f_source.html":[3,0,5,433],
 "d7/de7/lapacke__cgbequb_8c.html":[3,0,4,3,10],
@@ -242,12 +243,11 @@ var NAVTREEINDEX50 =
 "d7/de7/lapacke__stb__trans_8c.html":[3,0,4,4,102],
 "d7/de7/lapacke__stb__trans_8c_ad747de8cd5276e30889f34e8b1cb054c.html#ad747de8cd5276e30889f34e8b1cb054c":[3,0,4,4,102,0],
 "d7/de7/lapacke__stb__trans_8c_source.html":[3,0,4,4,102],
-"d7/de7/sopmtr_8f.html":[3,0,5,1300],
-"d7/de7/sopmtr_8f_source.html":[3,0,5,1300],
+"d7/de7/sopmtr_8f.html":[3,0,5,1298],
+"d7/de7/sopmtr_8f_source.html":[3,0,5,1298],
 "d7/de8/cblas__test_8h.html":[3,0,1,1,2],
 "d7/de8/cblas__test_8h_a0553fa4e0aa5ae85d3ed2c6d52347373.html#a0553fa4e0aa5ae85d3ed2c6d52347373":[3,0,1,1,2,22],
 "d7/de8/cblas__test_8h_a0646bf1e99ebf193e64c32dfaf9a4294.html#a0646bf1e99ebf193e64c32dfaf9a4294":[3,0,1,1,2,45],
 "d7/de8/cblas__test_8h_a085a5b85ae5e7ef8a2c61e99d173226c.html#a085a5b85ae5e7ef8a2c61e99d173226c":[3,0,1,1,2,112],
-"d7/de8/cblas__test_8h_a09a0c19becb051f9a525684543d69a76.html#a09a0c19becb051f9a525684543d69a76":[3,0,1,1,2,25],
-"d7/de8/cblas__test_8h_a09cdfd3508496c693a3c436f1172ead2.html#a09cdfd3508496c693a3c436f1172ead2":[3,0,1,1,2,16]
+"d7/de8/cblas__test_8h_a09a0c19becb051f9a525684543d69a76.html#a09a0c19becb051f9a525684543d69a76":[3,0,1,1,2,25]
 };
