@@ -1,5 +1,6 @@
 var NAVTREEINDEX51 =
 {
+"d7/de8/cblas__test_8h_a09cdfd3508496c693a3c436f1172ead2.html#a09cdfd3508496c693a3c436f1172ead2":[3,0,1,1,2,16],
 "d7/de8/cblas__test_8h_a09e5fdcbaa563ed4422c8699d5599d01.html#a09e5fdcbaa563ed4422c8699d5599d01":[3,0,1,1,2,39],
 "d7/de8/cblas__test_8h_a0ce298cee0b3ee1108aca33de9a623a9.html#a0ce298cee0b3ee1108aca33de9a623a9":[3,0,1,1,2,62],
 "d7/de8/cblas__test_8h_a0d2028f078fea2d57481e3739a70d3c1.html#a0d2028f078fea2d57481e3739a70d3c1":[3,0,1,1,2,67],
@@ -161,12 +162,12 @@ var NAVTREEINDEX51 =
 "d7/de8/cblas__test_8h_source.html":[3,0,1,1,2],
 "d7/de8/cherfsx_8f.html":[3,0,5,131],
 "d7/de8/cherfsx_8f_source.html":[3,0,5,131],
-"d7/de8/sgesv_8f.html":[3,0,5,1085],
-"d7/de8/sgesv_8f_source.html":[3,0,5,1085],
-"d7/de8/slaruv_8f.html":[3,0,5,1253],
-"d7/de8/slaruv_8f_source.html":[3,0,5,1253],
-"d7/de8/zsytrs__rook_8f.html":[3,0,5,1939],
-"d7/de8/zsytrs__rook_8f_source.html":[3,0,5,1939],
+"d7/de8/sgesv_8f.html":[3,0,5,1083],
+"d7/de8/sgesv_8f_source.html":[3,0,5,1083],
+"d7/de8/slaruv_8f.html":[3,0,5,1251],
+"d7/de8/slaruv_8f_source.html":[3,0,5,1251],
+"d7/de8/zsytrs__rook_8f.html":[3,0,5,1937],
+"d7/de8/zsytrs__rook_8f_source.html":[3,0,5,1937],
 "d7/de9/cgehd2_8f.html":[3,0,5,27],
 "d7/de9/cgehd2_8f_source.html":[3,0,5,27],
 "d7/dea/cchkeq_8f.html":[3,0,6,1,8],
@@ -187,8 +188,8 @@ var NAVTREEINDEX51 =
 "d7/def/lapacke__clange_8c.html":[3,0,4,3,334],
 "d7/def/lapacke__clange_8c_a74d0913fb3fa04f6b35405c43f3d5059.html#a74d0913fb3fa04f6b35405c43f3d5059":[3,0,4,3,334,0],
 "d7/def/lapacke__clange_8c_source.html":[3,0,4,3,334],
-"d7/def/spptrs_8f.html":[3,0,5,1370],
-"d7/def/spptrs_8f_source.html":[3,0,5,1370],
+"d7/def/spptrs_8f.html":[3,0,5,1368],
+"d7/def/spptrs_8f_source.html":[3,0,5,1368],
 "d7/df1/lapacke__sormtr__work_8c.html":[3,0,4,3,1523],
 "d7/df1/lapacke__sormtr__work_8c_a345792fedb3632cebc623479e4bf886d.html#a345792fedb3632cebc623479e4bf886d":[3,0,4,3,1523,0],
 "d7/df1/lapacke__sormtr__work_8c_source.html":[3,0,4,3,1523],
@@ -197,25 +198,25 @@ var NAVTREEINDEX51 =
 "d7/df2/lapacke__zpptrs_8c_source.html":[3,0,4,3,2268],
 "d7/df3/derrlq_8f.html":[3,0,6,1,275],
 "d7/df3/derrlq_8f_source.html":[3,0,6,1,275],
-"d7/df3/dsygv__2stage_8f.html":[3,0,5,919],
-"d7/df3/dsygv__2stage_8f_source.html":[3,0,5,919],
+"d7/df3/dsygv__2stage_8f.html":[3,0,5,918],
+"d7/df3/dsygv__2stage_8f_source.html":[3,0,5,918],
 "d7/df4/zlatzm_8f.html":[3,0,5,0,34],
 "d7/df4/zlatzm_8f_source.html":[3,0,5,0,34],
 "d7/df5/cgelqt3_8f.html":[3,0,5,34],
 "d7/df5/cgelqt3_8f_source.html":[3,0,5,34],
-"d7/df5/dlasd4_8f.html":[3,0,5,741],
-"d7/df5/dlasd4_8f_source.html":[3,0,5,741],
+"d7/df5/dlasd4_8f.html":[3,0,5,740],
+"d7/df5/dlasd4_8f_source.html":[3,0,5,740],
 "d7/df5/lapacke__dlagge__work_8c.html":[3,0,4,3,837],
 "d7/df5/lapacke__dlagge__work_8c_ab253055689a26d8fd91cabc128bc5a12.html#ab253055689a26d8fd91cabc128bc5a12":[3,0,4,3,837,0],
 "d7/df5/lapacke__dlagge__work_8c_source.html":[3,0,4,3,837],
-"d7/df6/dgbrfs_8f.html":[3,0,5,510],
-"d7/df6/dgbrfs_8f_source.html":[3,0,5,510],
+"d7/df6/dgbrfs_8f.html":[3,0,5,509],
+"d7/df6/dgbrfs_8f_source.html":[3,0,5,509],
 "d7/df7/ddrvgt_8f.html":[3,0,6,1,250],
 "d7/df7/ddrvgt_8f_source.html":[3,0,6,1,250],
-"d7/df7/zla__heamv_8f.html":[3,0,5,1716],
-"d7/df7/zla__heamv_8f_source.html":[3,0,5,1716],
-"d7/df8/zporfsx_8f.html":[3,0,5,1859],
-"d7/df8/zporfsx_8f_source.html":[3,0,5,1859],
+"d7/df7/zla__heamv_8f.html":[3,0,5,1714],
+"d7/df7/zla__heamv_8f_source.html":[3,0,5,1714],
+"d7/df8/zporfsx_8f.html":[3,0,5,1857],
+"d7/df8/zporfsx_8f_source.html":[3,0,5,1857],
 "d7/df9/drzt01_8f.html":[3,0,6,1,370],
 "d7/df9/drzt01_8f_source.html":[3,0,6,1,370],
 "d7/df9/zerrgg_8f.html":[3,0,6,0,321],
@@ -233,8 +234,8 @@ var NAVTREEINDEX51 =
 "d7/dfd/lapacke__cpbstf__work_8c.html":[3,0,4,3,377],
 "d7/dfd/lapacke__cpbstf__work_8c_a39a0affda59aaf8129c76e4ef3ed8fa9.html#a39a0affda59aaf8129c76e4ef3ed8fa9":[3,0,4,3,377,0],
 "d7/dfd/lapacke__cpbstf__work_8c_source.html":[3,0,4,3,377],
-"d7/dfd/ssptrs_8f.html":[3,0,5,1409],
-"d7/dfd/ssptrs_8f_source.html":[3,0,5,1409],
+"d7/dfd/ssptrs_8f.html":[3,0,5,1407],
+"d7/dfd/ssptrs_8f_source.html":[3,0,5,1407],
 "d7/dfe/lapacke__stpqrt2_8c.html":[3,0,4,3,1795],
 "d7/dfe/lapacke__stpqrt2_8c_a78c5a04a335abd99150c157551078a3b.html#a78c5a04a335abd99150c157551078a3b":[3,0,4,3,1795,0],
 "d7/dfe/lapacke__stpqrt2_8c_source.html":[3,0,4,3,1795],
@@ -248,6 +249,5 @@ var NAVTREEINDEX51 =
 "d8/d00/lapacke__ztpqrt2_8c_source.html":[3,0,4,3,2401],
 "d8/d01/serrgg_8f.html":[3,0,6,0,225],
 "d8/d01/serrgg_8f_source.html":[3,0,6,0,225],
-"d8/d01/slanhs_8f.html":[3,0,5,1190],
-"d8/d01/slanhs_8f_source.html":[3,0,5,1190]
+"d8/d01/slanhs_8f.html":[3,0,5,1188]
 };
