@@ -1,10 +1,11 @@
 var NAVTREEINDEX52 =
 {
+"d8/d01/slanhs_8f_source.html":[3,0,5,1188],
 "d8/d02/lapacke__ztpqrt__work_8c.html":[3,0,4,3,2403],
 "d8/d02/lapacke__ztpqrt__work_8c_a0a29c7d09b47c79bfb62ed649684b6d4.html#a0a29c7d09b47c79bfb62ed649684b6d4":[3,0,4,3,2403,0],
 "d8/d02/lapacke__ztpqrt__work_8c_source.html":[3,0,4,3,2403],
-"d8/d02/sisnan_8f.html":[3,0,5,1128],
-"d8/d02/sisnan_8f_source.html":[3,0,5,1128],
+"d8/d02/sisnan_8f.html":[3,0,5,1126],
+"d8/d02/sisnan_8f_source.html":[3,0,5,1126],
 "d8/d03/lapacke__ctbrfs__work_8c.html":[3,0,4,3,535],
 "d8/d03/lapacke__ctbrfs__work_8c_af6b61851b69d07d02cdf28c2941df845.html#af6b61851b69d07d02cdf28c2941df845":[3,0,4,3,535,0],
 "d8/d03/lapacke__ctbrfs__work_8c_source.html":[3,0,4,3,535],
@@ -16,8 +17,8 @@ var NAVTREEINDEX52 =
 "d8/d04/lapacke__csytrf_8c.html":[3,0,4,3,502],
 "d8/d04/lapacke__csytrf_8c_aeed2d6b51c7a0403a477f9c7e521ba6b.html#aeed2d6b51c7a0403a477f9c7e521ba6b":[3,0,4,3,502,0],
 "d8/d04/lapacke__csytrf_8c_source.html":[3,0,4,3,502],
-"d8/d05/dtptri_8f.html":[3,0,5,981],
-"d8/d05/dtptri_8f_source.html":[3,0,5,981],
+"d8/d05/dtptri_8f.html":[3,0,5,980],
+"d8/d05/dtptri_8f_source.html":[3,0,5,980],
 "d8/d05/zlatm5_8f.html":[3,0,6,2,68],
 "d8/d05/zlatm5_8f_source.html":[3,0,6,2,68],
 "d8/d06/dlatm7_8f.html":[3,0,6,2,32],
@@ -31,8 +32,8 @@ var NAVTREEINDEX52 =
 "d8/d07/lapacke__cpptrf_8c.html":[3,0,4,3,426],
 "d8/d07/lapacke__cpptrf_8c_a6b4643142d555b38a26f892c91f888ac.html#a6b4643142d555b38a26f892c91f888ac":[3,0,4,3,426,0],
 "d8/d07/lapacke__cpptrf_8c_source.html":[3,0,4,3,426],
-"d8/d09/zhgeqz_8f.html":[3,0,5,1688],
-"d8/d09/zhgeqz_8f_source.html":[3,0,5,1688],
+"d8/d09/zhgeqz_8f.html":[3,0,5,1686],
+"d8/d09/zhgeqz_8f_source.html":[3,0,5,1686],
 "d8/d0b/ztbt03_8f.html":[3,0,6,1,766],
 "d8/d0b/ztbt03_8f_source.html":[3,0,6,1,766],
 "d8/d0d/lapacke__csytrs__3__work_8c.html":[3,0,4,3,524],
@@ -61,21 +62,21 @@ var NAVTREEINDEX52 =
 "d8/d13/lapacke__zgeqrf__work_8c.html":[3,0,4,3,1919],
 "d8/d13/lapacke__zgeqrf__work_8c_a363f0a019b5f0f8268129cfa9b2113d4.html#a363f0a019b5f0f8268129cfa9b2113d4":[3,0,4,3,1919,0],
 "d8/d13/lapacke__zgeqrf__work_8c_source.html":[3,0,4,3,1919],
-"d8/d14/dsytrs__3_8f.html":[3,0,5,953],
-"d8/d14/dsytrs__3_8f_source.html":[3,0,5,953],
-"d8/d15/zgebak_8f.html":[3,0,5,1538],
-"d8/d15/zgebak_8f_source.html":[3,0,5,1538],
+"d8/d14/dsytrs__3_8f.html":[3,0,5,952],
+"d8/d14/dsytrs__3_8f_source.html":[3,0,5,952],
+"d8/d15/zgebak_8f.html":[3,0,5,1536],
+"d8/d15/zgebak_8f_source.html":[3,0,5,1536],
 "d8/d16/cblas__cherk_8c.html":[3,0,1,2,15],
 "d8/d16/cblas__cherk_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,15,2],
 "d8/d16/cblas__cherk_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,15,0],
 "d8/d16/cblas__cherk_8c_a6973991f19ad23c7de69091c9e269606.html#a6973991f19ad23c7de69091c9e269606":[3,0,1,2,15,4],
-"d8/d16/cblas__cherk_8c_a6d93d8aea94f22f705f56814b0044818.html#a6d93d8aea94f22f705f56814b0044818":[3,0,1,2,15,6],
 "d8/d16/cblas__cherk_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,15,3],
 "d8/d16/cblas__cherk_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,15,1],
 "d8/d16/cblas__cherk_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,15,5],
+"d8/d16/cblas__cherk_8c_ae56e58b21ee7336505299df4b799b9ae.html#ae56e58b21ee7336505299df4b799b9ae":[3,0,1,2,15,6],
 "d8/d16/cblas__cherk_8c_source.html":[3,0,1,2,15],
-"d8/d16/zgbequ_8f.html":[3,0,5,1528],
-"d8/d16/zgbequ_8f_source.html":[3,0,5,1528],
+"d8/d16/zgbequ_8f.html":[3,0,5,1526],
+"d8/d16/zgbequ_8f_source.html":[3,0,5,1526],
 "d8/d17/_t_e_s_t_i_n_g_2_l_i_n_2dtplqt_8f.html":[3,0,6,1,381],
 "d8/d17/_t_e_s_t_i_n_g_2_l_i_n_2dtplqt_8f_source.html":[3,0,6,1,381],
 "d8/d17/cungqr_8f.html":[3,0,5,477],
@@ -83,8 +84,8 @@ var NAVTREEINDEX52 =
 "d8/d17/lapacke__sgels__work_8c.html":[3,0,4,3,1305],
 "d8/d17/lapacke__sgels__work_8c_a2cc44bf3c88af516e7c0d05c9a7e3cef.html#a2cc44bf3c88af516e7c0d05c9a7e3cef":[3,0,4,3,1305,0],
 "d8/d17/lapacke__sgels__work_8c_source.html":[3,0,4,3,1305],
-"d8/d17/sptcon_8f.html":[3,0,5,1373],
-"d8/d17/sptcon_8f_source.html":[3,0,5,1373],
+"d8/d17/sptcon_8f.html":[3,0,5,1371],
+"d8/d17/sptcon_8f_source.html":[3,0,5,1371],
 "d8/d1b/lapacke__chbevx__2stage_8c.html":[3,0,4,3,183],
 "d8/d1b/lapacke__chbevx__2stage_8c_aab7d01e689a93ca53fadd11d4465ede2.html#aab7d01e689a93ca53fadd11d4465ede2":[3,0,4,3,183,0],
 "d8/d1b/lapacke__chbevx__2stage_8c_source.html":[3,0,4,3,183],
@@ -105,8 +106,8 @@ var NAVTREEINDEX52 =
 "d8/d1f/clatsp_8f_source.html":[3,0,6,1,131],
 "d8/d1f/zdrvev_8f.html":[3,0,6,0,311],
 "d8/d1f/zdrvev_8f_source.html":[3,0,6,0,311],
-"d8/d20/dlatdf_8f.html":[3,0,5,769],
-"d8/d20/dlatdf_8f_source.html":[3,0,5,769],
+"d8/d20/dlatdf_8f.html":[3,0,5,768],
+"d8/d20/dlatdf_8f_source.html":[3,0,5,768],
 "d8/d20/lapacke__ctgsja__work_8c.html":[3,0,4,3,553],
 "d8/d20/lapacke__ctgsja__work_8c_a628863f6992b0975656b6b455ce49729.html#a628863f6992b0975656b6b455ce49729":[3,0,4,3,553,0],
 "d8/d20/lapacke__ctgsja__work_8c_source.html":[3,0,4,3,553],
@@ -127,8 +128,8 @@ var NAVTREEINDEX52 =
 "d8/d21/lapacke__zgebal_8c_source.html":[3,0,4,3,1866],
 "d8/d21/sqlt02_8f.html":[3,0,6,1,528],
 "d8/d21/sqlt02_8f_source.html":[3,0,6,1,528],
-"d8/d22/zcposv_8f.html":[3,0,5,1524],
-"d8/d22/zcposv_8f_source.html":[3,0,5,1524],
+"d8/d22/zcposv_8f.html":[3,0,5,1522],
+"d8/d22/zcposv_8f_source.html":[3,0,5,1522],
 "d8/d23/lapacke__cptcon_8c.html":[3,0,4,3,434],
 "d8/d23/lapacke__cptcon_8c_ae8b3735e4940a4b5efbdf57abf16da43.html#ae8b3735e4940a4b5efbdf57abf16da43":[3,0,4,3,434,0],
 "d8/d23/lapacke__cptcon_8c_source.html":[3,0,4,3,434],
@@ -149,16 +150,16 @@ var NAVTREEINDEX52 =
 "d8/d28/lapacke__cungrq__work_8c_ae995c8eda65f53d1f2df96d1ca747fc1.html#ae995c8eda65f53d1f2df96d1ca747fc1":[3,0,4,3,619,0],
 "d8/d28/lapacke__cungrq__work_8c_source.html":[3,0,4,3,619],
 "d8/d29/cblas__csyrk_8c.html":[3,0,1,2,24],
+"d8/d29/cblas__csyrk_8c_a13d9f3742c700b68380ea94d468f4fda.html#a13d9f3742c700b68380ea94d468f4fda":[3,0,1,2,24,6],
 "d8/d29/cblas__csyrk_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,24,2],
 "d8/d29/cblas__csyrk_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,24,0],
 "d8/d29/cblas__csyrk_8c_a6973991f19ad23c7de69091c9e269606.html#a6973991f19ad23c7de69091c9e269606":[3,0,1,2,24,4],
 "d8/d29/cblas__csyrk_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,24,3],
 "d8/d29/cblas__csyrk_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,24,1],
 "d8/d29/cblas__csyrk_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,24,5],
-"d8/d29/cblas__csyrk_8c_abf6c3e3b40fccc388aa2f15afa663194.html#abf6c3e3b40fccc388aa2f15afa663194":[3,0,1,2,24,6],
 "d8/d29/cblas__csyrk_8c_source.html":[3,0,1,2,24],
-"d8/d29/sgtsv_8f.html":[3,0,5,1120],
-"d8/d29/sgtsv_8f_source.html":[3,0,5,1120],
+"d8/d29/sgtsv_8f.html":[3,0,5,1118],
+"d8/d29/sgtsv_8f_source.html":[3,0,5,1118],
 "d8/d2a/cdrvsg2stg_8f.html":[3,0,6,0,40],
 "d8/d2a/cdrvsg2stg_8f_source.html":[3,0,6,0,40],
 "d8/d2a/lapacke__spftrf__work_8c.html":[3,0,4,3,1541],
@@ -170,22 +171,22 @@ var NAVTREEINDEX52 =
 "d8/d2a/lapacke__zpttrf__work_8c.html":[3,0,4,3,2283],
 "d8/d2a/lapacke__zpttrf__work_8c_a70448e78506dbfa5ec527787ddac0b65.html#a70448e78506dbfa5ec527787ddac0b65":[3,0,4,3,2283,0],
 "d8/d2a/lapacke__zpttrf__work_8c_source.html":[3,0,4,3,2283],
-"d8/d2a/ssbevx_8f.html":[3,0,5,1387],
-"d8/d2a/ssbevx_8f_source.html":[3,0,5,1387],
+"d8/d2a/ssbevx_8f.html":[3,0,5,1385],
+"d8/d2a/ssbevx_8f_source.html":[3,0,5,1385],
 "d8/d2b/lapacke__zpteqr_8c.html":[3,0,4,3,2274],
 "d8/d2b/lapacke__zpteqr_8c_a7a757e8f1c1cfb9c0041a700f186f55f.html#a7a757e8f1c1cfb9c0041a700f186f55f":[3,0,4,3,2274,0],
 "d8/d2b/lapacke__zpteqr_8c_source.html":[3,0,4,3,2274],
 "d8/d2c/ddrvpb_8f.html":[3,0,6,1,252],
 "d8/d2c/ddrvpb_8f_source.html":[3,0,6,1,252],
-"d8/d2c/sla__gbrpvgrw_8f.html":[3,0,5,1132],
-"d8/d2c/sla__gbrpvgrw_8f_source.html":[3,0,5,1132],
-"d8/d2d/dgesvd_8f.html":[3,0,5,563],
-"d8/d2d/dgesvd_8f_source.html":[3,0,5,563],
+"d8/d2c/sla__gbrpvgrw_8f.html":[3,0,5,1130],
+"d8/d2c/sla__gbrpvgrw_8f_source.html":[3,0,5,1130],
+"d8/d2d/dgesvd_8f.html":[3,0,5,562],
+"d8/d2d/dgesvd_8f_source.html":[3,0,5,562],
 "d8/d2d/lapacke__cgtsv_8c.html":[3,0,4,3,166],
 "d8/d2d/lapacke__cgtsv_8c_a8467af7f67681e12857b1c9ec1f6f994.html#a8467af7f67681e12857b1c9ec1f6f994":[3,0,4,3,166,0],
 "d8/d2d/lapacke__cgtsv_8c_source.html":[3,0,4,3,166],
-"d8/d2e/dgemlqt_8f.html":[3,0,5,542],
-"d8/d2e/dgemlqt_8f_source.html":[3,0,5,542],
+"d8/d2e/dgemlqt_8f.html":[3,0,5,541],
+"d8/d2e/dgemlqt_8f_source.html":[3,0,5,541],
 "d8/d2e/lapacke__zhbgvx__work_8c.html":[3,0,4,3,2031],
 "d8/d2e/lapacke__zhbgvx__work_8c_a6a873016730f3bb85c0b89de79826e55.html#a6a873016730f3bb85c0b89de79826e55":[3,0,4,3,2031,0],
 "d8/d2e/lapacke__zhbgvx__work_8c_source.html":[3,0,4,3,2031],
@@ -193,13 +194,13 @@ var NAVTREEINDEX52 =
 "d8/d2f/chpevd_8f_source.html":[3,0,5,170],
 "d8/d2f/dlarge_8f.html":[3,0,6,2,23],
 "d8/d2f/dlarge_8f_source.html":[3,0,6,2,23],
-"d8/d2f/dpotrs_8f.html":[3,0,5,840],
-"d8/d2f/dpotrs_8f_source.html":[3,0,5,840],
+"d8/d2f/dpotrs_8f.html":[3,0,5,839],
+"d8/d2f/dpotrs_8f_source.html":[3,0,5,839],
 "d8/d2f/lapacke__dsptrd__work_8c.html":[3,0,4,3,1055],
 "d8/d2f/lapacke__dsptrd__work_8c_ac4b459797a0825898139b7ace71546b5.html#ac4b459797a0825898139b7ace71546b5":[3,0,4,3,1055,0],
 "d8/d2f/lapacke__dsptrd__work_8c_source.html":[3,0,4,3,1055],
-"d8/d2f/slaqr0_8f.html":[3,0,5,1211],
-"d8/d2f/slaqr0_8f_source.html":[3,0,5,1211],
+"d8/d2f/slaqr0_8f.html":[3,0,5,1209],
+"d8/d2f/slaqr0_8f_source.html":[3,0,5,1209],
 "d8/d30/clatdf_8f.html":[3,0,5,311],
 "d8/d30/clatdf_8f_source.html":[3,0,5,311],
 "d8/d31/lapacke__zlarnv_8c.html":[3,0,4,3,2194],
@@ -207,8 +208,8 @@ var NAVTREEINDEX52 =
 "d8/d31/lapacke__zlarnv_8c_source.html":[3,0,4,3,2194],
 "d8/d32/cblas__zdscal_8c.html":[3,0,1,2,115],
 "d8/d32/cblas__zdscal_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,115,0],
+"d8/d32/cblas__zdscal_8c_a70bd2afaf2d7d99a6d7980e671e80c8f.html#a70bd2afaf2d7d99a6d7980e671e80c8f":[3,0,1,2,115,2],
 "d8/d32/cblas__zdscal_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,115,1],
-"d8/d32/cblas__zdscal_8c_adf50cae4479505f872b7ed3f7f2bab58.html#adf50cae4479505f872b7ed3f7f2bab58":[3,0,1,2,115,2],
 "d8/d32/cblas__zdscal_8c_source.html":[3,0,1,2,115],
 "d8/d32/cpbtrs_8f.html":[3,0,5,329],
 "d8/d32/cpbtrs_8f_source.html":[3,0,5,329],
@@ -223,10 +224,10 @@ var NAVTREEINDEX52 =
 "d8/d32/lapacke__chetrf__rk_8c.html":[3,0,4,3,253],
 "d8/d32/lapacke__chetrf__rk_8c_af74e80385ab5a3294f08801b2c2672ff.html#af74e80385ab5a3294f08801b2c2672ff":[3,0,4,3,253,0],
 "d8/d32/lapacke__chetrf__rk_8c_source.html":[3,0,4,3,253],
-"d8/d32/spotf2_8f.html":[3,0,5,1358],
-"d8/d32/spotf2_8f_source.html":[3,0,5,1358],
-"d8/d32/zgeqrf_8f.html":[3,0,5,1571],
-"d8/d32/zgeqrf_8f_source.html":[3,0,5,1571],
+"d8/d32/spotf2_8f.html":[3,0,5,1356],
+"d8/d32/spotf2_8f_source.html":[3,0,5,1356],
+"d8/d32/zgeqrf_8f.html":[3,0,5,1569],
+"d8/d32/zgeqrf_8f_source.html":[3,0,5,1569],
 "d8/d33/lapacke__sgesvj__work_8c.html":[3,0,4,3,1355],
 "d8/d33/lapacke__sgesvj__work_8c_a4114f2a8459bda809165beb5e3688fa5.html#a4114f2a8459bda809165beb5e3688fa5":[3,0,4,3,1355,0],
 "d8/d33/lapacke__sgesvj__work_8c_source.html":[3,0,4,3,1355],
@@ -240,14 +241,13 @@ var NAVTREEINDEX52 =
 "d8/d35/cptt01_8f_source.html":[3,0,6,1,159],
 "d8/d35/dget01_8f.html":[3,0,6,1,305],
 "d8/d35/dget01_8f_source.html":[3,0,6,1,305],
-"d8/d35/dlaed1_8f.html":[3,0,5,632],
-"d8/d35/dlaed1_8f_source.html":[3,0,5,632],
-"d8/d35/dstein_8f.html":[3,0,5,893],
-"d8/d35/dstein_8f_source.html":[3,0,5,893],
+"d8/d35/dlaed1_8f.html":[3,0,5,631],
+"d8/d35/dlaed1_8f_source.html":[3,0,5,631],
+"d8/d35/dstein_8f.html":[3,0,5,892],
+"d8/d35/dstein_8f_source.html":[3,0,5,892],
 "d8/d35/schkrfp_8f.html":[3,0,6,1,414],
 "d8/d35/schkrfp_8f_source.html":[3,0,6,1,414],
 "d8/d36/lapacke__strtri_8c.html":[3,0,4,3,1824],
 "d8/d36/lapacke__strtri_8c_a2c94924d5ea123518cf6093d5ca98ec7.html#a2c94924d5ea123518cf6093d5ca98ec7":[3,0,4,3,1824,0],
-"d8/d36/lapacke__strtri_8c_source.html":[3,0,4,3,1824],
-"d8/d37/clavsy_8f.html":[3,0,6,1,140]
+"d8/d36/lapacke__strtri_8c_source.html":[3,0,4,3,1824]
 };
