@@ -1,5 +1,6 @@
 var NAVTREEINDEX53 =
 {
+"d8/d37/clavsy_8f.html":[3,0,6,1,140],
 "d8/d37/clavsy_8f_source.html":[3,0,6,1,140],
 "d8/d37/ctptri_8f.html":[3,0,5,443],
 "d8/d37/ctptri_8f_source.html":[3,0,5,443],
@@ -7,17 +8,17 @@ var NAVTREEINDEX53 =
 "d8/d37/lapacke__dsytrs__rook_8c.html":[3,0,4,3,1167],
 "d8/d37/lapacke__dsytrs__rook_8c_afed1a32dda5eee8f2cc2948fa3e87602.html#afed1a32dda5eee8f2cc2948fa3e87602":[3,0,4,3,1167,0],
 "d8/d37/lapacke__dsytrs__rook_8c_source.html":[3,0,4,3,1167],
-"d8/d37/zhetrs__rook_8f.html":[3,0,5,1686],
-"d8/d37/zhetrs__rook_8f_source.html":[3,0,5,1686],
+"d8/d37/zhetrs__rook_8f.html":[3,0,5,1684],
+"d8/d37/zhetrs__rook_8f_source.html":[3,0,5,1684],
 "d8/d37/zlattp_8f.html":[3,0,6,1,704],
 "d8/d37/zlattp_8f_source.html":[3,0,6,1,704],
 "d8/d39/lapacke__strttp__work_8c.html":[3,0,4,3,1831],
 "d8/d39/lapacke__strttp__work_8c_a87202384810e0500d460b51370ea72f5.html#a87202384810e0500d460b51370ea72f5":[3,0,4,3,1831,0],
 "d8/d39/lapacke__strttp__work_8c_source.html":[3,0,4,3,1831],
-"d8/d3a/dlansf_8f.html":[3,0,5,669],
-"d8/d3a/dlansf_8f_source.html":[3,0,5,669],
-"d8/d3a/dlargv_8f.html":[3,0,5,713],
-"d8/d3a/dlargv_8f_source.html":[3,0,5,713],
+"d8/d3a/dlansf_8f.html":[3,0,5,668],
+"d8/d3a/dlansf_8f_source.html":[3,0,5,668],
+"d8/d3a/dlargv_8f.html":[3,0,5,712],
+"d8/d3a/dlargv_8f_source.html":[3,0,5,712],
 "d8/d3a/lapacke__csytrs__aa__2stage__work_8c.html":[3,0,4,3,527],
 "d8/d3a/lapacke__csytrs__aa__2stage__work_8c_a30d65226aaa021a4ebca37007acbac47.html#a30d65226aaa021a4ebca37007acbac47":[3,0,4,3,527,0],
 "d8/d3a/lapacke__csytrs__aa__2stage__work_8c_source.html":[3,0,4,3,527],
@@ -29,50 +30,50 @@ var NAVTREEINDEX53 =
 "d8/d3b/lapacke__dlapy3_8c_source.html":[3,0,4,3,854],
 "d8/d3d/clatrs_8f.html":[3,0,5,314],
 "d8/d3d/clatrs_8f_source.html":[3,0,5,314],
-"d8/d3e/slamchtst_8f.html":[3,0,3,21],
-"d8/d3e/slamchtst_8f_source.html":[3,0,3,21],
+"d8/d3e/slamchtst_8f.html":[3,0,3,22],
+"d8/d3e/slamchtst_8f_source.html":[3,0,3,22],
 "d8/d40/lapacke__cupgtr__work_8c.html":[3,0,4,3,641],
 "d8/d40/lapacke__cupgtr__work_8c_a80625e6a17ec4ce4ac5068fd0c3042a2.html#a80625e6a17ec4ce4ac5068fd0c3042a2":[3,0,4,3,641,0],
 "d8/d40/lapacke__cupgtr__work_8c_source.html":[3,0,4,3,641],
-"d8/d40/sgehd2_8f.html":[3,0,5,1052],
-"d8/d40/sgehd2_8f_source.html":[3,0,5,1052],
+"d8/d40/sgehd2_8f.html":[3,0,5,1050],
+"d8/d40/sgehd2_8f_source.html":[3,0,5,1050],
 "d8/d42/dgtt05_8f.html":[3,0,6,1,314],
 "d8/d42/dgtt05_8f_source.html":[3,0,6,1,314],
 "d8/d42/lapacke__sgeqpf_8c.html":[3,0,4,3,1322],
 "d8/d42/lapacke__sgeqpf_8c_a5da9502454e29979407b5a1ccf5df9c0.html#a5da9502454e29979407b5a1ccf5df9c0":[3,0,4,3,1322,0],
 "d8/d42/lapacke__sgeqpf_8c_source.html":[3,0,4,3,1322],
 "d8/d43/group__real_g_bcomputational.html":[0,0,1,1,1],
+"d8/d43/group__real_g_bcomputational_ga0bcc0fe084053d5fb44740646a0abcb9.html#ga0bcc0fe084053d5fb44740646a0abcb9":[3,0,5,1036,0],
 "d8/d43/group__real_g_bcomputational_ga0bcc0fe084053d5fb44740646a0abcb9.html#ga0bcc0fe084053d5fb44740646a0abcb9":[0,0,1,1,1,6],
-"d8/d43/group__real_g_bcomputational_ga0bcc0fe084053d5fb44740646a0abcb9.html#ga0bcc0fe084053d5fb44740646a0abcb9":[3,0,5,1038,0],
-"d8/d43/group__real_g_bcomputational_ga1929cafd58d8fe59c200282e4497da0a.html#ga1929cafd58d8fe59c200282e4497da0a":[3,0,5,1029,0],
+"d8/d43/group__real_g_bcomputational_ga1929cafd58d8fe59c200282e4497da0a.html#ga1929cafd58d8fe59c200282e4497da0a":[3,0,5,1027,0],
 "d8/d43/group__real_g_bcomputational_ga1929cafd58d8fe59c200282e4497da0a.html#ga1929cafd58d8fe59c200282e4497da0a":[0,0,1,1,1,0],
+"d8/d43/group__real_g_bcomputational_ga1ca828b2948fbb78c91ed3e2961bcbd2.html#ga1ca828b2948fbb78c91ed3e2961bcbd2":[3,0,5,1038,0],
 "d8/d43/group__real_g_bcomputational_ga1ca828b2948fbb78c91ed3e2961bcbd2.html#ga1ca828b2948fbb78c91ed3e2961bcbd2":[0,0,1,1,1,8],
-"d8/d43/group__real_g_bcomputational_ga1ca828b2948fbb78c91ed3e2961bcbd2.html#ga1ca828b2948fbb78c91ed3e2961bcbd2":[3,0,5,1040,0],
-"d8/d43/group__real_g_bcomputational_ga1ff0196682b9e07d55a9267e236a9be5.html#ga1ff0196682b9e07d55a9267e236a9be5":[3,0,5,1130,0],
+"d8/d43/group__real_g_bcomputational_ga1ff0196682b9e07d55a9267e236a9be5.html#ga1ff0196682b9e07d55a9267e236a9be5":[3,0,5,1128,0],
 "d8/d43/group__real_g_bcomputational_ga1ff0196682b9e07d55a9267e236a9be5.html#ga1ff0196682b9e07d55a9267e236a9be5":[0,0,1,1,1,12],
 "d8/d43/group__real_g_bcomputational_ga2acdb08b4db950b2c7c27e5b233de143.html#ga2acdb08b4db950b2c7c27e5b233de143":[0,0,1,1,1,9],
-"d8/d43/group__real_g_bcomputational_ga2acdb08b4db950b2c7c27e5b233de143.html#ga2acdb08b4db950b2c7c27e5b233de143":[3,0,5,1100,0],
-"d8/d43/group__real_g_bcomputational_ga2afc11d15eaf27524838268032c62b94.html#ga2afc11d15eaf27524838268032c62b94":[3,0,5,1312,0],
+"d8/d43/group__real_g_bcomputational_ga2acdb08b4db950b2c7c27e5b233de143.html#ga2acdb08b4db950b2c7c27e5b233de143":[3,0,5,1098,0],
+"d8/d43/group__real_g_bcomputational_ga2afc11d15eaf27524838268032c62b94.html#ga2afc11d15eaf27524838268032c62b94":[3,0,5,1310,0],
 "d8/d43/group__real_g_bcomputational_ga2afc11d15eaf27524838268032c62b94.html#ga2afc11d15eaf27524838268032c62b94":[0,0,1,1,1,15],
 "d8/d43/group__real_g_bcomputational_ga2ec4f3b65681172c1dd786df6580b176.html#ga2ec4f3b65681172c1dd786df6580b176":[0,0,1,1,1,11],
-"d8/d43/group__real_g_bcomputational_ga2ec4f3b65681172c1dd786df6580b176.html#ga2ec4f3b65681172c1dd786df6580b176":[3,0,5,1129,0],
-"d8/d43/group__real_g_bcomputational_ga4b997132d5e41418449796f85b12fcc5.html#ga4b997132d5e41418449796f85b12fcc5":[3,0,5,1034,0],
+"d8/d43/group__real_g_bcomputational_ga2ec4f3b65681172c1dd786df6580b176.html#ga2ec4f3b65681172c1dd786df6580b176":[3,0,5,1127,0],
+"d8/d43/group__real_g_bcomputational_ga4b997132d5e41418449796f85b12fcc5.html#ga4b997132d5e41418449796f85b12fcc5":[3,0,5,1032,0],
 "d8/d43/group__real_g_bcomputational_ga4b997132d5e41418449796f85b12fcc5.html#ga4b997132d5e41418449796f85b12fcc5":[0,0,1,1,1,5],
-"d8/d43/group__real_g_bcomputational_ga5ce5ba6e2efc6f91b09cb066ec7d0eed.html#ga5ce5ba6e2efc6f91b09cb066ec7d0eed":[3,0,5,1131,0],
+"d8/d43/group__real_g_bcomputational_ga5ce5ba6e2efc6f91b09cb066ec7d0eed.html#ga5ce5ba6e2efc6f91b09cb066ec7d0eed":[3,0,5,1129,0],
 "d8/d43/group__real_g_bcomputational_ga5ce5ba6e2efc6f91b09cb066ec7d0eed.html#ga5ce5ba6e2efc6f91b09cb066ec7d0eed":[0,0,1,1,1,13],
-"d8/d43/group__real_g_bcomputational_ga7507b854d792a8dce687e6e876a7ab3f.html#ga7507b854d792a8dce687e6e876a7ab3f":[3,0,5,1101,0],
 "d8/d43/group__real_g_bcomputational_ga7507b854d792a8dce687e6e876a7ab3f.html#ga7507b854d792a8dce687e6e876a7ab3f":[0,0,1,1,1,10],
-"d8/d43/group__real_g_bcomputational_ga7f306ebeac9cac6e32fb0d3092d336aa.html#ga7f306ebeac9cac6e32fb0d3092d336aa":[3,0,5,1033,0],
+"d8/d43/group__real_g_bcomputational_ga7507b854d792a8dce687e6e876a7ab3f.html#ga7507b854d792a8dce687e6e876a7ab3f":[3,0,5,1099,0],
+"d8/d43/group__real_g_bcomputational_ga7f306ebeac9cac6e32fb0d3092d336aa.html#ga7f306ebeac9cac6e32fb0d3092d336aa":[3,0,5,1031,0],
 "d8/d43/group__real_g_bcomputational_ga7f306ebeac9cac6e32fb0d3092d336aa.html#ga7f306ebeac9cac6e32fb0d3092d336aa":[0,0,1,1,1,4],
-"d8/d43/group__real_g_bcomputational_ga8c2e30003a6a88fdf225cdd5fddc2a28.html#ga8c2e30003a6a88fdf225cdd5fddc2a28":[3,0,5,1032,0],
+"d8/d43/group__real_g_bcomputational_ga8c2e30003a6a88fdf225cdd5fddc2a28.html#ga8c2e30003a6a88fdf225cdd5fddc2a28":[3,0,5,1030,0],
 "d8/d43/group__real_g_bcomputational_ga8c2e30003a6a88fdf225cdd5fddc2a28.html#ga8c2e30003a6a88fdf225cdd5fddc2a28":[0,0,1,1,1,3],
-"d8/d43/group__real_g_bcomputational_gab69fe5a37c3f7361c009bce69f8baf3d.html#gab69fe5a37c3f7361c009bce69f8baf3d":[3,0,5,1030,0],
+"d8/d43/group__real_g_bcomputational_gab69fe5a37c3f7361c009bce69f8baf3d.html#gab69fe5a37c3f7361c009bce69f8baf3d":[3,0,5,1028,0],
 "d8/d43/group__real_g_bcomputational_gab69fe5a37c3f7361c009bce69f8baf3d.html#gab69fe5a37c3f7361c009bce69f8baf3d":[0,0,1,1,1,1],
-"d8/d43/group__real_g_bcomputational_gacebccf97a748c611292ce5e6b05d2168.html#gacebccf97a748c611292ce5e6b05d2168":[3,0,5,1039,0],
+"d8/d43/group__real_g_bcomputational_gacebccf97a748c611292ce5e6b05d2168.html#gacebccf97a748c611292ce5e6b05d2168":[3,0,5,1037,0],
 "d8/d43/group__real_g_bcomputational_gacebccf97a748c611292ce5e6b05d2168.html#gacebccf97a748c611292ce5e6b05d2168":[0,0,1,1,1,7],
-"d8/d43/group__real_g_bcomputational_gad6b951dfd2b71d1eb527d5f41da07ed2.html#gad6b951dfd2b71d1eb527d5f41da07ed2":[3,0,5,1031,0],
+"d8/d43/group__real_g_bcomputational_gad6b951dfd2b71d1eb527d5f41da07ed2.html#gad6b951dfd2b71d1eb527d5f41da07ed2":[3,0,5,1029,0],
 "d8/d43/group__real_g_bcomputational_gad6b951dfd2b71d1eb527d5f41da07ed2.html#gad6b951dfd2b71d1eb527d5f41da07ed2":[0,0,1,1,1,2],
-"d8/d43/group__real_g_bcomputational_gaebfb2731781fd1734b41bc3cc0222711.html#gaebfb2731781fd1734b41bc3cc0222711":[3,0,5,1132,0],
+"d8/d43/group__real_g_bcomputational_gaebfb2731781fd1734b41bc3cc0222711.html#gaebfb2731781fd1734b41bc3cc0222711":[3,0,5,1130,0],
 "d8/d43/group__real_g_bcomputational_gaebfb2731781fd1734b41bc3cc0222711.html#gaebfb2731781fd1734b41bc3cc0222711":[0,0,1,1,1,14],
 "d8/d43/lapacke__dsytrs__aa__work_8c.html":[3,0,4,3,1166],
 "d8/d43/lapacke__dsytrs__aa__work_8c_ae53746f8ae2b426240fa499f63011eca.html#ae53746f8ae2b426240fa499f63011eca":[3,0,4,3,1166,0],
@@ -80,22 +81,22 @@ var NAVTREEINDEX53 =
 "d8/d44/cblas__dspr2_8c.html":[3,0,1,2,51],
 "d8/d44/cblas__dspr2_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,51,0],
 "d8/d44/cblas__dspr2_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,51,1],
-"d8/d44/cblas__dspr2_8c_a4302e9a601bca950d2da5f6dbcc0725d.html#a4302e9a601bca950d2da5f6dbcc0725d":[3,0,1,2,51,4],
+"d8/d44/cblas__dspr2_8c_a541a264dbeaabe393e4a50ad86cce2ac.html#a541a264dbeaabe393e4a50ad86cce2ac":[3,0,1,2,51,4],
 "d8/d44/cblas__dspr2_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,51,2],
 "d8/d44/cblas__dspr2_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,51,3],
 "d8/d44/cblas__dspr2_8c_source.html":[3,0,1,2,51],
 "d8/d44/lapacke__spoequ_8c.html":[3,0,4,3,1548],
 "d8/d44/lapacke__spoequ_8c_a3d00cf7d50267301cff536b53b259136.html#a3d00cf7d50267301cff536b53b259136":[3,0,4,3,1548,0],
 "d8/d44/lapacke__spoequ_8c_source.html":[3,0,4,3,1548],
-"d8/d44/zlascl2_8f.html":[3,0,5,1821],
-"d8/d44/zlascl2_8f_source.html":[3,0,5,1821],
-"d8/d45/zlauum_8f.html":[3,0,5,1842],
-"d8/d45/zlauum_8f_source.html":[3,0,5,1842],
+"d8/d44/zlascl2_8f.html":[3,0,5,1819],
+"d8/d44/zlascl2_8f_source.html":[3,0,5,1819],
+"d8/d45/zlauum_8f.html":[3,0,5,1840],
+"d8/d45/zlauum_8f_source.html":[3,0,5,1840],
 "d8/d46/lapacke__zstein_8c.html":[3,0,4,3,2304],
 "d8/d46/lapacke__zstein_8c_a4c5a9cb4132a5a5fbb4710101d37645e.html#a4c5a9cb4132a5a5fbb4710101d37645e":[3,0,4,3,2304,0],
 "d8/d46/lapacke__zstein_8c_source.html":[3,0,4,3,2304],
-"d8/d46/zsyswapr_8f.html":[3,0,5,1919],
-"d8/d46/zsyswapr_8f_source.html":[3,0,5,1919],
+"d8/d46/zsyswapr_8f.html":[3,0,5,1917],
+"d8/d46/zsyswapr_8f_source.html":[3,0,5,1917],
 "d8/d48/cgeqr_8f.html":[3,0,5,46],
 "d8/d48/cgeqr_8f_a67fc4b5034f55173b2460a10436d591a.html#a67fc4b5034f55173b2460a10436d591a":[3,0,5,46,0],
 "d8/d48/cgeqr_8f_source.html":[3,0,5,46],
@@ -103,8 +104,8 @@ var NAVTREEINDEX53 =
 "d8/d48/serrst_8f_source.html":[3,0,6,0,227],
 "d8/d49/cget35_8f.html":[3,0,6,0,56],
 "d8/d49/cget35_8f_source.html":[3,0,6,0,56],
-"d8/d49/sgesvd_8f.html":[3,0,5,1086],
-"d8/d49/sgesvd_8f_source.html":[3,0,5,1086],
+"d8/d49/sgesvd_8f.html":[3,0,5,1084],
+"d8/d49/sgesvd_8f_source.html":[3,0,5,1084],
 "d8/d4a/cgegs_8f.html":[3,0,5,0,0],
 "d8/d4a/cgegs_8f_source.html":[3,0,5,0,0],
 "d8/d4a/lapacke__checon_8c.html":[3,0,4,3,196],
@@ -115,8 +116,8 @@ var NAVTREEINDEX53 =
 "d8/d4d/lapacke__chpcon_8c.html":[3,0,4,3,282],
 "d8/d4d/lapacke__chpcon_8c_a9f082a65fc6a0a1ef80f0398540a47ff.html#a9f082a65fc6a0a1ef80f0398540a47ff":[3,0,4,3,282,0],
 "d8/d4d/lapacke__chpcon_8c_source.html":[3,0,4,3,282],
-"d8/d4f/dsytri__rook_8f.html":[3,0,5,950],
-"d8/d4f/dsytri__rook_8f_source.html":[3,0,5,950],
+"d8/d4f/dsytri__rook_8f.html":[3,0,5,949],
+"d8/d4f/dsytri__rook_8f_source.html":[3,0,5,949],
 "d8/d50/lapacke__cgtsvx__work_8c.html":[3,0,4,3,169],
 "d8/d50/lapacke__cgtsvx__work_8c_a0771ac08846677090e43bd388085e71b.html#a0771ac08846677090e43bd388085e71b":[3,0,4,3,169,0],
 "d8/d50/lapacke__cgtsvx__work_8c_source.html":[3,0,4,3,169],
@@ -126,8 +127,8 @@ var NAVTREEINDEX53 =
 "d8/d51/clamswlq_8f.html":[3,0,5,239],
 "d8/d51/clamswlq_8f_add7bf6db65fb9a14f9f1c638a87b9d36.html#add7bf6db65fb9a14f9f1c638a87b9d36":[3,0,5,239,0],
 "d8/d51/clamswlq_8f_source.html":[3,0,5,239],
-"d8/d51/dsbev_8f.html":[3,0,5,861],
-"d8/d51/dsbev_8f_source.html":[3,0,5,861],
+"d8/d51/dsbev_8f.html":[3,0,5,860],
+"d8/d51/dsbev_8f_source.html":[3,0,5,860],
 "d8/d51/dtrt06_8f.html":[3,0,6,1,391],
 "d8/d51/dtrt06_8f_source.html":[3,0,6,1,391],
 "d8/d52/cherk_8f.html":[3,0,0,0,15],
@@ -138,8 +139,8 @@ var NAVTREEINDEX53 =
 "d8/d54/lapacke__dgetrs_8c.html":[3,0,4,3,770],
 "d8/d54/lapacke__dgetrs_8c_a044782d17dd9592ab7d2b5b4f5c0f7a7.html#a044782d17dd9592ab7d2b5b4f5c0f7a7":[3,0,4,3,770,0],
 "d8/d54/lapacke__dgetrs_8c_source.html":[3,0,4,3,770],
-"d8/d54/zgesdd_8f.html":[3,0,5,1581],
-"d8/d54/zgesdd_8f_source.html":[3,0,5,1581],
+"d8/d54/zgesdd_8f.html":[3,0,5,1579],
+"d8/d54/zgesdd_8f_source.html":[3,0,5,1579],
 "d8/d56/ctpsv_8f.html":[3,0,0,0,30],
 "d8/d56/ctpsv_8f_source.html":[3,0,0,0,30],
 "d8/d57/lapacke__cgelsd_8c.html":[3,0,4,3,58],
@@ -170,7 +171,7 @@ var NAVTREEINDEX53 =
 "d8/d5d/cblas__ztrsm_8c_a8bc04ca7122be8af5c345be6464f102a.html#a8bc04ca7122be8af5c345be6464f102a":[3,0,1,2,142,5],
 "d8/d5d/cblas__ztrsm_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,142,1],
 "d8/d5d/cblas__ztrsm_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,142,7],
-"d8/d5d/cblas__ztrsm_8c_ab1b7a6d883698cb073d7cc74833cc59a.html#ab1b7a6d883698cb073d7cc74833cc59a":[3,0,1,2,142,8],
+"d8/d5d/cblas__ztrsm_8c_aae1e650167b4d9dbb0b6c489f058939f.html#aae1e650167b4d9dbb0b6c489f058939f":[3,0,1,2,142,8],
 "d8/d5d/cblas__ztrsm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,142,3],
 "d8/d5d/cblas__ztrsm_8c_source.html":[3,0,1,2,142],
 "d8/d5d/lapacke__cheevd_8c.html":[3,0,4,3,206],
@@ -185,11 +186,11 @@ var NAVTREEINDEX53 =
 "d8/d5e/lapacke__zunmqr__work_8c.html":[3,0,4,3,2471],
 "d8/d5e/lapacke__zunmqr__work_8c_a53b199238acd5d748ebd6fd1a9bced8c.html#a53b199238acd5d748ebd6fd1a9bced8c":[3,0,4,3,2471,0],
 "d8/d5e/lapacke__zunmqr__work_8c_source.html":[3,0,4,3,2471],
-"d8/d5e/stpmlqt_8f.html":[3,0,5,1495],
-"d8/d5e/stpmlqt_8f_source.html":[3,0,5,1495],
+"d8/d5e/stpmlqt_8f.html":[3,0,5,1493],
+"d8/d5e/stpmlqt_8f_source.html":[3,0,5,1493],
 "d8/d61/cblas__ctrsm_8c.html":[3,0,1,2,31],
 "d8/d61/cblas__ctrsm_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,31,0],
-"d8/d61/cblas__ctrsm_8c_a1da659f3b355d193f8f3ad203487d993.html#a1da659f3b355d193f8f3ad203487d993":[3,0,1,2,31,8],
+"d8/d61/cblas__ctrsm_8c_a06c17af5fdb6d73fa74e34f3757bb4b7.html#a06c17af5fdb6d73fa74e34f3757bb4b7":[3,0,1,2,31,8],
 "d8/d61/cblas__ctrsm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,31,2],
 "d8/d61/cblas__ctrsm_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,31,6],
 "d8/d61/cblas__ctrsm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,31,4],
@@ -198,25 +199,25 @@ var NAVTREEINDEX53 =
 "d8/d61/cblas__ctrsm_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,31,7],
 "d8/d61/cblas__ctrsm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,31,3],
 "d8/d61/cblas__ctrsm_8c_source.html":[3,0,1,2,31],
-"d8/d61/sgeesx_8f.html":[3,0,5,1049],
-"d8/d61/sgeesx_8f_source.html":[3,0,5,1049],
-"d8/d63/dpotri_8f.html":[3,0,5,839],
-"d8/d63/dpotri_8f_source.html":[3,0,5,839],
+"d8/d61/sgeesx_8f.html":[3,0,5,1047],
+"d8/d61/sgeesx_8f_source.html":[3,0,5,1047],
+"d8/d63/dpotri_8f.html":[3,0,5,838],
+"d8/d63/dpotri_8f_source.html":[3,0,5,838],
 "d8/d63/lapacke__zgesvj_8c.html":[3,0,4,3,1944],
 "d8/d63/lapacke__zgesvj_8c_a67348828623908b24f9d04f40e12f13b.html#a67348828623908b24f9d04f40e12f13b":[3,0,4,3,1944,0],
 "d8/d63/lapacke__zgesvj_8c_source.html":[3,0,4,3,1944],
 "d8/d66/cstt22_8f.html":[3,0,6,0,83],
 "d8/d66/cstt22_8f_source.html":[3,0,6,0,83],
-"d8/d66/dhseqr_8f.html":[3,0,5,604],
-"d8/d66/dhseqr_8f_source.html":[3,0,5,604],
+"d8/d66/dhseqr_8f.html":[3,0,5,603],
+"d8/d66/dhseqr_8f_source.html":[3,0,5,603],
 "d8/d66/lapacke__sgerfsx_8c.html":[3,0,4,3,1340],
 "d8/d66/lapacke__sgerfsx_8c_a64574af3d4f9dd86ac95069c19517a33.html#a64574af3d4f9dd86ac95069c19517a33":[3,0,4,3,1340,0],
 "d8/d66/lapacke__sgerfsx_8c_source.html":[3,0,4,3,1340],
 "d8/d67/isamaxsub_8f.html":[3,0,1,2,154],
 "d8/d67/isamaxsub_8f_a0f2c0b4af3ee757213ae42712e3084a5.html#a0f2c0b4af3ee757213ae42712e3084a5":[3,0,1,2,154,0],
 "d8/d67/isamaxsub_8f_source.html":[3,0,1,2,154],
-"d8/d67/sgesdd_8f.html":[3,0,5,1084],
-"d8/d67/sgesdd_8f_source.html":[3,0,5,1084],
+"d8/d67/sgesdd_8f.html":[3,0,5,1082],
+"d8/d67/sgesdd_8f_source.html":[3,0,5,1082],
 "d8/d68/lapacke__zsytrs__3_8c.html":[3,0,4,3,2361],
 "d8/d68/lapacke__zsytrs__3_8c_a4d9316a627860399a08a8be1ed472a4c.html#a4d9316a627860399a08a8be1ed472a4c":[3,0,4,3,2361,0],
 "d8/d68/lapacke__zsytrs__3_8c_source.html":[3,0,4,3,2361],
@@ -232,7 +233,7 @@ var NAVTREEINDEX53 =
 "d8/d69/cblas__cher2k_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,14,4],
 "d8/d69/cblas__cher2k_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,14,1],
 "d8/d69/cblas__cher2k_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,14,6],
-"d8/d69/cblas__cher2k_8c_ace4a1da318cd65a438cc863218eea24b.html#ace4a1da318cd65a438cc863218eea24b":[3,0,1,2,14,7],
+"d8/d69/cblas__cher2k_8c_ad754f92fd02b9fbb77852c509dd9b2f8.html#ad754f92fd02b9fbb77852c509dd9b2f8":[3,0,1,2,14,7],
 "d8/d69/cblas__cher2k_8c_source.html":[3,0,1,2,14],
 "d8/d69/lapacke__csytri2__work_8c.html":[3,0,4,3,514],
 "d8/d69/lapacke__csytri2__work_8c_a1e463ed9f30650fc5dcc4ae97e2c8a63.html#a1e463ed9f30650fc5dcc4ae97e2c8a63":[3,0,4,3,514,0],
@@ -243,11 +244,10 @@ var NAVTREEINDEX53 =
 "d8/d6b/lapacke__ztp__nancheck_8c.html":[3,0,4,4,144],
 "d8/d6b/lapacke__ztp__nancheck_8c_a90ce2e4972f1f2a133ac2264aceb4149.html#a90ce2e4972f1f2a133ac2264aceb4149":[3,0,4,4,144,0],
 "d8/d6b/lapacke__ztp__nancheck_8c_source.html":[3,0,4,4,144],
-"d8/d6b/zlacon_8f.html":[3,0,5,1735],
-"d8/d6b/zlacon_8f_source.html":[3,0,5,1735],
+"d8/d6b/zlacon_8f.html":[3,0,5,1733],
+"d8/d6b/zlacon_8f_source.html":[3,0,5,1733],
 "d8/d6c/group__variants_p_ocomputational.html":[0,0,4,2],
 "d8/d6c/group__variants_p_ocomputational_ga2f55f604a6003d03b5cd4a0adcfb74d6.html#ga2f55f604a6003d03b5cd4a0adcfb74d6":[3,0,5,1,0,0,1,0],
 "d8/d6c/group__variants_p_ocomputational_ga2f55f604a6003d03b5cd4a0adcfb74d6.html#ga2f55f604a6003d03b5cd4a0adcfb74d6":[3,0,5,1,0,1,1,0],
-"d8/d6c/group__variants_p_ocomputational_ga2f55f604a6003d03b5cd4a0adcfb74d6.html#ga2f55f604a6003d03b5cd4a0adcfb74d6":[0,0,4,2,1],
-"d8/d6c/group__variants_p_ocomputational_ga4e85f48dbd837ccbbf76aa077f33de19.html#ga4e85f48dbd837ccbbf76aa077f33de19":[3,0,5,1,0,0,0,0]
+"d8/d6c/group__variants_p_ocomputational_ga2f55f604a6003d03b5cd4a0adcfb74d6.html#ga2f55f604a6003d03b5cd4a0adcfb74d6":[0,0,4,2,1]
 };
