@@ -1,157 +1,158 @@
 var NAVTREEINDEX55 =
 {
+"d8/d97/cgelqf_8f.html":[3,0,5,32],
 "d8/d97/cgelqf_8f_source.html":[3,0,5,32],
 "d8/d97/lapacke__spptrf__work_8c.html":[3,0,4,3,1581],
 "d8/d97/lapacke__spptrf__work_8c_a7a05618e78cd5503fa332c2f176d4177.html#a7a05618e78cd5503fa332c2f176d4177":[3,0,4,3,1581,0],
 "d8/d97/lapacke__spptrf__work_8c_source.html":[3,0,4,3,1581],
-"d8/d97/slaqr5_8f.html":[3,0,5,1216],
-"d8/d97/slaqr5_8f_source.html":[3,0,5,1216],
+"d8/d97/slaqr5_8f.html":[3,0,5,1214],
+"d8/d97/slaqr5_8f_source.html":[3,0,5,1214],
 "d8/d98/lapacke__cheev__work_8c.html":[3,0,4,3,205],
 "d8/d98/lapacke__cheev__work_8c_a0bb11fc81c5399c9fee3df67676befc4.html#a0bb11fc81c5399c9fee3df67676befc4":[3,0,4,3,205,0],
 "d8/d98/lapacke__cheev__work_8c_source.html":[3,0,4,3,205],
 "d8/d98/lapacke__dsbevd__2stage__work_8c.html":[3,0,4,3,1010],
 "d8/d98/lapacke__dsbevd__2stage__work_8c_a6266fdd561d1d29ab9704d0177b30139.html#a6266fdd561d1d29ab9704d0177b30139":[3,0,4,3,1010,0],
 "d8/d98/lapacke__dsbevd__2stage__work_8c_source.html":[3,0,4,3,1010],
-"d8/d99/strevc3_8f.html":[3,0,5,1507],
-"d8/d99/strevc3_8f_source.html":[3,0,5,1507],
+"d8/d99/strevc3_8f.html":[3,0,5,1505],
+"d8/d99/strevc3_8f_source.html":[3,0,5,1505],
 "d8/d9b/_l_i_n_2clarhs_8f.html":[3,0,6,1,128],
 "d8/d9b/_l_i_n_2clarhs_8f_source.html":[3,0,6,1,128],
 "d8/d9b/group__double_o_t_h_e_rauxiliary.html":[0,0,8,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga0be048656bc24255a136a80361283e02.html#ga0be048656bc24255a136a80361283e02":[0,0,8,0,25],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga0be048656bc24255a136a80361283e02.html#ga0be048656bc24255a136a80361283e02":[3,0,5,676,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga0be048656bc24255a136a80361283e02.html#ga0be048656bc24255a136a80361283e02":[3,0,5,675,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga0dbbd44bb182ef241e7e7085616535ee.html#ga0dbbd44bb182ef241e7e7085616535ee":[0,0,8,0,44],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga0dbbd44bb182ef241e7e7085616535ee.html#ga0dbbd44bb182ef241e7e7085616535ee":[3,0,5,707,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga0dbbd44bb182ef241e7e7085616535ee.html#ga0dbbd44bb182ef241e7e7085616535ee":[3,0,5,706,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga106114a2b25c901f8e780dec465f1245.html#ga106114a2b25c901f8e780dec465f1245":[0,0,8,0,29],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga106114a2b25c901f8e780dec465f1245.html#ga106114a2b25c901f8e780dec465f1245":[3,0,5,686,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga106114a2b25c901f8e780dec465f1245.html#ga106114a2b25c901f8e780dec465f1245":[3,0,5,685,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga10da782c8833b0a63452726912c827b3.html#ga10da782c8833b0a63452726912c827b3":[0,0,8,0,6],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga10da782c8833b0a63452726912c827b3.html#ga10da782c8833b0a63452726912c827b3":[3,0,5,642,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga10da782c8833b0a63452726912c827b3.html#ga10da782c8833b0a63452726912c827b3":[3,0,5,641,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga12cd3d91cf44b97877272c85c410af6c.html#ga12cd3d91cf44b97877272c85c410af6c":[0,0,8,0,35],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga12cd3d91cf44b97877272c85c410af6c.html#ga12cd3d91cf44b97877272c85c410af6c":[3,0,5,692,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga12cd3d91cf44b97877272c85c410af6c.html#ga12cd3d91cf44b97877272c85c410af6c":[3,0,5,691,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga1f392426727c4fc1c10c80b6d356a801.html#ga1f392426727c4fc1c10c80b6d356a801":[0,0,8,0,61],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga1f392426727c4fc1c10c80b6d356a801.html#ga1f392426727c4fc1c10c80b6d356a801":[3,0,5,776,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga1f392426727c4fc1c10c80b6d356a801.html#ga1f392426727c4fc1c10c80b6d356a801":[3,0,5,775,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga20390bfb124ffe45b13e41d5bcc95f45.html#ga20390bfb124ffe45b13e41d5bcc95f45":[0,0,8,0,18],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga20390bfb124ffe45b13e41d5bcc95f45.html#ga20390bfb124ffe45b13e41d5bcc95f45":[3,0,5,666,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga20390bfb124ffe45b13e41d5bcc95f45.html#ga20390bfb124ffe45b13e41d5bcc95f45":[3,0,5,665,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga2294dd0eea75a474e13df58a1effe7af.html#ga2294dd0eea75a474e13df58a1effe7af":[0,0,8,0,55],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga2294dd0eea75a474e13df58a1effe7af.html#ga2294dd0eea75a474e13df58a1effe7af":[3,0,5,768,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga2294dd0eea75a474e13df58a1effe7af.html#ga2294dd0eea75a474e13df58a1effe7af":[3,0,5,767,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga25cff1fc222eccac2633af51f7eff84a.html#ga25cff1fc222eccac2633af51f7eff84a":[0,0,8,0,47],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga25cff1fc222eccac2633af51f7eff84a.html#ga25cff1fc222eccac2633af51f7eff84a":[3,0,5,710,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga25cff1fc222eccac2633af51f7eff84a.html#ga25cff1fc222eccac2633af51f7eff84a":[3,0,5,709,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga2744c0a54e6012d58fb4eefb75f48c65.html#ga2744c0a54e6012d58fb4eefb75f48c65":[0,0,8,0,56],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga2744c0a54e6012d58fb4eefb75f48c65.html#ga2744c0a54e6012d58fb4eefb75f48c65":[3,0,5,769,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga2744c0a54e6012d58fb4eefb75f48c65.html#ga2744c0a54e6012d58fb4eefb75f48c65":[3,0,5,768,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga29ca36fd484bb98a9badd427d337ed59.html#ga29ca36fd484bb98a9badd427d337ed59":[0,0,8,0,26],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga29ca36fd484bb98a9badd427d337ed59.html#ga29ca36fd484bb98a9badd427d337ed59":[3,0,5,679,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga29ca36fd484bb98a9badd427d337ed59.html#ga29ca36fd484bb98a9badd427d337ed59":[3,0,5,678,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga2dc1a3d70502af09fcfe2dacd2110813.html#ga2dc1a3d70502af09fcfe2dacd2110813":[0,0,8,0,27],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga2dc1a3d70502af09fcfe2dacd2110813.html#ga2dc1a3d70502af09fcfe2dacd2110813":[3,0,5,680,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga2dc1a3d70502af09fcfe2dacd2110813.html#ga2dc1a3d70502af09fcfe2dacd2110813":[3,0,5,679,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga305adfeca0e3bed5530e96cac624434c.html#ga305adfeca0e3bed5530e96cac624434c":[0,0,8,0,36],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga305adfeca0e3bed5530e96cac624434c.html#ga305adfeca0e3bed5530e96cac624434c":[3,0,5,693,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga305adfeca0e3bed5530e96cac624434c.html#ga305adfeca0e3bed5530e96cac624434c":[3,0,5,692,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga30b528e74865e6d94574db1c3b084129.html#ga30b528e74865e6d94574db1c3b084129":[0,0,8,0,48],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga30b528e74865e6d94574db1c3b084129.html#ga30b528e74865e6d94574db1c3b084129":[3,0,5,711,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga30b528e74865e6d94574db1c3b084129.html#ga30b528e74865e6d94574db1c3b084129":[3,0,5,710,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga331dd66010736c74b3e4b219b06cf11b.html#ga331dd66010736c74b3e4b219b06cf11b":[0,0,8,0,58],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga331dd66010736c74b3e4b219b06cf11b.html#ga331dd66010736c74b3e4b219b06cf11b":[3,0,5,771,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga331dd66010736c74b3e4b219b06cf11b.html#ga331dd66010736c74b3e4b219b06cf11b":[3,0,5,770,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga39a2b39f56ce497b218c5f48339ee712.html#ga39a2b39f56ce497b218c5f48339ee712":[0,0,8,0,42],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga39a2b39f56ce497b218c5f48339ee712.html#ga39a2b39f56ce497b218c5f48339ee712":[3,0,5,705,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga39a2b39f56ce497b218c5f48339ee712.html#ga39a2b39f56ce497b218c5f48339ee712":[3,0,5,704,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga3ccc0cf84b0493bd9adcdc02fcff449f.html#ga3ccc0cf84b0493bd9adcdc02fcff449f":[0,0,8,0,53],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga3ccc0cf84b0493bd9adcdc02fcff449f.html#ga3ccc0cf84b0493bd9adcdc02fcff449f":[3,0,5,761,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga3ccc0cf84b0493bd9adcdc02fcff449f.html#ga3ccc0cf84b0493bd9adcdc02fcff449f":[3,0,5,760,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga3d1a5bbad7b3d2bfaa82bef2bbff5ed1.html#ga3d1a5bbad7b3d2bfaa82bef2bbff5ed1":[0,0,8,0,52],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga3d1a5bbad7b3d2bfaa82bef2bbff5ed1.html#ga3d1a5bbad7b3d2bfaa82bef2bbff5ed1":[3,0,5,729,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga3d1a5bbad7b3d2bfaa82bef2bbff5ed1.html#ga3d1a5bbad7b3d2bfaa82bef2bbff5ed1":[3,0,5,728,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga3e7a0e049c0748bed7fb5817a0ecb2a6.html#ga3e7a0e049c0748bed7fb5817a0ecb2a6":[0,0,8,0,23],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga3e7a0e049c0748bed7fb5817a0ecb2a6.html#ga3e7a0e049c0748bed7fb5817a0ecb2a6":[3,0,5,674,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga3e7a0e049c0748bed7fb5817a0ecb2a6.html#ga3e7a0e049c0748bed7fb5817a0ecb2a6":[3,0,5,673,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga40ee368f59ef386fcf3ebf901f066c8b.html#ga40ee368f59ef386fcf3ebf901f066c8b":[0,0,8,0,5],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga40ee368f59ef386fcf3ebf901f066c8b.html#ga40ee368f59ef386fcf3ebf901f066c8b":[3,0,5,628,2],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga40ee368f59ef386fcf3ebf901f066c8b.html#ga40ee368f59ef386fcf3ebf901f066c8b":[3,0,5,627,2],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga420406ddf3a9d559a40543fa70829ae8.html#ga420406ddf3a9d559a40543fa70829ae8":[0,0,8,0,51],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga420406ddf3a9d559a40543fa70829ae8.html#ga420406ddf3a9d559a40543fa70829ae8":[3,0,5,724,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga420406ddf3a9d559a40543fa70829ae8.html#ga420406ddf3a9d559a40543fa70829ae8":[3,0,5,723,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga4944aae03c7a236a2d36bee520665e5d.html#ga4944aae03c7a236a2d36bee520665e5d":[0,0,8,0,40],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4944aae03c7a236a2d36bee520665e5d.html#ga4944aae03c7a236a2d36bee520665e5d":[3,0,5,703,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4944aae03c7a236a2d36bee520665e5d.html#ga4944aae03c7a236a2d36bee520665e5d":[3,0,5,702,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga4c15bef45ba06e975cc60b7d30bdd2b4.html#ga4c15bef45ba06e975cc60b7d30bdd2b4":[0,0,8,0,8],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4c15bef45ba06e975cc60b7d30bdd2b4.html#ga4c15bef45ba06e975cc60b7d30bdd2b4":[3,0,5,645,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4c15bef45ba06e975cc60b7d30bdd2b4.html#ga4c15bef45ba06e975cc60b7d30bdd2b4":[3,0,5,644,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga4cc655aa88beb6f2f8dfa621cbe6aea7.html#ga4cc655aa88beb6f2f8dfa621cbe6aea7":[0,0,8,0,34],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4cc655aa88beb6f2f8dfa621cbe6aea7.html#ga4cc655aa88beb6f2f8dfa621cbe6aea7":[3,0,5,691,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4cc655aa88beb6f2f8dfa621cbe6aea7.html#ga4cc655aa88beb6f2f8dfa621cbe6aea7":[3,0,5,690,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga4d60649d5f6ca5d4d7f1dce3cfe81450.html#ga4d60649d5f6ca5d4d7f1dce3cfe81450":[0,0,8,0,33],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4d60649d5f6ca5d4d7f1dce3cfe81450.html#ga4d60649d5f6ca5d4d7f1dce3cfe81450":[3,0,5,690,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4d60649d5f6ca5d4d7f1dce3cfe81450.html#ga4d60649d5f6ca5d4d7f1dce3cfe81450":[3,0,5,689,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga4ddb5f5d3f584b1bb41d99ab13cf44eb.html#ga4ddb5f5d3f584b1bb41d99ab13cf44eb":[0,0,8,0,39],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4ddb5f5d3f584b1bb41d99ab13cf44eb.html#ga4ddb5f5d3f584b1bb41d99ab13cf44eb":[3,0,5,697,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga4ddb5f5d3f584b1bb41d99ab13cf44eb.html#ga4ddb5f5d3f584b1bb41d99ab13cf44eb":[3,0,5,696,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga53d62355f41d66eb53f3230e71a869b5.html#ga53d62355f41d66eb53f3230e71a869b5":[0,0,8,0,16],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga53d62355f41d66eb53f3230e71a869b5.html#ga53d62355f41d66eb53f3230e71a869b5":[3,0,5,654,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga53d62355f41d66eb53f3230e71a869b5.html#ga53d62355f41d66eb53f3230e71a869b5":[3,0,5,653,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga5d13d1960b3f7ed1342aa5889196dc2f.html#ga5d13d1960b3f7ed1342aa5889196dc2f":[0,0,8,0,38],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga5d13d1960b3f7ed1342aa5889196dc2f.html#ga5d13d1960b3f7ed1342aa5889196dc2f":[3,0,5,695,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga5d13d1960b3f7ed1342aa5889196dc2f.html#ga5d13d1960b3f7ed1342aa5889196dc2f":[3,0,5,694,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga6485b97a0a7b7cd0146722a7d88a2bbc.html#ga6485b97a0a7b7cd0146722a7d88a2bbc":[0,0,8,0,32],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga6485b97a0a7b7cd0146722a7d88a2bbc.html#ga6485b97a0a7b7cd0146722a7d88a2bbc":[3,0,5,689,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga6485b97a0a7b7cd0146722a7d88a2bbc.html#ga6485b97a0a7b7cd0146722a7d88a2bbc":[3,0,5,688,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga662e4c4f54a2670dd8408f6b6b306dec.html#ga662e4c4f54a2670dd8408f6b6b306dec":[0,0,8,0,62],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga662e4c4f54a2670dd8408f6b6b306dec.html#ga662e4c4f54a2670dd8408f6b6b306dec":[3,0,5,859,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga662e4c4f54a2670dd8408f6b6b306dec.html#ga662e4c4f54a2670dd8408f6b6b306dec":[3,0,5,858,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga690ca51f259260f1c838fcf2d550540d.html#ga690ca51f259260f1c838fcf2d550540d":[0,0,8,0,4],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga690ca51f259260f1c838fcf2d550540d.html#ga690ca51f259260f1c838fcf2d550540d":[3,0,5,628,1],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga690ca51f259260f1c838fcf2d550540d.html#ga690ca51f259260f1c838fcf2d550540d":[3,0,5,627,1],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga6a16dced8cd4fd4de9f73c977992d5a7.html#ga6a16dced8cd4fd4de9f73c977992d5a7":[0,0,8,0,60],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga6a16dced8cd4fd4de9f73c977992d5a7.html#ga6a16dced8cd4fd4de9f73c977992d5a7":[3,0,5,775,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga6a16dced8cd4fd4de9f73c977992d5a7.html#ga6a16dced8cd4fd4de9f73c977992d5a7":[3,0,5,774,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga78226eb6548e718c68940e25709dc36b.html#ga78226eb6548e718c68940e25709dc36b":[0,0,8,0,15],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga78226eb6548e718c68940e25709dc36b.html#ga78226eb6548e718c68940e25709dc36b":[3,0,5,0,15,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga7a374be57f1611d886c1ac0a6999351d.html#ga7a374be57f1611d886c1ac0a6999351d":[0,0,8,0,49],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga7a374be57f1611d886c1ac0a6999351d.html#ga7a374be57f1611d886c1ac0a6999351d":[3,0,5,712,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga7a374be57f1611d886c1ac0a6999351d.html#ga7a374be57f1611d886c1ac0a6999351d":[3,0,5,711,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga7b430b81bbddf88bc99268a506931aef.html#ga7b430b81bbddf88bc99268a506931aef":[0,0,8,0,7],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga7b430b81bbddf88bc99268a506931aef.html#ga7b430b81bbddf88bc99268a506931aef":[3,0,5,644,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga7b430b81bbddf88bc99268a506931aef.html#ga7b430b81bbddf88bc99268a506931aef":[3,0,5,643,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga81f2fe4ff54dc550df187655d17e61c4.html#ga81f2fe4ff54dc550df187655d17e61c4":[0,0,8,0,10],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga81f2fe4ff54dc550df187655d17e61c4.html#ga81f2fe4ff54dc550df187655d17e61c4":[3,0,5,647,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga81f2fe4ff54dc550df187655d17e61c4.html#ga81f2fe4ff54dc550df187655d17e61c4":[3,0,5,646,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga83c81583bd444e0cf021fb006cd9a5e8.html#ga83c81583bd444e0cf021fb006cd9a5e8":[0,0,8,0,43],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga83c81583bd444e0cf021fb006cd9a5e8.html#ga83c81583bd444e0cf021fb006cd9a5e8":[3,0,5,706,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga83c81583bd444e0cf021fb006cd9a5e8.html#ga83c81583bd444e0cf021fb006cd9a5e8":[3,0,5,705,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga87564a9846d7f12fe65190872e63f1a1.html#ga87564a9846d7f12fe65190872e63f1a1":[0,0,8,0,57],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga87564a9846d7f12fe65190872e63f1a1.html#ga87564a9846d7f12fe65190872e63f1a1":[3,0,5,770,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga87564a9846d7f12fe65190872e63f1a1.html#ga87564a9846d7f12fe65190872e63f1a1":[3,0,5,769,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga90a33ebcf3fcd23cd2fb636a0caac073.html#ga90a33ebcf3fcd23cd2fb636a0caac073":[0,0,8,0,0],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga90a33ebcf3fcd23cd2fb636a0caac073.html#ga90a33ebcf3fcd23cd2fb636a0caac073":[3,0,5,624,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga90a33ebcf3fcd23cd2fb636a0caac073.html#ga90a33ebcf3fcd23cd2fb636a0caac073":[3,0,5,623,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga950ac5a7f906aba4b160ec77b72146ad.html#ga950ac5a7f906aba4b160ec77b72146ad":[0,0,8,0,54],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga950ac5a7f906aba4b160ec77b72146ad.html#ga950ac5a7f906aba4b160ec77b72146ad":[3,0,5,767,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga950ac5a7f906aba4b160ec77b72146ad.html#ga950ac5a7f906aba4b160ec77b72146ad":[3,0,5,766,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_ga9b62da514b4a671acd3e3f63d018f01e.html#ga9b62da514b4a671acd3e3f63d018f01e":[0,0,8,0,1],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_ga9b62da514b4a671acd3e3f63d018f01e.html#ga9b62da514b4a671acd3e3f63d018f01e":[3,0,5,625,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_ga9b62da514b4a671acd3e3f63d018f01e.html#ga9b62da514b4a671acd3e3f63d018f01e":[3,0,5,624,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaa0f06b236f313b54f85fed1b62c152dc.html#gaa0f06b236f313b54f85fed1b62c152dc":[0,0,8,0,31],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa0f06b236f313b54f85fed1b62c152dc.html#gaa0f06b236f313b54f85fed1b62c152dc":[3,0,5,688,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa0f06b236f313b54f85fed1b62c152dc.html#gaa0f06b236f313b54f85fed1b62c152dc":[3,0,5,687,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaa495c9c519906a3053f0ec56d702ef5f.html#gaa495c9c519906a3053f0ec56d702ef5f":[0,0,8,0,59],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa495c9c519906a3053f0ec56d702ef5f.html#gaa495c9c519906a3053f0ec56d702ef5f":[3,0,5,772,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa495c9c519906a3053f0ec56d702ef5f.html#gaa495c9c519906a3053f0ec56d702ef5f":[3,0,5,771,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaa6587111426ea9176a800939521c2586.html#gaa6587111426ea9176a800939521c2586":[0,0,8,0,63],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa6587111426ea9176a800939521c2586.html#gaa6587111426ea9176a800939521c2586":[3,0,5,979,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa6587111426ea9176a800939521c2586.html#gaa6587111426ea9176a800939521c2586":[3,0,5,978,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaa677995264e5de3914a3817a66e753c5.html#gaa677995264e5de3914a3817a66e753c5":[0,0,8,0,13],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa677995264e5de3914a3817a66e753c5.html#gaa677995264e5de3914a3817a66e753c5":[3,0,5,652,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaa677995264e5de3914a3817a66e753c5.html#gaa677995264e5de3914a3817a66e753c5":[3,0,5,651,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaab73b5456fe2ae079f549904132126b8.html#gaab73b5456fe2ae079f549904132126b8":[0,0,8,0,2],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaab73b5456fe2ae079f549904132126b8.html#gaab73b5456fe2ae079f549904132126b8":[3,0,5,626,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaab73b5456fe2ae079f549904132126b8.html#gaab73b5456fe2ae079f549904132126b8":[3,0,5,625,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaabb59655e820b3551af27781bd716143.html#gaabb59655e820b3551af27781bd716143":[0,0,8,0,45],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaabb59655e820b3551af27781bd716143.html#gaabb59655e820b3551af27781bd716143":[3,0,5,708,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaabb59655e820b3551af27781bd716143.html#gaabb59655e820b3551af27781bd716143":[3,0,5,707,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaae162fb6287043628a9c10d8388fe150.html#gaae162fb6287043628a9c10d8388fe150":[0,0,8,0,21],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaae162fb6287043628a9c10d8388fe150.html#gaae162fb6287043628a9c10d8388fe150":[3,0,5,670,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaae162fb6287043628a9c10d8388fe150.html#gaae162fb6287043628a9c10d8388fe150":[3,0,5,669,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gab29fb7acb6d53d816856903e9c918242.html#gab29fb7acb6d53d816856903e9c918242":[0,0,8,0,19],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gab29fb7acb6d53d816856903e9c918242.html#gab29fb7acb6d53d816856903e9c918242":[3,0,5,667,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gab29fb7acb6d53d816856903e9c918242.html#gab29fb7acb6d53d816856903e9c918242":[3,0,5,666,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gab8e471e78747e2583fff75bc7d1e209e.html#gab8e471e78747e2583fff75bc7d1e209e":[0,0,8,0,46],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gab8e471e78747e2583fff75bc7d1e209e.html#gab8e471e78747e2583fff75bc7d1e209e":[3,0,5,709,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gab8e471e78747e2583fff75bc7d1e209e.html#gab8e471e78747e2583fff75bc7d1e209e":[3,0,5,708,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gabfeff162a9dd30dd471ae166497072b1.html#gabfeff162a9dd30dd471ae166497072b1":[0,0,8,0,20],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gabfeff162a9dd30dd471ae166497072b1.html#gabfeff162a9dd30dd471ae166497072b1":[3,0,5,668,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gabfeff162a9dd30dd471ae166497072b1.html#gabfeff162a9dd30dd471ae166497072b1":[3,0,5,667,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gac1312699353e70d4e05bb21f60d76e27.html#gac1312699353e70d4e05bb21f60d76e27":[0,0,8,0,64],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gac1312699353e70d4e05bb21f60d76e27.html#gac1312699353e70d4e05bb21f60d76e27":[3,0,5,1293,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gac1312699353e70d4e05bb21f60d76e27.html#gac1312699353e70d4e05bb21f60d76e27":[3,0,5,1291,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gad0418b909a2871d01b8d43c24f0f207b.html#gad0418b909a2871d01b8d43c24f0f207b":[0,0,8,0,17],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gad0418b909a2871d01b8d43c24f0f207b.html#gad0418b909a2871d01b8d43c24f0f207b":[3,0,5,656,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gad0418b909a2871d01b8d43c24f0f207b.html#gad0418b909a2871d01b8d43c24f0f207b":[3,0,5,655,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gad1c0279ec29e8ac222f1e319f4144fcb.html#gad1c0279ec29e8ac222f1e319f4144fcb":[0,0,8,0,3],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gad1c0279ec29e8ac222f1e319f4144fcb.html#gad1c0279ec29e8ac222f1e319f4144fcb":[3,0,5,628,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gad1c0279ec29e8ac222f1e319f4144fcb.html#gad1c0279ec29e8ac222f1e319f4144fcb":[3,0,5,627,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gad9142f99aa1184d5c4d815dad7ec5d21.html#gad9142f99aa1184d5c4d815dad7ec5d21":[0,0,8,0,24],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gad9142f99aa1184d5c4d815dad7ec5d21.html#gad9142f99aa1184d5c4d815dad7ec5d21":[3,0,5,675,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gad9142f99aa1184d5c4d815dad7ec5d21.html#gad9142f99aa1184d5c4d815dad7ec5d21":[3,0,5,674,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gad9f2277feb511ff205c0caf084e29109.html#gad9f2277feb511ff205c0caf084e29109":[0,0,8,0,12],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gad9f2277feb511ff205c0caf084e29109.html#gad9f2277feb511ff205c0caf084e29109":[3,0,5,651,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gad9f2277feb511ff205c0caf084e29109.html#gad9f2277feb511ff205c0caf084e29109":[3,0,5,650,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gade0bc366bd92b104f6c715630425e4e8.html#gade0bc366bd92b104f6c715630425e4e8":[0,0,8,0,22],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gade0bc366bd92b104f6c715630425e4e8.html#gade0bc366bd92b104f6c715630425e4e8":[3,0,5,673,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gade0bc366bd92b104f6c715630425e4e8.html#gade0bc366bd92b104f6c715630425e4e8":[3,0,5,672,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gae1b81ff82ec4fad649a7703143c22f63.html#gae1b81ff82ec4fad649a7703143c22f63":[0,0,8,0,41],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gae1b81ff82ec4fad649a7703143c22f63.html#gae1b81ff82ec4fad649a7703143c22f63":[3,0,5,704,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gae1b81ff82ec4fad649a7703143c22f63.html#gae1b81ff82ec4fad649a7703143c22f63":[3,0,5,703,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gae577e9789fe58c91e173f8babd10f2a4.html#gae577e9789fe58c91e173f8babd10f2a4":[0,0,8,0,50],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gae577e9789fe58c91e173f8babd10f2a4.html#gae577e9789fe58c91e173f8babd10f2a4":[3,0,5,713,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gae577e9789fe58c91e173f8babd10f2a4.html#gae577e9789fe58c91e173f8babd10f2a4":[3,0,5,712,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gae8c1cf92f99ff26b8730c2fa2fbfd8d0.html#gae8c1cf92f99ff26b8730c2fa2fbfd8d0":[0,0,8,0,28],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gae8c1cf92f99ff26b8730c2fa2fbfd8d0.html#gae8c1cf92f99ff26b8730c2fa2fbfd8d0":[3,0,5,681,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gae8c1cf92f99ff26b8730c2fa2fbfd8d0.html#gae8c1cf92f99ff26b8730c2fa2fbfd8d0":[3,0,5,680,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gae9390b8aa28d639a2e67f2aa33583e97.html#gae9390b8aa28d639a2e67f2aa33583e97":[0,0,8,0,30],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gae9390b8aa28d639a2e67f2aa33583e97.html#gae9390b8aa28d639a2e67f2aa33583e97":[3,0,5,687,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gae9390b8aa28d639a2e67f2aa33583e97.html#gae9390b8aa28d639a2e67f2aa33583e97":[3,0,5,686,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaef588ae9e76526cc89802086ae5eec11.html#gaef588ae9e76526cc89802086ae5eec11":[0,0,8,0,11],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaef588ae9e76526cc89802086ae5eec11.html#gaef588ae9e76526cc89802086ae5eec11":[3,0,5,649,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaef588ae9e76526cc89802086ae5eec11.html#gaef588ae9e76526cc89802086ae5eec11":[3,0,5,648,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaf902d1fcc013fc898363099c8f867e10.html#gaf902d1fcc013fc898363099c8f867e10":[0,0,8,0,14],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaf902d1fcc013fc898363099c8f867e10.html#gaf902d1fcc013fc898363099c8f867e10":[3,0,5,653,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaf902d1fcc013fc898363099c8f867e10.html#gaf902d1fcc013fc898363099c8f867e10":[3,0,5,652,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gaf9669940660e6494f544bf6f7df7f589.html#gaf9669940660e6494f544bf6f7df7f589":[0,0,8,0,9],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gaf9669940660e6494f544bf6f7df7f589.html#gaf9669940660e6494f544bf6f7df7f589":[3,0,5,646,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gaf9669940660e6494f544bf6f7df7f589.html#gaf9669940660e6494f544bf6f7df7f589":[3,0,5,645,0],
 "d8/d9b/group__double_o_t_h_e_rauxiliary_gafb54dec29809e79d1ed0f1ef7b6c452b.html#gafb54dec29809e79d1ed0f1ef7b6c452b":[0,0,8,0,37],
-"d8/d9b/group__double_o_t_h_e_rauxiliary_gafb54dec29809e79d1ed0f1ef7b6c452b.html#gafb54dec29809e79d1ed0f1ef7b6c452b":[3,0,5,694,0],
+"d8/d9b/group__double_o_t_h_e_rauxiliary_gafb54dec29809e79d1ed0f1ef7b6c452b.html#gafb54dec29809e79d1ed0f1ef7b6c452b":[3,0,5,693,0],
 "d8/d9b/lapacke__zsytrf__aa__work_8c.html":[3,0,4,3,2344],
 "d8/d9b/lapacke__zsytrf__aa__work_8c_aac0a302b3707b4a6f0e019a0c8c46f95.html#aac0a302b3707b4a6f0e019a0c8c46f95":[3,0,4,3,2344,0],
 "d8/d9b/lapacke__zsytrf__aa__work_8c_source.html":[3,0,4,3,2344],
-"d8/d9b/sgeequb_8f.html":[3,0,5,1047],
-"d8/d9b/sgeequb_8f_source.html":[3,0,5,1047],
+"d8/d9b/sgeequb_8f.html":[3,0,5,1045],
+"d8/d9b/sgeequb_8f_source.html":[3,0,5,1045],
 "d8/d9c/lapacke__cgelsy_8c.html":[3,0,4,3,62],
 "d8/d9c/lapacke__cgelsy_8c_a473b73733c5fc9687bfc34454a5d36a3.html#a473b73733c5fc9687bfc34454a5d36a3":[3,0,4,3,62,0],
 "d8/d9c/lapacke__cgelsy_8c_source.html":[3,0,4,3,62],
@@ -167,24 +168,24 @@ var NAVTREEINDEX55 =
 "d8/da1/lapacke__ssytri_8c.html":[3,0,4,3,1744],
 "d8/da1/lapacke__ssytri_8c_afd75f0b3c354cd3c93f98c4bf97a536c.html#afd75f0b3c354cd3c93f98c4bf97a536c":[3,0,4,3,1744,0],
 "d8/da1/lapacke__ssytri_8c_source.html":[3,0,4,3,1744],
-"d8/da1/zhbevd_8f.html":[3,0,5,1625],
-"d8/da1/zhbevd_8f_source.html":[3,0,5,1625],
-"d8/da1/ztgsna_8f.html":[3,0,5,1952],
-"d8/da1/ztgsna_8f_source.html":[3,0,5,1952],
-"d8/da3/dpbrfs_8f.html":[3,0,5,818],
-"d8/da3/dpbrfs_8f_source.html":[3,0,5,818],
+"d8/da1/zhbevd_8f.html":[3,0,5,1623],
+"d8/da1/zhbevd_8f_source.html":[3,0,5,1623],
+"d8/da1/ztgsna_8f.html":[3,0,5,1950],
+"d8/da1/ztgsna_8f_source.html":[3,0,5,1950],
+"d8/da3/dpbrfs_8f.html":[3,0,5,817],
+"d8/da3/dpbrfs_8f_source.html":[3,0,5,817],
 "d8/da5/cblas__ztpmv_8c.html":[3,0,1,2,138],
 "d8/da5/cblas__ztpmv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,138,0],
 "d8/da5/cblas__ztpmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,138,1],
-"d8/da5/cblas__ztpmv_8c_a468b9dc90835687bb3b2a177aaeb79f7.html#a468b9dc90835687bb3b2a177aaeb79f7":[3,0,1,2,138,5],
 "d8/da5/cblas__ztpmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,138,3],
 "d8/da5/cblas__ztpmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,138,2],
 "d8/da5/cblas__ztpmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,138,4],
+"d8/da5/cblas__ztpmv_8c_ae4caac6a4a5cd4b5b4ffa42b9d97dc46.html#ae4caac6a4a5cd4b5b4ffa42b9d97dc46":[3,0,1,2,138,5],
 "d8/da5/cblas__ztpmv_8c_source.html":[3,0,1,2,138],
 "d8/da7/group__real_g_bauxiliary.html":[0,0,1,2,1],
-"d8/da7/group__real_g_bauxiliary_ga4041f9392fd5e5137bcbb2ed29ae3b14.html#ga4041f9392fd5e5137bcbb2ed29ae3b14":[3,0,5,1207,0],
+"d8/da7/group__real_g_bauxiliary_ga4041f9392fd5e5137bcbb2ed29ae3b14.html#ga4041f9392fd5e5137bcbb2ed29ae3b14":[3,0,5,1205,0],
 "d8/da7/group__real_g_bauxiliary_ga4041f9392fd5e5137bcbb2ed29ae3b14.html#ga4041f9392fd5e5137bcbb2ed29ae3b14":[0,0,1,2,1,1],
-"d8/da7/group__real_g_bauxiliary_gaf4b60512534024c921af88def5b806b7.html#gaf4b60512534024c921af88def5b806b7":[3,0,5,1187,0],
+"d8/da7/group__real_g_bauxiliary_gaf4b60512534024c921af88def5b806b7.html#gaf4b60512534024c921af88def5b806b7":[3,0,5,1185,0],
 "d8/da7/group__real_g_bauxiliary_gaf4b60512534024c921af88def5b806b7.html#gaf4b60512534024c921af88def5b806b7":[0,0,1,2,1,0],
 "d8/da7/lapacke__zpotrf2_8c.html":[3,0,4,3,2247],
 "d8/da7/lapacke__zpotrf2_8c_ab5fb613926bc7712dd8b7fb6dadf1c31.html#ab5fb613926bc7712dd8b7fb6dadf1c31":[3,0,4,3,2247,0],
@@ -202,30 +203,30 @@ var NAVTREEINDEX55 =
 "d8/daa/lapacke__zgeqr__work_8c_afe1c342fb5f84ebed447c6a8b2d5c8fa.html#afe1c342fb5f84ebed447c6a8b2d5c8fa":[3,0,4,3,1917,0],
 "d8/daa/lapacke__zgeqr__work_8c_source.html":[3,0,4,3,1917],
 "d8/dab/group__complex16_h_eauxiliary.html":[0,0,3,3,1],
-"d8/dab/group__complex16_h_eauxiliary_ga37927cbfd870be1c27dd7438c9b1e61f.html#ga37927cbfd870be1c27dd7438c9b1e61f":[3,0,5,1661,0],
+"d8/dab/group__complex16_h_eauxiliary_ga37927cbfd870be1c27dd7438c9b1e61f.html#ga37927cbfd870be1c27dd7438c9b1e61f":[3,0,5,1659,0],
 "d8/dab/group__complex16_h_eauxiliary_ga37927cbfd870be1c27dd7438c9b1e61f.html#ga37927cbfd870be1c27dd7438c9b1e61f":[0,0,3,3,1,0],
-"d8/dab/group__complex16_h_eauxiliary_ga6feff6b992299f847b477b9b9574ea51.html#ga6feff6b992299f847b477b9b9574ea51":[3,0,5,1766,0],
 "d8/dab/group__complex16_h_eauxiliary_ga6feff6b992299f847b477b9b9574ea51.html#ga6feff6b992299f847b477b9b9574ea51":[0,0,3,3,1,1],
-"d8/dab/group__complex16_h_eauxiliary_gaab30acac07bbf74be363c17541d9cd0e.html#gaab30acac07bbf74be363c17541d9cd0e":[3,0,5,1783,0],
+"d8/dab/group__complex16_h_eauxiliary_ga6feff6b992299f847b477b9b9574ea51.html#ga6feff6b992299f847b477b9b9574ea51":[3,0,5,1764,0],
+"d8/dab/group__complex16_h_eauxiliary_gaab30acac07bbf74be363c17541d9cd0e.html#gaab30acac07bbf74be363c17541d9cd0e":[3,0,5,1781,0],
 "d8/dab/group__complex16_h_eauxiliary_gaab30acac07bbf74be363c17541d9cd0e.html#gaab30acac07bbf74be363c17541d9cd0e":[0,0,3,3,1,2],
 "d8/dab/lapacke__zgesvj__work_8c.html":[3,0,4,3,1945],
 "d8/dab/lapacke__zgesvj__work_8c_a208980c8167c8ce63d0765562f9cc3ec.html#a208980c8167c8ce63d0765562f9cc3ec":[3,0,4,3,1945,0],
 "d8/dab/lapacke__zgesvj__work_8c_source.html":[3,0,4,3,1945],
-"d8/dab/ssbevx__2stage_8f.html":[3,0,5,1388],
-"d8/dab/ssbevx__2stage_8f_source.html":[3,0,5,1388],
+"d8/dab/ssbevx__2stage_8f.html":[3,0,5,1386],
+"d8/dab/ssbevx__2stage_8f_source.html":[3,0,5,1386],
 "d8/dac/lapacke__dlarfb__work_8c.html":[3,0,4,3,857],
 "d8/dac/lapacke__dlarfb__work_8c_a36a1bb82992d6e7238eb8977e6eae9fd.html#a36a1bb82992d6e7238eb8977e6eae9fd":[3,0,4,3,857,0],
 "d8/dac/lapacke__dlarfb__work_8c_source.html":[3,0,4,3,857],
 "d8/dae/lapacke__ssytrs2__work_8c.html":[3,0,4,3,1754],
 "d8/dae/lapacke__ssytrs2__work_8c_a0c84dfcfb1f4b7ca8518b7679077b3f5.html#a0c84dfcfb1f4b7ca8518b7679077b3f5":[3,0,4,3,1754,0],
 "d8/dae/lapacke__ssytrs2__work_8c_source.html":[3,0,4,3,1754],
-"d8/dae/sorgtsqr__row_8f.html":[3,0,5,1322],
-"d8/dae/sorgtsqr__row_8f_a42f4eef695a6bca9094ae4427c3403e4.html#a42f4eef695a6bca9094ae4427c3403e4":[3,0,5,1322,0],
-"d8/dae/sorgtsqr__row_8f_source.html":[3,0,5,1322],
+"d8/dae/sorgtsqr__row_8f.html":[3,0,5,1320],
+"d8/dae/sorgtsqr__row_8f_a42f4eef695a6bca9094ae4427c3403e4.html#a42f4eef695a6bca9094ae4427c3403e4":[3,0,5,1320,0],
+"d8/dae/sorgtsqr__row_8f_source.html":[3,0,5,1320],
 "d8/daf/cblas__dscal_8c.html":[3,0,1,2,47],
 "d8/daf/cblas__dscal_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,47,0],
 "d8/daf/cblas__dscal_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,47,1],
-"d8/daf/cblas__dscal_8c_addf14b41ace86f09c82b7ebdee073ca9.html#addf14b41ace86f09c82b7ebdee073ca9":[3,0,1,2,47,2],
+"d8/daf/cblas__dscal_8c_a7c41a0cb01661bf387ce902474d96336.html#a7c41a0cb01661bf387ce902474d96336":[3,0,1,2,47,2],
 "d8/daf/cblas__dscal_8c_source.html":[3,0,1,2,47],
 "d8/daf/saxpy_8f.html":[3,0,0,0,78],
 "d8/daf/saxpy_8f_source.html":[3,0,0,0,78],
@@ -246,8 +247,7 @@ var NAVTREEINDEX55 =
 "d8/db1/zpot02_8f.html":[3,0,6,1,721],
 "d8/db1/zpot02_8f_source.html":[3,0,6,1,721],
 "d8/db2/group__real_p_ocomputational.html":[0,0,4,1,1],
+"d8/db2/group__real_p_ocomputational_ga1c4ce423c2ec828b01d52cad754c5d80.html#ga1c4ce423c2ec828b01d52cad754c5d80":[3,0,5,1352,0],
 "d8/db2/group__real_p_ocomputational_ga1c4ce423c2ec828b01d52cad754c5d80.html#ga1c4ce423c2ec828b01d52cad754c5d80":[0,0,4,1,1,7],
-"d8/db2/group__real_p_ocomputational_ga1c4ce423c2ec828b01d52cad754c5d80.html#ga1c4ce423c2ec828b01d52cad754c5d80":[3,0,5,1354,0],
-"d8/db2/group__real_p_ocomputational_ga3c5c3e920ce930471a2ff63c637b00be.html#ga3c5c3e920ce930471a2ff63c637b00be":[3,0,5,1360,0],
-"d8/db2/group__real_p_ocomputational_ga3c5c3e920ce930471a2ff63c637b00be.html#ga3c5c3e920ce930471a2ff63c637b00be":[0,0,4,1,1,10]
+"d8/db2/group__real_p_ocomputational_ga3c5c3e920ce930471a2ff63c637b00be.html#ga3c5c3e920ce930471a2ff63c637b00be":[3,0,5,1358,0]
 };
