@@ -1,83 +1,84 @@
 var NAVTREEINDEX57 =
 {
+"d8/ddc/group__real_g_ecomputational_ga2e9ace4615da2fb5201a1bdeff3ad15c.html#ga2e9ace4615da2fb5201a1bdeff3ad15c":[0,0,0,3,1,13],
 "d8/ddc/group__real_g_ecomputational_ga2e9d9ccc8569cb5d6e38371c61c37de1.html#ga2e9d9ccc8569cb5d6e38371c61c37de1":[0,0,0,3,1,40],
-"d8/ddc/group__real_g_ecomputational_ga2e9d9ccc8569cb5d6e38371c61c37de1.html#ga2e9d9ccc8569cb5d6e38371c61c37de1":[3,0,5,1484,0],
-"d8/ddc/group__real_g_ecomputational_ga39adc3981edd0d968a4369941431ce3d.html#ga39adc3981edd0d968a4369941431ce3d":[3,0,5,1079,0],
+"d8/ddc/group__real_g_ecomputational_ga2e9d9ccc8569cb5d6e38371c61c37de1.html#ga2e9d9ccc8569cb5d6e38371c61c37de1":[3,0,5,1482,0],
+"d8/ddc/group__real_g_ecomputational_ga39adc3981edd0d968a4369941431ce3d.html#ga39adc3981edd0d968a4369941431ce3d":[3,0,5,1077,0],
 "d8/ddc/group__real_g_ecomputational_ga39adc3981edd0d968a4369941431ce3d.html#ga39adc3981edd0d968a4369941431ce3d":[0,0,0,3,1,23],
-"d8/ddc/group__real_g_ecomputational_ga3b9e414215d20cd99cbd3be489989a96.html#ga3b9e414215d20cd99cbd3be489989a96":[3,0,5,1075,0],
+"d8/ddc/group__real_g_ecomputational_ga3b9e414215d20cd99cbd3be489989a96.html#ga3b9e414215d20cd99cbd3be489989a96":[3,0,5,1073,0],
 "d8/ddc/group__real_g_ecomputational_ga3b9e414215d20cd99cbd3be489989a96.html#ga3b9e414215d20cd99cbd3be489989a96":[0,0,0,3,1,19],
-"d8/ddc/group__real_g_ecomputational_ga3e50914b0060d102e0c71d08ee0d5618.html#ga3e50914b0060d102e0c71d08ee0d5618":[3,0,5,1133,0],
+"d8/ddc/group__real_g_ecomputational_ga3e50914b0060d102e0c71d08ee0d5618.html#ga3e50914b0060d102e0c71d08ee0d5618":[3,0,5,1131,0],
 "d8/ddc/group__real_g_ecomputational_ga3e50914b0060d102e0c71d08ee0d5618.html#ga3e50914b0060d102e0c71d08ee0d5618":[0,0,0,3,1,34],
-"d8/ddc/group__real_g_ecomputational_ga418228a8d0645cee0ff6a89a3b9a8e19.html#ga418228a8d0645cee0ff6a89a3b9a8e19":[3,0,5,1077,0],
 "d8/ddc/group__real_g_ecomputational_ga418228a8d0645cee0ff6a89a3b9a8e19.html#ga418228a8d0645cee0ff6a89a3b9a8e19":[0,0,0,3,1,21],
+"d8/ddc/group__real_g_ecomputational_ga418228a8d0645cee0ff6a89a3b9a8e19.html#ga418228a8d0645cee0ff6a89a3b9a8e19":[3,0,5,1075,0],
+"d8/ddc/group__real_g_ecomputational_ga461f4ac32685a5ca30e293ee73d32920.html#ga461f4ac32685a5ca30e293ee73d32920":[3,0,5,1087,0],
 "d8/ddc/group__real_g_ecomputational_ga461f4ac32685a5ca30e293ee73d32920.html#ga461f4ac32685a5ca30e293ee73d32920":[0,0,0,3,1,27],
-"d8/ddc/group__real_g_ecomputational_ga461f4ac32685a5ca30e293ee73d32920.html#ga461f4ac32685a5ca30e293ee73d32920":[3,0,5,1089,0],
-"d8/ddc/group__real_g_ecomputational_ga4f76117b1ac28f73144480945cbc5200.html#ga4f76117b1ac28f73144480945cbc5200":[3,0,5,1095,0],
+"d8/ddc/group__real_g_ecomputational_ga4f76117b1ac28f73144480945cbc5200.html#ga4f76117b1ac28f73144480945cbc5200":[3,0,5,1093,0],
 "d8/ddc/group__real_g_ecomputational_ga4f76117b1ac28f73144480945cbc5200.html#ga4f76117b1ac28f73144480945cbc5200":[0,0,0,3,1,30],
-"d8/ddc/group__real_g_ecomputational_ga5d3d13fe83e675d743f67f6afdd94041.html#ga5d3d13fe83e675d743f67f6afdd94041":[3,0,5,1042,0],
+"d8/ddc/group__real_g_ecomputational_ga5d3d13fe83e675d743f67f6afdd94041.html#ga5d3d13fe83e675d743f67f6afdd94041":[3,0,5,1040,0],
 "d8/ddc/group__real_g_ecomputational_ga5d3d13fe83e675d743f67f6afdd94041.html#ga5d3d13fe83e675d743f67f6afdd94041":[0,0,0,3,1,1],
-"d8/ddc/group__real_g_ecomputational_ga5e9f3f3c1012927a2df1456522a0e297.html#ga5e9f3f3c1012927a2df1456522a0e297":[3,0,5,1081,0],
+"d8/ddc/group__real_g_ecomputational_ga5e9f3f3c1012927a2df1456522a0e297.html#ga5e9f3f3c1012927a2df1456522a0e297":[3,0,5,1079,0],
 "d8/ddc/group__real_g_ecomputational_ga5e9f3f3c1012927a2df1456522a0e297.html#ga5e9f3f3c1012927a2df1456522a0e297":[0,0,0,3,1,25],
+"d8/ddc/group__real_g_ecomputational_ga63f9e3af96fa42609e41bf3d77660bdf.html#ga63f9e3af96fa42609e41bf3d77660bdf":[3,0,5,1068,0],
 "d8/ddc/group__real_g_ecomputational_ga63f9e3af96fa42609e41bf3d77660bdf.html#ga63f9e3af96fa42609e41bf3d77660bdf":[0,0,0,3,1,14],
-"d8/ddc/group__real_g_ecomputational_ga63f9e3af96fa42609e41bf3d77660bdf.html#ga63f9e3af96fa42609e41bf3d77660bdf":[3,0,5,1070,0],
+"d8/ddc/group__real_g_ecomputational_ga6cf9836380912f68d520a17c77832d65.html#ga6cf9836380912f68d520a17c77832d65":[3,0,5,1080,0],
 "d8/ddc/group__real_g_ecomputational_ga6cf9836380912f68d520a17c77832d65.html#ga6cf9836380912f68d520a17c77832d65":[0,0,0,3,1,26],
-"d8/ddc/group__real_g_ecomputational_ga6cf9836380912f68d520a17c77832d65.html#ga6cf9836380912f68d520a17c77832d65":[3,0,5,1082,0],
-"d8/ddc/group__real_g_ecomputational_ga7cb54fa1727bf0166523036f4948bc56.html#ga7cb54fa1727bf0166523036f4948bc56":[3,0,5,1074,0],
+"d8/ddc/group__real_g_ecomputational_ga7cb54fa1727bf0166523036f4948bc56.html#ga7cb54fa1727bf0166523036f4948bc56":[3,0,5,1072,0],
 "d8/ddc/group__real_g_ecomputational_ga7cb54fa1727bf0166523036f4948bc56.html#ga7cb54fa1727bf0166523036f4948bc56":[0,0,0,3,1,18],
-"d8/ddc/group__real_g_ecomputational_ga852b6c5f1ed8ffe46a79b504e7e03e3f.html#ga852b6c5f1ed8ffe46a79b504e7e03e3f":[3,0,5,1043,0],
+"d8/ddc/group__real_g_ecomputational_ga852b6c5f1ed8ffe46a79b504e7e03e3f.html#ga852b6c5f1ed8ffe46a79b504e7e03e3f":[3,0,5,1041,0],
 "d8/ddc/group__real_g_ecomputational_ga852b6c5f1ed8ffe46a79b504e7e03e3f.html#ga852b6c5f1ed8ffe46a79b504e7e03e3f":[0,0,0,3,1,2],
-"d8/ddc/group__real_g_ecomputational_ga867bbfcb127db8f51ef22f7b29089ca7.html#ga867bbfcb127db8f51ef22f7b29089ca7":[3,0,5,1067,0],
 "d8/ddc/group__real_g_ecomputational_ga867bbfcb127db8f51ef22f7b29089ca7.html#ga867bbfcb127db8f51ef22f7b29089ca7":[0,0,0,3,1,11],
+"d8/ddc/group__real_g_ecomputational_ga867bbfcb127db8f51ef22f7b29089ca7.html#ga867bbfcb127db8f51ef22f7b29089ca7":[3,0,5,1065,0],
 "d8/ddc/group__real_g_ecomputational_ga8979d77a9ad2c9791bd813c2fe3f954e.html#ga8979d77a9ad2c9791bd813c2fe3f954e":[0,0,0,3,1,17],
-"d8/ddc/group__real_g_ecomputational_ga8979d77a9ad2c9791bd813c2fe3f954e.html#ga8979d77a9ad2c9791bd813c2fe3f954e":[3,0,5,1073,0],
-"d8/ddc/group__real_g_ecomputational_ga89f21d7700aaccc5fc72ca3316c33463.html#ga89f21d7700aaccc5fc72ca3316c33463":[3,0,5,1045,0],
+"d8/ddc/group__real_g_ecomputational_ga8979d77a9ad2c9791bd813c2fe3f954e.html#ga8979d77a9ad2c9791bd813c2fe3f954e":[3,0,5,1071,0],
+"d8/ddc/group__real_g_ecomputational_ga89f21d7700aaccc5fc72ca3316c33463.html#ga89f21d7700aaccc5fc72ca3316c33463":[3,0,5,1043,0],
 "d8/ddc/group__real_g_ecomputational_ga89f21d7700aaccc5fc72ca3316c33463.html#ga89f21d7700aaccc5fc72ca3316c33463":[0,0,0,3,1,4],
-"d8/ddc/group__real_g_ecomputational_ga8d99c11b94db3d5eac75cac46a0f2e17.html#ga8d99c11b94db3d5eac75cac46a0f2e17":[3,0,5,1094,0],
+"d8/ddc/group__real_g_ecomputational_ga8d99c11b94db3d5eac75cac46a0f2e17.html#ga8d99c11b94db3d5eac75cac46a0f2e17":[3,0,5,1092,0],
 "d8/ddc/group__real_g_ecomputational_ga8d99c11b94db3d5eac75cac46a0f2e17.html#ga8d99c11b94db3d5eac75cac46a0f2e17":[0,0,0,3,1,29],
-"d8/ddc/group__real_g_ecomputational_ga917f47a5ef044ed957fb3516584d1e06.html#ga917f47a5ef044ed957fb3516584d1e06":[3,0,5,1200,0],
+"d8/ddc/group__real_g_ecomputational_ga917f47a5ef044ed957fb3516584d1e06.html#ga917f47a5ef044ed957fb3516584d1e06":[3,0,5,1198,0],
 "d8/ddc/group__real_g_ecomputational_ga917f47a5ef044ed957fb3516584d1e06.html#ga917f47a5ef044ed957fb3516584d1e06":[0,0,0,3,1,38],
-"d8/ddc/group__real_g_ecomputational_ga971828f964b9d15b72ea12b3d8321d88.html#ga971828f964b9d15b72ea12b3d8321d88":[3,0,5,1053,0],
+"d8/ddc/group__real_g_ecomputational_ga971828f964b9d15b72ea12b3d8321d88.html#ga971828f964b9d15b72ea12b3d8321d88":[3,0,5,1051,0],
 "d8/ddc/group__real_g_ecomputational_ga971828f964b9d15b72ea12b3d8321d88.html#ga971828f964b9d15b72ea12b3d8321d88":[0,0,0,3,1,8],
+"d8/ddc/group__real_g_ecomputational_gaa00bcf4d83a118cb6f0b6619d6ffaa24.html#gaa00bcf4d83a118cb6f0b6619d6ffaa24":[3,0,5,1095,0],
 "d8/ddc/group__real_g_ecomputational_gaa00bcf4d83a118cb6f0b6619d6ffaa24.html#gaa00bcf4d83a118cb6f0b6619d6ffaa24":[0,0,0,3,1,32],
-"d8/ddc/group__real_g_ecomputational_gaa00bcf4d83a118cb6f0b6619d6ffaa24.html#gaa00bcf4d83a118cb6f0b6619d6ffaa24":[3,0,5,1097,0],
-"d8/ddc/group__real_g_ecomputational_gaa7ed93332ee7ff7ab268080a453615b6.html#gaa7ed93332ee7ff7ab268080a453615b6":[3,0,5,1044,0],
+"d8/ddc/group__real_g_ecomputational_gaa7ed93332ee7ff7ab268080a453615b6.html#gaa7ed93332ee7ff7ab268080a453615b6":[3,0,5,1042,0],
 "d8/ddc/group__real_g_ecomputational_gaa7ed93332ee7ff7ab268080a453615b6.html#gaa7ed93332ee7ff7ab268080a453615b6":[0,0,0,3,1,3],
-"d8/ddc/group__real_g_ecomputational_gaabb10a799ac110d898984792acafa8f4.html#gaabb10a799ac110d898984792acafa8f4":[3,0,5,1125,0],
+"d8/ddc/group__real_g_ecomputational_gaabb10a799ac110d898984792acafa8f4.html#gaabb10a799ac110d898984792acafa8f4":[3,0,5,1123,0],
 "d8/ddc/group__real_g_ecomputational_gaabb10a799ac110d898984792acafa8f4.html#gaabb10a799ac110d898984792acafa8f4":[0,0,0,3,1,33],
-"d8/ddc/group__real_g_ecomputational_gab9b698b35b884b4d17b9713e76fabe37.html#gab9b698b35b884b4d17b9713e76fabe37":[3,0,5,1093,0],
+"d8/ddc/group__real_g_ecomputational_gab9b698b35b884b4d17b9713e76fabe37.html#gab9b698b35b884b4d17b9713e76fabe37":[3,0,5,1091,0],
 "d8/ddc/group__real_g_ecomputational_gab9b698b35b884b4d17b9713e76fabe37.html#gab9b698b35b884b4d17b9713e76fabe37":[0,0,0,3,1,28],
-"d8/ddc/group__real_g_ecomputational_gabe2075a63cd1cd91a5fa0b521868f0d4.html#gabe2075a63cd1cd91a5fa0b521868f0d4":[3,0,5,1136,0],
+"d8/ddc/group__real_g_ecomputational_gabe2075a63cd1cd91a5fa0b521868f0d4.html#gabe2075a63cd1cd91a5fa0b521868f0d4":[3,0,5,1134,0],
 "d8/ddc/group__real_g_ecomputational_gabe2075a63cd1cd91a5fa0b521868f0d4.html#gabe2075a63cd1cd91a5fa0b521868f0d4":[0,0,0,3,1,37],
 "d8/ddc/group__real_g_ecomputational_gac3876ee65cc8a4a6130d8f1aa9117931.html#gac3876ee65cc8a4a6130d8f1aa9117931":[3,0,5,0,21,0],
 "d8/ddc/group__real_g_ecomputational_gac3876ee65cc8a4a6130d8f1aa9117931.html#gac3876ee65cc8a4a6130d8f1aa9117931":[0,0,0,3,1,15],
-"d8/ddc/group__real_g_ecomputational_gacd1ae8241f3d12cfa0f1d5ecdbc32eca.html#gacd1ae8241f3d12cfa0f1d5ecdbc32eca":[3,0,5,1072,0],
+"d8/ddc/group__real_g_ecomputational_gacd1ae8241f3d12cfa0f1d5ecdbc32eca.html#gacd1ae8241f3d12cfa0f1d5ecdbc32eca":[3,0,5,1070,0],
 "d8/ddc/group__real_g_ecomputational_gacd1ae8241f3d12cfa0f1d5ecdbc32eca.html#gacd1ae8241f3d12cfa0f1d5ecdbc32eca":[0,0,0,3,1,16],
-"d8/ddc/group__real_g_ecomputational_gad036a50aafd810967583ed8854e6cd3a.html#gad036a50aafd810967583ed8854e6cd3a":[3,0,5,1041,0],
+"d8/ddc/group__real_g_ecomputational_gad036a50aafd810967583ed8854e6cd3a.html#gad036a50aafd810967583ed8854e6cd3a":[3,0,5,1039,0],
 "d8/ddc/group__real_g_ecomputational_gad036a50aafd810967583ed8854e6cd3a.html#gad036a50aafd810967583ed8854e6cd3a":[0,0,0,3,1,0],
 "d8/ddc/group__real_g_ecomputational_gad283ab77593ac86c29172972b41f917b.html#gad283ab77593ac86c29172972b41f917b":[0,0,0,3,1,24],
-"d8/ddc/group__real_g_ecomputational_gad283ab77593ac86c29172972b41f917b.html#gad283ab77593ac86c29172972b41f917b":[3,0,5,1080,0],
-"d8/ddc/group__real_g_ecomputational_gaf05e763f3d07240f35350dd583ecf4f2.html#gaf05e763f3d07240f35350dd583ecf4f2":[3,0,5,1047,0],
+"d8/ddc/group__real_g_ecomputational_gad283ab77593ac86c29172972b41f917b.html#gad283ab77593ac86c29172972b41f917b":[3,0,5,1078,0],
 "d8/ddc/group__real_g_ecomputational_gaf05e763f3d07240f35350dd583ecf4f2.html#gaf05e763f3d07240f35350dd583ecf4f2":[0,0,0,3,1,6],
-"d8/ddc/group__real_g_ecomputational_gaff7dd464bee9a9ace7e576e4ecca33c0.html#gaff7dd464bee9a9ace7e576e4ecca33c0":[3,0,5,1057,0],
+"d8/ddc/group__real_g_ecomputational_gaf05e763f3d07240f35350dd583ecf4f2.html#gaf05e763f3d07240f35350dd583ecf4f2":[3,0,5,1045,0],
+"d8/ddc/group__real_g_ecomputational_gaff7dd464bee9a9ace7e576e4ecca33c0.html#gaff7dd464bee9a9ace7e576e4ecca33c0":[3,0,5,1055,0],
 "d8/ddc/group__real_g_ecomputational_gaff7dd464bee9a9ace7e576e4ecca33c0.html#gaff7dd464bee9a9ace7e576e4ecca33c0":[0,0,0,3,1,10],
 "d8/ddc/lapacke__ztgexc_8c.html":[3,0,4,3,2386],
 "d8/ddc/lapacke__ztgexc_8c_ac8e2043a2a10f68efba4bf5a09d3a6ab.html#ac8e2043a2a10f68efba4bf5a09d3a6ab":[3,0,4,3,2386,0],
 "d8/ddc/lapacke__ztgexc_8c_source.html":[3,0,4,3,2386],
 "d8/ddd/_l_i_n_2zlarhs_8f.html":[3,0,6,1,698],
 "d8/ddd/_l_i_n_2zlarhs_8f_source.html":[3,0,6,1,698],
-"d8/dde/dgels_8f.html":[3,0,5,537],
-"d8/dde/dgels_8f_source.html":[3,0,5,537],
-"d8/dde/dlaqz0_8f.html":[3,0,5,698],
-"d8/dde/dlaqz0_8f_source.html":[3,0,5,698],
+"d8/dde/dgels_8f.html":[3,0,5,536],
+"d8/dde/dgels_8f_source.html":[3,0,5,536],
+"d8/dde/dlaqz0_8f.html":[3,0,5,697],
+"d8/dde/dlaqz0_8f_source.html":[3,0,5,697],
 "d8/dde/dqpt01_8f.html":[3,0,6,1,353],
 "d8/dde/dqpt01_8f_source.html":[3,0,6,1,353],
-"d8/ddf/dgbsvx_8f.html":[3,0,5,513],
-"d8/ddf/dgbsvx_8f_source.html":[3,0,5,513],
+"d8/ddf/dgbsvx_8f.html":[3,0,5,512],
+"d8/ddf/dgbsvx_8f_source.html":[3,0,5,512],
 "d8/ddf/lapacke__dgbsv_8c.html":[3,0,4,3,666],
 "d8/ddf/lapacke__dgbsv_8c_a84fd8b92816876c9c6c20608a1362aa5.html#a84fd8b92816876c9c6c20608a1362aa5":[3,0,4,3,666,0],
 "d8/ddf/lapacke__dgbsv_8c_source.html":[3,0,4,3,666],
-"d8/ddf/ssbevd__2stage_8f.html":[3,0,5,1386],
-"d8/ddf/ssbevd__2stage_8f_source.html":[3,0,5,1386],
+"d8/ddf/ssbevd__2stage_8f.html":[3,0,5,1384],
+"d8/ddf/ssbevd__2stage_8f_source.html":[3,0,5,1384],
 "d8/de1/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2cgetrf_8f.html":[3,0,5,1,1,2,0],
 "d8/de1/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2cgetrf_8f_source.html":[3,0,5,1,1,2,0],
 "d8/de1/ztrmm_8f.html":[3,0,0,0,147],
@@ -128,13 +129,13 @@ var NAVTREEINDEX57 =
 "d8/df1/lapacke__dlapmt_8c.html":[3,0,4,3,850],
 "d8/df1/lapacke__dlapmt_8c_a1ad4216cb02871ab000100fdeb8602d2.html#a1ad4216cb02871ab000100fdeb8602d2":[3,0,4,3,850,0],
 "d8/df1/lapacke__dlapmt_8c_source.html":[3,0,4,3,850],
-"d8/df2/dlansp_8f.html":[3,0,5,670],
-"d8/df2/dlansp_8f_source.html":[3,0,5,670],
+"d8/df2/dlansp_8f.html":[3,0,5,669],
+"d8/df2/dlansp_8f_source.html":[3,0,5,669],
 "d8/df2/lapacke__dstevd__work_8c.html":[3,0,4,3,1079],
 "d8/df2/lapacke__dstevd__work_8c_a547af64c6b66924837b8e9be8d2fc252.html#a547af64c6b66924837b8e9be8d2fc252":[3,0,4,3,1079,0],
 "d8/df2/lapacke__dstevd__work_8c_source.html":[3,0,4,3,1079],
-"d8/df3/dorm22_8f.html":[3,0,5,802],
-"d8/df3/dorm22_8f_source.html":[3,0,5,802],
+"d8/df3/dorm22_8f.html":[3,0,5,801],
+"d8/df3/dorm22_8f_source.html":[3,0,5,801],
 "d8/df3/lapacke__ssptri_8c.html":[3,0,4,3,1652],
 "d8/df3/lapacke__ssptri_8c_a5d62930ffc465f4796f9db1ff5476815.html#a5d62930ffc465f4796f9db1ff5476815":[3,0,4,3,1652,0],
 "d8/df3/lapacke__ssptri_8c_source.html":[3,0,4,3,1652],
@@ -149,12 +150,12 @@ var NAVTREEINDEX57 =
 "d8/df4/lapacke__zpteqr__work_8c.html":[3,0,4,3,2275],
 "d8/df4/lapacke__zpteqr__work_8c_a25d7320d52b145c8ffad53fc9cce76ab.html#a25d7320d52b145c8ffad53fc9cce76ab":[3,0,4,3,2275,0],
 "d8/df4/lapacke__zpteqr__work_8c_source.html":[3,0,4,3,2275],
-"d8/df5/slarrv_8f.html":[3,0,5,1247],
-"d8/df5/slarrv_8f_source.html":[3,0,5,1247],
-"d8/df7/dgghd3_8f.html":[3,0,5,586],
-"d8/df7/dgghd3_8f_source.html":[3,0,5,586],
-"d8/df7/dlauu2_8f.html":[3,0,5,775],
-"d8/df7/dlauu2_8f_source.html":[3,0,5,775],
+"d8/df5/slarrv_8f.html":[3,0,5,1245],
+"d8/df5/slarrv_8f_source.html":[3,0,5,1245],
+"d8/df7/dgghd3_8f.html":[3,0,5,585],
+"d8/df7/dgghd3_8f_source.html":[3,0,5,585],
+"d8/df7/dlauu2_8f.html":[3,0,5,774],
+"d8/df7/dlauu2_8f_source.html":[3,0,5,774],
 "d8/df7/lapacke__dsytri__3__work_8c.html":[3,0,4,3,1156],
 "d8/df7/lapacke__dsytri__3__work_8c_ab033c7a86cf6fced02a91c9e2cf2c186.html#ab033c7a86cf6fced02a91c9e2cf2c186":[3,0,4,3,1156,0],
 "d8/df7/lapacke__dsytri__3__work_8c_source.html":[3,0,4,3,1156],
@@ -176,12 +177,12 @@ var NAVTREEINDEX57 =
 "d8/dfb/slarge_8f_source.html":[3,0,6,2,42],
 "d8/dfc/ddrvac_8f.html":[3,0,6,1,245],
 "d8/dfc/ddrvac_8f_source.html":[3,0,6,1,245],
-"d8/dfc/sgeqrt_8f.html":[3,0,5,1076],
-"d8/dfc/sgeqrt_8f_source.html":[3,0,5,1076],
+"d8/dfc/sgeqrt_8f.html":[3,0,5,1074],
+"d8/dfc/sgeqrt_8f_source.html":[3,0,5,1074],
 "d8/dfc/zchkq3_8f.html":[3,0,6,1,592],
 "d8/dfc/zchkq3_8f_source.html":[3,0,6,1,592],
-"d8/dfd/dlas2_8f.html":[3,0,5,734],
-"d8/dfd/dlas2_8f_source.html":[3,0,5,734],
+"d8/dfd/dlas2_8f.html":[3,0,5,733],
+"d8/dfd/dlas2_8f_source.html":[3,0,5,733],
 "d8/dfe/lapacke__zgebak__work_8c.html":[3,0,4,3,1865],
 "d8/dfe/lapacke__zgebak__work_8c_a6cf65b5fd3e482a53133914b43a13582.html#a6cf65b5fd3e482a53133914b43a13582":[3,0,4,3,1865,0],
 "d8/dfe/lapacke__zgebak__work_8c_source.html":[3,0,4,3,1865],
@@ -191,14 +192,14 @@ var NAVTREEINDEX57 =
 "d9/d00/lapacke__spbsv__work_8c.html":[3,0,4,3,1533],
 "d9/d00/lapacke__spbsv__work_8c_acbc221b4cc287040d3d578cf517f99eb.html#acbc221b4cc287040d3d578cf517f99eb":[3,0,4,3,1533,0],
 "d9/d00/lapacke__spbsv__work_8c_source.html":[3,0,4,3,1533],
-"d9/d00/secondtst_8f.html":[3,0,3,18],
-"d9/d00/secondtst_8f_a0570ca1cf766f03082ebb966c1e55640.html#a0570ca1cf766f03082ebb966c1e55640":[3,0,3,18,1],
-"d9/d00/secondtst_8f_source.html":[3,0,3,18],
+"d9/d00/secondtst_8f.html":[3,0,3,19],
+"d9/d00/secondtst_8f_a0570ca1cf766f03082ebb966c1e55640.html#a0570ca1cf766f03082ebb966c1e55640":[3,0,3,19,1],
+"d9/d00/secondtst_8f_source.html":[3,0,3,19],
 "d9/d01/lapacke__strsen_8c.html":[3,0,4,3,1818],
 "d9/d01/lapacke__strsen_8c_a231b97741b707f4a1450dbfd53ed7de1.html#a231b97741b707f4a1450dbfd53ed7de1":[3,0,4,3,1818,0],
 "d9/d01/lapacke__strsen_8c_source.html":[3,0,4,3,1818],
-"d9/d01/ssytrf__aa_8f.html":[3,0,5,1461],
-"d9/d01/ssytrf__aa_8f_source.html":[3,0,5,1461],
+"d9/d01/ssytrf__aa_8f.html":[3,0,5,1459],
+"d9/d01/ssytrf__aa_8f_source.html":[3,0,5,1459],
 "d9/d02/lapacke__ssfrk_8c.html":[3,0,4,3,1624],
 "d9/d02/lapacke__ssfrk_8c_a129dce3da3b5113df4c4d6f788ba6545.html#a129dce3da3b5113df4c4d6f788ba6545":[3,0,4,3,1624,0],
 "d9/d02/lapacke__ssfrk_8c_source.html":[3,0,4,3,1624],
@@ -229,25 +230,24 @@ var NAVTREEINDEX57 =
 "d9/d06/lapacke__ssyevx_8c.html":[3,0,4,3,1698],
 "d9/d06/lapacke__ssyevx_8c_abca21a2ff47cf83fad5ed607f7d59632.html#abca21a2ff47cf83fad5ed607f7d59632":[3,0,4,3,1698,0],
 "d9/d06/lapacke__ssyevx_8c_source.html":[3,0,4,3,1698],
-"d9/d07/dlaisnan_8f.html":[3,0,5,655],
-"d9/d07/dlaisnan_8f_source.html":[3,0,5,655],
+"d9/d07/dlaisnan_8f.html":[3,0,5,654],
+"d9/d07/dlaisnan_8f_source.html":[3,0,5,654],
 "d9/d07/lapacke__cpteqr__work_8c.html":[3,0,4,3,437],
 "d9/d07/lapacke__cpteqr__work_8c_ad25d8f92cc56b8768f68580504e95777.html#ad25d8f92cc56b8768f68580504e95777":[3,0,4,3,437,0],
 "d9/d07/lapacke__cpteqr__work_8c_source.html":[3,0,4,3,437],
 "d9/d08/dbdsdc_8f.html":[3,0,5,501],
 "d9/d08/dbdsdc_8f_source.html":[3,0,5,501],
-"d9/d08/slaorhr__col__getrfnp2_8f.html":[3,0,5,1201],
-"d9/d08/slaorhr__col__getrfnp2_8f_source.html":[3,0,5,1201],
+"d9/d08/slaorhr__col__getrfnp2_8f.html":[3,0,5,1199],
+"d9/d08/slaorhr__col__getrfnp2_8f_source.html":[3,0,5,1199],
 "d9/d09/cgbsvxx_8f.html":[3,0,5,12],
 "d9/d09/cgbsvxx_8f_source.html":[3,0,5,12],
-"d9/d0b/dzsum1_8f.html":[3,0,5,999],
-"d9/d0b/dzsum1_8f_source.html":[3,0,5,999],
+"d9/d0b/dzsum1_8f.html":[3,0,5,998],
+"d9/d0b/dzsum1_8f_source.html":[3,0,5,998],
 "d9/d0c/spbt05_8f.html":[3,0,6,1,514],
 "d9/d0c/spbt05_8f_source.html":[3,0,6,1,514],
-"d9/d0c/zlarrv_8f.html":[3,0,5,1813],
-"d9/d0c/zlarrv_8f_source.html":[3,0,5,1813],
-"d9/d0e/dsecnd___i_n_t___c_p_u___t_i_m_e_8f.html":[3,0,3,5],
-"d9/d0e/dsecnd___i_n_t___c_p_u___t_i_m_e_8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,5,0],
-"d9/d0e/dsecnd___i_n_t___c_p_u___t_i_m_e_8f_source.html":[3,0,3,5],
-"d9/d0e/group__level1.html":[0,2,0]
+"d9/d0c/zlarrv_8f.html":[3,0,5,1811],
+"d9/d0c/zlarrv_8f_source.html":[3,0,5,1811],
+"d9/d0e/dsecnd___i_n_t___c_p_u___t_i_m_e_8f.html":[3,0,3,6],
+"d9/d0e/dsecnd___i_n_t___c_p_u___t_i_m_e_8f_afe21a6b76340ac0afd7f0f84326e7918.html#afe21a6b76340ac0afd7f0f84326e7918":[3,0,3,6,0],
+"d9/d0e/dsecnd___i_n_t___c_p_u___t_i_m_e_8f_source.html":[3,0,3,6]
 };
