@@ -1,16 +1,17 @@
 var NAVTREEINDEX58 =
 {
+"d9/d0e/group__level1.html":[0,2,0],
 "d9/d0f/lapacke__dsyevx__2stage__work_8c.html":[3,0,4,3,1106],
 "d9/d0f/lapacke__dsyevx__2stage__work_8c_a0d0e62b31ac65cd9a0e954fac5c506a6.html#a0d0e62b31ac65cd9a0e954fac5c506a6":[3,0,4,3,1106,0],
 "d9/d0f/lapacke__dsyevx__2stage__work_8c_source.html":[3,0,4,3,1106],
 "d9/d10/lapacke__zsyrfsx__work_8c.html":[3,0,4,3,2323],
 "d9/d10/lapacke__zsyrfsx__work_8c_afe8c0d9f521e7bfb94bf9e3d35c2ce76.html#afe8c0d9f521e7bfb94bf9e3d35c2ce76":[3,0,4,3,2323,0],
 "d9/d10/lapacke__zsyrfsx__work_8c_source.html":[3,0,4,3,2323],
-"d9/d10/zhesv__aa_8f.html":[3,0,5,1655],
-"d9/d10/zhesv__aa_8f_source.html":[3,0,5,1655],
-"d9/d11/ssytrd__sb2st_8_f.html":[3,0,5,1458],
-"d9/d11/ssytrd__sb2st_8_f_a90942cfa6102976162f88eb246dbde5e.html#a90942cfa6102976162f88eb246dbde5e":[3,0,5,1458,0],
-"d9/d11/ssytrd__sb2st_8_f_source.html":[3,0,5,1458],
+"d9/d10/zhesv__aa_8f.html":[3,0,5,1653],
+"d9/d10/zhesv__aa_8f_source.html":[3,0,5,1653],
+"d9/d11/ssytrd__sb2st_8_f.html":[3,0,5,1456],
+"d9/d11/ssytrd__sb2st_8_f_a90942cfa6102976162f88eb246dbde5e.html#a90942cfa6102976162f88eb246dbde5e":[3,0,5,1456,0],
+"d9/d11/ssytrd__sb2st_8_f_source.html":[3,0,5,1456],
 "d9/d12/cget36_8f.html":[3,0,6,0,57],
 "d9/d12/cget36_8f_source.html":[3,0,6,0,57],
 "d9/d12/lapacke__dlamch_8c.html":[3,0,4,3,840],
@@ -18,18 +19,18 @@ var NAVTREEINDEX58 =
 "d9/d12/lapacke__dlamch_8c_source.html":[3,0,4,3,840],
 "d9/d13/cppsv_8f.html":[3,0,5,349],
 "d9/d13/cppsv_8f_source.html":[3,0,5,349],
-"d9/d13/dgbcon_8f.html":[3,0,5,507],
-"d9/d13/dgbcon_8f_source.html":[3,0,5,507],
+"d9/d13/dgbcon_8f.html":[3,0,5,506],
+"d9/d13/dgbcon_8f_source.html":[3,0,5,506],
 "d9/d13/lapacke__spbtrs_8c.html":[3,0,4,3,1538],
 "d9/d13/lapacke__spbtrs_8c_addb87d63b5da653a844bb72ab27679ed.html#addb87d63b5da653a844bb72ab27679ed":[3,0,4,3,1538,0],
 "d9/d13/lapacke__spbtrs_8c_source.html":[3,0,4,3,1538],
-"d9/d13/slarnv_8f.html":[3,0,5,1237],
-"d9/d13/slarnv_8f_source.html":[3,0,5,1237],
+"d9/d13/slarnv_8f.html":[3,0,5,1235],
+"d9/d13/slarnv_8f_source.html":[3,0,5,1235],
 "d9/d14/lapacke__dsygv__work_8c.html":[3,0,4,3,1113],
 "d9/d14/lapacke__dsygv__work_8c_a6d195ac18acc7b6e42ffd8b45ace456b.html#a6d195ac18acc7b6e42ffd8b45ace456b":[3,0,4,3,1113,0],
 "d9/d14/lapacke__dsygv__work_8c_source.html":[3,0,4,3,1113],
-"d9/d15/sporfs_8f.html":[3,0,5,1353],
-"d9/d15/sporfs_8f_source.html":[3,0,5,1353],
+"d9/d15/sporfs_8f.html":[3,0,5,1351],
+"d9/d15/sporfs_8f_source.html":[3,0,5,1351],
 "d9/d15/zlakf2_8f.html":[3,0,6,2,60],
 "d9/d15/zlakf2_8f_source.html":[3,0,6,2,60],
 "d9/d17/lapacke__stbtrs_8c.html":[3,0,4,3,1768],
@@ -41,31 +42,31 @@ var NAVTREEINDEX58 =
 "d9/d18/lapacke__dsfrk_8c.html":[3,0,4,3,1026],
 "d9/d18/lapacke__dsfrk_8c_a9913830add17b1edb00b38a906101e30.html#a9913830add17b1edb00b38a906101e30":[3,0,4,3,1026,0],
 "d9/d18/lapacke__dsfrk_8c_source.html":[3,0,4,3,1026],
-"d9/d18/slartgs_8f.html":[3,0,5,1251],
-"d9/d18/slartgs_8f_source.html":[3,0,5,1251],
+"d9/d18/slartgs_8f.html":[3,0,5,1249],
+"d9/d18/slartgs_8f_source.html":[3,0,5,1249],
 "d9/d19/clatmt_8f.html":[3,0,6,2,17],
 "d9/d19/clatmt_8f_source.html":[3,0,6,2,17],
 "d9/d19/lapacke__ctrcon_8c.html":[3,0,4,3,578],
 "d9/d19/lapacke__ctrcon_8c_a43968f39573af1cec7efe03718e45178.html#a43968f39573af1cec7efe03718e45178":[3,0,4,3,578,0],
 "d9/d19/lapacke__ctrcon_8c_source.html":[3,0,4,3,578],
-"d9/d1b/ilaenv2stage_8f.html":[3,0,5,1008],
-"d9/d1b/ilaenv2stage_8f_source.html":[3,0,5,1008],
-"d9/d1c/dsyconvf_8f.html":[3,0,5,905],
-"d9/d1c/dsyconvf_8f_source.html":[3,0,5,905],
+"d9/d1b/ilaenv2stage_8f.html":[3,0,5,1007],
+"d9/d1b/ilaenv2stage_8f_source.html":[3,0,5,1007],
+"d9/d1c/dsyconvf_8f.html":[3,0,5,904],
+"d9/d1c/dsyconvf_8f_source.html":[3,0,5,904],
 "d9/d1c/lapacke__sggsvp_8c.html":[3,0,4,3,1406],
 "d9/d1c/lapacke__sggsvp_8c_a8b2c4b88879e3f31472a967119d42d13.html#a8b2c4b88879e3f31472a967119d42d13":[3,0,4,3,1406,0],
 "d9/d1c/lapacke__sggsvp_8c_source.html":[3,0,4,3,1406],
 "d9/d1d/cgges3_8f.html":[3,0,5,78],
 "d9/d1d/cgges3_8f_source.html":[3,0,5,78],
-"d9/d1d/dorgqr_8f.html":[3,0,5,795],
-"d9/d1d/dorgqr_8f_source.html":[3,0,5,795],
+"d9/d1d/dorgqr_8f.html":[3,0,5,794],
+"d9/d1d/dorgqr_8f_source.html":[3,0,5,794],
 "d9/d1d/lapacke__zgeqr2_8c.html":[3,0,4,3,1915],
 "d9/d1d/lapacke__zgeqr2_8c_af37ea516c27add2375d873a13c288024.html#af37ea516c27add2375d873a13c288024":[3,0,4,3,1915,0],
 "d9/d1d/lapacke__zgeqr2_8c_source.html":[3,0,4,3,1915],
 "d9/d1d/zckgqr_8f.html":[3,0,6,0,299],
 "d9/d1d/zckgqr_8f_source.html":[3,0,6,0,299],
-"d9/d1e/dstemr_8f.html":[3,0,5,894],
-"d9/d1e/dstemr_8f_source.html":[3,0,5,894],
+"d9/d1e/dstemr_8f.html":[3,0,5,893],
+"d9/d1e/dstemr_8f_source.html":[3,0,5,893],
 "d9/d20/csytrs_8f.html":[3,0,5,413],
 "d9/d20/csytrs_8f_source.html":[3,0,5,413],
 "d9/d20/lapacke__cheevx_8c.html":[3,0,4,3,214],
@@ -80,8 +81,8 @@ var NAVTREEINDEX58 =
 "d9/d27/lapacke__ssysv__aa__work_8c.html":[3,0,4,3,1720],
 "d9/d27/lapacke__ssysv__aa__work_8c_a98456c8cc5dfe1eef4ebb1f204b9b321.html#a98456c8cc5dfe1eef4ebb1f204b9b321":[3,0,4,3,1720,0],
 "d9/d27/lapacke__ssysv__aa__work_8c_source.html":[3,0,4,3,1720],
-"d9/d28/dgeev_8f.html":[3,0,5,527],
-"d9/d28/dgeev_8f_source.html":[3,0,5,527],
+"d9/d28/dgeev_8f.html":[3,0,5,526],
+"d9/d28/dgeev_8f_source.html":[3,0,5,526],
 "d9/d29/lapacke__dpptri__work_8c.html":[3,0,4,3,985],
 "d9/d29/lapacke__dpptri__work_8c_adae1e292b54afd2d5866b0894ac2b29c.html#adae1e292b54afd2d5866b0894ac2b29c":[3,0,4,3,985,0],
 "d9/d29/lapacke__dpptri__work_8c_source.html":[3,0,4,3,985],
@@ -90,8 +91,8 @@ var NAVTREEINDEX58 =
 "d9/d29/lapacke__zspsvx__work_8c_source.html":[3,0,4,3,2293],
 "d9/d2b/cdrvsx_8f.html":[3,0,6,0,43],
 "d9/d2b/cdrvsx_8f_source.html":[3,0,6,0,43],
-"d9/d2b/zsytrs2_8f.html":[3,0,5,1935],
-"d9/d2b/zsytrs2_8f_source.html":[3,0,5,1935],
+"d9/d2b/zsytrs2_8f.html":[3,0,5,1933],
+"d9/d2b/zsytrs2_8f_source.html":[3,0,5,1933],
 "d9/d2c/lapacke__zsytrs__work_8c.html":[3,0,4,3,2369],
 "d9/d2c/lapacke__zsytrs__work_8c_afe3db59a5cade955c66cafd053ad7d58.html#afe3db59a5cade955c66cafd053ad7d58":[3,0,4,3,2369,0],
 "d9/d2c/lapacke__zsytrs__work_8c_source.html":[3,0,4,3,2369],
@@ -101,8 +102,8 @@ var NAVTREEINDEX58 =
 "d9/d2f/lapacke__ssytrs__aa_8c.html":[3,0,4,3,1757],
 "d9/d2f/lapacke__ssytrs__aa_8c_a54e1216162300988acdc8424d018ce28.html#a54e1216162300988acdc8424d018ce28":[3,0,4,3,1757,0],
 "d9/d2f/lapacke__ssytrs__aa_8c_source.html":[3,0,4,3,1757],
-"d9/d2f/sgttrf_8f.html":[3,0,5,1122],
-"d9/d2f/sgttrf_8f_source.html":[3,0,5,1122],
+"d9/d2f/sgttrf_8f.html":[3,0,5,1120],
+"d9/d2f/sgttrf_8f_source.html":[3,0,5,1120],
 "d9/d30/dchkst2stg_8f.html":[3,0,6,0,104],
 "d9/d30/dchkst2stg_8f_source.html":[3,0,6,0,104],
 "d9/d30/lapacke__sgeev__work_8c.html":[3,0,4,3,1291],
@@ -114,16 +115,16 @@ var NAVTREEINDEX58 =
 "d9/d32/zerrge_8f_source.html":[3,0,6,1,646],
 "d9/d33/dchkpt_8f.html":[3,0,6,1,225],
 "d9/d33/dchkpt_8f_source.html":[3,0,6,1,225],
-"d9/d33/dlartg_8f90.html":[3,0,5,726],
-"d9/d33/dlartg_8f90_source.html":[3,0,5,726],
+"d9/d33/dlartg_8f90.html":[3,0,5,725],
+"d9/d33/dlartg_8f90_source.html":[3,0,5,725],
 "d9/d34/lapacke__stptrs_8c.html":[3,0,4,3,1804],
 "d9/d34/lapacke__stptrs_8c_ab92eb30d55214e0ce8066a057e593b7b.html#ab92eb30d55214e0ce8066a057e593b7b":[3,0,4,3,1804,0],
 "d9/d34/lapacke__stptrs_8c_source.html":[3,0,4,3,1804],
 "d9/d35/lapacke__spf__nancheck_8c.html":[3,0,4,4,87],
 "d9/d35/lapacke__spf__nancheck_8c_a75f57311cdb5728fb1ba4c9a3c4fa6ed.html#a75f57311cdb5728fb1ba4c9a3c4fa6ed":[3,0,4,4,87,0],
 "d9/d35/lapacke__spf__nancheck_8c_source.html":[3,0,4,4,87],
-"d9/d35/zgbtf2_8f.html":[3,0,5,1535],
-"d9/d35/zgbtf2_8f_source.html":[3,0,5,1535],
+"d9/d35/zgbtf2_8f.html":[3,0,5,1533],
+"d9/d35/zgbtf2_8f_source.html":[3,0,5,1533],
 "d9/d37/lapacke__cspcon__work_8c.html":[3,0,4,3,449],
 "d9/d37/lapacke__cspcon__work_8c_a4eea61ee9251be167005ebe8da05bc68.html#a4eea61ee9251be167005ebe8da05bc68":[3,0,4,3,449,0],
 "d9/d37/lapacke__cspcon__work_8c_source.html":[3,0,4,3,449],
@@ -150,10 +151,10 @@ var NAVTREEINDEX58 =
 "d9/d3d/lapacke__sopmtr__work_8c.html":[3,0,4,3,1485],
 "d9/d3d/lapacke__sopmtr__work_8c_a3e4891438a82eb44987a2e388d401ee1.html#a3e4891438a82eb44987a2e388d401ee1":[3,0,4,3,1485,0],
 "d9/d3d/lapacke__sopmtr__work_8c_source.html":[3,0,4,3,1485],
-"d9/d3e/dggevx_8f.html":[3,0,5,584],
-"d9/d3e/dggevx_8f_source.html":[3,0,5,584],
-"d9/d3f/dsteqr_8f.html":[3,0,5,895],
-"d9/d3f/dsteqr_8f_source.html":[3,0,5,895],
+"d9/d3e/dggevx_8f.html":[3,0,5,583],
+"d9/d3e/dggevx_8f_source.html":[3,0,5,583],
+"d9/d3f/dsteqr_8f.html":[3,0,5,894],
+"d9/d3f/dsteqr_8f_source.html":[3,0,5,894],
 "d9/d40/cerrqr_8f.html":[3,0,6,1,90],
 "d9/d40/cerrqr_8f_source.html":[3,0,6,1,90],
 "d9/d40/cget07_8f.html":[3,0,6,1,115],
@@ -176,8 +177,8 @@ var NAVTREEINDEX58 =
 "d9/d44/lapacke__zhetrd_8c.html":[3,0,4,3,2084],
 "d9/d44/lapacke__zhetrd_8c_aed43f53b0212ca31c9f52aa2b56f57c4.html#aed43f53b0212ca31c9f52aa2b56f57c4":[3,0,4,3,2084,0],
 "d9/d44/lapacke__zhetrd_8c_source.html":[3,0,4,3,2084],
-"d9/d45/dstevr_8f.html":[3,0,5,899],
-"d9/d45/dstevr_8f_source.html":[3,0,5,899],
+"d9/d45/dstevr_8f.html":[3,0,5,898],
+"d9/d45/dstevr_8f_source.html":[3,0,5,898],
 "d9/d45/lapacke__slarfb_8c.html":[3,0,4,3,1454],
 "d9/d45/lapacke__slarfb_8c_a8ea179c23c43f935b65d38bc5037f4c5.html#a8ea179c23c43f935b65d38bc5037f4c5":[3,0,4,3,1454,0],
 "d9/d45/lapacke__slarfb_8c_source.html":[3,0,4,3,1454],
@@ -190,12 +191,12 @@ var NAVTREEINDEX58 =
 "d9/d46/zgbmv_8f_source.html":[3,0,0,0,122],
 "d9/d47/sdsdot_8f.html":[3,0,0,0,84],
 "d9/d47/sdsdot_8f_source.html":[3,0,0,0,84],
-"d9/d47/slapmr_8f.html":[3,0,5,1203],
-"d9/d47/slapmr_8f_source.html":[3,0,5,1203],
+"d9/d47/slapmr_8f.html":[3,0,5,1201],
+"d9/d47/slapmr_8f_source.html":[3,0,5,1201],
 "d9/d47/zhet01__rook_8f.html":[3,0,6,1,693],
 "d9/d47/zhet01__rook_8f_source.html":[3,0,6,1,693],
-"d9/d47/zpoequ_8f.html":[3,0,5,1856],
-"d9/d47/zpoequ_8f_source.html":[3,0,5,1856],
+"d9/d47/zpoequ_8f.html":[3,0,5,1854],
+"d9/d47/zpoequ_8f_source.html":[3,0,5,1854],
 "d9/d48/chetrf__rk_8f.html":[3,0,5,151],
 "d9/d48/chetrf__rk_8f_source.html":[3,0,5,151],
 "d9/d48/lapacke__sstedc_8c.html":[3,0,4,3,1658],
@@ -208,8 +209,8 @@ var NAVTREEINDEX58 =
 "d9/d49/schkbk_8f_source.html":[3,0,6,0,189],
 "d9/d49/zrqt01_8f.html":[3,0,6,1,750],
 "d9/d49/zrqt01_8f_source.html":[3,0,6,1,750],
-"d9/d4a/stpttf_8f.html":[3,0,5,1503],
-"d9/d4a/stpttf_8f_source.html":[3,0,5,1503],
+"d9/d4a/stpttf_8f.html":[3,0,5,1501],
+"d9/d4a/stpttf_8f_source.html":[3,0,5,1501],
 "d9/d4b/lapacke__csyconv_8c.html":[3,0,4,3,476],
 "d9/d4b/lapacke__csyconv_8c_a98973bd372492a718d80b99adee05327.html#a98973bd372492a718d80b99adee05327":[3,0,4,3,476,0],
 "d9/d4b/lapacke__csyconv_8c_source.html":[3,0,4,3,476],
@@ -222,22 +223,22 @@ var NAVTREEINDEX58 =
 "d9/d4c/lapacke__dggrqf_8c.html":[3,0,4,3,802],
 "d9/d4c/lapacke__dggrqf_8c_a07d2d192409dad5c1ee86dca6ba17ea6.html#a07d2d192409dad5c1ee86dca6ba17ea6":[3,0,4,3,802,0],
 "d9/d4c/lapacke__dggrqf_8c_source.html":[3,0,4,3,802],
-"d9/d4d/ztpqrt_8f.html":[3,0,5,1960],
-"d9/d4d/ztpqrt_8f_source.html":[3,0,5,1960],
-"d9/d4e/dgelss_8f.html":[3,0,5,539],
-"d9/d4e/dgelss_8f_source.html":[3,0,5,539],
-"d9/d4e/zlaqr4_8f.html":[3,0,5,1791],
-"d9/d4e/zlaqr4_8f_source.html":[3,0,5,1791],
+"d9/d4d/ztpqrt_8f.html":[3,0,5,1958],
+"d9/d4d/ztpqrt_8f_source.html":[3,0,5,1958],
+"d9/d4e/dgelss_8f.html":[3,0,5,538],
+"d9/d4e/dgelss_8f_source.html":[3,0,5,538],
+"d9/d4e/zlaqr4_8f.html":[3,0,5,1789],
+"d9/d4e/zlaqr4_8f_source.html":[3,0,5,1789],
 "d9/d4f/lapacke__zhp__nancheck_8c.html":[3,0,4,4,122],
 "d9/d4f/lapacke__zhp__nancheck_8c_a312a8798eaf2d8776e696518754f25e3.html#a312a8798eaf2d8776e696518754f25e3":[3,0,4,4,122,0],
 "d9/d4f/lapacke__zhp__nancheck_8c_source.html":[3,0,4,4,122],
-"d9/d50/slasyf__rook_8f.html":[3,0,5,1289],
-"d9/d50/slasyf__rook_8f_source.html":[3,0,5,1289],
+"d9/d50/slasyf__rook_8f.html":[3,0,5,1287],
+"d9/d50/slasyf__rook_8f_source.html":[3,0,5,1287],
 "d9/d51/lapacke__cgeqrfp__work_8c.html":[3,0,4,3,83],
 "d9/d51/lapacke__cgeqrfp__work_8c_aa3b003d7b4482cd007757b731e3c8b50.html#aa3b003d7b4482cd007757b731e3c8b50":[3,0,4,3,83,0],
 "d9/d51/lapacke__cgeqrfp__work_8c_source.html":[3,0,4,3,83],
-"d9/d52/dggev_8f.html":[3,0,5,582],
-"d9/d52/dggev_8f_source.html":[3,0,5,582],
+"d9/d52/dggev_8f.html":[3,0,5,581],
+"d9/d52/dggev_8f_source.html":[3,0,5,581],
 "d9/d52/ztrt03_8f.html":[3,0,6,1,776],
 "d9/d52/ztrt03_8f_source.html":[3,0,6,1,776],
 "d9/d53/dsbt21_8f.html":[3,0,6,0,168],
@@ -248,6 +249,5 @@ var NAVTREEINDEX58 =
 "d9/d54/dsyt01__rook_8f.html":[3,0,6,1,376],
 "d9/d54/dsyt01__rook_8f_source.html":[3,0,6,1,376],
 "d9/d54/group___o_t_h_e_reigen.html":[0,0,7],
-"d9/d54/lapacke__cunbdb_8c.html":[3,0,4,3,602],
-"d9/d54/lapacke__cunbdb_8c_a5e002ab0bd5e0e7ae0cfd90b6303cc99.html#a5e002ab0bd5e0e7ae0cfd90b6303cc99":[3,0,4,3,602,0]
+"d9/d54/lapacke__cunbdb_8c.html":[3,0,4,3,602]
 };
