@@ -1,5 +1,6 @@
 var NAVTREEINDEX59 =
 {
+"d9/d54/lapacke__cunbdb_8c_a5e002ab0bd5e0e7ae0cfd90b6303cc99.html#a5e002ab0bd5e0e7ae0cfd90b6303cc99":[3,0,4,3,602,0],
 "d9/d54/lapacke__cunbdb_8c_source.html":[3,0,4,3,602],
 "d9/d54/lapacke__sppequ_8c.html":[3,0,4,3,1572],
 "d9/d54/lapacke__sppequ_8c_ad0ecdd8a8d22a28209cc9ffbe2b8d0b9.html#ad0ecdd8a8d22a28209cc9ffbe2b8d0b9":[3,0,4,3,1572,0],
@@ -22,10 +23,10 @@ var NAVTREEINDEX59 =
 "d9/d5c/lapacke__zhetrf__rook_8c.html":[3,0,4,3,2093],
 "d9/d5c/lapacke__zhetrf__rook_8c_a8d22c211f01f532ac3259ed363c7422b.html#a8d22c211f01f532ac3259ed363c7422b":[3,0,4,3,2093,0],
 "d9/d5c/lapacke__zhetrf__rook_8c_source.html":[3,0,4,3,2093],
-"d9/d5c/sorg2l_8f.html":[3,0,5,1310],
-"d9/d5c/sorg2l_8f_source.html":[3,0,5,1310],
-"d9/d5c/zgeqr2_8f.html":[3,0,5,1569],
-"d9/d5c/zgeqr2_8f_source.html":[3,0,5,1569],
+"d9/d5c/sorg2l_8f.html":[3,0,5,1308],
+"d9/d5c/sorg2l_8f_source.html":[3,0,5,1308],
+"d9/d5c/zgeqr2_8f.html":[3,0,5,1567],
+"d9/d5c/zgeqr2_8f_source.html":[3,0,5,1567],
 "d9/d5f/ctbsv_8f.html":[3,0,0,0,28],
 "d9/d5f/ctbsv_8f_source.html":[3,0,0,0,28],
 "d9/d5f/ddrvgex_8f.html":[3,0,6,1,249],
@@ -37,8 +38,8 @@ var NAVTREEINDEX59 =
 "d9/d60/cgbt02_8f_source.html":[3,0,6,1,104],
 "d9/d60/slattr_8f.html":[3,0,6,1,501],
 "d9/d60/slattr_8f_source.html":[3,0,6,1,501],
-"d9/d60/ssytrd__2stage_8f.html":[3,0,5,1457],
-"d9/d60/ssytrd__2stage_8f_source.html":[3,0,5,1457],
+"d9/d60/ssytrd__2stage_8f.html":[3,0,5,1455],
+"d9/d60/ssytrd__2stage_8f_source.html":[3,0,5,1455],
 "d9/d61/lapacke__dbdsvdx__work_8c.html":[3,0,4,3,651],
 "d9/d61/lapacke__dbdsvdx__work_8c_a2c2dd9db320a408d433f5426eb045ecd.html#a2c2dd9db320a408d433f5426eb045ecd":[3,0,4,3,651,0],
 "d9/d61/lapacke__dbdsvdx__work_8c_source.html":[3,0,4,3,651],
@@ -75,10 +76,10 @@ var NAVTREEINDEX59 =
 "d9/d63/lapacke__zlaghe__work_8c_source.html":[3,0,4,3,2169],
 "d9/d63/zdrges3_8f.html":[3,0,6,0,304],
 "d9/d63/zdrges3_8f_source.html":[3,0,6,0,304],
-"d9/d63/ztpcon_8f.html":[3,0,5,1955],
-"d9/d63/ztpcon_8f_source.html":[3,0,5,1955],
-"d9/d64/_s_r_c_2xerbla_8f.html":[3,0,5,1519],
-"d9/d64/_s_r_c_2xerbla_8f_source.html":[3,0,5,1519],
+"d9/d63/ztpcon_8f.html":[3,0,5,1953],
+"d9/d63/ztpcon_8f_source.html":[3,0,5,1953],
+"d9/d64/_s_r_c_2xerbla_8f.html":[3,0,5,1517],
+"d9/d64/_s_r_c_2xerbla_8f_source.html":[3,0,5,1517],
 "d9/d65/cla__porpvgrw_8f.html":[3,0,5,204],
 "d9/d65/cla__porpvgrw_8f_source.html":[3,0,5,204],
 "d9/d65/zlatmt_8f.html":[3,0,6,2,73],
@@ -94,12 +95,12 @@ var NAVTREEINDEX59 =
 "d9/d67/lapacke__zggsvd3__work_8c.html":[3,0,4,3,1994],
 "d9/d67/lapacke__zggsvd3__work_8c_a5256cd15411521750dbc59951d65c1ab.html#a5256cd15411521750dbc59951d65c1ab":[3,0,4,3,1994,0],
 "d9/d67/lapacke__zggsvd3__work_8c_source.html":[3,0,4,3,1994],
-"d9/d69/dorgtsqr__row_8f.html":[3,0,5,800],
-"d9/d69/dorgtsqr__row_8f_source.html":[3,0,5,800],
+"d9/d69/dorgtsqr__row_8f.html":[3,0,5,799],
+"d9/d69/dorgtsqr__row_8f_source.html":[3,0,5,799],
 "d9/d6a/cpot01_8f.html":[3,0,6,1,150],
 "d9/d6a/cpot01_8f_source.html":[3,0,6,1,150],
-"d9/d6a/dsyrfs_8f.html":[3,0,5,922],
-"d9/d6a/dsyrfs_8f_source.html":[3,0,5,922],
+"d9/d6a/dsyrfs_8f.html":[3,0,5,921],
+"d9/d6a/dsyrfs_8f_source.html":[3,0,5,921],
 "d9/d6a/lapacke__chbev__2stage_8c.html":[3,0,4,3,175],
 "d9/d6a/lapacke__chbev__2stage_8c_a6684cb0301a3872f63dee2698c8ab7ad.html#a6684cb0301a3872f63dee2698c8ab7ad":[3,0,4,3,175,0],
 "d9/d6a/lapacke__chbev__2stage_8c_source.html":[3,0,4,3,175],
@@ -116,11 +117,11 @@ var NAVTREEINDEX59 =
 "d9/d6d/lapacke__zupgtr_8c.html":[3,0,4,3,2478],
 "d9/d6d/lapacke__zupgtr_8c_aecad3e68e3c7869bbe86eafecdb311fe.html#aecad3e68e3c7869bbe86eafecdb311fe":[3,0,4,3,2478,0],
 "d9/d6d/lapacke__zupgtr_8c_source.html":[3,0,4,3,2478],
-"d9/d6d/ssb2st__kernels_8f.html":[3,0,5,1382],
-"d9/d6d/ssb2st__kernels_8f_a27e1055765fdc389a93da63bb0acbf6a.html#a27e1055765fdc389a93da63bb0acbf6a":[3,0,5,1382,0],
-"d9/d6d/ssb2st__kernels_8f_source.html":[3,0,5,1382],
-"d9/d6f/dposv_8f.html":[3,0,5,833],
-"d9/d6f/dposv_8f_source.html":[3,0,5,833],
+"d9/d6d/ssb2st__kernels_8f.html":[3,0,5,1380],
+"d9/d6d/ssb2st__kernels_8f_a27e1055765fdc389a93da63bb0acbf6a.html#a27e1055765fdc389a93da63bb0acbf6a":[3,0,5,1380,0],
+"d9/d6d/ssb2st__kernels_8f_source.html":[3,0,5,1380],
+"d9/d6f/dposv_8f.html":[3,0,5,832],
+"d9/d6f/dposv_8f_source.html":[3,0,5,832],
 "d9/d6f/lapacke__ssytri2x_8c.html":[3,0,4,3,1747],
 "d9/d6f/lapacke__ssytri2x_8c_a05ad16eee1bb28d9d80031cdd354084c.html#a05ad16eee1bb28d9d80031cdd354084c":[3,0,4,3,1747,0],
 "d9/d6f/lapacke__ssytri2x_8c_source.html":[3,0,4,3,1747],
@@ -169,24 +170,24 @@ var NAVTREEINDEX59 =
 "d9/d7a/lapacke__chetrs__rook__work_8c.html":[3,0,4,3,276],
 "d9/d7a/lapacke__chetrs__rook__work_8c_acaba422793154d42d17bcacd13f70baf.html#acaba422793154d42d17bcacd13f70baf":[3,0,4,3,276,0],
 "d9/d7a/lapacke__chetrs__rook__work_8c_source.html":[3,0,4,3,276],
-"d9/d7a/zgebrd_8f.html":[3,0,5,1541],
-"d9/d7a/zgebrd_8f_source.html":[3,0,5,1541],
+"d9/d7a/zgebrd_8f.html":[3,0,5,1539],
+"d9/d7a/zgebrd_8f_source.html":[3,0,5,1539],
 "d9/d7b/lapacke__zgeequ__work_8c.html":[3,0,4,3,1873],
 "d9/d7b/lapacke__zgeequ__work_8c_af2da0bd6b4e68f495a113069e924ab2a.html#af2da0bd6b4e68f495a113069e924ab2a":[3,0,4,3,1873,0],
 "d9/d7b/lapacke__zgeequ__work_8c_source.html":[3,0,4,3,1873],
 "d9/d7b/lapacke__zhetrs__3__work_8c.html":[3,0,4,3,2108],
 "d9/d7b/lapacke__zhetrs__3__work_8c_ac9a16e8a381b31ebac4fa4cc9941493f.html#ac9a16e8a381b31ebac4fa4cc9941493f":[3,0,4,3,2108,0],
 "d9/d7b/lapacke__zhetrs__3__work_8c_source.html":[3,0,4,3,2108],
-"d9/d7b/zlaqr0_8f.html":[3,0,5,1787],
-"d9/d7b/zlaqr0_8f_source.html":[3,0,5,1787],
+"d9/d7b/zlaqr0_8f.html":[3,0,5,1785],
+"d9/d7b/zlaqr0_8f_source.html":[3,0,5,1785],
 "d9/d80/lapacke__csp__trans_8c.html":[3,0,4,4,26],
 "d9/d80/lapacke__csp__trans_8c_a2850ba9f786d34a2b9d30f51db4285e8.html#a2850ba9f786d34a2b9d30f51db4285e8":[3,0,4,4,26,0],
 "d9/d80/lapacke__csp__trans_8c_source.html":[3,0,4,4,26],
 "d9/d80/lapacke__zgesvd__work_8c.html":[3,0,4,3,1939],
 "d9/d80/lapacke__zgesvd__work_8c_aff095e9fc22c4b0fa35c1291e8940024.html#aff095e9fc22c4b0fa35c1291e8940024":[3,0,4,3,1939,0],
 "d9/d80/lapacke__zgesvd__work_8c_source.html":[3,0,4,3,1939],
-"d9/d80/slaed8_8f.html":[3,0,5,1162],
-"d9/d80/slaed8_8f_source.html":[3,0,5,1162],
+"d9/d80/slaed8_8f.html":[3,0,5,1160],
+"d9/d80/slaed8_8f_source.html":[3,0,5,1160],
 "d9/d81/lapacke__dbdsqr_8c.html":[3,0,4,3,648],
 "d9/d81/lapacke__dbdsqr_8c_a8dd01e8c6eb31550f90802f3bb111185.html#a8dd01e8c6eb31550f90802f3bb111185":[3,0,4,3,648,0],
 "d9/d81/lapacke__dbdsqr_8c_source.html":[3,0,4,3,648],
@@ -204,27 +205,27 @@ var NAVTREEINDEX59 =
 "d9/d83/lapacke__zherfsx__work_8c.html":[3,0,4,3,2069],
 "d9/d83/lapacke__zherfsx__work_8c_a8554a743127a014c0e1c73df4f81c423.html#a8554a743127a014c0e1c73df4f81c423":[3,0,4,3,2069,0],
 "d9/d83/lapacke__zherfsx__work_8c_source.html":[3,0,4,3,2069],
-"d9/d83/sgelq2_8f.html":[3,0,5,1056],
-"d9/d83/sgelq2_8f_source.html":[3,0,5,1056],
+"d9/d83/sgelq2_8f.html":[3,0,5,1054],
+"d9/d83/sgelq2_8f_source.html":[3,0,5,1054],
 "d9/d84/cblas__drot_8c.html":[3,0,1,2,42],
 "d9/d84/cblas__drot_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,42,0],
 "d9/d84/cblas__drot_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,42,1],
-"d9/d84/cblas__drot_8c_a4d863be8512a8bd716288f914166582b.html#a4d863be8512a8bd716288f914166582b":[3,0,1,2,42,3],
 "d9/d84/cblas__drot_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,42,2],
+"d9/d84/cblas__drot_8c_afabc7142a41f6767efbef85fc944c8b4.html#afabc7142a41f6767efbef85fc944c8b4":[3,0,1,2,42,3],
 "d9/d84/cblas__drot_8c_source.html":[3,0,1,2,42],
 "d9/d84/dtpsv_8f.html":[3,0,0,0,65],
 "d9/d84/dtpsv_8f_source.html":[3,0,0,0,65],
-"d9/d84/dtrcon_8f.html":[3,0,5,985],
-"d9/d84/dtrcon_8f_source.html":[3,0,5,985],
+"d9/d84/dtrcon_8f.html":[3,0,5,984],
+"d9/d84/dtrcon_8f_source.html":[3,0,5,984],
 "d9/d84/lapacke__dtbtrs__work_8c.html":[3,0,4,3,1175],
 "d9/d84/lapacke__dtbtrs__work_8c_acb3e113a61fe19fe4da9979c056b1a6d.html#acb3e113a61fe19fe4da9979c056b1a6d":[3,0,4,3,1175,0],
 "d9/d84/lapacke__dtbtrs__work_8c_source.html":[3,0,4,3,1175],
-"d9/d84/sormrq_8f.html":[3,0,5,1335],
-"d9/d84/sormrq_8f_source.html":[3,0,5,1335],
-"d9/d85/zlarfx_8f.html":[3,0,5,1809],
-"d9/d85/zlarfx_8f_source.html":[3,0,5,1809],
-"d9/d86/ilazlr_8f.html":[3,0,5,1015],
-"d9/d86/ilazlr_8f_source.html":[3,0,5,1015],
+"d9/d84/sormrq_8f.html":[3,0,5,1333],
+"d9/d84/sormrq_8f_source.html":[3,0,5,1333],
+"d9/d85/zlarfx_8f.html":[3,0,5,1807],
+"d9/d85/zlarfx_8f_source.html":[3,0,5,1807],
+"d9/d86/ilazlr_8f.html":[3,0,5,1014],
+"d9/d86/ilazlr_8f_source.html":[3,0,5,1014],
 "d9/d86/lapacke__dggevx_8c.html":[3,0,4,3,790],
 "d9/d86/lapacke__dggevx_8c_a288aa2384ce2710aed3560b16b2286b1.html#a288aa2384ce2710aed3560b16b2286b1":[3,0,4,3,790,0],
 "d9/d86/lapacke__dggevx_8c_source.html":[3,0,4,3,790],
@@ -233,10 +234,10 @@ var NAVTREEINDEX59 =
 "d9/d87/lapacke__ssyconv__work_8c.html":[3,0,4,3,1683],
 "d9/d87/lapacke__ssyconv__work_8c_af4079f7e8c09a344763ac840bae9987e.html#af4079f7e8c09a344763ac840bae9987e":[3,0,4,3,1683,0],
 "d9/d87/lapacke__ssyconv__work_8c_source.html":[3,0,4,3,1683],
-"d9/d88/ztplqt_8f.html":[3,0,5,1956],
-"d9/d88/ztplqt_8f_source.html":[3,0,5,1956],
-"d9/d89/dspsv_8f.html":[3,0,5,884],
-"d9/d89/dspsv_8f_source.html":[3,0,5,884],
+"d9/d88/ztplqt_8f.html":[3,0,5,1954],
+"d9/d88/ztplqt_8f_source.html":[3,0,5,1954],
+"d9/d89/dspsv_8f.html":[3,0,5,883],
+"d9/d89/dspsv_8f_source.html":[3,0,5,883],
 "d9/d89/lapacke__zsytri2_8c.html":[3,0,4,3,2351],
 "d9/d89/lapacke__zsytri2_8c_aa4194fd13fd25dee44431477881e9a88.html#aa4194fd13fd25dee44431477881e9a88":[3,0,4,3,2351,0],
 "d9/d89/lapacke__zsytri2_8c_source.html":[3,0,4,3,2351],
@@ -248,6 +249,5 @@ var NAVTREEINDEX59 =
 "d9/d8a/lapacke__sgejsv__work_8c_source.html":[3,0,4,3,1297],
 "d9/d8b/dlaord_8f.html":[3,0,6,1,316],
 "d9/d8b/dlaord_8f_source.html":[3,0,6,1,316],
-"d9/d8b/slaed0_8f.html":[3,0,5,1154],
-"d9/d8b/slaed0_8f_source.html":[3,0,5,1154]
+"d9/d8b/slaed0_8f.html":[3,0,5,1152]
 };
