@@ -1,42 +1,41 @@
 var NAVTREEINDEX60 =
 {
+"d9/d8b/slaed0_8f_source.html":[3,0,5,1152],
 "d9/d8c/lapacke__chegst__work_8c.html":[3,0,4,3,219],
 "d9/d8c/lapacke__chegst__work_8c_a56de6275490643f739df883bb7f7e8b5.html#a56de6275490643f739df883bb7f7e8b5":[3,0,4,3,219,0],
 "d9/d8c/lapacke__chegst__work_8c_source.html":[3,0,4,3,219],
-"d9/d8d/dlaqr0_8f.html":[3,0,5,688],
-"d9/d8d/dlaqr0_8f_source.html":[3,0,5,688],
-"d9/d8e/dcombssq_8f.html":[3,0,5,504],
-"d9/d8e/dcombssq_8f_source.html":[3,0,5,504],
+"d9/d8d/dlaqr0_8f.html":[3,0,5,687],
+"d9/d8d/dlaqr0_8f_source.html":[3,0,5,687],
 "d9/d8e/group__double_g_eeigen.html":[0,0,0,1,0],
-"d9/d8e/group__double_g_eeigen_ga2233e8611b7b529422497036b284b438.html#ga2233e8611b7b529422497036b284b438":[3,0,5,525,0],
 "d9/d8e/group__double_g_eeigen_ga2233e8611b7b529422497036b284b438.html#ga2233e8611b7b529422497036b284b438":[0,0,0,1,0,0],
-"d9/d8e/group__double_g_eeigen_ga28d81b96083b18aa21c47e2e6ff59e5a.html#ga28d81b96083b18aa21c47e2e6ff59e5a":[3,0,5,583,0],
+"d9/d8e/group__double_g_eeigen_ga2233e8611b7b529422497036b284b438.html#ga2233e8611b7b529422497036b284b438":[3,0,5,524,0],
+"d9/d8e/group__double_g_eeigen_ga28d81b96083b18aa21c47e2e6ff59e5a.html#ga28d81b96083b18aa21c47e2e6ff59e5a":[3,0,5,582,0],
 "d9/d8e/group__double_g_eeigen_ga28d81b96083b18aa21c47e2e6ff59e5a.html#ga28d81b96083b18aa21c47e2e6ff59e5a":[0,0,0,1,0,10],
-"d9/d8e/group__double_g_eeigen_ga3903b5dcbc186bcc5b2db0604331dbb6.html#ga3903b5dcbc186bcc5b2db0604331dbb6":[3,0,5,580,0],
+"d9/d8e/group__double_g_eeigen_ga3903b5dcbc186bcc5b2db0604331dbb6.html#ga3903b5dcbc186bcc5b2db0604331dbb6":[3,0,5,579,0],
 "d9/d8e/group__double_g_eeigen_ga3903b5dcbc186bcc5b2db0604331dbb6.html#ga3903b5dcbc186bcc5b2db0604331dbb6":[0,0,0,1,0,7],
 "d9/d8e/group__double_g_eeigen_ga4a909655349307569c2a11e703a7ac08.html#ga4a909655349307569c2a11e703a7ac08":[3,0,5,0,10,0],
 "d9/d8e/group__double_g_eeigen_ga4a909655349307569c2a11e703a7ac08.html#ga4a909655349307569c2a11e703a7ac08":[0,0,0,1,0,5],
+"d9/d8e/group__double_g_eeigen_ga4e35e1d4e9b63ba9eef4ba8aff3debae.html#ga4e35e1d4e9b63ba9eef4ba8aff3debae":[3,0,5,527,0],
 "d9/d8e/group__double_g_eeigen_ga4e35e1d4e9b63ba9eef4ba8aff3debae.html#ga4e35e1d4e9b63ba9eef4ba8aff3debae":[0,0,0,1,0,3],
-"d9/d8e/group__double_g_eeigen_ga4e35e1d4e9b63ba9eef4ba8aff3debae.html#ga4e35e1d4e9b63ba9eef4ba8aff3debae":[3,0,5,528,0],
-"d9/d8e/group__double_g_eeigen_ga4f59e87e670a755b41cbdd7e97f36bea.html#ga4f59e87e670a755b41cbdd7e97f36bea":[3,0,5,582,0],
+"d9/d8e/group__double_g_eeigen_ga4f59e87e670a755b41cbdd7e97f36bea.html#ga4f59e87e670a755b41cbdd7e97f36bea":[3,0,5,581,0],
 "d9/d8e/group__double_g_eeigen_ga4f59e87e670a755b41cbdd7e97f36bea.html#ga4f59e87e670a755b41cbdd7e97f36bea":[0,0,0,1,0,9],
-"d9/d8e/group__double_g_eeigen_ga58099bb0f4ebe6a1f6f6078e05a6fb78.html#ga58099bb0f4ebe6a1f6f6078e05a6fb78":[3,0,5,584,0],
+"d9/d8e/group__double_g_eeigen_ga58099bb0f4ebe6a1f6f6078e05a6fb78.html#ga58099bb0f4ebe6a1f6f6078e05a6fb78":[3,0,5,583,0],
 "d9/d8e/group__double_g_eeigen_ga58099bb0f4ebe6a1f6f6078e05a6fb78.html#ga58099bb0f4ebe6a1f6f6078e05a6fb78":[0,0,0,1,0,11],
+"d9/d8e/group__double_g_eeigen_ga66e19253344358f5dee1e60502b9e96f.html#ga66e19253344358f5dee1e60502b9e96f":[3,0,5,526,0],
 "d9/d8e/group__double_g_eeigen_ga66e19253344358f5dee1e60502b9e96f.html#ga66e19253344358f5dee1e60502b9e96f":[0,0,0,1,0,2],
-"d9/d8e/group__double_g_eeigen_ga66e19253344358f5dee1e60502b9e96f.html#ga66e19253344358f5dee1e60502b9e96f":[3,0,5,527,0],
+"d9/d8e/group__double_g_eeigen_ga745081b04dc6f1b5a93a5d8b31aec915.html#ga745081b04dc6f1b5a93a5d8b31aec915":[3,0,5,525,0],
 "d9/d8e/group__double_g_eeigen_ga745081b04dc6f1b5a93a5d8b31aec915.html#ga745081b04dc6f1b5a93a5d8b31aec915":[0,0,0,1,0,1],
-"d9/d8e/group__double_g_eeigen_ga745081b04dc6f1b5a93a5d8b31aec915.html#ga745081b04dc6f1b5a93a5d8b31aec915":[3,0,5,526,0],
-"d9/d8e/group__double_g_eeigen_ga8637d4b822e19d10327ddcb4235dc08e.html#ga8637d4b822e19d10327ddcb4235dc08e":[3,0,5,579,0],
 "d9/d8e/group__double_g_eeigen_ga8637d4b822e19d10327ddcb4235dc08e.html#ga8637d4b822e19d10327ddcb4235dc08e":[0,0,0,1,0,6],
-"d9/d8e/group__double_g_eeigen_ga923e1df287c0a880641462ce42607936.html#ga923e1df287c0a880641462ce42607936":[3,0,5,581,0],
+"d9/d8e/group__double_g_eeigen_ga8637d4b822e19d10327ddcb4235dc08e.html#ga8637d4b822e19d10327ddcb4235dc08e":[3,0,5,578,0],
+"d9/d8e/group__double_g_eeigen_ga923e1df287c0a880641462ce42607936.html#ga923e1df287c0a880641462ce42607936":[3,0,5,580,0],
 "d9/d8e/group__double_g_eeigen_ga923e1df287c0a880641462ce42607936.html#ga923e1df287c0a880641462ce42607936":[0,0,0,1,0,8],
-"d9/d8e/group__double_g_eeigen_gaf64f56e7012093f95cd35f59271b85bf.html#gaf64f56e7012093f95cd35f59271b85bf":[3,0,5,0,9,0],
 "d9/d8e/group__double_g_eeigen_gaf64f56e7012093f95cd35f59271b85bf.html#gaf64f56e7012093f95cd35f59271b85bf":[0,0,0,1,0,4],
+"d9/d8e/group__double_g_eeigen_gaf64f56e7012093f95cd35f59271b85bf.html#gaf64f56e7012093f95cd35f59271b85bf":[3,0,5,0,9,0],
 "d9/d90/lapacke__dlaset_8c.html":[3,0,4,3,872],
 "d9/d90/lapacke__dlaset_8c_a4de77e5cc9b335cf6a67ae84c832a6cb.html#a4de77e5cc9b335cf6a67ae84c832a6cb":[3,0,4,3,872,0],
 "d9/d90/lapacke__dlaset_8c_source.html":[3,0,4,3,872],
-"d9/d91/dsytrf__rk_8f.html":[3,0,5,943],
-"d9/d91/dsytrf__rk_8f_source.html":[3,0,5,943],
+"d9/d91/dsytrf__rk_8f.html":[3,0,5,942],
+"d9/d91/dsytrf__rk_8f_source.html":[3,0,5,942],
 "d9/d92/ctpt05_8f.html":[3,0,6,1,201],
 "d9/d92/ctpt05_8f_source.html":[3,0,6,1,201],
 "d9/d92/lapacke__cptsv_8c.html":[3,0,4,3,440],
@@ -45,8 +44,8 @@ var NAVTREEINDEX60 =
 "d9/d93/lapacke__sggglm__work_8c.html":[3,0,4,3,1391],
 "d9/d93/lapacke__sggglm__work_8c_af7b98639feefe63d89ce59bb3f83bfd7.html#af7b98639feefe63d89ce59bb3f83bfd7":[3,0,4,3,1391,0],
 "d9/d93/lapacke__sggglm__work_8c_source.html":[3,0,4,3,1391],
-"d9/d94/zgelss_8f.html":[3,0,5,1559],
-"d9/d94/zgelss_8f_source.html":[3,0,5,1559],
+"d9/d94/zgelss_8f.html":[3,0,5,1557],
+"d9/d94/zgelss_8f_source.html":[3,0,5,1557],
 "d9/d96/lapacke__dorgtr__work_8c.html":[3,0,4,3,907],
 "d9/d96/lapacke__dorgtr__work_8c_a15c028c8920b058395dbe1049df139b4.html#a15c028c8920b058395dbe1049df139b4":[3,0,4,3,907,0],
 "d9/d96/lapacke__dorgtr__work_8c_source.html":[3,0,4,3,907],
@@ -105,22 +104,22 @@ var NAVTREEINDEX60 =
 "d9/d9b/lapacke__sgbrfsx__work_8c.html":[3,0,4,3,1263],
 "d9/d9b/lapacke__sgbrfsx__work_8c_a5e116ce37c56c310d8057302f4fe25bd.html#a5e116ce37c56c310d8057302f4fe25bd":[3,0,4,3,1263,0],
 "d9/d9b/lapacke__sgbrfsx__work_8c_source.html":[3,0,4,3,1263],
-"d9/d9c/dsysv__rk_8f.html":[3,0,5,927],
-"d9/d9c/dsysv__rk_8f_source.html":[3,0,5,927],
+"d9/d9c/dsysv__rk_8f.html":[3,0,5,926],
+"d9/d9c/dsysv__rk_8f_source.html":[3,0,5,926],
 "d9/d9c/lapacke__ctp__trans_8c.html":[3,0,4,4,35],
 "d9/d9c/lapacke__ctp__trans_8c_a69a6815759a956dcc25a90d7cba0916e.html#a69a6815759a956dcc25a90d7cba0916e":[3,0,4,4,35,0],
 "d9/d9c/lapacke__ctp__trans_8c_source.html":[3,0,4,4,35],
-"d9/d9c/slaed1_8f.html":[3,0,5,1155],
-"d9/d9c/slaed1_8f_source.html":[3,0,5,1155],
-"d9/d9d/ssysv_8f.html":[3,0,5,1444],
-"d9/d9d/ssysv_8f_source.html":[3,0,5,1444],
-"d9/d9d/zsytrs_8f.html":[3,0,5,1934],
-"d9/d9d/zsytrs_8f_source.html":[3,0,5,1934],
+"d9/d9c/slaed1_8f.html":[3,0,5,1153],
+"d9/d9c/slaed1_8f_source.html":[3,0,5,1153],
+"d9/d9d/ssysv_8f.html":[3,0,5,1442],
+"d9/d9d/ssysv_8f_source.html":[3,0,5,1442],
+"d9/d9d/zsytrs_8f.html":[3,0,5,1932],
+"d9/d9d/zsytrs_8f_source.html":[3,0,5,1932],
 "d9/d9e/lapacke__cst__nancheck_8c.html":[3,0,4,4,27],
 "d9/d9e/lapacke__cst__nancheck_8c_ae514b3cc5b9de4b946e50e312cd8d76f.html#ae514b3cc5b9de4b946e50e312cd8d76f":[3,0,4,4,27,0],
 "d9/d9e/lapacke__cst__nancheck_8c_source.html":[3,0,4,4,27],
-"d9/d9e/ssyequb_8f.html":[3,0,5,1427],
-"d9/d9e/ssyequb_8f_source.html":[3,0,5,1427],
+"d9/d9e/ssyequb_8f.html":[3,0,5,1425],
+"d9/d9e/ssyequb_8f_source.html":[3,0,5,1425],
 "d9/d9e/ztbt06_8f.html":[3,0,6,1,768],
 "d9/d9e/ztbt06_8f_source.html":[3,0,6,1,768],
 "d9/d9f/sdrvrf2_8f.html":[3,0,6,1,439],
@@ -130,8 +129,8 @@ var NAVTREEINDEX60 =
 "d9/da1/lapacke__ssytrf__aa_8c.html":[3,0,4,3,1735],
 "d9/da1/lapacke__ssytrf__aa_8c_ab0b99d8db3ea7cee18c363d48819222c.html#ab0b99d8db3ea7cee18c363d48819222c":[3,0,4,3,1735,0],
 "d9/da1/lapacke__ssytrf__aa_8c_source.html":[3,0,4,3,1735],
-"d9/da1/ztbcon_8f.html":[3,0,5,1940],
-"d9/da1/ztbcon_8f_source.html":[3,0,5,1940],
+"d9/da1/ztbcon_8f.html":[3,0,5,1938],
+"d9/da1/ztbcon_8f_source.html":[3,0,5,1938],
 "d9/da2/cchkec_8f.html":[3,0,6,0,14],
 "d9/da2/cchkec_8f_source.html":[3,0,6,0,14],
 "d9/da2/lapacke__dgels_8c.html":[3,0,4,3,706],
@@ -142,18 +141,18 @@ var NAVTREEINDEX60 =
 "d9/da3/lapacke__dtrtrs_8c_source.html":[3,0,4,3,1232],
 "d9/da4/cposvx_8f.html":[3,0,5,339],
 "d9/da4/cposvx_8f_source.html":[3,0,5,339],
-"d9/da4/zgesvdq_8f.html":[3,0,5,1584],
-"d9/da4/zgesvdq_8f_source.html":[3,0,5,1584],
-"d9/da6/zhetri__3x_8f.html":[3,0,5,1679],
-"d9/da6/zhetri__3x_8f_source.html":[3,0,5,1679],
-"d9/da7/dlacon_8f.html":[3,0,5,626],
-"d9/da7/dlacon_8f_source.html":[3,0,5,626],
-"d9/da7/dspgvd_8f.html":[3,0,5,880],
-"d9/da7/dspgvd_8f_source.html":[3,0,5,880],
+"d9/da4/zgesvdq_8f.html":[3,0,5,1582],
+"d9/da4/zgesvdq_8f_source.html":[3,0,5,1582],
+"d9/da6/zhetri__3x_8f.html":[3,0,5,1677],
+"d9/da6/zhetri__3x_8f_source.html":[3,0,5,1677],
+"d9/da7/dlacon_8f.html":[3,0,5,625],
+"d9/da7/dlacon_8f_source.html":[3,0,5,625],
+"d9/da7/dspgvd_8f.html":[3,0,5,879],
+"d9/da7/dspgvd_8f_source.html":[3,0,5,879],
 "d9/da9/sswap_8f.html":[3,0,0,0,99],
 "d9/da9/sswap_8f_source.html":[3,0,0,0,99],
-"d9/daa/dsbevx_8f.html":[3,0,5,865],
-"d9/daa/dsbevx_8f_source.html":[3,0,5,865],
+"d9/daa/dsbevx_8f.html":[3,0,5,864],
+"d9/daa/dsbevx_8f_source.html":[3,0,5,864],
 "d9/daa/lapacke__zsysv__rk_8c.html":[3,0,4,3,2329],
 "d9/daa/lapacke__zsysv__rk_8c_a5128f531acf2cd36395685a36de95031.html#a5128f531acf2cd36395685a36de95031":[3,0,4,3,2329,0],
 "d9/daa/lapacke__zsysv__rk_8c_source.html":[3,0,4,3,2329],
@@ -166,8 +165,8 @@ var NAVTREEINDEX60 =
 "d9/dab/lapacke__zgesdd__work_8c.html":[3,0,4,3,1935],
 "d9/dab/lapacke__zgesdd__work_8c_ac5cc3b68e6c2b675181d5d10e8077873.html#ac5cc3b68e6c2b675181d5d10e8077873":[3,0,4,3,1935,0],
 "d9/dab/lapacke__zgesdd__work_8c_source.html":[3,0,4,3,1935],
-"d9/dac/zptsv_8f.html":[3,0,5,1881],
-"d9/dac/zptsv_8f_source.html":[3,0,5,1881],
+"d9/dac/zptsv_8f.html":[3,0,5,1879],
+"d9/dac/zptsv_8f_source.html":[3,0,5,1879],
 "d9/dad/clavhe_8f.html":[3,0,6,1,136],
 "d9/dad/clavhe_8f_source.html":[3,0,6,1,136],
 "d9/dad/lapacke__chesv__aa__2stage_8c.html":[3,0,4,3,234],
@@ -179,8 +178,8 @@ var NAVTREEINDEX60 =
 "d9/dad/lapacke__zsytrf__aa__2stage_8c.html":[3,0,4,3,2342],
 "d9/dad/lapacke__zsytrf__aa__2stage_8c_abd281c328ef28fafcdc159e7adccaa18.html#abd281c328ef28fafcdc159e7adccaa18":[3,0,4,3,2342,0],
 "d9/dad/lapacke__zsytrf__aa__2stage_8c_source.html":[3,0,4,3,2342],
-"d9/dad/ssytri2x_8f.html":[3,0,5,1467],
-"d9/dad/ssytri2x_8f_source.html":[3,0,5,1467],
+"d9/dad/ssytri2x_8f.html":[3,0,5,1465],
+"d9/dad/ssytri2x_8f_source.html":[3,0,5,1465],
 "d9/dae/cdrvhe__aa_8f.html":[3,0,6,1,51],
 "d9/dae/cdrvhe__aa_8f_source.html":[3,0,6,1,51],
 "d9/dae/lapacke__cgetrf_8c.html":[3,0,4,3,114],
@@ -197,10 +196,10 @@ var NAVTREEINDEX60 =
 "d9/daf/lapacke__ssygv_8c.html":[3,0,4,3,1704],
 "d9/daf/lapacke__ssygv_8c_a46364a6a43118cd7eff5ced05f0ef71b.html#a46364a6a43118cd7eff5ced05f0ef71b":[3,0,4,3,1704,0],
 "d9/daf/lapacke__ssygv_8c_source.html":[3,0,4,3,1704],
-"d9/daf/sggsvd3_8f.html":[3,0,5,1114],
-"d9/daf/sggsvd3_8f_source.html":[3,0,5,1114],
-"d9/db0/dsytf2_8f.html":[3,0,5,933],
-"d9/db0/dsytf2_8f_source.html":[3,0,5,933],
+"d9/daf/sggsvd3_8f.html":[3,0,5,1112],
+"d9/daf/sggsvd3_8f_source.html":[3,0,5,1112],
+"d9/db0/dsytf2_8f.html":[3,0,5,932],
+"d9/db0/dsytf2_8f_source.html":[3,0,5,932],
 "d9/db0/lapacke__claghe_8c.html":[3,0,4,3,330],
 "d9/db0/lapacke__claghe_8c_ae5147f096d25f2cf33a1c6bb970aee44.html#ae5147f096d25f2cf33a1c6bb970aee44":[3,0,4,3,330,0],
 "d9/db0/lapacke__claghe_8c_source.html":[3,0,4,3,330],
@@ -214,23 +213,23 @@ var NAVTREEINDEX60 =
 "d9/db2/c__s2chke_8c_aee62f43c93689b5e385df2cdda91ecae.html#aee62f43c93689b5e385df2cdda91ecae":[3,0,1,3,17,6],
 "d9/db2/c__s2chke_8c_af30da35794de1880d501d5bee1bc2797.html#af30da35794de1880d501d5bee1bc2797":[3,0,1,3,17,1],
 "d9/db2/c__s2chke_8c_source.html":[3,0,1,3,17],
-"d9/db2/dlarzb_8f.html":[3,0,5,732],
-"d9/db2/dlarzb_8f_source.html":[3,0,5,732],
+"d9/db2/dlarzb_8f.html":[3,0,5,731],
+"d9/db2/dlarzb_8f_source.html":[3,0,5,731],
 "d9/db3/lapacke__sspgst_8c.html":[3,0,4,3,1634],
 "d9/db3/lapacke__sspgst_8c_a9364fdebf3760877c0b262403f707247.html#a9364fdebf3760877c0b262403f707247":[3,0,4,3,1634,0],
 "d9/db3/lapacke__sspgst_8c_source.html":[3,0,4,3,1634],
 "d9/db4/chet01__aa_8f.html":[3,0,6,1,121],
 "d9/db4/chet01__aa_8f_source.html":[3,0,6,1,121],
-"d9/db4/zlansb_8f.html":[3,0,5,1771],
-"d9/db4/zlansb_8f_source.html":[3,0,5,1771],
+"d9/db4/zlansb_8f.html":[3,0,5,1769],
+"d9/db4/zlansb_8f_source.html":[3,0,5,1769],
 "d9/db5/lapacke__dstevd_8c.html":[3,0,4,3,1078],
 "d9/db5/lapacke__dstevd_8c_ab6883923203d7317f737e951a55561ae.html#ab6883923203d7317f737e951a55561ae":[3,0,4,3,1078,0],
 "d9/db5/lapacke__dstevd_8c_source.html":[3,0,4,3,1078],
-"d9/db5/slalsa_8f.html":[3,0,5,1181],
-"d9/db5/slalsa_8f_source.html":[3,0,5,1181],
-"d9/db5/slamtsqr_8f.html":[3,0,5,1185],
-"d9/db5/slamtsqr_8f_a5aacfaca08216005b6a3b48950782d07.html#a5aacfaca08216005b6a3b48950782d07":[3,0,5,1185,0],
-"d9/db5/slamtsqr_8f_source.html":[3,0,5,1185],
+"d9/db5/slalsa_8f.html":[3,0,5,1179],
+"d9/db5/slalsa_8f_source.html":[3,0,5,1179],
+"d9/db5/slamtsqr_8f.html":[3,0,5,1183],
+"d9/db5/slamtsqr_8f_a5aacfaca08216005b6a3b48950782d07.html#a5aacfaca08216005b6a3b48950782d07":[3,0,5,1183,0],
+"d9/db5/slamtsqr_8f_source.html":[3,0,5,1183],
 "d9/db6/c__dblat1_8f.html":[3,0,1,3,14],
 "d9/db6/c__dblat1_8f_a011668799647094e60c6a7c2ad859b65.html#a011668799647094e60c6a7c2ad859b65":[3,0,1,3,14,3],
 "d9/db6/c__dblat1_8f_a077aa8449e1055cdecdebf7cb41738a5.html#a077aa8449e1055cdecdebf7cb41738a5":[3,0,1,3,14,8],
@@ -249,5 +248,6 @@ var NAVTREEINDEX60 =
 "d9/db7/sdrvsp_8f.html":[3,0,6,1,443],
 "d9/db7/sdrvsp_8f_source.html":[3,0,6,1,443],
 "d9/db8/lapacke__dppsv_8c.html":[3,0,4,3,978],
-"d9/db8/lapacke__dppsv_8c_a3c23513fd46b126486ef7d97ab346e0d.html#a3c23513fd46b126486ef7d97ab346e0d":[3,0,4,3,978,0]
+"d9/db8/lapacke__dppsv_8c_a3c23513fd46b126486ef7d97ab346e0d.html#a3c23513fd46b126486ef7d97ab346e0d":[3,0,4,3,978,0],
+"d9/db8/lapacke__dppsv_8c_source.html":[3,0,4,3,978]
 };
