@@ -1,6 +1,5 @@
 var NAVTREEINDEX77 =
 {
-"d9/df9/cspsv_8f.html":[3,0,5,369],
 "d9/df9/cspsv_8f_source.html":[3,0,5,369],
 "d9/dfa/clarfgp_8f.html":[3,0,5,286],
 "d9/dfa/clarfgp_8f_source.html":[3,0,5,286],
@@ -18,8 +17,8 @@ var NAVTREEINDEX77 =
 "d9/dfc/lapacke__stzrzf__work_8c.html":[3,0,4,3,1833],
 "d9/dfc/lapacke__stzrzf__work_8c_a409f9e17e7cf866e8359848530a5ddb8.html#a409f9e17e7cf866e8359848530a5ddb8":[3,0,4,3,1833,0],
 "d9/dfc/lapacke__stzrzf__work_8c_source.html":[3,0,4,3,1833],
-"d9/dfc/sla__syamv_8f.html":[3,0,5,1141],
-"d9/dfc/sla__syamv_8f_source.html":[3,0,5,1141],
+"d9/dfc/sla__syamv_8f.html":[3,0,5,1139],
+"d9/dfc/sla__syamv_8f_source.html":[3,0,5,1139],
 "d9/dfc/stbt05_8f.html":[3,0,6,1,556],
 "d9/dfc/stbt05_8f_source.html":[3,0,6,1,556],
 "d9/dfd/cgetrs_8f.html":[3,0,5,72],
@@ -30,8 +29,8 @@ var NAVTREEINDEX77 =
 "d9/dfd/lapacke__ssygvx__work_8c.html":[3,0,4,3,1711],
 "d9/dfd/lapacke__ssygvx__work_8c_a663322f0b5e964298bb3773be6f5949e.html#a663322f0b5e964298bb3773be6f5949e":[3,0,4,3,1711,0],
 "d9/dfd/lapacke__ssygvx__work_8c_source.html":[3,0,4,3,1711],
-"d9/dfe/dlasd0_8f.html":[3,0,5,737],
-"d9/dfe/dlasd0_8f_source.html":[3,0,5,737],
+"d9/dfe/dlasd0_8f.html":[3,0,5,736],
+"d9/dfe/dlasd0_8f_source.html":[3,0,5,736],
 "d9/dfe/lapacke__cgghd3__work_8c.html":[3,0,4,3,145],
 "d9/dfe/lapacke__cgghd3__work_8c_ae498818a2c387f718187f81f718a6fe4.html#ae498818a2c387f718187f81f718a6fe4":[3,0,4,3,145,0],
 "d9/dfe/lapacke__cgghd3__work_8c_source.html":[3,0,4,3,145],
@@ -44,8 +43,8 @@ var NAVTREEINDEX77 =
 "da/d00/lapacke__cggglm_8c.html":[3,0,4,3,142],
 "da/d00/lapacke__cggglm_8c_a82e126c1fa2c52e4134b844524d7505f.html#a82e126c1fa2c52e4134b844524d7505f":[3,0,4,3,142,0],
 "da/d00/lapacke__cggglm_8c_source.html":[3,0,4,3,142],
-"da/d01/stfttr_8f.html":[3,0,5,1483],
-"da/d01/stfttr_8f_source.html":[3,0,5,1483],
+"da/d01/stfttr_8f.html":[3,0,5,1481],
+"da/d01/stfttr_8f_source.html":[3,0,5,1481],
 "da/d02/lapacke__chbevd__work_8c.html":[3,0,4,3,181],
 "da/d02/lapacke__chbevd__work_8c_af796b0077915ce91eb5898028c9d1ff9.html#af796b0077915ce91eb5898028c9d1ff9":[3,0,4,3,181,0],
 "da/d02/lapacke__chbevd__work_8c_source.html":[3,0,4,3,181],
@@ -57,25 +56,25 @@ var NAVTREEINDEX77 =
 "da/d03/lapacke__zgbcon__work_8c_source.html":[3,0,4,3,1845],
 "da/d03/sqrt04_8f.html":[3,0,6,1,535],
 "da/d03/sqrt04_8f_source.html":[3,0,6,1,535],
-"da/d04/slamrg_8f.html":[3,0,5,1183],
-"da/d04/slamrg_8f_source.html":[3,0,5,1183],
+"da/d04/slamrg_8f.html":[3,0,5,1181],
+"da/d04/slamrg_8f_source.html":[3,0,5,1181],
 "da/d05/schksy__rk_8f.html":[3,0,6,1,420],
 "da/d05/schksy__rk_8f_source.html":[3,0,6,1,420],
-"da/d05/slags2_8f.html":[3,0,5,1170],
-"da/d05/slags2_8f_source.html":[3,0,5,1170],
+"da/d05/slags2_8f.html":[3,0,5,1168],
+"da/d05/slags2_8f_source.html":[3,0,5,1168],
 "da/d06/lapacke__zgesvdx_8c.html":[3,0,4,3,1942],
 "da/d06/lapacke__zgesvdx_8c_a5dcecad0983e7192474ba06503d510f1.html#a5dcecad0983e7192474ba06503d510f1":[3,0,4,3,1942,0],
 "da/d06/lapacke__zgesvdx_8c_source.html":[3,0,4,3,1942],
 "da/d07/zget51_8f.html":[3,0,6,0,333],
 "da/d07/zget51_8f_source.html":[3,0,6,0,333],
-"da/d08/slag2d_8f.html":[3,0,5,1169],
-"da/d08/slag2d_8f_source.html":[3,0,5,1169],
+"da/d08/slag2d_8f.html":[3,0,5,1167],
+"da/d08/slag2d_8f_source.html":[3,0,5,1167],
 "da/d09/cggev_8f.html":[3,0,5,80],
 "da/d09/cggev_8f_source.html":[3,0,5,80],
-"da/d09/dtfsm_8f.html":[3,0,5,960],
-"da/d09/dtfsm_8f_source.html":[3,0,5,960],
-"da/d09/zsycon_8f.html":[3,0,5,1901],
-"da/d09/zsycon_8f_source.html":[3,0,5,1901],
+"da/d09/dtfsm_8f.html":[3,0,5,959],
+"da/d09/dtfsm_8f_source.html":[3,0,5,959],
+"da/d09/zsycon_8f.html":[3,0,5,1899],
+"da/d09/zsycon_8f_source.html":[3,0,5,1899],
 "da/d0a/lapacke__zgetf2_8c.html":[3,0,4,3,1950],
 "da/d0a/lapacke__zgetf2_8c_aa1711224f4798f1a35722a8e3c7cf509.html#aa1711224f4798f1a35722a8e3c7cf509":[3,0,4,3,1950,0],
 "da/d0a/lapacke__zgetf2_8c_source.html":[3,0,4,3,1950],
@@ -83,48 +82,48 @@ var NAVTREEINDEX77 =
 "da/d0b/cgetsls_8f_source.html":[3,0,5,73],
 "da/d0b/csytf2__rk_8f.html":[3,0,5,400],
 "da/d0b/csytf2__rk_8f_source.html":[3,0,5,400],
-"da/d0b/dla__porfsx__extended_8f.html":[3,0,5,616],
-"da/d0b/dla__porfsx__extended_8f_source.html":[3,0,5,616],
+"da/d0b/dla__porfsx__extended_8f.html":[3,0,5,615],
+"da/d0b/dla__porfsx__extended_8f_source.html":[3,0,5,615],
 "da/d0b/group__complex16__lin.html":[0,1,1,3],
 "da/d0b/group__complex16__lin_ga0126a2ab78162cd15e37a138892af0c2.html#ga0126a2ab78162cd15e37a138892af0c2":[0,1,1,3,85],
 "da/d0b/group__complex16__lin_ga0126a2ab78162cd15e37a138892af0c2.html#ga0126a2ab78162cd15e37a138892af0c2":[3,0,6,1,673,0],
 "da/d0b/group__complex16__lin_ga02ea73af4c37a9504c443c5e8ecaf5f1.html#ga02ea73af4c37a9504c443c5e8ecaf5f1":[0,1,1,3,33],
 "da/d0b/group__complex16__lin_ga02ea73af4c37a9504c443c5e8ecaf5f1.html#ga02ea73af4c37a9504c443c5e8ecaf5f1":[3,0,6,1,607,0],
-"da/d0b/group__complex16__lin_ga04baac26bbc8ee20fd25493ef16268ba.html#ga04baac26bbc8ee20fd25493ef16268ba":[0,1,1,3,105],
 "da/d0b/group__complex16__lin_ga04baac26bbc8ee20fd25493ef16268ba.html#ga04baac26bbc8ee20fd25493ef16268ba":[3,0,6,1,693,0],
-"da/d0b/group__complex16__lin_ga05129173a9815715e39e9dd80336cf3b.html#ga05129173a9815715e39e9dd80336cf3b":[3,0,6,1,584,0],
+"da/d0b/group__complex16__lin_ga04baac26bbc8ee20fd25493ef16268ba.html#ga04baac26bbc8ee20fd25493ef16268ba":[0,1,1,3,105],
 "da/d0b/group__complex16__lin_ga05129173a9815715e39e9dd80336cf3b.html#ga05129173a9815715e39e9dd80336cf3b":[0,1,1,3,12],
+"da/d0b/group__complex16__lin_ga05129173a9815715e39e9dd80336cf3b.html#ga05129173a9815715e39e9dd80336cf3b":[3,0,6,1,584,0],
 "da/d0b/group__complex16__lin_ga084dd84c46d4f65bc024bb2aaf4c9562.html#ga084dd84c46d4f65bc024bb2aaf4c9562":[0,1,1,3,48],
 "da/d0b/group__complex16__lin_ga084dd84c46d4f65bc024bb2aaf4c9562.html#ga084dd84c46d4f65bc024bb2aaf4c9562":[3,0,6,1,626,0],
-"da/d0b/group__complex16__lin_ga0b09867599fc3188f403b8713c1f1830.html#ga0b09867599fc3188f403b8713c1f1830":[3,0,6,1,735,0],
 "da/d0b/group__complex16__lin_ga0b09867599fc3188f403b8713c1f1830.html#ga0b09867599fc3188f403b8713c1f1830":[0,1,1,3,145],
+"da/d0b/group__complex16__lin_ga0b09867599fc3188f403b8713c1f1830.html#ga0b09867599fc3188f403b8713c1f1830":[3,0,6,1,735,0],
 "da/d0b/group__complex16__lin_ga0b7ccd92df6065f4ab5fbdd16c9d373d.html#ga0b7ccd92df6065f4ab5fbdd16c9d373d":[0,1,1,3,132],
 "da/d0b/group__complex16__lin_ga0b7ccd92df6065f4ab5fbdd16c9d373d.html#ga0b7ccd92df6065f4ab5fbdd16c9d373d":[3,0,6,1,722,0],
-"da/d0b/group__complex16__lin_ga0c19baa73f3b0c8a185eae2f9ed474f9.html#ga0c19baa73f3b0c8a185eae2f9ed474f9":[3,0,6,1,703,0],
 "da/d0b/group__complex16__lin_ga0c19baa73f3b0c8a185eae2f9ed474f9.html#ga0c19baa73f3b0c8a185eae2f9ed474f9":[0,1,1,3,115],
-"da/d0b/group__complex16__lin_ga0c294a42b3a456d8a3308f8618612ac8.html#ga0c294a42b3a456d8a3308f8618612ac8":[3,0,6,1,678,0],
+"da/d0b/group__complex16__lin_ga0c19baa73f3b0c8a185eae2f9ed474f9.html#ga0c19baa73f3b0c8a185eae2f9ed474f9":[3,0,6,1,703,0],
 "da/d0b/group__complex16__lin_ga0c294a42b3a456d8a3308f8618612ac8.html#ga0c294a42b3a456d8a3308f8618612ac8":[0,1,1,3,90],
+"da/d0b/group__complex16__lin_ga0c294a42b3a456d8a3308f8618612ac8.html#ga0c294a42b3a456d8a3308f8618612ac8":[3,0,6,1,678,0],
 "da/d0b/group__complex16__lin_ga0ce7bb7fb30f3f354b818d2b494184e0.html#ga0ce7bb7fb30f3f354b818d2b494184e0":[0,1,1,3,190],
 "da/d0b/group__complex16__lin_ga0ce7bb7fb30f3f354b818d2b494184e0.html#ga0ce7bb7fb30f3f354b818d2b494184e0":[3,0,6,1,781,0],
 "da/d0b/group__complex16__lin_ga0d325cbc88970971a5673c0270522854.html#ga0d325cbc88970971a5673c0270522854":[0,1,1,3,154],
 "da/d0b/group__complex16__lin_ga0d325cbc88970971a5673c0270522854.html#ga0d325cbc88970971a5673c0270522854":[3,0,6,1,744,0],
-"da/d0b/group__complex16__lin_ga0d8f1484cb381a6248ce3ea09def8c47.html#ga0d8f1484cb381a6248ce3ea09def8c47":[3,0,6,1,590,0],
 "da/d0b/group__complex16__lin_ga0d8f1484cb381a6248ce3ea09def8c47.html#ga0d8f1484cb381a6248ce3ea09def8c47":[0,1,1,3,16],
+"da/d0b/group__complex16__lin_ga0d8f1484cb381a6248ce3ea09def8c47.html#ga0d8f1484cb381a6248ce3ea09def8c47":[3,0,6,1,590,0],
 "da/d0b/group__complex16__lin_ga0fdeafb50cbcccdea9de662332c04fa4.html#ga0fdeafb50cbcccdea9de662332c04fa4":[0,1,1,3,67],
 "da/d0b/group__complex16__lin_ga0fdeafb50cbcccdea9de662332c04fa4.html#ga0fdeafb50cbcccdea9de662332c04fa4":[3,0,6,1,648,0],
 "da/d0b/group__complex16__lin_ga133833da7f627d2fbe3f7592f89d12ec.html#ga133833da7f627d2fbe3f7592f89d12ec":[0,1,1,3,29],
 "da/d0b/group__complex16__lin_ga133833da7f627d2fbe3f7592f89d12ec.html#ga133833da7f627d2fbe3f7592f89d12ec":[3,0,6,1,603,0],
 "da/d0b/group__complex16__lin_ga1726c70221988e5ffd6cc9936d7987cd.html#ga1726c70221988e5ffd6cc9936d7987cd":[3,0,6,1,756,0],
 "da/d0b/group__complex16__lin_ga1726c70221988e5ffd6cc9936d7987cd.html#ga1726c70221988e5ffd6cc9936d7987cd":[0,1,1,3,166],
-"da/d0b/group__complex16__lin_ga17eb857b93d82c43fa9211c57359e5cb.html#ga17eb857b93d82c43fa9211c57359e5cb":[0,1,1,3,37],
 "da/d0b/group__complex16__lin_ga17eb857b93d82c43fa9211c57359e5cb.html#ga17eb857b93d82c43fa9211c57359e5cb":[3,0,6,1,612,0],
-"da/d0b/group__complex16__lin_ga18d7472059556852d8160b70d49a885e.html#ga18d7472059556852d8160b70d49a885e":[3,0,6,1,642,0],
-"da/d0b/group__complex16__lin_ga18d7472059556852d8160b70d49a885e.html#ga18d7472059556852d8160b70d49a885e":[0,1,1,3,58],
+"da/d0b/group__complex16__lin_ga17eb857b93d82c43fa9211c57359e5cb.html#ga17eb857b93d82c43fa9211c57359e5cb":[0,1,1,3,37],
 "da/d0b/group__complex16__lin_ga18d7472059556852d8160b70d49a885e.html#ga18d7472059556852d8160b70d49a885e":[3,0,6,1,637,0],
+"da/d0b/group__complex16__lin_ga18d7472059556852d8160b70d49a885e.html#ga18d7472059556852d8160b70d49a885e":[0,1,1,3,58],
+"da/d0b/group__complex16__lin_ga18d7472059556852d8160b70d49a885e.html#ga18d7472059556852d8160b70d49a885e":[3,0,6,1,642,0],
 "da/d0b/group__complex16__lin_ga19147017ea28c048ca6b1febe831e689.html#ga19147017ea28c048ca6b1febe831e689":[0,1,1,3,161],
 "da/d0b/group__complex16__lin_ga19147017ea28c048ca6b1febe831e689.html#ga19147017ea28c048ca6b1febe831e689":[3,0,6,1,751,0],
-"da/d0b/group__complex16__lin_ga1a83d0f19354b6504e079719a8b3c5e0.html#ga1a83d0f19354b6504e079719a8b3c5e0":[0,1,1,3,173],
 "da/d0b/group__complex16__lin_ga1a83d0f19354b6504e079719a8b3c5e0.html#ga1a83d0f19354b6504e079719a8b3c5e0":[3,0,6,1,763,0],
+"da/d0b/group__complex16__lin_ga1a83d0f19354b6504e079719a8b3c5e0.html#ga1a83d0f19354b6504e079719a8b3c5e0":[0,1,1,3,173],
 "da/d0b/group__complex16__lin_ga1df5aa34783d6231594835e0f8e2d35d.html#ga1df5aa34783d6231594835e0f8e2d35d":[3,0,6,1,606,0],
 "da/d0b/group__complex16__lin_ga1df5aa34783d6231594835e0f8e2d35d.html#ga1df5aa34783d6231594835e0f8e2d35d":[0,1,1,3,32],
 "da/d0b/group__complex16__lin_ga20022a8d9003ce2c4853d7f926d80c12.html#ga20022a8d9003ce2c4853d7f926d80c12":[3,0,6,1,709,0],
@@ -132,18 +131,18 @@ var NAVTREEINDEX77 =
 "da/d0b/group__complex16__lin_ga2049172c13429dc2d228133d63822449.html#ga2049172c13429dc2d228133d63822449":[3,0,6,1,649,0],
 "da/d0b/group__complex16__lin_ga2049172c13429dc2d228133d63822449.html#ga2049172c13429dc2d228133d63822449":[0,1,1,3,68],
 "da/d0b/group__complex16__lin_ga2049172c13429dc2d228133d63822449.html#ga2049172c13429dc2d228133d63822449":[3,0,6,1,650,0],
-"da/d0b/group__complex16__lin_ga21a23f83120cc66fe6e1e90c97bc5412.html#ga21a23f83120cc66fe6e1e90c97bc5412":[0,1,1,3,119],
 "da/d0b/group__complex16__lin_ga21a23f83120cc66fe6e1e90c97bc5412.html#ga21a23f83120cc66fe6e1e90c97bc5412":[3,0,6,1,707,0],
+"da/d0b/group__complex16__lin_ga21a23f83120cc66fe6e1e90c97bc5412.html#ga21a23f83120cc66fe6e1e90c97bc5412":[0,1,1,3,119],
 "da/d0b/group__complex16__lin_ga21bcdd5aac646c1d1485c53b82ca6dc4.html#ga21bcdd5aac646c1d1485c53b82ca6dc4":[0,1,1,3,118],
 "da/d0b/group__complex16__lin_ga21bcdd5aac646c1d1485c53b82ca6dc4.html#ga21bcdd5aac646c1d1485c53b82ca6dc4":[3,0,6,1,706,0],
 "da/d0b/group__complex16__lin_ga242870f68b9a2b6e44d0d0182924f9a3.html#ga242870f68b9a2b6e44d0d0182924f9a3":[0,1,1,3,171],
 "da/d0b/group__complex16__lin_ga242870f68b9a2b6e44d0d0182924f9a3.html#ga242870f68b9a2b6e44d0d0182924f9a3":[3,0,6,1,761,0],
 "da/d0b/group__complex16__lin_ga2494e654692b79e367a4c5cfcdb83ec7.html#ga2494e654692b79e367a4c5cfcdb83ec7":[0,1,1,3,114],
 "da/d0b/group__complex16__lin_ga2494e654692b79e367a4c5cfcdb83ec7.html#ga2494e654692b79e367a4c5cfcdb83ec7":[3,0,6,1,702,0],
-"da/d0b/group__complex16__lin_ga25109e0598738760709f81202f3fd7ce.html#ga25109e0598738760709f81202f3fd7ce":[3,0,6,1,572,0],
 "da/d0b/group__complex16__lin_ga25109e0598738760709f81202f3fd7ce.html#ga25109e0598738760709f81202f3fd7ce":[0,1,1,3,0],
-"da/d0b/group__complex16__lin_ga26fcf841c714a1ad6781cd252892f32b.html#ga26fcf841c714a1ad6781cd252892f32b":[0,1,1,3,146],
+"da/d0b/group__complex16__lin_ga25109e0598738760709f81202f3fd7ce.html#ga25109e0598738760709f81202f3fd7ce":[3,0,6,1,572,0],
 "da/d0b/group__complex16__lin_ga26fcf841c714a1ad6781cd252892f32b.html#ga26fcf841c714a1ad6781cd252892f32b":[3,0,6,1,736,0],
+"da/d0b/group__complex16__lin_ga26fcf841c714a1ad6781cd252892f32b.html#ga26fcf841c714a1ad6781cd252892f32b":[0,1,1,3,146],
 "da/d0b/group__complex16__lin_ga2728fb8c1a2c82e2e1b3a25a3178d666.html#ga2728fb8c1a2c82e2e1b3a25a3178d666":[0,1,1,3,122],
 "da/d0b/group__complex16__lin_ga2728fb8c1a2c82e2e1b3a25a3178d666.html#ga2728fb8c1a2c82e2e1b3a25a3178d666":[3,0,6,1,710,0],
 "da/d0b/group__complex16__lin_ga28c5999b94bcb2329f73db89500dc07f.html#ga28c5999b94bcb2329f73db89500dc07f":[0,1,1,3,78],
@@ -164,16 +163,16 @@ var NAVTREEINDEX77 =
 "da/d0b/group__complex16__lin_ga300ddc900d24cfb5370a648a85292d3a.html#ga300ddc900d24cfb5370a648a85292d3a":[3,0,6,1,729,0],
 "da/d0b/group__complex16__lin_ga318dc4b25035c0d0a9af021761890b4f.html#ga318dc4b25035c0d0a9af021761890b4f":[3,0,6,1,719,0],
 "da/d0b/group__complex16__lin_ga318dc4b25035c0d0a9af021761890b4f.html#ga318dc4b25035c0d0a9af021761890b4f":[0,1,1,3,129],
-"da/d0b/group__complex16__lin_ga32222e6b141ed4dead7eb2955de004b6.html#ga32222e6b141ed4dead7eb2955de004b6":[3,0,6,1,593,0],
 "da/d0b/group__complex16__lin_ga32222e6b141ed4dead7eb2955de004b6.html#ga32222e6b141ed4dead7eb2955de004b6":[0,1,1,3,19],
+"da/d0b/group__complex16__lin_ga32222e6b141ed4dead7eb2955de004b6.html#ga32222e6b141ed4dead7eb2955de004b6":[3,0,6,1,593,0],
 "da/d0b/group__complex16__lin_ga36a5116fd7b1d89e4f15688c65c5551d.html#ga36a5116fd7b1d89e4f15688c65c5551d":[3,0,6,1,768,0],
 "da/d0b/group__complex16__lin_ga36a5116fd7b1d89e4f15688c65c5551d.html#ga36a5116fd7b1d89e4f15688c65c5551d":[0,1,1,3,178],
 "da/d0b/group__complex16__lin_ga389ba329fb6b7b36c0dfc00c310f8a24.html#ga389ba329fb6b7b36c0dfc00c310f8a24":[3,0,6,1,680,0],
 "da/d0b/group__complex16__lin_ga389ba329fb6b7b36c0dfc00c310f8a24.html#ga389ba329fb6b7b36c0dfc00c310f8a24":[0,1,1,3,92],
-"da/d0b/group__complex16__lin_ga3923aca089a56be98bd3954ef9b35e25.html#ga3923aca089a56be98bd3954ef9b35e25":[0,1,1,3,158],
 "da/d0b/group__complex16__lin_ga3923aca089a56be98bd3954ef9b35e25.html#ga3923aca089a56be98bd3954ef9b35e25":[3,0,6,1,748,0],
-"da/d0b/group__complex16__lin_ga39c5dd459cba9d2c8dff8a69e18da609.html#ga39c5dd459cba9d2c8dff8a69e18da609":[0,1,1,3,69],
+"da/d0b/group__complex16__lin_ga3923aca089a56be98bd3954ef9b35e25.html#ga3923aca089a56be98bd3954ef9b35e25":[0,1,1,3,158],
 "da/d0b/group__complex16__lin_ga39c5dd459cba9d2c8dff8a69e18da609.html#ga39c5dd459cba9d2c8dff8a69e18da609":[3,0,6,1,651,0],
+"da/d0b/group__complex16__lin_ga39c5dd459cba9d2c8dff8a69e18da609.html#ga39c5dd459cba9d2c8dff8a69e18da609":[0,1,1,3,69],
 "da/d0b/group__complex16__lin_ga3d55441f4aa7be616d35cea3f4a95ac7.html#ga3d55441f4aa7be616d35cea3f4a95ac7":[0,1,1,3,168],
 "da/d0b/group__complex16__lin_ga3d55441f4aa7be616d35cea3f4a95ac7.html#ga3d55441f4aa7be616d35cea3f4a95ac7":[3,0,6,1,758,0],
 "da/d0b/group__complex16__lin_ga3e903a24ec934049b72e6d83c8dfcbe6.html#ga3e903a24ec934049b72e6d83c8dfcbe6":[0,1,1,3,189],
@@ -184,42 +183,42 @@ var NAVTREEINDEX77 =
 "da/d0b/group__complex16__lin_ga3f3806a102b68ce47af8fee0c5fbf3a0.html#ga3f3806a102b68ce47af8fee0c5fbf3a0":[3,0,6,1,643,0],
 "da/d0b/group__complex16__lin_ga413921e3029c9feeeb8663929fa873da.html#ga413921e3029c9feeeb8663929fa873da":[0,1,1,3,102],
 "da/d0b/group__complex16__lin_ga413921e3029c9feeeb8663929fa873da.html#ga413921e3029c9feeeb8663929fa873da":[3,0,6,1,690,0],
-"da/d0b/group__complex16__lin_ga4320e5032c699ad967cec7368d2f680b.html#ga4320e5032c699ad967cec7368d2f680b":[3,0,6,1,675,0],
 "da/d0b/group__complex16__lin_ga4320e5032c699ad967cec7368d2f680b.html#ga4320e5032c699ad967cec7368d2f680b":[0,1,1,3,87],
+"da/d0b/group__complex16__lin_ga4320e5032c699ad967cec7368d2f680b.html#ga4320e5032c699ad967cec7368d2f680b":[3,0,6,1,675,0],
 "da/d0b/group__complex16__lin_ga43d103e2ff555e377504128efe9220a1.html#ga43d103e2ff555e377504128efe9220a1":[0,1,1,3,50],
 "da/d0b/group__complex16__lin_ga43d103e2ff555e377504128efe9220a1.html#ga43d103e2ff555e377504128efe9220a1":[3,0,6,1,629,0],
 "da/d0b/group__complex16__lin_ga46d62d752089745257463056e41a8ef0.html#ga46d62d752089745257463056e41a8ef0":[0,1,1,3,55],
 "da/d0b/group__complex16__lin_ga46d62d752089745257463056e41a8ef0.html#ga46d62d752089745257463056e41a8ef0":[3,0,6,1,634,0],
-"da/d0b/group__complex16__lin_ga46df602571824842eac873f7e1e4bacf.html#ga46df602571824842eac873f7e1e4bacf":[0,1,1,3,77],
 "da/d0b/group__complex16__lin_ga46df602571824842eac873f7e1e4bacf.html#ga46df602571824842eac873f7e1e4bacf":[3,0,6,1,662,0],
-"da/d0b/group__complex16__lin_ga47bf3369481a967271fcd380d5261926.html#ga47bf3369481a967271fcd380d5261926":[3,0,6,1,671,0],
+"da/d0b/group__complex16__lin_ga46df602571824842eac873f7e1e4bacf.html#ga46df602571824842eac873f7e1e4bacf":[0,1,1,3,77],
 "da/d0b/group__complex16__lin_ga47bf3369481a967271fcd380d5261926.html#ga47bf3369481a967271fcd380d5261926":[0,1,1,3,84],
+"da/d0b/group__complex16__lin_ga47bf3369481a967271fcd380d5261926.html#ga47bf3369481a967271fcd380d5261926":[3,0,6,1,671,0],
 "da/d0b/group__complex16__lin_ga47bf3369481a967271fcd380d5261926.html#ga47bf3369481a967271fcd380d5261926":[3,0,6,1,672,0],
-"da/d0b/group__complex16__lin_ga48582705f728291055c10605e86b6b00.html#ga48582705f728291055c10605e86b6b00":[3,0,6,1,636,0],
 "da/d0b/group__complex16__lin_ga48582705f728291055c10605e86b6b00.html#ga48582705f728291055c10605e86b6b00":[0,1,1,3,57],
+"da/d0b/group__complex16__lin_ga48582705f728291055c10605e86b6b00.html#ga48582705f728291055c10605e86b6b00":[3,0,6,1,636,0],
 "da/d0b/group__complex16__lin_ga4b67e894aaa9446001baffcf8bd1ee3e.html#ga4b67e894aaa9446001baffcf8bd1ee3e":[0,1,1,3,152],
 "da/d0b/group__complex16__lin_ga4b67e894aaa9446001baffcf8bd1ee3e.html#ga4b67e894aaa9446001baffcf8bd1ee3e":[3,0,6,1,742,0],
 "da/d0b/group__complex16__lin_ga4b7585cc98106e8f34e416519b8de353.html#ga4b7585cc98106e8f34e416519b8de353":[0,1,1,3,72],
 "da/d0b/group__complex16__lin_ga4b7585cc98106e8f34e416519b8de353.html#ga4b7585cc98106e8f34e416519b8de353":[3,0,6,1,657,0],
 "da/d0b/group__complex16__lin_ga4bd01f25f215673bd12964dadced5dc5.html#ga4bd01f25f215673bd12964dadced5dc5":[0,1,1,3,162],
 "da/d0b/group__complex16__lin_ga4bd01f25f215673bd12964dadced5dc5.html#ga4bd01f25f215673bd12964dadced5dc5":[3,0,6,1,752,0],
-"da/d0b/group__complex16__lin_ga4cc0ba067dc31156572387f8ee82cd98.html#ga4cc0ba067dc31156572387f8ee82cd98":[3,0,6,1,733,0],
 "da/d0b/group__complex16__lin_ga4cc0ba067dc31156572387f8ee82cd98.html#ga4cc0ba067dc31156572387f8ee82cd98":[0,1,1,3,143],
+"da/d0b/group__complex16__lin_ga4cc0ba067dc31156572387f8ee82cd98.html#ga4cc0ba067dc31156572387f8ee82cd98":[3,0,6,1,733,0],
 "da/d0b/group__complex16__lin_ga4db56cc9cdd85da19098aedac161c6c3.html#ga4db56cc9cdd85da19098aedac161c6c3":[3,0,6,1,689,0],
 "da/d0b/group__complex16__lin_ga4db56cc9cdd85da19098aedac161c6c3.html#ga4db56cc9cdd85da19098aedac161c6c3":[0,1,1,3,101],
 "da/d0b/group__complex16__lin_ga5009236de87a2dccfca9a6de334feb1e.html#ga5009236de87a2dccfca9a6de334feb1e":[0,1,1,3,149],
 "da/d0b/group__complex16__lin_ga5009236de87a2dccfca9a6de334feb1e.html#ga5009236de87a2dccfca9a6de334feb1e":[3,0,6,1,739,0],
 "da/d0b/group__complex16__lin_ga517b2a3d5a1aaa88452df114ca216c1e.html#ga517b2a3d5a1aaa88452df114ca216c1e":[0,1,1,3,39],
-"da/d0b/group__complex16__lin_ga517b2a3d5a1aaa88452df114ca216c1e.html#ga517b2a3d5a1aaa88452df114ca216c1e":[3,0,6,1,615,0],
 "da/d0b/group__complex16__lin_ga517b2a3d5a1aaa88452df114ca216c1e.html#ga517b2a3d5a1aaa88452df114ca216c1e":[3,0,6,1,616,0],
+"da/d0b/group__complex16__lin_ga517b2a3d5a1aaa88452df114ca216c1e.html#ga517b2a3d5a1aaa88452df114ca216c1e":[3,0,6,1,615,0],
 "da/d0b/group__complex16__lin_ga53e3ebc0f47d199b12a87fb375f56a19.html#ga53e3ebc0f47d199b12a87fb375f56a19":[0,1,1,3,98],
 "da/d0b/group__complex16__lin_ga53e3ebc0f47d199b12a87fb375f56a19.html#ga53e3ebc0f47d199b12a87fb375f56a19":[3,0,6,1,686,0],
 "da/d0b/group__complex16__lin_ga53ebf71b58cf35b308955e1ca4a82fa2.html#ga53ebf71b58cf35b308955e1ca4a82fa2":[3,0,6,1,764,0],
 "da/d0b/group__complex16__lin_ga53ebf71b58cf35b308955e1ca4a82fa2.html#ga53ebf71b58cf35b308955e1ca4a82fa2":[0,1,1,3,174],
 "da/d0b/group__complex16__lin_ga540d078adc1358e618132670f1bee892.html#ga540d078adc1358e618132670f1bee892":[0,1,1,3,96],
 "da/d0b/group__complex16__lin_ga540d078adc1358e618132670f1bee892.html#ga540d078adc1358e618132670f1bee892":[3,0,6,1,684,0],
-"da/d0b/group__complex16__lin_ga54c4ed4d0acdb6353a6c2aebfe3be0ef.html#ga54c4ed4d0acdb6353a6c2aebfe3be0ef":[3,0,6,1,595,0],
 "da/d0b/group__complex16__lin_ga54c4ed4d0acdb6353a6c2aebfe3be0ef.html#ga54c4ed4d0acdb6353a6c2aebfe3be0ef":[0,1,1,3,21],
+"da/d0b/group__complex16__lin_ga54c4ed4d0acdb6353a6c2aebfe3be0ef.html#ga54c4ed4d0acdb6353a6c2aebfe3be0ef":[3,0,6,1,595,0],
 "da/d0b/group__complex16__lin_ga56c9d78521095c6480bbb925c269ecc0.html#ga56c9d78521095c6480bbb925c269ecc0":[0,1,1,3,51],
 "da/d0b/group__complex16__lin_ga56c9d78521095c6480bbb925c269ecc0.html#ga56c9d78521095c6480bbb925c269ecc0":[3,0,6,1,630,0],
 "da/d0b/group__complex16__lin_ga56e04460a51baee5bf4cd2ae7588bc2c.html#ga56e04460a51baee5bf4cd2ae7588bc2c":[0,1,1,3,56],
@@ -249,5 +248,6 @@ var NAVTREEINDEX77 =
 "da/d0b/group__complex16__lin_ga64f700e8682490333d41b9afb0728e36.html#ga64f700e8682490333d41b9afb0728e36":[3,0,6,1,737,0],
 "da/d0b/group__complex16__lin_ga64f700e8682490333d41b9afb0728e36.html#ga64f700e8682490333d41b9afb0728e36":[0,1,1,3,147],
 "da/d0b/group__complex16__lin_ga666cbbea4ef0e9e26467ed912e950288.html#ga666cbbea4ef0e9e26467ed912e950288":[0,1,1,3,7],
-"da/d0b/group__complex16__lin_ga666cbbea4ef0e9e26467ed912e950288.html#ga666cbbea4ef0e9e26467ed912e950288":[3,0,6,1,579,0]
+"da/d0b/group__complex16__lin_ga666cbbea4ef0e9e26467ed912e950288.html#ga666cbbea4ef0e9e26467ed912e950288":[3,0,6,1,579,0],
+"da/d0b/group__complex16__lin_ga66b4060d0db57474ba432cdcebbb8f27.html#ga66b4060d0db57474ba432cdcebbb8f27":[0,1,1,3,140]
 };
