@@ -1,6 +1,5 @@
 var NAVTREEINDEX83 =
 {
-"da/d8e/lapacke__utils_8h_a21e1e2f15ce0995e9bcda13cdf93f603.html#a21e1e2f15ce0995e9bcda13cdf93f603":[3,0,4,1,3,23],
 "da/d8e/lapacke__utils_8h_a2850ba9f786d34a2b9d30f51db4285e8.html#a2850ba9f786d34a2b9d30f51db4285e8":[3,0,4,1,3,39],
 "da/d8e/lapacke__utils_8h_a2b48c1d2944f756d8d29b40f97287bc6.html#a2b48c1d2944f756d8d29b40f97287bc6":[3,0,4,1,3,71],
 "da/d8e/lapacke__utils_8h_a2fb7e26f3586bb1a302c4d26bba07448.html#a2fb7e26f3586bb1a302c4d26bba07448":[3,0,4,1,3,103],
@@ -168,8 +167,8 @@ var NAVTREEINDEX83 =
 "da/d94/group__complex_g_tcomputational.html":[0,0,5,1,2],
 "da/d94/group__complex_g_tcomputational_ga74d1d5397dae5f211149667ea29c36b9.html#ga74d1d5397dae5f211149667ea29c36b9":[0,0,5,1,2,2],
 "da/d94/group__complex_g_tcomputational_ga74d1d5397dae5f211149667ea29c36b9.html#ga74d1d5397dae5f211149667ea29c36b9":[3,0,5,97,0],
-"da/d94/group__complex_g_tcomputational_ga8f80227b32b600dc75a5e982005ec1c2.html#ga8f80227b32b600dc75a5e982005ec1c2":[0,0,5,1,2,0],
 "da/d94/group__complex_g_tcomputational_ga8f80227b32b600dc75a5e982005ec1c2.html#ga8f80227b32b600dc75a5e982005ec1c2":[3,0,5,93,0],
+"da/d94/group__complex_g_tcomputational_ga8f80227b32b600dc75a5e982005ec1c2.html#ga8f80227b32b600dc75a5e982005ec1c2":[0,0,5,1,2,0],
 "da/d94/group__complex_g_tcomputational_ga92eec53c6ac6c6285a10e7d05d9c00d5.html#ga92eec53c6ac6c6285a10e7d05d9c00d5":[3,0,5,94,0],
 "da/d94/group__complex_g_tcomputational_ga92eec53c6ac6c6285a10e7d05d9c00d5.html#ga92eec53c6ac6c6285a10e7d05d9c00d5":[0,0,5,1,2,1],
 "da/d94/group__complex_g_tcomputational_gab3cb48a1dae8355cc937e9c97ac5ded0.html#gab3cb48a1dae8355cc937e9c97ac5ded0":[3,0,5,99,0],
@@ -180,8 +179,8 @@ var NAVTREEINDEX83 =
 "da/d94/zlahrd_8f_source.html":[3,0,5,0,33],
 "da/d94/zlavhe__rook_8f.html":[3,0,6,1,707],
 "da/d94/zlavhe__rook_8f_source.html":[3,0,6,1,707],
-"da/d94/zsytrf_8f.html":[3,0,5,1923],
-"da/d94/zsytrf_8f_source.html":[3,0,5,1923],
+"da/d94/zsytrf_8f.html":[3,0,5,1921],
+"da/d94/zsytrf_8f_source.html":[3,0,5,1921],
 "da/d95/cgbrfsx_8f.html":[3,0,5,9],
 "da/d95/cgbrfsx_8f_source.html":[3,0,5,9],
 "da/d96/cerrsyx_8f.html":[3,0,6,1,96],
@@ -193,16 +192,16 @@ var NAVTREEINDEX83 =
 "da/d97/lapacke__dormtr__work_8c_source.html":[3,0,4,3,925],
 "da/d98/sdrvls_8f.html":[3,0,6,1,432],
 "da/d98/sdrvls_8f_source.html":[3,0,6,1,432],
-"da/d99/zsprfs_8f.html":[3,0,5,1890],
-"da/d99/zsprfs_8f_source.html":[3,0,5,1890],
+"da/d99/zsprfs_8f.html":[3,0,5,1888],
+"da/d99/zsprfs_8f_source.html":[3,0,5,1888],
 "da/d9b/_cintface_8c.html":[3,0,4,2,0],
 "da/d9b/_cintface_8c_a4a3ad144d505252637f3347504c998a0.html#a4a3ad144d505252637f3347504c998a0":[3,0,4,2,0,2],
 "da/d9b/_cintface_8c_a6259ea61712e34e7c7781485c260d8c2.html#a6259ea61712e34e7c7781485c260d8c2":[3,0,4,2,0,1],
 "da/d9b/_cintface_8c_aa116148e717b4724c32e67cd86e1e32a.html#aa116148e717b4724c32e67cd86e1e32a":[3,0,4,2,0,0],
 "da/d9b/_cintface_8c_aec48cfd9e54e2ec992c5a1f85af630e9.html#aec48cfd9e54e2ec992c5a1f85af630e9":[3,0,4,2,0,3],
 "da/d9b/_cintface_8c_source.html":[3,0,4,2,0],
-"da/d9b/dgeqr2p_8f.html":[3,0,5,550],
-"da/d9b/dgeqr2p_8f_source.html":[3,0,5,550],
+"da/d9b/dgeqr2p_8f.html":[3,0,5,549],
+"da/d9b/dgeqr2p_8f_source.html":[3,0,5,549],
 "da/d9b/group__single__blas__testing.html":[0,2,4,0],
 "da/d9b/group__single__blas__testing_ga69200e45d128ffb1e3014de8845f3933.html#ga69200e45d128ffb1e3014de8845f3933":[3,0,0,1,7,4],
 "da/d9b/group__single__blas__testing_ga69200e45d128ffb1e3014de8845f3933.html#ga69200e45d128ffb1e3014de8845f3933":[0,2,4,0,1],
@@ -210,10 +209,10 @@ var NAVTREEINDEX83 =
 "da/d9b/group__single__blas__testing_gaed614e5d25dd65001fae0671947d4b3c.html#gaed614e5d25dd65001fae0671947d4b3c":[0,2,4,0,0],
 "da/d9b/group__single__blas__testing_gaeec1d20ed538f1a0d9a200b8c8747fd2.html#gaeec1d20ed538f1a0d9a200b8c8747fd2":[3,0,0,1,8,4],
 "da/d9b/group__single__blas__testing_gaeec1d20ed538f1a0d9a200b8c8747fd2.html#gaeec1d20ed538f1a0d9a200b8c8747fd2":[0,2,4,0,2],
-"da/d9b/zlabrd_8f.html":[3,0,5,1732],
-"da/d9b/zlabrd_8f_source.html":[3,0,5,1732],
-"da/d9d/dgeequ_8f.html":[3,0,5,523],
-"da/d9d/dgeequ_8f_source.html":[3,0,5,523],
+"da/d9b/zlabrd_8f.html":[3,0,5,1730],
+"da/d9b/zlabrd_8f_source.html":[3,0,5,1730],
+"da/d9d/dgeequ_8f.html":[3,0,5,522],
+"da/d9d/dgeequ_8f_source.html":[3,0,5,522],
 "da/d9d/lapacke__sgeqrt2__work_8c.html":[3,0,4,3,1334],
 "da/d9d/lapacke__sgeqrt2__work_8c_af63cdc671439acf9bce398a9f03c39d4.html#af63cdc671439acf9bce398a9f03c39d4":[3,0,4,3,1334,0],
 "da/d9d/lapacke__sgeqrt2__work_8c_source.html":[3,0,4,3,1334],
@@ -221,11 +220,11 @@ var NAVTREEINDEX83 =
 "da/d9e/serrlqtp_8f_source.html":[3,0,6,1,456],
 "da/d9f/cblas__sgbmv_8c.html":[3,0,1,2,81],
 "da/d9f/cblas__sgbmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,81,0],
+"da/d9f/cblas__sgbmv_8c_a1bda6cca634c37dcbe6e87fe8db3b0a9.html#a1bda6cca634c37dcbe6e87fe8db3b0a9":[3,0,1,2,81,8],
 "da/d9f/cblas__sgbmv_8c_a29ba8bdd334215dc3b4217c4959d2649.html#a29ba8bdd334215dc3b4217c4959d2649":[3,0,1,2,81,3],
 "da/d9f/cblas__sgbmv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,81,1],
 "da/d9f/cblas__sgbmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,81,7],
 "da/d9f/cblas__sgbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,81,6],
-"da/d9f/cblas__sgbmv_8c_a7e26d93c1d46b7efe292f872e64c7649.html#a7e26d93c1d46b7efe292f872e64c7649":[3,0,1,2,81,8],
 "da/d9f/cblas__sgbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,81,4],
 "da/d9f/cblas__sgbmv_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,81,5],
 "da/d9f/cblas__sgbmv_8c_ae807ea950f545d041c6bcc92187e1f10.html#ae807ea950f545d041c6bcc92187e1f10":[3,0,1,2,81,2],
@@ -246,8 +245,9 @@ var NAVTREEINDEX83 =
 "da/d9f/sgbt05_8f_source.html":[3,0,6,1,478],
 "da/d9f/sspt21_8f.html":[3,0,6,0,267],
 "da/d9f/sspt21_8f_source.html":[3,0,6,0,267],
-"da/da2/dorbdb1_8f.html":[3,0,5,780],
-"da/da2/dorbdb1_8f_source.html":[3,0,5,780],
+"da/da2/dorbdb1_8f.html":[3,0,5,779],
+"da/da2/dorbdb1_8f_source.html":[3,0,5,779],
 "da/da2/lapacke__dlaswp_8c.html":[3,0,4,3,878],
-"da/da2/lapacke__dlaswp_8c_a6ffca7082560c6858f8e11698217dc32.html#a6ffca7082560c6858f8e11698217dc32":[3,0,4,3,878,0]
+"da/da2/lapacke__dlaswp_8c_a6ffca7082560c6858f8e11698217dc32.html#a6ffca7082560c6858f8e11698217dc32":[3,0,4,3,878,0],
+"da/da2/lapacke__dlaswp_8c_source.html":[3,0,4,3,878]
 };
