@@ -1,25 +1,24 @@
 var NAVTREEINDEX87 =
 {
-"da/dff/group__complex_s_ycomputational_gabb66fb23be3a7311b71271a2717b35eb.html#gabb66fb23be3a7311b71271a2717b35eb":[0,0,2,2,2,0],
 "da/dff/group__complex_s_ycomputational_gabb66fb23be3a7311b71271a2717b35eb.html#gabb66fb23be3a7311b71271a2717b35eb":[3,0,5,134,0],
-"da/dff/group__complex_s_ycomputational_gabce9144e260f297b4424e543a9a263ec.html#gabce9144e260f297b4424e543a9a263ec":[3,0,5,385,0],
 "da/dff/group__complex_s_ycomputational_gabce9144e260f297b4424e543a9a263ec.html#gabce9144e260f297b4424e543a9a263ec":[0,0,2,2,2,18],
+"da/dff/group__complex_s_ycomputational_gabce9144e260f297b4424e543a9a263ec.html#gabce9144e260f297b4424e543a9a263ec":[3,0,5,385,0],
 "da/dff/group__complex_s_ycomputational_gabd38670b8caa9c8b2f0be9f0a7c14e38.html#gabd38670b8caa9c8b2f0be9f0a7c14e38":[0,0,2,2,2,37],
 "da/dff/group__complex_s_ycomputational_gabd38670b8caa9c8b2f0be9f0a7c14e38.html#gabd38670b8caa9c8b2f0be9f0a7c14e38":[3,0,5,413,0],
 "da/dff/group__complex_s_ycomputational_gacd5839d735315079d2ecc8afc9402352.html#gacd5839d735315079d2ecc8afc9402352":[0,0,2,2,2,26],
 "da/dff/group__complex_s_ycomputational_gacd5839d735315079d2ecc8afc9402352.html#gacd5839d735315079d2ecc8afc9402352":[3,0,5,402,0],
 "da/dff/group__complex_s_ycomputational_gad484921e85594add6d0df79cced0a0d4.html#gad484921e85594add6d0df79cced0a0d4":[0,0,2,2,2,2],
 "da/dff/group__complex_s_ycomputational_gad484921e85594add6d0df79cced0a0d4.html#gad484921e85594add6d0df79cced0a0d4":[3,0,5,163,0],
-"da/dff/group__complex_s_ycomputational_gad885e99b62087bfc142f1ca6e51f6941.html#gad885e99b62087bfc142f1ca6e51f6941":[3,0,5,409,0],
 "da/dff/group__complex_s_ycomputational_gad885e99b62087bfc142f1ca6e51f6941.html#gad885e99b62087bfc142f1ca6e51f6941":[0,0,2,2,2,33],
-"da/dff/group__complex_s_ycomputational_gad8ebf2778aa871f9f2efc3cea43af789.html#gad8ebf2778aa871f9f2efc3cea43af789":[3,0,5,405,0],
+"da/dff/group__complex_s_ycomputational_gad885e99b62087bfc142f1ca6e51f6941.html#gad885e99b62087bfc142f1ca6e51f6941":[3,0,5,409,0],
 "da/dff/group__complex_s_ycomputational_gad8ebf2778aa871f9f2efc3cea43af789.html#gad8ebf2778aa871f9f2efc3cea43af789":[0,0,2,2,2,29],
+"da/dff/group__complex_s_ycomputational_gad8ebf2778aa871f9f2efc3cea43af789.html#gad8ebf2778aa871f9f2efc3cea43af789":[3,0,5,405,0],
 "da/dff/group__complex_s_ycomputational_gaddedc7be67d858405bb3bbdd98b779b6.html#gaddedc7be67d858405bb3bbdd98b779b6":[0,0,2,2,2,17],
 "da/dff/group__complex_s_ycomputational_gaddedc7be67d858405bb3bbdd98b779b6.html#gaddedc7be67d858405bb3bbdd98b779b6":[3,0,5,384,0],
-"da/dff/group__complex_s_ycomputational_gaef7add4f653067c9b3e44569e6766d95.html#gaef7add4f653067c9b3e44569e6766d95":[0,0,2,2,2,43],
 "da/dff/group__complex_s_ycomputational_gaef7add4f653067c9b3e44569e6766d95.html#gaef7add4f653067c9b3e44569e6766d95":[3,0,5,433,0],
-"da/dff/group__complex_s_ycomputational_gaf000d2b89e57201eeb048c5ba949039b.html#gaf000d2b89e57201eeb048c5ba949039b":[0,0,2,2,2,8],
+"da/dff/group__complex_s_ycomputational_gaef7add4f653067c9b3e44569e6766d95.html#gaef7add4f653067c9b3e44569e6766d95":[0,0,2,2,2,43],
 "da/dff/group__complex_s_ycomputational_gaf000d2b89e57201eeb048c5ba949039b.html#gaf000d2b89e57201eeb048c5ba949039b":[3,0,5,230,0],
+"da/dff/group__complex_s_ycomputational_gaf000d2b89e57201eeb048c5ba949039b.html#gaf000d2b89e57201eeb048c5ba949039b":[0,0,2,2,2,8],
 "da/dff/group__complex_s_ycomputational_gaf114d2ed6bf289689ae829559cb7c1e2.html#gaf114d2ed6bf289689ae829559cb7c1e2":[0,0,2,2,2,41],
 "da/dff/group__complex_s_ycomputational_gaf114d2ed6bf289689ae829559cb7c1e2.html#gaf114d2ed6bf289689ae829559cb7c1e2":[3,0,5,417,0],
 "da/dff/group__complex_s_ycomputational_gafb343bb24f1cd1459070aeff219956ad.html#gafb343bb24f1cd1459070aeff219956ad":[3,0,5,412,0],
@@ -61,11 +60,11 @@ var NAVTREEINDEX87 =
 "db/d0b/cblas__saxpy_8c.html":[3,0,1,2,75],
 "db/d0b/cblas__saxpy_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,75,0],
 "db/d0b/cblas__saxpy_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,75,1],
+"db/d0b/cblas__saxpy_8c_a785b8977d02b5e78bde6a1a1327df766.html#a785b8977d02b5e78bde6a1a1327df766":[3,0,1,2,75,3],
 "db/d0b/cblas__saxpy_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,75,2],
-"db/d0b/cblas__saxpy_8c_ab3cb382c4b23db7c80bd5cc3b3ca8897.html#ab3cb382c4b23db7c80bd5cc3b3ca8897":[3,0,1,2,75,3],
 "db/d0b/cblas__saxpy_8c_source.html":[3,0,1,2,75],
-"db/d0b/zhbevx_8f.html":[3,0,5,1627],
-"db/d0b/zhbevx_8f_source.html":[3,0,5,1627],
+"db/d0b/zhbevx_8f.html":[3,0,5,1625],
+"db/d0b/zhbevx_8f_source.html":[3,0,5,1625],
 "db/d0d/dlatm3_8f.html":[3,0,6,2,29],
 "db/d0d/dlatm3_8f_source.html":[3,0,6,2,29],
 "db/d0d/lapacke__cpftri_8c.html":[3,0,4,3,388],
@@ -90,8 +89,8 @@ var NAVTREEINDEX87 =
 "db/d0f/lapacke__spteqr_8c.html":[3,0,4,3,1590],
 "db/d0f/lapacke__spteqr_8c_aa98172c092c3db3fa1fb24dd2fc53e80.html#aa98172c092c3db3fa1fb24dd2fc53e80":[3,0,4,3,1590,0],
 "db/d0f/lapacke__spteqr_8c_source.html":[3,0,4,3,1590],
-"db/d10/dlarfx_8f.html":[3,0,5,711],
-"db/d10/dlarfx_8f_source.html":[3,0,5,711],
+"db/d10/dlarfx_8f.html":[3,0,5,710],
+"db/d10/dlarfx_8f_source.html":[3,0,5,710],
 "db/d10/lapacke__ztrrfs_8c.html":[3,0,4,3,2422],
 "db/d10/lapacke__ztrrfs_8c_a2bf0e60a8cf3ed939e143f8d8da44f03.html#a2bf0e60a8cf3ed939e143f8d8da44f03":[3,0,4,3,2422,0],
 "db/d10/lapacke__ztrrfs_8c_source.html":[3,0,4,3,2422],
@@ -106,8 +105,8 @@ var NAVTREEINDEX87 =
 "db/d12/lapacke__slaswp_8c.html":[3,0,4,3,1476],
 "db/d12/lapacke__slaswp_8c_a7917769add4bb9b39364808d88ebfb81.html#a7917769add4bb9b39364808d88ebfb81":[3,0,4,3,1476,0],
 "db/d12/lapacke__slaswp_8c_source.html":[3,0,4,3,1476],
-"db/d12/zgtcon_8f.html":[3,0,5,1615],
-"db/d12/zgtcon_8f_source.html":[3,0,5,1615],
+"db/d12/zgtcon_8f.html":[3,0,5,1613],
+"db/d12/zgtcon_8f_source.html":[3,0,5,1613],
 "db/d14/lapacke__zhetrf__aa__work_8c.html":[3,0,4,3,2090],
 "db/d14/lapacke__zhetrf__aa__work_8c_a5dd0b02f1bbf3cb84b5b4e2397cd5244.html#a5dd0b02f1bbf3cb84b5b4e2397cd5244":[3,0,4,3,2090,0],
 "db/d14/lapacke__zhetrf__aa__work_8c_source.html":[3,0,4,3,2090],
@@ -119,8 +118,8 @@ var NAVTREEINDEX87 =
 "db/d15/lapacke__csytrf__aa__2stage_8c_source.html":[3,0,4,3,504],
 "db/d15/serrvxx_8f.html":[3,0,6,1,475],
 "db/d15/serrvxx_8f_source.html":[3,0,6,1,475],
-"db/d15/sstev_8f.html":[3,0,5,1417],
-"db/d15/sstev_8f_source.html":[3,0,5,1417],
+"db/d15/sstev_8f.html":[3,0,5,1415],
+"db/d15/sstev_8f_source.html":[3,0,5,1415],
 "db/d16/cgelqt_8f.html":[3,0,5,33],
 "db/d16/cgelqt_8f_source.html":[3,0,5,33],
 "db/d16/lapacke__dgeqp3__work_8c.html":[3,0,4,3,723],
@@ -161,17 +160,17 @@ var NAVTREEINDEX87 =
 "db/d1f/lapacke__zhbgvd__work_8c.html":[3,0,4,3,2029],
 "db/d1f/lapacke__zhbgvd__work_8c_a8ad6f28775b910479fd50a9f837a3555.html#a8ad6f28775b910479fd50a9f837a3555":[3,0,4,3,2029,0],
 "db/d1f/lapacke__zhbgvd__work_8c_source.html":[3,0,4,3,2029],
-"db/d20/dlaed5_8f.html":[3,0,5,636],
-"db/d20/dlaed5_8f_source.html":[3,0,5,636],
+"db/d20/dlaed5_8f.html":[3,0,5,635],
+"db/d20/dlaed5_8f_source.html":[3,0,5,635],
 "db/d20/lapacke__zheswapr_8c.html":[3,0,4,3,2082],
 "db/d20/lapacke__zheswapr_8c_acbabb2f49471670f0e8a8b2776f6f29e.html#acbabb2f49471670f0e8a8b2776f6f29e":[3,0,4,3,2082,0],
 "db/d20/lapacke__zheswapr_8c_source.html":[3,0,4,3,2082],
-"db/d21/zlacrm_8f.html":[3,0,5,1738],
-"db/d21/zlacrm_8f_source.html":[3,0,5,1738],
-"db/d21/zlapmt_8f.html":[3,0,5,1779],
-"db/d21/zlapmt_8f_source.html":[3,0,5,1779],
-"db/d22/zlacn2_8f.html":[3,0,5,1734],
-"db/d22/zlacn2_8f_source.html":[3,0,5,1734],
+"db/d21/zlacrm_8f.html":[3,0,5,1736],
+"db/d21/zlacrm_8f_source.html":[3,0,5,1736],
+"db/d21/zlapmt_8f.html":[3,0,5,1777],
+"db/d21/zlapmt_8f_source.html":[3,0,5,1777],
+"db/d22/zlacn2_8f.html":[3,0,5,1732],
+"db/d22/zlacn2_8f_source.html":[3,0,5,1732],
 "db/d23/c__sblas3_8c.html":[3,0,1,3,21],
 "db/d23/c__sblas3_8c_a2ada8c3b3bc4809dd85829998a58dca2.html#a2ada8c3b3bc4809dd85829998a58dca2":[3,0,1,3,21,2],
 "db/d23/c__sblas3_8c_a4615dde839bf319bcdb0166e061c9379.html#a4615dde839bf319bcdb0166e061c9379":[3,0,1,3,21,0],
@@ -183,30 +182,30 @@ var NAVTREEINDEX87 =
 "db/d23/lapacke__stgsyl_8c.html":[3,0,4,3,1788],
 "db/d23/lapacke__stgsyl_8c_afb69ce4ee080572d725375a79887d186.html#afb69ce4ee080572d725375a79887d186":[3,0,4,3,1788,0],
 "db/d23/lapacke__stgsyl_8c_source.html":[3,0,4,3,1788],
-"db/d23/sgtcon_8f.html":[3,0,5,1118],
-"db/d23/sgtcon_8f_source.html":[3,0,5,1118],
-"db/d26/spotri_8f.html":[3,0,5,1361],
-"db/d26/spotri_8f_source.html":[3,0,5,1361],
-"db/d27/zhecon__rook_8f.html":[3,0,5,1636],
-"db/d27/zhecon__rook_8f_source.html":[3,0,5,1636],
-"db/d28/zgetsls_8f.html":[3,0,5,1595],
-"db/d28/zgetsls_8f_source.html":[3,0,5,1595],
-"db/d28/zsytrf__rk_8f.html":[3,0,5,1926],
-"db/d28/zsytrf__rk_8f_source.html":[3,0,5,1926],
+"db/d23/sgtcon_8f.html":[3,0,5,1116],
+"db/d23/sgtcon_8f_source.html":[3,0,5,1116],
+"db/d26/spotri_8f.html":[3,0,5,1359],
+"db/d26/spotri_8f_source.html":[3,0,5,1359],
+"db/d27/zhecon__rook_8f.html":[3,0,5,1634],
+"db/d27/zhecon__rook_8f_source.html":[3,0,5,1634],
+"db/d28/zgetsls_8f.html":[3,0,5,1593],
+"db/d28/zgetsls_8f_source.html":[3,0,5,1593],
+"db/d28/zsytrf__rk_8f.html":[3,0,5,1924],
+"db/d28/zsytrf__rk_8f_source.html":[3,0,5,1924],
 "db/d29/cchkhe__aa__2stage_8f.html":[3,0,6,1,14],
 "db/d29/cchkhe__aa__2stage_8f_source.html":[3,0,6,1,14],
-"db/d29/zgerfs_8f.html":[3,0,5,1576],
-"db/d29/zgerfs_8f_source.html":[3,0,5,1576],
-"db/d2a/dsysv__rook_8f.html":[3,0,5,928],
-"db/d2a/dsysv__rook_8f_source.html":[3,0,5,928],
+"db/d29/zgerfs_8f.html":[3,0,5,1574],
+"db/d29/zgerfs_8f_source.html":[3,0,5,1574],
+"db/d2a/dsysv__rook_8f.html":[3,0,5,927],
+"db/d2a/dsysv__rook_8f_source.html":[3,0,5,927],
 "db/d2a/lapacke__sgels_8c.html":[3,0,4,3,1304],
 "db/d2a/lapacke__sgels_8c_a0c4eae5340f5dba16872489a1bac2c77.html#a0c4eae5340f5dba16872489a1bac2c77":[3,0,4,3,1304,0],
 "db/d2a/lapacke__sgels_8c_source.html":[3,0,4,3,1304],
 "db/d2b/lapacke__zheevd_8c.html":[3,0,4,3,2044],
 "db/d2b/lapacke__zheevd_8c_aae1343ce26b8dcb1eda916bce3c816ef.html#aae1343ce26b8dcb1eda916bce3c816ef":[3,0,4,3,2044,0],
 "db/d2b/lapacke__zheevd_8c_source.html":[3,0,4,3,2044],
-"db/d2b/ssprfs_8f.html":[3,0,5,1403],
-"db/d2b/ssprfs_8f_source.html":[3,0,5,1403],
+"db/d2b/ssprfs_8f.html":[3,0,5,1401],
+"db/d2b/ssprfs_8f_source.html":[3,0,5,1401],
 "db/d2b/zqrt01_8f.html":[3,0,6,1,737],
 "db/d2b/zqrt01_8f_source.html":[3,0,6,1,737],
 "db/d2c/lapacke__ctrttf_8c.html":[3,0,4,3,596],
@@ -222,32 +221,33 @@ var NAVTREEINDEX87 =
 "db/d2d/lapacke__dtpttf_8c.html":[3,0,4,3,1212],
 "db/d2d/lapacke__dtpttf_8c_a11908c2f68410504f82c40eb8d86af71.html#a11908c2f68410504f82c40eb8d86af71":[3,0,4,3,1212,0],
 "db/d2d/lapacke__dtpttf_8c_source.html":[3,0,4,3,1212],
-"db/d2d/sbdsqr_8f.html":[3,0,5,1024],
-"db/d2d/sbdsqr_8f_source.html":[3,0,5,1024],
+"db/d2d/sbdsqr_8f.html":[3,0,5,1023],
+"db/d2d/sbdsqr_8f_source.html":[3,0,5,1023],
 "db/d2d/zdotu_8f.html":[3,0,0,0,119],
 "db/d2d/zdotu_8f_source.html":[3,0,0,0,119],
-"db/d2e/dlassq_8f90.html":[3,0,5,758],
-"db/d2e/dlassq_8f90_source.html":[3,0,5,758],
+"db/d2e/dlassq_8f90.html":[3,0,5,757],
+"db/d2e/dlassq_8f90_source.html":[3,0,5,757],
 "db/d30/lapacke__zhptrs_8c.html":[3,0,4,3,2148],
 "db/d30/lapacke__zhptrs_8c_a4b9f08d4d5adcf25510cea831b567108.html#a4b9f08d4d5adcf25510cea831b567108":[3,0,4,3,2148,0],
 "db/d30/lapacke__zhptrs_8c_source.html":[3,0,4,3,2148],
 "db/d31/lapacke__ctgsyl_8c.html":[3,0,4,3,556],
 "db/d31/lapacke__ctgsyl_8c_af58951b52ae9a98a3ba74371ca647919.html#af58951b52ae9a98a3ba74371ca647919":[3,0,4,3,556,0],
 "db/d31/lapacke__ctgsyl_8c_source.html":[3,0,4,3,556],
-"db/d31/zgerqf_8f.html":[3,0,5,1579],
-"db/d31/zgerqf_8f_source.html":[3,0,5,1579],
+"db/d31/zgerqf_8f.html":[3,0,5,1577],
+"db/d31/zgerqf_8f_source.html":[3,0,5,1577],
 "db/d32/lapacke__dgelsd__work_8c.html":[3,0,4,3,709],
 "db/d32/lapacke__dgelsd__work_8c_af80cae17f7931e25de26b1d111e116ff.html#af80cae17f7931e25de26b1d111e116ff":[3,0,4,3,709,0],
 "db/d32/lapacke__dgelsd__work_8c_source.html":[3,0,4,3,709],
-"db/d33/slasd3_8f.html":[3,0,5,1263],
-"db/d33/slasd3_8f_source.html":[3,0,5,1263],
+"db/d33/slasd3_8f.html":[3,0,5,1261],
+"db/d33/slasd3_8f_source.html":[3,0,5,1261],
 "db/d34/dzasumsub_8f.html":[3,0,1,2,150],
 "db/d34/dzasumsub_8f_a2241e5aebad85ef33dba22962dde760a.html#a2241e5aebad85ef33dba22962dde760a":[3,0,1,2,150,0],
 "db/d34/dzasumsub_8f_source.html":[3,0,1,2,150],
-"db/d37/dtfttp_8f.html":[3,0,5,962],
-"db/d37/dtfttp_8f_source.html":[3,0,5,962],
+"db/d37/dtfttp_8f.html":[3,0,5,961],
+"db/d37/dtfttp_8f_source.html":[3,0,5,961],
 "db/d38/cgeqlf_8f.html":[3,0,5,44],
 "db/d38/cgeqlf_8f_source.html":[3,0,5,44],
 "db/d39/clansp_8f.html":[3,0,5,251],
-"db/d39/clansp_8f_source.html":[3,0,5,251]
+"db/d39/clansp_8f_source.html":[3,0,5,251],
+"db/d39/lapacke__ztrsna_8c.html":[3,0,4,3,2426]
 };
