@@ -1,24 +1,23 @@
 var NAVTREEINDEX88 =
 {
-"db/d39/lapacke__ztrsna_8c.html":[3,0,4,3,2426],
 "db/d39/lapacke__ztrsna_8c_a32e8c0be467de778140c8d5acd75e298.html#a32e8c0be467de778140c8d5acd75e298":[3,0,4,3,2426,0],
 "db/d39/lapacke__ztrsna_8c_source.html":[3,0,4,3,2426],
-"db/d3a/dgttrf_8f.html":[3,0,5,599],
-"db/d3a/dgttrf_8f_source.html":[3,0,5,599],
+"db/d3a/dgttrf_8f.html":[3,0,5,598],
+"db/d3a/dgttrf_8f_source.html":[3,0,5,598],
 "db/d3a/lapacke__dstein__work_8c.html":[3,0,4,3,1069],
 "db/d3a/lapacke__dstein__work_8c_aca4d724f2ff8b66ece42d5d08a18fa38.html#aca4d724f2ff8b66ece42d5d08a18fa38":[3,0,4,3,1069,0],
 "db/d3a/lapacke__dstein__work_8c_source.html":[3,0,4,3,1069],
 "db/d3a/lapacke__zsytri__3__work_8c.html":[3,0,4,3,2356],
 "db/d3a/lapacke__zsytri__3__work_8c_a7a47eef35f56151013f8b1ed3a4d12de.html#a7a47eef35f56151013f8b1ed3a4d12de":[3,0,4,3,2356,0],
 "db/d3a/lapacke__zsytri__3__work_8c_source.html":[3,0,4,3,2356],
-"db/d3b/dlaqr4_8f.html":[3,0,5,692],
-"db/d3b/dlaqr4_8f_source.html":[3,0,5,692],
+"db/d3b/dlaqr4_8f.html":[3,0,5,691],
+"db/d3b/dlaqr4_8f_source.html":[3,0,5,691],
 "db/d3d/cchkrq_8f.html":[3,0,6,1,32],
 "db/d3d/cchkrq_8f_source.html":[3,0,6,1,32],
 "db/d3d/ctgsy2_8f.html":[3,0,5,432],
 "db/d3d/ctgsy2_8f_source.html":[3,0,5,432],
-"db/d3d/dpotrf2_8f.html":[3,0,5,838],
-"db/d3d/dpotrf2_8f_source.html":[3,0,5,838],
+"db/d3d/dpotrf2_8f.html":[3,0,5,837],
+"db/d3d/dpotrf2_8f_source.html":[3,0,5,837],
 "db/d3d/lapacke__chb__trans_8c.html":[3,0,4,4,9],
 "db/d3d/lapacke__chb__trans_8c_aca370fe0228e428f33e7dfe0c87452d2.html#aca370fe0228e428f33e7dfe0c87452d2":[3,0,4,4,9,0],
 "db/d3d/lapacke__chb__trans_8c_source.html":[3,0,4,4,9],
@@ -46,22 +45,22 @@ var NAVTREEINDEX88 =
 "db/d41/lapacke__sgeqrf__work_8c_ac34e99a863038d8cc9d80483424420d4.html#ac34e99a863038d8cc9d80483424420d4":[3,0,4,3,1329,0],
 "db/d41/lapacke__sgeqrf__work_8c_source.html":[3,0,4,3,1329],
 "db/d42/cblas__dzasum_8c.html":[3,0,1,2,67],
+"db/d42/cblas__dzasum_8c_a134b0023f20040d27be120122746d9a6.html#a134b0023f20040d27be120122746d9a6":[3,0,1,2,67,2],
 "db/d42/cblas__dzasum_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,67,0],
-"db/d42/cblas__dzasum_8c_a550d16f376078526678f463aaaec2123.html#a550d16f376078526678f463aaaec2123":[3,0,1,2,67,2],
 "db/d42/cblas__dzasum_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,67,1],
 "db/d42/cblas__dzasum_8c_source.html":[3,0,1,2,67],
 "db/d42/lapacke__dbdsdc__work_8c.html":[3,0,4,3,647],
 "db/d42/lapacke__dbdsdc__work_8c_a641a41cb1fd7de17535c81d095aa68c6.html#a641a41cb1fd7de17535c81d095aa68c6":[3,0,4,3,647,0],
 "db/d42/lapacke__dbdsdc__work_8c_source.html":[3,0,4,3,647],
-"db/d43/sgesvdq_8f.html":[3,0,5,1087],
-"db/d43/sgesvdq_8f_source.html":[3,0,5,1087],
-"db/d43/zladiv_8f.html":[3,0,5,1740],
-"db/d43/zladiv_8f_source.html":[3,0,5,1740],
+"db/d43/sgesvdq_8f.html":[3,0,5,1085],
+"db/d43/sgesvdq_8f_source.html":[3,0,5,1085],
+"db/d43/zladiv_8f.html":[3,0,5,1738],
+"db/d43/zladiv_8f_source.html":[3,0,5,1738],
 "db/d45/lapacke__clapmr_8c.html":[3,0,4,3,342],
 "db/d45/lapacke__clapmr_8c_a9daa915128f9f7ffb3b40c7760a81f4a.html#a9daa915128f9f7ffb3b40c7760a81f4a":[3,0,4,3,342,0],
 "db/d45/lapacke__clapmr_8c_source.html":[3,0,4,3,342],
-"db/d45/slangb_8f.html":[3,0,5,1187],
-"db/d45/slangb_8f_source.html":[3,0,5,1187],
+"db/d45/slangb_8f.html":[3,0,5,1185],
+"db/d45/slangb_8f_source.html":[3,0,5,1185],
 "db/d45/zglmts_8f.html":[3,0,6,0,336],
 "db/d45/zglmts_8f_source.html":[3,0,6,0,336],
 "db/d46/lapacke__ctr__nancheck_8c.html":[3,0,4,4,36],
@@ -70,24 +69,24 @@ var NAVTREEINDEX88 =
 "db/d47/lapacke__cporfsx_8c.html":[3,0,4,3,400],
 "db/d47/lapacke__cporfsx_8c_ae1fe8480431ecf05d0fefe058d29d69f.html#ae1fe8480431ecf05d0fefe058d29d69f":[3,0,4,3,400,0],
 "db/d47/lapacke__cporfsx_8c_source.html":[3,0,4,3,400],
-"db/d47/slaein_8f.html":[3,0,5,1165],
-"db/d47/slaein_8f_source.html":[3,0,5,1165],
+"db/d47/slaein_8f.html":[3,0,5,1163],
+"db/d47/slaein_8f_source.html":[3,0,5,1163],
 "db/d48/lapacke__dgeev__work_8c.html":[3,0,4,3,693],
 "db/d48/lapacke__dgeev__work_8c_a4c991536aec8ed47e9c7e3c7a4f0ec15.html#a4c991536aec8ed47e9c7e3c7a4f0ec15":[3,0,4,3,693,0],
 "db/d48/lapacke__dgeev__work_8c_source.html":[3,0,4,3,693],
-"db/d48/zlalsa_8f.html":[3,0,5,1758],
-"db/d48/zlalsa_8f_source.html":[3,0,5,1758],
+"db/d48/zlalsa_8f.html":[3,0,5,1756],
+"db/d48/zlalsa_8f_source.html":[3,0,5,1756],
 "db/d49/cunbdb4_8f.html":[3,0,5,465],
 "db/d49/cunbdb4_8f_source.html":[3,0,5,465],
-"db/d49/zla__geamv_8f.html":[3,0,5,1711],
-"db/d49/zla__geamv_8f_source.html":[3,0,5,1711],
-"db/d4a/dtrsen_8f.html":[3,0,5,990],
-"db/d4a/dtrsen_8f_source.html":[3,0,5,990],
+"db/d49/zla__geamv_8f.html":[3,0,5,1709],
+"db/d49/zla__geamv_8f_source.html":[3,0,5,1709],
+"db/d4a/dtrsen_8f.html":[3,0,5,989],
+"db/d4a/dtrsen_8f_source.html":[3,0,5,989],
 "db/d4b/lapacke__slarfb__work_8c.html":[3,0,4,3,1455],
 "db/d4b/lapacke__slarfb__work_8c_a6bcc8657f8d60db5e96d0ff0718c0bda.html#a6bcc8657f8d60db5e96d0ff0718c0bda":[3,0,4,3,1455,0],
 "db/d4b/lapacke__slarfb__work_8c_source.html":[3,0,4,3,1455],
-"db/d4b/slagv2_8f.html":[3,0,5,1174],
-"db/d4b/slagv2_8f_source.html":[3,0,5,1174],
+"db/d4b/slagv2_8f.html":[3,0,5,1172],
+"db/d4b/slagv2_8f_source.html":[3,0,5,1172],
 "db/d4c/lapacke__dtgexc_8c.html":[3,0,4,3,1186],
 "db/d4c/lapacke__dtgexc_8c_a6cac59ef9477cfa1c944a79ffa91c71c.html#a6cac59ef9477cfa1c944a79ffa91c71c":[3,0,4,3,1186,0],
 "db/d4c/lapacke__dtgexc_8c_source.html":[3,0,4,3,1186],
@@ -118,8 +117,8 @@ var NAVTREEINDEX88 =
 "db/d51/lapacke__zggrqf_8c.html":[3,0,4,3,1990],
 "db/d51/lapacke__zggrqf_8c_abb162c2b32e9293122dfd5ec2827a6bc.html#abb162c2b32e9293122dfd5ec2827a6bc":[3,0,4,3,1990,0],
 "db/d51/lapacke__zggrqf_8c_source.html":[3,0,4,3,1990],
-"db/d51/zpbsvx_8f.html":[3,0,5,1848],
-"db/d51/zpbsvx_8f_source.html":[3,0,5,1848],
+"db/d51/zpbsvx_8f.html":[3,0,5,1846],
+"db/d51/zpbsvx_8f_source.html":[3,0,5,1846],
 "db/d53/cget37_8f.html":[3,0,6,0,58],
 "db/d53/cget37_8f_source.html":[3,0,6,0,58],
 "db/d53/scasum_8f.html":[3,0,0,0,80],
@@ -127,30 +126,30 @@ var NAVTREEINDEX88 =
 "db/d54/zcklse_8f.html":[3,0,6,0,301],
 "db/d54/zcklse_8f_source.html":[3,0,6,0,301],
 "db/d55/group__complex16_g_eeigen.html":[0,0,0,1,3],
+"db/d55/group__complex16_g_eeigen_ga0eb4e3d75621a1ce1685064db1ac58f0.html#ga0eb4e3d75621a1ce1685064db1ac58f0":[3,0,5,1545,0],
 "db/d55/group__complex16_g_eeigen_ga0eb4e3d75621a1ce1685064db1ac58f0.html#ga0eb4e3d75621a1ce1685064db1ac58f0":[0,0,0,1,3,2],
-"db/d55/group__complex16_g_eeigen_ga0eb4e3d75621a1ce1685064db1ac58f0.html#ga0eb4e3d75621a1ce1685064db1ac58f0":[3,0,5,1547,0],
 "db/d55/group__complex16_g_eeigen_ga16024be7f650b57a748b1947d64adbe5.html#ga16024be7f650b57a748b1947d64adbe5":[3,0,5,0,28,0],
 "db/d55/group__complex16_g_eeigen_ga16024be7f650b57a748b1947d64adbe5.html#ga16024be7f650b57a748b1947d64adbe5":[0,0,0,1,3,5],
 "db/d55/group__complex16_g_eeigen_ga20c384504d174350a16063cbc115281e.html#ga20c384504d174350a16063cbc115281e":[0,0,0,1,3,7],
-"db/d55/group__complex16_g_eeigen_ga20c384504d174350a16063cbc115281e.html#ga20c384504d174350a16063cbc115281e":[3,0,5,1600,0],
+"db/d55/group__complex16_g_eeigen_ga20c384504d174350a16063cbc115281e.html#ga20c384504d174350a16063cbc115281e":[3,0,5,1598,0],
 "db/d55/group__complex16_g_eeigen_ga255e11cea9a4fdadaffd2506c86ce53b.html#ga255e11cea9a4fdadaffd2506c86ce53b":[0,0,0,1,3,0],
-"db/d55/group__complex16_g_eeigen_ga255e11cea9a4fdadaffd2506c86ce53b.html#ga255e11cea9a4fdadaffd2506c86ce53b":[3,0,5,1545,0],
-"db/d55/group__complex16_g_eeigen_ga5b71a5031d2efac59c8f97c707407f65.html#ga5b71a5031d2efac59c8f97c707407f65":[3,0,5,1546,0],
+"db/d55/group__complex16_g_eeigen_ga255e11cea9a4fdadaffd2506c86ce53b.html#ga255e11cea9a4fdadaffd2506c86ce53b":[3,0,5,1543,0],
 "db/d55/group__complex16_g_eeigen_ga5b71a5031d2efac59c8f97c707407f65.html#ga5b71a5031d2efac59c8f97c707407f65":[0,0,0,1,3,1],
-"db/d55/group__complex16_g_eeigen_ga5c144215dc103ce90a76e324d36e0ec4.html#ga5c144215dc103ce90a76e324d36e0ec4":[3,0,5,1603,0],
+"db/d55/group__complex16_g_eeigen_ga5b71a5031d2efac59c8f97c707407f65.html#ga5b71a5031d2efac59c8f97c707407f65":[3,0,5,1544,0],
+"db/d55/group__complex16_g_eeigen_ga5c144215dc103ce90a76e324d36e0ec4.html#ga5c144215dc103ce90a76e324d36e0ec4":[3,0,5,1601,0],
 "db/d55/group__complex16_g_eeigen_ga5c144215dc103ce90a76e324d36e0ec4.html#ga5c144215dc103ce90a76e324d36e0ec4":[0,0,0,1,3,10],
+"db/d55/group__complex16_g_eeigen_ga73f44f731074e8f98990b89711bd60fa.html#ga73f44f731074e8f98990b89711bd60fa":[3,0,5,1599,0],
 "db/d55/group__complex16_g_eeigen_ga73f44f731074e8f98990b89711bd60fa.html#ga73f44f731074e8f98990b89711bd60fa":[0,0,0,1,3,8],
-"db/d55/group__complex16_g_eeigen_ga73f44f731074e8f98990b89711bd60fa.html#ga73f44f731074e8f98990b89711bd60fa":[3,0,5,1601,0],
-"db/d55/group__complex16_g_eeigen_ga788ffb82ac609cc3e99de43c4cea3e7b.html#ga788ffb82ac609cc3e99de43c4cea3e7b":[3,0,5,1599,0],
+"db/d55/group__complex16_g_eeigen_ga788ffb82ac609cc3e99de43c4cea3e7b.html#ga788ffb82ac609cc3e99de43c4cea3e7b":[3,0,5,1597,0],
 "db/d55/group__complex16_g_eeigen_ga788ffb82ac609cc3e99de43c4cea3e7b.html#ga788ffb82ac609cc3e99de43c4cea3e7b":[0,0,0,1,3,6],
-"db/d55/group__complex16_g_eeigen_ga79fcce20c617429ccf985e6f123a6171.html#ga79fcce20c617429ccf985e6f123a6171":[3,0,5,1602,0],
+"db/d55/group__complex16_g_eeigen_ga79fcce20c617429ccf985e6f123a6171.html#ga79fcce20c617429ccf985e6f123a6171":[3,0,5,1600,0],
 "db/d55/group__complex16_g_eeigen_ga79fcce20c617429ccf985e6f123a6171.html#ga79fcce20c617429ccf985e6f123a6171":[0,0,0,1,3,9],
 "db/d55/group__complex16_g_eeigen_gaad769423756706f1186027c9dd7615e4.html#gaad769423756706f1186027c9dd7615e4":[0,0,0,1,3,11],
-"db/d55/group__complex16_g_eeigen_gaad769423756706f1186027c9dd7615e4.html#gaad769423756706f1186027c9dd7615e4":[3,0,5,1604,0],
+"db/d55/group__complex16_g_eeigen_gaad769423756706f1186027c9dd7615e4.html#gaad769423756706f1186027c9dd7615e4":[3,0,5,1602,0],
 "db/d55/group__complex16_g_eeigen_gad43ce2e0f0453844b8ff88c5dfe30b13.html#gad43ce2e0f0453844b8ff88c5dfe30b13":[3,0,5,0,27,0],
 "db/d55/group__complex16_g_eeigen_gad43ce2e0f0453844b8ff88c5dfe30b13.html#gad43ce2e0f0453844b8ff88c5dfe30b13":[0,0,0,1,3,4],
-"db/d55/group__complex16_g_eeigen_gae55acf82651540f7d8f36715eec0900d.html#gae55acf82651540f7d8f36715eec0900d":[3,0,5,1548,0],
 "db/d55/group__complex16_g_eeigen_gae55acf82651540f7d8f36715eec0900d.html#gae55acf82651540f7d8f36715eec0900d":[0,0,0,1,3,3],
+"db/d55/group__complex16_g_eeigen_gae55acf82651540f7d8f36715eec0900d.html#gae55acf82651540f7d8f36715eec0900d":[3,0,5,1546,0],
 "db/d57/lapacke__cbbcsd__work_8c.html":[3,0,4,3,1],
 "db/d57/lapacke__cbbcsd__work_8c_a8a2d41c614e8061ea8322cb675ff824d.html#a8a2d41c614e8061ea8322cb675ff824d":[3,0,4,3,1,0],
 "db/d57/lapacke__cbbcsd__work_8c_source.html":[3,0,4,3,1],
@@ -171,8 +170,8 @@ var NAVTREEINDEX88 =
 "db/d5a/lapacke__zgges__work_8c.html":[3,0,4,3,1971],
 "db/d5a/lapacke__zgges__work_8c_a3c05e15f1eaae9a1e7c9dc185c1cc284.html#a3c05e15f1eaae9a1e7c9dc185c1cc284":[3,0,4,3,1971,0],
 "db/d5a/lapacke__zgges__work_8c_source.html":[3,0,4,3,1971],
-"db/d5b/dlasq3_8f.html":[3,0,5,752],
-"db/d5b/dlasq3_8f_source.html":[3,0,5,752],
+"db/d5b/dlasq3_8f.html":[3,0,5,751],
+"db/d5b/dlasq3_8f_source.html":[3,0,5,751],
 "db/d5b/lapacke__zgbequ__work_8c.html":[3,0,4,3,1847],
 "db/d5b/lapacke__zgbequ__work_8c_add46c8cc94e41ef56ea86195b9c15a05.html#add46c8cc94e41ef56ea86195b9c15a05":[3,0,4,3,1847,0],
 "db/d5b/lapacke__zgbequ__work_8c_source.html":[3,0,4,3,1847],
@@ -195,17 +194,17 @@ var NAVTREEINDEX88 =
 "db/d5c/sgeqrs_8f_source.html":[3,0,6,1,482],
 "db/d5c/sger_8f.html":[3,0,0,0,88],
 "db/d5c/sger_8f_source.html":[3,0,0,0,88],
-"db/d5d/dla__porpvgrw_8f.html":[3,0,5,617],
-"db/d5d/dla__porpvgrw_8f_source.html":[3,0,5,617],
+"db/d5d/dla__porpvgrw_8f.html":[3,0,5,616],
+"db/d5d/dla__porpvgrw_8f_source.html":[3,0,5,616],
 "db/d5e/cblas__csymm_8c.html":[3,0,1,2,22],
 "db/d5e/cblas__csymm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,22,2],
-"db/d5e/cblas__csymm_8c_a2322e37ef2f737aa29c19d3d0a8d8d6b.html#a2322e37ef2f737aa29c19d3d0a8d8d6b":[3,0,1,2,22,7],
 "db/d5e/cblas__csymm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,22,1],
 "db/d5e/cblas__csymm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,22,4],
 "db/d5e/cblas__csymm_8c_a8bc04ca7122be8af5c345be6464f102a.html#a8bc04ca7122be8af5c345be6464f102a":[3,0,1,2,22,5],
 "db/d5e/cblas__csymm_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,22,0],
 "db/d5e/cblas__csymm_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,22,6],
 "db/d5e/cblas__csymm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,22,3],
+"db/d5e/cblas__csymm_8c_adec963e3c151516913f2b32679f8f0b6.html#adec963e3c151516913f2b32679f8f0b6":[3,0,1,2,22,7],
 "db/d5e/cblas__csymm_8c_source.html":[3,0,1,2,22],
 "db/d5f/cdrvgbx_8f.html":[3,0,6,1,46],
 "db/d5f/cdrvgbx_8f_source.html":[3,0,6,1,46],
@@ -213,41 +212,42 @@ var NAVTREEINDEX88 =
 "db/d5f/cgeru_8f_source.html":[3,0,0,0,8],
 "db/d5f/chbgvx_8f.html":[3,0,5,110],
 "db/d5f/chbgvx_8f_source.html":[3,0,5,110],
-"db/d61/dsytrs2_8f.html":[3,0,5,952],
-"db/d61/dsytrs2_8f_source.html":[3,0,5,952],
+"db/d61/dsytrs2_8f.html":[3,0,5,951],
+"db/d61/dsytrs2_8f_source.html":[3,0,5,951],
 "db/d61/group__complex16_o_t_h_e_reigen.html":[0,0,7,3],
 "db/d61/group__complex16_o_t_h_e_reigen_ga07f979a2315db5c8c22c0522c3793134.html#ga07f979a2315db5c8c22c0522c3793134":[0,0,7,3,10],
-"db/d61/group__complex16_o_t_h_e_reigen_ga07f979a2315db5c8c22c0522c3793134.html#ga07f979a2315db5c8c22c0522c3793134":[3,0,5,1690,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga07f979a2315db5c8c22c0522c3793134.html#ga07f979a2315db5c8c22c0522c3793134":[3,0,5,1688,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga253ab29dd3917b1cbc9e35c022d14383.html#ga253ab29dd3917b1cbc9e35c022d14383":[0,0,7,3,4],
-"db/d61/group__complex16_o_t_h_e_reigen_ga253ab29dd3917b1cbc9e35c022d14383.html#ga253ab29dd3917b1cbc9e35c022d14383":[3,0,5,1626,0],
-"db/d61/group__complex16_o_t_h_e_reigen_ga2e244a94bea7118e2aedcd3342276a80.html#ga2e244a94bea7118e2aedcd3342276a80":[3,0,5,1691,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga253ab29dd3917b1cbc9e35c022d14383.html#ga253ab29dd3917b1cbc9e35c022d14383":[3,0,5,1624,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga2e244a94bea7118e2aedcd3342276a80.html#ga2e244a94bea7118e2aedcd3342276a80":[3,0,5,1689,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga2e244a94bea7118e2aedcd3342276a80.html#ga2e244a94bea7118e2aedcd3342276a80":[0,0,7,3,11],
-"db/d61/group__complex16_o_t_h_e_reigen_ga3854721b34946230321131ed9e3c08e3.html#ga3854721b34946230321131ed9e3c08e3":[3,0,5,1625,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga3854721b34946230321131ed9e3c08e3.html#ga3854721b34946230321131ed9e3c08e3":[0,0,7,3,3],
+"db/d61/group__complex16_o_t_h_e_reigen_ga3854721b34946230321131ed9e3c08e3.html#ga3854721b34946230321131ed9e3c08e3":[3,0,5,1623,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga42094c90148d11dd8eb7627231144c09.html#ga42094c90148d11dd8eb7627231144c09":[3,0,5,1626,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga42094c90148d11dd8eb7627231144c09.html#ga42094c90148d11dd8eb7627231144c09":[0,0,7,3,6],
-"db/d61/group__complex16_o_t_h_e_reigen_ga42094c90148d11dd8eb7627231144c09.html#ga42094c90148d11dd8eb7627231144c09":[3,0,5,1628,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga597ea234c22684386ad82c7515285514.html#ga597ea234c22684386ad82c7515285514":[0,0,7,3,8],
-"db/d61/group__complex16_o_t_h_e_reigen_ga597ea234c22684386ad82c7515285514.html#ga597ea234c22684386ad82c7515285514":[3,0,5,1631,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga597ea234c22684386ad82c7515285514.html#ga597ea234c22684386ad82c7515285514":[3,0,5,1629,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga5d02ab79a002e32a7fd26a9e8a8f5638.html#ga5d02ab79a002e32a7fd26a9e8a8f5638":[0,0,7,3,12],
-"db/d61/group__complex16_o_t_h_e_reigen_ga5d02ab79a002e32a7fd26a9e8a8f5638.html#ga5d02ab79a002e32a7fd26a9e8a8f5638":[3,0,5,1692,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga5d02ab79a002e32a7fd26a9e8a8f5638.html#ga5d02ab79a002e32a7fd26a9e8a8f5638":[3,0,5,1690,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga72184c03c8976891c11e42f3463c2d38.html#ga72184c03c8976891c11e42f3463c2d38":[0,0,7,3,1],
-"db/d61/group__complex16_o_t_h_e_reigen_ga72184c03c8976891c11e42f3463c2d38.html#ga72184c03c8976891c11e42f3463c2d38":[3,0,5,1623,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga72184c03c8976891c11e42f3463c2d38.html#ga72184c03c8976891c11e42f3463c2d38":[3,0,5,1621,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga76a8cfc758f8dc17ac37f6eed2ef18a4.html#ga76a8cfc758f8dc17ac37f6eed2ef18a4":[0,0,7,3,7],
-"db/d61/group__complex16_o_t_h_e_reigen_ga76a8cfc758f8dc17ac37f6eed2ef18a4.html#ga76a8cfc758f8dc17ac37f6eed2ef18a4":[3,0,5,1630,0],
-"db/d61/group__complex16_o_t_h_e_reigen_ga7e9ce5ea3c8adfc5d28e92904c34984f.html#ga7e9ce5ea3c8adfc5d28e92904c34984f":[3,0,5,1605,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga76a8cfc758f8dc17ac37f6eed2ef18a4.html#ga76a8cfc758f8dc17ac37f6eed2ef18a4":[3,0,5,1628,0],
 "db/d61/group__complex16_o_t_h_e_reigen_ga7e9ce5ea3c8adfc5d28e92904c34984f.html#ga7e9ce5ea3c8adfc5d28e92904c34984f":[0,0,7,3,0],
+"db/d61/group__complex16_o_t_h_e_reigen_ga7e9ce5ea3c8adfc5d28e92904c34984f.html#ga7e9ce5ea3c8adfc5d28e92904c34984f":[3,0,5,1603,0],
+"db/d61/group__complex16_o_t_h_e_reigen_gaa447b35fe8cbabe3cf262579e49a96b1.html#gaa447b35fe8cbabe3cf262579e49a96b1":[3,0,5,1694,0],
 "db/d61/group__complex16_o_t_h_e_reigen_gaa447b35fe8cbabe3cf262579e49a96b1.html#gaa447b35fe8cbabe3cf262579e49a96b1":[0,0,7,3,15],
-"db/d61/group__complex16_o_t_h_e_reigen_gaa447b35fe8cbabe3cf262579e49a96b1.html#gaa447b35fe8cbabe3cf262579e49a96b1":[3,0,5,1696,0],
 "db/d61/group__complex16_o_t_h_e_reigen_gae5f2fa86e4c29e27fccf6cb9ea1c54a2.html#gae5f2fa86e4c29e27fccf6cb9ea1c54a2":[0,0,7,3,5],
-"db/d61/group__complex16_o_t_h_e_reigen_gae5f2fa86e4c29e27fccf6cb9ea1c54a2.html#gae5f2fa86e4c29e27fccf6cb9ea1c54a2":[3,0,5,1627,0],
+"db/d61/group__complex16_o_t_h_e_reigen_gae5f2fa86e4c29e27fccf6cb9ea1c54a2.html#gae5f2fa86e4c29e27fccf6cb9ea1c54a2":[3,0,5,1625,0],
 "db/d61/group__complex16_o_t_h_e_reigen_gae902a3301300bbb1a46459cb990192ad.html#gae902a3301300bbb1a46459cb990192ad":[0,0,7,3,9],
-"db/d61/group__complex16_o_t_h_e_reigen_gae902a3301300bbb1a46459cb990192ad.html#gae902a3301300bbb1a46459cb990192ad":[3,0,5,1632,0],
+"db/d61/group__complex16_o_t_h_e_reigen_gae902a3301300bbb1a46459cb990192ad.html#gae902a3301300bbb1a46459cb990192ad":[3,0,5,1630,0],
 "db/d61/group__complex16_o_t_h_e_reigen_gaf530dcc3dabfea2488e8d639df175d5f.html#gaf530dcc3dabfea2488e8d639df175d5f":[0,0,7,3,13],
-"db/d61/group__complex16_o_t_h_e_reigen_gaf530dcc3dabfea2488e8d639df175d5f.html#gaf530dcc3dabfea2488e8d639df175d5f":[3,0,5,1694,0],
+"db/d61/group__complex16_o_t_h_e_reigen_gaf530dcc3dabfea2488e8d639df175d5f.html#gaf530dcc3dabfea2488e8d639df175d5f":[3,0,5,1692,0],
 "db/d61/group__complex16_o_t_h_e_reigen_gaf637994a7cb287906efc0254d7d58f69.html#gaf637994a7cb287906efc0254d7d58f69":[0,0,7,3,2],
-"db/d61/group__complex16_o_t_h_e_reigen_gaf637994a7cb287906efc0254d7d58f69.html#gaf637994a7cb287906efc0254d7d58f69":[3,0,5,1624,0],
+"db/d61/group__complex16_o_t_h_e_reigen_gaf637994a7cb287906efc0254d7d58f69.html#gaf637994a7cb287906efc0254d7d58f69":[3,0,5,1622,0],
+"db/d61/group__complex16_o_t_h_e_reigen_gaf6720700dfc0d1692416a4e9bab0e6a7.html#gaf6720700dfc0d1692416a4e9bab0e6a7":[3,0,5,1693,0],
 "db/d61/group__complex16_o_t_h_e_reigen_gaf6720700dfc0d1692416a4e9bab0e6a7.html#gaf6720700dfc0d1692416a4e9bab0e6a7":[0,0,7,3,14],
-"db/d61/group__complex16_o_t_h_e_reigen_gaf6720700dfc0d1692416a4e9bab0e6a7.html#gaf6720700dfc0d1692416a4e9bab0e6a7":[3,0,5,1695,0],
-"db/d62/dggqrf_8f.html":[3,0,5,589],
-"db/d62/dggqrf_8f_source.html":[3,0,5,589]
+"db/d62/dggqrf_8f.html":[3,0,5,588],
+"db/d62/dggqrf_8f_source.html":[3,0,5,588],
+"db/d62/lapacke__zhecon__3__work_8c.html":[3,0,4,3,2036]
 };
