@@ -1,11 +1,10 @@
 var NAVTREEINDEX90 =
 {
-"db/d9c/lapacke__dlansy_8c.html":[3,0,4,3,844],
 "db/d9c/lapacke__dlansy_8c_a02712ae13e14c6ec8aad80550af20e0c.html#a02712ae13e14c6ec8aad80550af20e0c":[3,0,4,3,844,0],
 "db/d9c/lapacke__dlansy_8c_source.html":[3,0,4,3,844],
-"db/d9f/ssytrs__3_8f.html":[3,0,5,1473],
-"db/d9f/ssytrs__3_8f_a33ef97f409544eacf4cdcab5cb062ec6.html#a33ef97f409544eacf4cdcab5cb062ec6":[3,0,5,1473,0],
-"db/d9f/ssytrs__3_8f_source.html":[3,0,5,1473],
+"db/d9f/ssytrs__3_8f.html":[3,0,5,1471],
+"db/d9f/ssytrs__3_8f_a33ef97f409544eacf4cdcab5cb062ec6.html#a33ef97f409544eacf4cdcab5cb062ec6":[3,0,5,1471,0],
+"db/d9f/ssytrs__3_8f_source.html":[3,0,5,1471],
 "db/da0/group__lin.html":[0,1,1],
 "db/da4/lapacke__cggev_8c.html":[3,0,4,3,136],
 "db/da4/lapacke__cggev_8c_aff964616bd2098b6e9d90b1a4b9691e1.html#aff964616bd2098b6e9d90b1a4b9691e1":[3,0,4,3,136,0],
@@ -25,23 +24,23 @@ var NAVTREEINDEX90 =
 "db/da8/lapacke__cgebrd__work_8c.html":[3,0,4,3,31],
 "db/da8/lapacke__cgebrd__work_8c_a23d2ee997557e1ff1b3066b56f7a8f1f.html#a23d2ee997557e1ff1b3066b56f7a8f1f":[3,0,4,3,31,0],
 "db/da8/lapacke__cgebrd__work_8c_source.html":[3,0,4,3,31],
-"db/da9/zpbtrf_8f.html":[3,0,5,1850],
-"db/da9/zpbtrf_8f_source.html":[3,0,5,1850],
-"db/daa/slaqsp_8f.html":[3,0,5,1218],
-"db/daa/slaqsp_8f_source.html":[3,0,5,1218],
-"db/dad/dlansb_8f.html":[3,0,5,668],
-"db/dad/dlansb_8f_source.html":[3,0,5,668],
-"db/dad/zuncsd2by1_8f.html":[3,0,5,1990],
-"db/dad/zuncsd2by1_8f_source.html":[3,0,5,1990],
+"db/da9/zpbtrf_8f.html":[3,0,5,1848],
+"db/da9/zpbtrf_8f_source.html":[3,0,5,1848],
+"db/daa/slaqsp_8f.html":[3,0,5,1216],
+"db/daa/slaqsp_8f_source.html":[3,0,5,1216],
+"db/dad/dlansb_8f.html":[3,0,5,667],
+"db/dad/dlansb_8f_source.html":[3,0,5,667],
+"db/dad/zuncsd2by1_8f.html":[3,0,5,1988],
+"db/dad/zuncsd2by1_8f_source.html":[3,0,5,1988],
 "db/daf/lapacke__dgeequb__work_8c.html":[3,0,4,3,687],
 "db/daf/lapacke__dgeequb__work_8c_a5bf4e98c37a4bd195cb128e0d2ac3796.html#a5bf4e98c37a4bd195cb128e0d2ac3796":[3,0,4,3,687,0],
 "db/daf/lapacke__dgeequb__work_8c_source.html":[3,0,4,3,687],
 "db/db0/serrgex_8f.html":[3,0,6,1,452],
 "db/db0/serrgex_8f_source.html":[3,0,6,1,452],
-"db/db0/zlaqsy_8f.html":[3,0,5,1795],
-"db/db0/zlaqsy_8f_source.html":[3,0,5,1795],
-"db/db1/dlae2_8f.html":[3,0,5,629],
-"db/db1/dlae2_8f_source.html":[3,0,5,629],
+"db/db0/zlaqsy_8f.html":[3,0,5,1793],
+"db/db0/zlaqsy_8f_source.html":[3,0,5,1793],
+"db/db1/dlae2_8f.html":[3,0,5,628],
+"db/db1/dlae2_8f_source.html":[3,0,5,628],
 "db/db1/lapacke__dpptrs_8c.html":[3,0,4,3,986],
 "db/db1/lapacke__dpptrs_8c_ae511499036d2d301d53181147270cc02.html#ae511499036d2d301d53181147270cc02":[3,0,4,3,986,0],
 "db/db1/lapacke__dpptrs_8c_source.html":[3,0,4,3,986],
@@ -52,17 +51,17 @@ var NAVTREEINDEX90 =
 "db/db2/snrm2sub_8f_source.html":[3,0,1,2,161],
 "db/db2/sppt05_8f.html":[3,0,6,1,522],
 "db/db2/sppt05_8f_source.html":[3,0,6,1,522],
-"db/db2/zpttrf_8f.html":[3,0,5,1883],
-"db/db2/zpttrf_8f_source.html":[3,0,5,1883],
-"db/db3/dlasd7_8f.html":[3,0,5,744],
-"db/db3/dlasd7_8f_source.html":[3,0,5,744],
+"db/db2/zpttrf_8f.html":[3,0,5,1881],
+"db/db2/zpttrf_8f_source.html":[3,0,5,1881],
+"db/db3/dlasd7_8f.html":[3,0,5,743],
+"db/db3/dlasd7_8f_source.html":[3,0,5,743],
 "db/db3/lapacke__cgemqrt__work_8c.html":[3,0,4,3,69],
 "db/db3/lapacke__cgemqrt__work_8c_a20bb416e88dec0f088a4227e20733586.html#a20bb416e88dec0f088a4227e20733586":[3,0,4,3,69,0],
 "db/db3/lapacke__cgemqrt__work_8c_source.html":[3,0,4,3,69],
 "db/db4/clarft_8f.html":[3,0,5,287],
 "db/db4/clarft_8f_source.html":[3,0,5,287],
-"db/db4/dgesdd_8f.html":[3,0,5,561],
-"db/db4/dgesdd_8f_source.html":[3,0,5,561],
+"db/db4/dgesdd_8f.html":[3,0,5,560],
+"db/db4/dgesdd_8f_source.html":[3,0,5,560],
 "db/db5/lapacke__chpgst_8c.html":[3,0,4,3,290],
 "db/db5/lapacke__chpgst_8c_afab06212402f3341a6020f83ee029060.html#afab06212402f3341a6020f83ee029060":[3,0,4,3,290,0],
 "db/db5/lapacke__chpgst_8c_source.html":[3,0,4,3,290],
@@ -72,8 +71,8 @@ var NAVTREEINDEX90 =
 "db/db6/lapacke__zgglse_8c.html":[3,0,4,3,1986],
 "db/db6/lapacke__zgglse_8c_ab9afa51cf9d1111ea9434e827f88f80b.html#ab9afa51cf9d1111ea9434e827f88f80b":[3,0,4,3,1986,0],
 "db/db6/lapacke__zgglse_8c_source.html":[3,0,4,3,1986],
-"db/db8/dtptrs_8f.html":[3,0,5,982],
-"db/db8/dtptrs_8f_source.html":[3,0,5,982],
+"db/db8/dtptrs_8f.html":[3,0,5,981],
+"db/db8/dtptrs_8f_source.html":[3,0,5,981],
 "db/db9/lapacke__zlacrm__work_8c.html":[3,0,4,3,2163],
 "db/db9/lapacke__zlacrm__work_8c_a6e72348d51ef81dc68854408dd43e5a3.html#a6e72348d51ef81dc68854408dd43e5a3":[3,0,4,3,2163,0],
 "db/db9/lapacke__zlacrm__work_8c_source.html":[3,0,4,3,2163],
@@ -86,8 +85,8 @@ var NAVTREEINDEX90 =
 "db/dba/lapacke__ssygst__work_8c.html":[3,0,4,3,1703],
 "db/dba/lapacke__ssygst__work_8c_abc183df3c15f265273c0c2bb4bfbb4a4.html#abc183df3c15f265273c0c2bb4bfbb4a4":[3,0,4,3,1703,0],
 "db/dba/lapacke__ssygst__work_8c_source.html":[3,0,4,3,1703],
-"db/dba/zpstrf_8f.html":[3,0,5,1877],
-"db/dba/zpstrf_8f_source.html":[3,0,5,1877],
+"db/dba/zpstrf_8f.html":[3,0,5,1875],
+"db/dba/zpstrf_8f_source.html":[3,0,5,1875],
 "db/dbd/lapacke__stpttf__work_8c.html":[3,0,4,3,1807],
 "db/dbd/lapacke__stpttf__work_8c_a2b9c3e8d6e30ba85de32623c2ee1bf76.html#a2b9c3e8d6e30ba85de32623c2ee1bf76":[3,0,4,3,1807,0],
 "db/dbd/lapacke__stpttf__work_8c_source.html":[3,0,4,3,1807],
@@ -103,7 +102,7 @@ var NAVTREEINDEX90 =
 "db/dc0/lapacke__ctpttf_8c_source.html":[3,0,4,3,574],
 "db/dc2/cblas__cher_8c.html":[3,0,1,2,12],
 "db/dc2/cblas__cher_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,12,0],
-"db/dc2/cblas__cher_8c_a29151e8ce446111c7ad321f69ff6e4a0.html#a29151e8ce446111c7ad321f69ff6e4a0":[3,0,1,2,12,4],
+"db/dc2/cblas__cher_8c_a23682f379de4e3fad03f8509f610bb26.html#a23682f379de4e3fad03f8509f610bb26":[3,0,1,2,12,4],
 "db/dc2/cblas__cher_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,12,2],
 "db/dc2/cblas__cher_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,12,1],
 "db/dc2/cblas__cher_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,12,3],
@@ -123,8 +122,8 @@ var NAVTREEINDEX90 =
 "db/dc5/cblas__ctpmv_8c.html":[3,0,1,2,27],
 "db/dc5/cblas__ctpmv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,27,0],
 "db/dc5/cblas__ctpmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,27,1],
-"db/dc5/cblas__ctpmv_8c_a1f2ac5f5f683cc132978b01997856a9b.html#a1f2ac5f5f683cc132978b01997856a9b":[3,0,1,2,27,5],
 "db/dc5/cblas__ctpmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,27,3],
+"db/dc5/cblas__ctpmv_8c_a78aacf0a77d00bc93097049795de5731.html#a78aacf0a77d00bc93097049795de5731":[3,0,1,2,27,5],
 "db/dc5/cblas__ctpmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,27,2],
 "db/dc5/cblas__ctpmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,27,4],
 "db/dc5/cblas__ctpmv_8c_source.html":[3,0,1,2,27],
@@ -139,8 +138,8 @@ var NAVTREEINDEX90 =
 "db/dc5/lapacke__cpf__nancheck_8c_source.html":[3,0,4,4,18],
 "db/dc5/zchkqrtp_8f.html":[3,0,6,1,596],
 "db/dc5/zchkqrtp_8f_source.html":[3,0,6,1,596],
-"db/dc5/zlahr2_8f.html":[3,0,5,1755],
-"db/dc5/zlahr2_8f_source.html":[3,0,5,1755],
+"db/dc5/zlahr2_8f.html":[3,0,5,1753],
+"db/dc5/zlahr2_8f_source.html":[3,0,5,1753],
 "db/dc6/lapacke__cggsvp__work_8c.html":[3,0,4,3,161],
 "db/dc6/lapacke__cggsvp__work_8c_ab5718bbe8a8aea87fcf36a6417e37570.html#ab5718bbe8a8aea87fcf36a6417e37570":[3,0,4,3,161,0],
 "db/dc6/lapacke__cggsvp__work_8c_source.html":[3,0,4,3,161],
@@ -157,23 +156,23 @@ var NAVTREEINDEX90 =
 "db/dc9/group__single__blas__level3.html":[0,2,2,0],
 "db/dc9/group__single__blas__level3_ga5a8ec25aba550c224cf6941fca7a2c98.html#ga5a8ec25aba550c224cf6941fca7a2c98":[0,2,2,0,4],
 "db/dc9/group__single__blas__level3_ga5a8ec25aba550c224cf6941fca7a2c98.html#ga5a8ec25aba550c224cf6941fca7a2c98":[3,0,0,0,110,0],
-"db/dc9/group__single__blas__level3_ga6ee4760a413296c246b1ecbc1ac985a0.html#ga6ee4760a413296c246b1ecbc1ac985a0":[0,2,2,0,2],
 "db/dc9/group__single__blas__level3_ga6ee4760a413296c246b1ecbc1ac985a0.html#ga6ee4760a413296c246b1ecbc1ac985a0":[3,0,0,0,104,0],
+"db/dc9/group__single__blas__level3_ga6ee4760a413296c246b1ecbc1ac985a0.html#ga6ee4760a413296c246b1ecbc1ac985a0":[0,2,2,0,2],
 "db/dc9/group__single__blas__level3_ga8e8391a9873114d97e2b63e39fe83b2e.html#ga8e8391a9873114d97e2b63e39fe83b2e":[0,2,2,0,1],
 "db/dc9/group__single__blas__level3_ga8e8391a9873114d97e2b63e39fe83b2e.html#ga8e8391a9873114d97e2b63e39fe83b2e":[3,0,0,0,100,0],
 "db/dc9/group__single__blas__level3_ga9893cceb3ffc7ce400eee405970191b3.html#ga9893cceb3ffc7ce400eee405970191b3":[0,2,2,0,5],
 "db/dc9/group__single__blas__level3_ga9893cceb3ffc7ce400eee405970191b3.html#ga9893cceb3ffc7ce400eee405970191b3":[3,0,0,0,112,0],
 "db/dc9/group__single__blas__level3_gae953a93420ca237670f5c67bbde9d9ff.html#gae953a93420ca237670f5c67bbde9d9ff":[0,2,2,0,3],
 "db/dc9/group__single__blas__level3_gae953a93420ca237670f5c67bbde9d9ff.html#gae953a93420ca237670f5c67bbde9d9ff":[3,0,0,0,105,0],
-"db/dc9/group__single__blas__level3_gafe51bacb54592ff5de056acabd83c260.html#gafe51bacb54592ff5de056acabd83c260":[0,2,2,0,0],
 "db/dc9/group__single__blas__level3_gafe51bacb54592ff5de056acabd83c260.html#gafe51bacb54592ff5de056acabd83c260":[3,0,0,0,86,0],
+"db/dc9/group__single__blas__level3_gafe51bacb54592ff5de056acabd83c260.html#gafe51bacb54592ff5de056acabd83c260":[0,2,2,0,0],
 "db/dc9/lapacke__dpb__trans_8c.html":[3,0,4,4,49],
 "db/dc9/lapacke__dpb__trans_8c_ada8037e4b01ec6731f3b1d4c66de078e.html#ada8037e4b01ec6731f3b1d4c66de078e":[3,0,4,4,49,0],
 "db/dc9/lapacke__dpb__trans_8c_source.html":[3,0,4,4,49],
 "db/dca/derrrq_8f.html":[3,0,6,1,289],
 "db/dca/derrrq_8f_source.html":[3,0,6,1,289],
-"db/dca/dtrevc_8f.html":[3,0,5,986],
-"db/dca/dtrevc_8f_source.html":[3,0,5,986],
+"db/dca/dtrevc_8f.html":[3,0,5,985],
+"db/dca/dtrevc_8f_source.html":[3,0,5,985],
 "db/dcc/dbdsqr_8f.html":[3,0,5,502],
 "db/dcc/dbdsqr_8f_source.html":[3,0,5,502],
 "db/dcc/lapacke__zgeqp3_8c.html":[3,0,4,3,1910],
@@ -188,8 +187,8 @@ var NAVTREEINDEX90 =
 "db/dcd/lapacke__spotrf2_8c.html":[3,0,4,3,1563],
 "db/dcd/lapacke__spotrf2_8c_a82d994b19ff078eeff60af28b8e85e14.html#a82d994b19ff078eeff60af28b8e85e14":[3,0,4,3,1563,0],
 "db/dcd/lapacke__spotrf2_8c_source.html":[3,0,4,3,1563],
-"db/dcd/zgetc2_8f.html":[3,0,5,1589],
-"db/dcd/zgetc2_8f_source.html":[3,0,5,1589],
+"db/dcd/zgetc2_8f.html":[3,0,5,1587],
+"db/dcd/zgetc2_8f_source.html":[3,0,5,1587],
 "db/dd1/group__sing_g_e.html":[0,0,0,2],
 "db/dd1/lapacke__cpftrf_8c.html":[3,0,4,3,386],
 "db/dd1/lapacke__cpftrf_8c_a3db1bdb4e15d7d379fe2fd1be0d7d35b.html#a3db1bdb4e15d7d379fe2fd1be0d7d35b":[3,0,4,3,386,0],
@@ -220,8 +219,8 @@ var NAVTREEINDEX90 =
 "db/dd6/zlqt03_8f_source.html":[3,0,6,1,714],
 "db/dd7/dtrt02_8f.html":[3,0,6,1,388],
 "db/dd7/dtrt02_8f_source.html":[3,0,6,1,388],
-"db/ddb/dgges_8f.html":[3,0,5,579],
-"db/ddb/dgges_8f_source.html":[3,0,5,579],
+"db/ddb/dgges_8f.html":[3,0,5,578],
+"db/ddb/dgges_8f_source.html":[3,0,5,578],
 "db/ddb/lapacke__ztrtrs_8c.html":[3,0,4,3,2432],
 "db/ddb/lapacke__ztrtrs_8c_ab7070dc14fffff06d20e58efe520c4d3.html#ab7070dc14fffff06d20e58efe520c4d3":[3,0,4,3,2432,0],
 "db/ddb/lapacke__ztrtrs_8c_source.html":[3,0,4,3,2432],
@@ -233,12 +232,12 @@ var NAVTREEINDEX90 =
 "db/ddc/lapacke__zpprfs_8c_source.html":[3,0,4,3,2258],
 "db/ddf/cchkaa_8_f.html":[3,0,6,1,7],
 "db/ddf/cchkaa_8_f_source.html":[3,0,6,1,7],
-"db/ddf/ztrttf_8f.html":[3,0,5,1979],
-"db/ddf/ztrttf_8f_source.html":[3,0,5,1979],
+"db/ddf/ztrttf_8f.html":[3,0,5,1977],
+"db/ddf/ztrttf_8f_source.html":[3,0,5,1977],
 "db/de1/clasyf_8f.html":[3,0,5,306],
 "db/de1/clasyf_8f_source.html":[3,0,5,306],
-"db/de4/dgecon_8f.html":[3,0,5,522],
-"db/de4/dgecon_8f_source.html":[3,0,5,522],
+"db/de4/dgecon_8f.html":[3,0,5,521],
+"db/de4/dgecon_8f_source.html":[3,0,5,521],
 "db/de4/lapacke__dpftrf_8c.html":[3,0,4,3,942],
 "db/de4/lapacke__dpftrf_8c_a8cd516c9f3a88d54392bd04678af7977.html#a8cd516c9f3a88d54392bd04678af7977":[3,0,4,3,942,0],
 "db/de4/lapacke__dpftrf_8c_source.html":[3,0,4,3,942],
@@ -247,7 +246,8 @@ var NAVTREEINDEX90 =
 "db/de4/lapacke__sgbsvxx__work_8c_source.html":[3,0,4,3,1269],
 "db/de5/clatzm_8f.html":[3,0,5,0,7],
 "db/de5/clatzm_8f_source.html":[3,0,5,0,7],
-"db/de5/dgeqp3_8f.html":[3,0,5,547],
-"db/de5/dgeqp3_8f_source.html":[3,0,5,547],
-"db/de5/lapacke__zgbtrf_8c.html":[3,0,4,3,1860]
+"db/de5/dgeqp3_8f.html":[3,0,5,546],
+"db/de5/dgeqp3_8f_source.html":[3,0,5,546],
+"db/de5/lapacke__zgbtrf_8c.html":[3,0,4,3,1860],
+"db/de5/lapacke__zgbtrf_8c_a8749b35bbb4f32553a65a6b2a17d18c1.html#a8749b35bbb4f32553a65a6b2a17d18c1":[3,0,4,3,1860,0]
 };
