@@ -1,9 +1,8 @@
 var NAVTREEINDEX91 =
 {
-"db/de5/lapacke__zgbtrf_8c_a8749b35bbb4f32553a65a6b2a17d18c1.html#a8749b35bbb4f32553a65a6b2a17d18c1":[3,0,4,3,1860,0],
 "db/de5/lapacke__zgbtrf_8c_source.html":[3,0,4,3,1860],
-"db/de6/zpftri_8f.html":[3,0,5,1853],
-"db/de6/zpftri_8f_source.html":[3,0,5,1853],
+"db/de6/zpftri_8f.html":[3,0,5,1851],
+"db/de6/zpftri_8f_source.html":[3,0,5,1851],
 "db/de7/lapacke__ctprfs__work_8c.html":[3,0,4,3,569],
 "db/de7/lapacke__ctprfs__work_8c_a06536b61edd487afedd908275686dd6a.html#a06536b61edd487afedd908275686dd6a":[3,0,4,3,569,0],
 "db/de7/lapacke__ctprfs__work_8c_source.html":[3,0,4,3,569],
@@ -12,17 +11,17 @@ var NAVTREEINDEX91 =
 "db/de8/lapacke__zlarfx_8c_source.html":[3,0,4,3,2192],
 "db/dea/ddrvsyx_8f.html":[3,0,6,1,268],
 "db/dea/ddrvsyx_8f_source.html":[3,0,6,1,268],
-"db/dea/slansy_8f.html":[3,0,5,1195],
-"db/dea/slansy_8f_source.html":[3,0,5,1195],
+"db/dea/slansy_8f.html":[3,0,5,1193],
+"db/dea/slansy_8f_source.html":[3,0,5,1193],
 "db/deb/lapacke__zlanhe_8c.html":[3,0,4,3,2174],
 "db/deb/lapacke__zlanhe_8c_abc785249729389d5737af5e6d3b44e77.html#abc785249729389d5737af5e6d3b44e77":[3,0,4,3,2174,0],
 "db/deb/lapacke__zlanhe_8c_source.html":[3,0,4,3,2174],
 "db/deb/lapacke__ztgevc__work_8c.html":[3,0,4,3,2385],
 "db/deb/lapacke__ztgevc__work_8c_a4c0c8178580dca1ef2a9e58b53e1c0be.html#a4c0c8178580dca1ef2a9e58b53e1c0be":[3,0,4,3,2385,0],
 "db/deb/lapacke__ztgevc__work_8c_source.html":[3,0,4,3,2385],
-"db/deb/tstiee_8f.html":[3,0,3,22],
-"db/deb/tstiee_8f_ac9e158139ad16abc79a0dce7ae8ad8c9.html#ac9e158139ad16abc79a0dce7ae8ad8c9":[3,0,3,22,0],
-"db/deb/tstiee_8f_source.html":[3,0,3,22],
+"db/deb/tstiee_8f.html":[3,0,3,24],
+"db/deb/tstiee_8f_ac9e158139ad16abc79a0dce7ae8ad8c9.html#ac9e158139ad16abc79a0dce7ae8ad8c9":[3,0,3,24,0],
+"db/deb/tstiee_8f_source.html":[3,0,3,24],
 "db/dec/claqps_8f.html":[3,0,5,265],
 "db/dec/claqps_8f_source.html":[3,0,5,265],
 "db/ded/ddrgsx_8f.html":[3,0,6,0,115],
@@ -45,10 +44,10 @@ var NAVTREEINDEX91 =
 "db/def/group__complex__blas__level3_gac4e11e8e8a4b0c802d2229b08da341f6.html#gac4e11e8e8a4b0c802d2229b08da341f6":[3,0,0,0,5,0],
 "db/def/group__complex__blas__level3_gad2d1853a142397404eae974b6574ece3.html#gad2d1853a142397404eae974b6574ece3":[3,0,0,0,10,0],
 "db/def/group__complex__blas__level3_gad2d1853a142397404eae974b6574ece3.html#gad2d1853a142397404eae974b6574ece3":[0,2,2,2,1],
-"db/def/group__complex__blas__level3_gad7c297c05b482699b6d60a29c8d4a165.html#gad7c297c05b482699b6d60a29c8d4a165":[0,2,2,2,7],
 "db/def/group__complex__blas__level3_gad7c297c05b482699b6d60a29c8d4a165.html#gad7c297c05b482699b6d60a29c8d4a165":[3,0,0,0,31,0],
-"db/def/group__complex__blas__level3_gade9f14cf41f0cefea7918d716f3e1c20.html#gade9f14cf41f0cefea7918d716f3e1c20":[3,0,0,0,15,0],
+"db/def/group__complex__blas__level3_gad7c297c05b482699b6d60a29c8d4a165.html#gad7c297c05b482699b6d60a29c8d4a165":[0,2,2,2,7],
 "db/def/group__complex__blas__level3_gade9f14cf41f0cefea7918d716f3e1c20.html#gade9f14cf41f0cefea7918d716f3e1c20":[0,2,2,2,3],
+"db/def/group__complex__blas__level3_gade9f14cf41f0cefea7918d716f3e1c20.html#gade9f14cf41f0cefea7918d716f3e1c20":[3,0,0,0,15,0],
 "db/def/group__complex__blas__level3_gaf33844c7fd27e5434496d2ce0c1fc9d4.html#gaf33844c7fd27e5434496d2ce0c1fc9d4":[0,2,2,2,8],
 "db/def/group__complex__blas__level3_gaf33844c7fd27e5434496d2ce0c1fc9d4.html#gaf33844c7fd27e5434496d2ce0c1fc9d4":[3,0,0,0,33,0],
 "db/def/group__complex__blas__level3_gaf5266b622e0fbbd972cfc2df3061984f.html#gaf5266b622e0fbbd972cfc2df3061984f":[0,2,2,2,2],
@@ -59,24 +58,24 @@ var NAVTREEINDEX91 =
 "db/def/lapacke__dgbtrs__work_8c.html":[3,0,4,3,675],
 "db/def/lapacke__dgbtrs__work_8c_a10798bcaf52a3610626a000b9a32ae66.html#a10798bcaf52a3610626a000b9a32ae66":[3,0,4,3,675,0],
 "db/def/lapacke__dgbtrs__work_8c_source.html":[3,0,4,3,675],
-"db/df0/dormrz_8f.html":[3,0,5,814],
-"db/df0/dormrz_8f_source.html":[3,0,5,814],
-"db/df0/slantr_8f.html":[3,0,5,1198],
-"db/df0/slantr_8f_source.html":[3,0,5,1198],
-"db/df2/dsyconvf__rook_8f.html":[3,0,5,906],
-"db/df2/dsyconvf__rook_8f_source.html":[3,0,5,906],
+"db/df0/dormrz_8f.html":[3,0,5,813],
+"db/df0/dormrz_8f_source.html":[3,0,5,813],
+"db/df0/slantr_8f.html":[3,0,5,1196],
+"db/df0/slantr_8f_source.html":[3,0,5,1196],
+"db/df2/dsyconvf__rook_8f.html":[3,0,5,905],
+"db/df2/dsyconvf__rook_8f_source.html":[3,0,5,905],
 "db/df2/lapacke__dggesx_8c.html":[3,0,4,3,784],
 "db/df2/lapacke__dggesx_8c_a4ae664231117af153833f9a19131c471.html#a4ae664231117af153833f9a19131c471":[3,0,4,3,784,0],
 "db/df2/lapacke__dggesx_8c_source.html":[3,0,4,3,784],
-"db/df3/zhesv__rk_8f.html":[3,0,5,1657],
-"db/df3/zhesv__rk_8f_source.html":[3,0,5,1657],
-"db/df4/dlamswlq_8f.html":[3,0,5,661],
-"db/df4/dlamswlq_8f_a1fa2f387d69d499a33db38d9e0d9065f.html#a1fa2f387d69d499a33db38d9e0d9065f":[3,0,5,661,0],
-"db/df4/dlamswlq_8f_source.html":[3,0,5,661],
-"db/df4/dlarfb_8f.html":[3,0,5,706],
-"db/df4/dlarfb_8f_source.html":[3,0,5,706],
-"db/df4/dsytrf__rook_8f.html":[3,0,5,944],
-"db/df4/dsytrf__rook_8f_source.html":[3,0,5,944],
+"db/df3/zhesv__rk_8f.html":[3,0,5,1655],
+"db/df3/zhesv__rk_8f_source.html":[3,0,5,1655],
+"db/df4/dlamswlq_8f.html":[3,0,5,660],
+"db/df4/dlamswlq_8f_a1fa2f387d69d499a33db38d9e0d9065f.html#a1fa2f387d69d499a33db38d9e0d9065f":[3,0,5,660,0],
+"db/df4/dlamswlq_8f_source.html":[3,0,5,660],
+"db/df4/dlarfb_8f.html":[3,0,5,705],
+"db/df4/dlarfb_8f_source.html":[3,0,5,705],
+"db/df4/dsytrf__rook_8f.html":[3,0,5,943],
+"db/df4/dsytrf__rook_8f_source.html":[3,0,5,943],
 "db/df4/lapacke__ctzrzf__work_8c.html":[3,0,4,3,601],
 "db/df4/lapacke__ctzrzf__work_8c_a5fae983ee8b7d27f3bc33b7a851929e3.html#a5fae983ee8b7d27f3bc33b7a851929e3":[3,0,4,3,601,0],
 "db/df4/lapacke__ctzrzf__work_8c_source.html":[3,0,4,3,601],
@@ -125,15 +124,15 @@ var NAVTREEINDEX91 =
 "db/df9/lapacke__cgeqrt2__work_8c_source.html":[3,0,4,3,86],
 "db/dfa/cdrges_8f.html":[3,0,6,0,30],
 "db/dfa/cdrges_8f_source.html":[3,0,6,0,30],
-"db/dfa/dtgex2_8f.html":[3,0,5,965],
-"db/dfa/dtgex2_8f_source.html":[3,0,5,965],
+"db/dfa/dtgex2_8f.html":[3,0,5,964],
+"db/dfa/dtgex2_8f_source.html":[3,0,5,964],
 "db/dfa/lapacke__cggsvp_8c.html":[3,0,4,3,158],
 "db/dfa/lapacke__cggsvp_8c_a01500aacdedfc557ad18af4e0b6122a5.html#a01500aacdedfc557ad18af4e0b6122a5":[3,0,4,3,158,0],
 "db/dfa/lapacke__cggsvp_8c_source.html":[3,0,4,3,158],
 "db/dfb/cgeqr2_8f.html":[3,0,5,47],
 "db/dfb/cgeqr2_8f_source.html":[3,0,5,47],
-"db/dfc/dtgexc_8f.html":[3,0,5,966],
-"db/dfc/dtgexc_8f_source.html":[3,0,5,966],
+"db/dfc/dtgexc_8f.html":[3,0,5,965],
+"db/dfc/dtgexc_8f_source.html":[3,0,5,965],
 "db/dfd/lapacke__dtgevc_8c.html":[3,0,4,3,1184],
 "db/dfd/lapacke__dtgevc_8c_a87ae4c118f8c87b0052ae4db4b7643b4.html#a87ae4c118f8c87b0052ae4db4b7643b4":[3,0,4,3,1184,0],
 "db/dfd/lapacke__dtgevc_8c_source.html":[3,0,4,3,1184],
@@ -162,57 +161,57 @@ var NAVTREEINDEX91 =
 "dc/d02/lapacke__zunmqr_8c.html":[3,0,4,3,2470],
 "dc/d02/lapacke__zunmqr_8c_a70a83145d0b21ca5775fa96ecd6d6644.html#a70a83145d0b21ca5775fa96ecd6d6644":[3,0,4,3,2470,0],
 "dc/d02/lapacke__zunmqr_8c_source.html":[3,0,4,3,2470],
-"dc/d04/dsygst_8f.html":[3,0,5,917],
-"dc/d04/dsygst_8f_source.html":[3,0,5,917],
+"dc/d04/dsygst_8f.html":[3,0,5,916],
+"dc/d04/dsygst_8f_source.html":[3,0,5,916],
 "dc/d04/group___h_e.html":[0,0,3],
 "dc/d04/zchkpp_8f.html":[3,0,6,1,589],
 "dc/d04/zchkpp_8f_source.html":[3,0,6,1,589],
 "dc/d05/dsyrk_8f.html":[3,0,0,0,61],
 "dc/d05/dsyrk_8f_source.html":[3,0,0,0,61],
-"dc/d06/ilaclc_8f.html":[3,0,5,1002],
-"dc/d06/ilaclc_8f_source.html":[3,0,5,1002],
+"dc/d06/ilaclc_8f.html":[3,0,5,1001],
+"dc/d06/ilaclc_8f_source.html":[3,0,5,1001],
 "dc/d06/lapacke__zppsv_8c.html":[3,0,4,3,2260],
 "dc/d06/lapacke__zppsv_8c_aaea1b1f6c9999b10dda36e63a2c0a218.html#aaea1b1f6c9999b10dda36e63a2c0a218":[3,0,4,3,2260,0],
 "dc/d06/lapacke__zppsv_8c_source.html":[3,0,4,3,2260],
 "dc/d06/sspt01_8f.html":[3,0,6,1,549],
 "dc/d06/sspt01_8f_source.html":[3,0,6,1,549],
-"dc/d07/dgbequb_8f.html":[3,0,5,509],
-"dc/d07/dgbequb_8f_source.html":[3,0,5,509],
+"dc/d07/dgbequb_8f.html":[3,0,5,508],
+"dc/d07/dgbequb_8f_source.html":[3,0,5,508],
 "dc/d08/stbt03_8f.html":[3,0,6,1,555],
 "dc/d08/stbt03_8f_source.html":[3,0,6,1,555],
 "dc/d09/cblas__srot_8c.html":[3,0,1,2,86],
-"dc/d09/cblas__srot_8c_a1050438afc83892110500db753a419f3.html#a1050438afc83892110500db753a419f3":[3,0,1,2,86,3],
 "dc/d09/cblas__srot_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,86,0],
 "dc/d09/cblas__srot_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,86,1],
+"dc/d09/cblas__srot_8c_a720fa5b6a496bb33b0e634babba74384.html#a720fa5b6a496bb33b0e634babba74384":[3,0,1,2,86,3],
 "dc/d09/cblas__srot_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,86,2],
 "dc/d09/cblas__srot_8c_source.html":[3,0,1,2,86],
-"dc/d09/dlange_8f.html":[3,0,5,665],
-"dc/d09/dlange_8f_source.html":[3,0,5,665],
+"dc/d09/dlange_8f.html":[3,0,5,664],
+"dc/d09/dlange_8f_source.html":[3,0,5,664],
 "dc/d09/lapacke__sporfs_8c.html":[3,0,4,3,1552],
 "dc/d09/lapacke__sporfs_8c_a022a274558ce78113b67697ee0d0b6fe.html#a022a274558ce78113b67697ee0d0b6fe":[3,0,4,3,1552,0],
 "dc/d09/lapacke__sporfs_8c_source.html":[3,0,4,3,1552],
 "dc/d09/lapacke__zheevr__2stage_8c.html":[3,0,4,3,2049],
 "dc/d09/lapacke__zheevr__2stage_8c_a1644ad7a37bb638e1b884ed8c938490e.html#a1644ad7a37bb638e1b884ed8c938490e":[3,0,4,3,2049,0],
 "dc/d09/lapacke__zheevr__2stage_8c_source.html":[3,0,4,3,2049],
-"dc/d09/slamswlq_8f.html":[3,0,5,1184],
-"dc/d09/slamswlq_8f_a31ca6763f721e788df6de9e4e4fdaf19.html#a31ca6763f721e788df6de9e4e4fdaf19":[3,0,5,1184,0],
-"dc/d09/slamswlq_8f_source.html":[3,0,5,1184],
-"dc/d0a/dsytri2_8f.html":[3,0,5,946],
-"dc/d0a/dsytri2_8f_source.html":[3,0,5,946],
-"dc/d0a/spprfs_8f.html":[3,0,5,1365],
-"dc/d0a/spprfs_8f_source.html":[3,0,5,1365],
-"dc/d0a/zpftrf_8f.html":[3,0,5,1852],
-"dc/d0a/zpftrf_8f_source.html":[3,0,5,1852],
+"dc/d09/slamswlq_8f.html":[3,0,5,1182],
+"dc/d09/slamswlq_8f_a31ca6763f721e788df6de9e4e4fdaf19.html#a31ca6763f721e788df6de9e4e4fdaf19":[3,0,5,1182,0],
+"dc/d09/slamswlq_8f_source.html":[3,0,5,1182],
+"dc/d0a/dsytri2_8f.html":[3,0,5,945],
+"dc/d0a/dsytri2_8f_source.html":[3,0,5,945],
+"dc/d0a/spprfs_8f.html":[3,0,5,1363],
+"dc/d0a/spprfs_8f_source.html":[3,0,5,1363],
+"dc/d0a/zpftrf_8f.html":[3,0,5,1850],
+"dc/d0a/zpftrf_8f_source.html":[3,0,5,1850],
 "dc/d0b/cblas__csscal_8c.html":[3,0,1,2,20],
 "dc/d0b/cblas__csscal_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,20,0],
 "dc/d0b/cblas__csscal_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,20,1],
-"dc/d0b/cblas__csscal_8c_a98afc9535aea989a4ac9fce39744724d.html#a98afc9535aea989a4ac9fce39744724d":[3,0,1,2,20,2],
+"dc/d0b/cblas__csscal_8c_af188630f492fb75610745e01d906635c.html#af188630f492fb75610745e01d906635c":[3,0,1,2,20,2],
 "dc/d0b/cblas__csscal_8c_source.html":[3,0,1,2,20],
 "dc/d0b/group__complex16_g_bauxiliary.html":[0,0,1,2,3],
-"dc/d0b/group__complex16_g_bauxiliary_ga0a7b3dc47c271db64d0f1001bcd2cdf7.html#ga0a7b3dc47c271db64d0f1001bcd2cdf7":[3,0,5,1780,0],
 "dc/d0b/group__complex16_g_bauxiliary_ga0a7b3dc47c271db64d0f1001bcd2cdf7.html#ga0a7b3dc47c271db64d0f1001bcd2cdf7":[0,0,1,2,3,1],
-"dc/d0b/group__complex16_g_bauxiliary_gad6a0255b5203b49d0f7828f0e03522aa.html#gad6a0255b5203b49d0f7828f0e03522aa":[3,0,5,1762,0],
+"dc/d0b/group__complex16_g_bauxiliary_ga0a7b3dc47c271db64d0f1001bcd2cdf7.html#ga0a7b3dc47c271db64d0f1001bcd2cdf7":[3,0,5,1778,0],
 "dc/d0b/group__complex16_g_bauxiliary_gad6a0255b5203b49d0f7828f0e03522aa.html#gad6a0255b5203b49d0f7828f0e03522aa":[0,0,1,2,3,0],
+"dc/d0b/group__complex16_g_bauxiliary_gad6a0255b5203b49d0f7828f0e03522aa.html#gad6a0255b5203b49d0f7828f0e03522aa":[3,0,5,1760,0],
 "dc/d0b/lapacke__dgeqlf_8c.html":[3,0,4,3,720],
 "dc/d0b/lapacke__dgeqlf_8c_a28926ae7122ed0291070837f4afa6f70.html#a28926ae7122ed0291070837f4afa6f70":[3,0,4,3,720,0],
 "dc/d0b/lapacke__dgeqlf_8c_source.html":[3,0,4,3,720],
@@ -221,21 +220,21 @@ var NAVTREEINDEX91 =
 "dc/d0b/sggsvd_8f_source.html":[3,0,5,0,22],
 "dc/d0b/sgrqts_8f.html":[3,0,6,0,249],
 "dc/d0b/sgrqts_8f_source.html":[3,0,6,0,249],
-"dc/d0b/slansf_8f.html":[3,0,5,1192],
-"dc/d0b/slansf_8f_source.html":[3,0,5,1192],
+"dc/d0b/slansf_8f.html":[3,0,5,1190],
+"dc/d0b/slansf_8f_source.html":[3,0,5,1190],
 "dc/d0c/cchkunhr__col_8f.html":[3,0,6,1,44],
 "dc/d0c/cchkunhr__col_8f_source.html":[3,0,6,1,44],
-"dc/d0c/dtgsna_8f.html":[3,0,5,969],
-"dc/d0c/dtgsna_8f_source.html":[3,0,5,969],
+"dc/d0c/dtgsna_8f.html":[3,0,5,968],
+"dc/d0c/dtgsna_8f_source.html":[3,0,5,968],
 "dc/d0c/lapacke__sgesvdq__work_8c.html":[3,0,4,3,1351],
 "dc/d0c/lapacke__sgesvdq__work_8c_a26001898a32ad6da74def54b3baab3e1.html#a26001898a32ad6da74def54b3baab3e1":[3,0,4,3,1351,0],
 "dc/d0c/lapacke__sgesvdq__work_8c_source.html":[3,0,4,3,1351],
 "dc/d0c/zdrvhe__rook_8f.html":[3,0,6,1,622],
 "dc/d0c/zdrvhe__rook_8f_source.html":[3,0,6,1,622],
-"dc/d0c/zrot_8f.html":[3,0,5,1886],
-"dc/d0c/zrot_8f_source.html":[3,0,5,1886],
-"dc/d0d/zlanhp_8f.html":[3,0,5,1768],
-"dc/d0d/zlanhp_8f_source.html":[3,0,5,1768],
+"dc/d0c/zrot_8f.html":[3,0,5,1884],
+"dc/d0c/zrot_8f_source.html":[3,0,5,1884],
+"dc/d0d/zlanhp_8f.html":[3,0,5,1766],
+"dc/d0d/zlanhp_8f_source.html":[3,0,5,1766],
 "dc/d0e/ddrges_8f.html":[3,0,6,0,111],
 "dc/d0e/ddrges_8f_source.html":[3,0,6,0,111],
 "dc/d10/lapacke__zhetrs__rook_8c.html":[3,0,4,3,2113],
@@ -248,6 +247,7 @@ var NAVTREEINDEX91 =
 "dc/d12/lapacke__zhbevd_8c_source.html":[3,0,4,3,2016],
 "dc/d13/clasyf__aa_8f.html":[3,0,5,307],
 "dc/d13/clasyf__aa_8f_source.html":[3,0,5,307],
-"dc/d13/sorml2_8f.html":[3,0,5,1329],
-"dc/d13/sorml2_8f_source.html":[3,0,5,1329]
+"dc/d13/sorml2_8f.html":[3,0,5,1327],
+"dc/d13/sorml2_8f_source.html":[3,0,5,1327],
+"dc/d14/lapacke__zggsvd_8c.html":[3,0,4,3,1992]
 };
