@@ -1,6 +1,5 @@
 var NAVTREEINDEX92 =
 {
-"dc/d14/lapacke__zggsvd_8c.html":[3,0,4,3,1992],
 "dc/d14/lapacke__zggsvd_8c_a8dea9e6a81ab80654e4f7800e94bb6ac.html#a8dea9e6a81ab80654e4f7800e94bb6ac":[3,0,4,3,1992,0],
 "dc/d14/lapacke__zggsvd_8c_source.html":[3,0,4,3,1992],
 "dc/d15/cla__porfsx__extended_8f.html":[3,0,5,203],
@@ -25,23 +24,23 @@ var NAVTREEINDEX92 =
 "dc/d17/group__complex16__blas__level3_ga6c1fde6c797cc1032c19242662f370f2.html#ga6c1fde6c797cc1032c19242662f370f2":[3,0,0,0,128,0],
 "dc/d17/group__complex16__blas__level3_ga71e68893445a523b923411ebf4c22582.html#ga71e68893445a523b923411ebf4c22582":[0,2,2,3,3],
 "dc/d17/group__complex16__blas__level3_ga71e68893445a523b923411ebf4c22582.html#ga71e68893445a523b923411ebf4c22582":[3,0,0,0,133,0],
-"dc/d17/group__complex16__blas__level3_ga7610d30107c40b4009d5c9359d9c6c28.html#ga7610d30107c40b4009d5c9359d9c6c28":[3,0,0,0,132,0],
 "dc/d17/group__complex16__blas__level3_ga7610d30107c40b4009d5c9359d9c6c28.html#ga7610d30107c40b4009d5c9359d9c6c28":[0,2,2,3,2],
-"dc/d17/group__complex16__blas__level3_gabe5914922259539af5fa20f324a58add.html#gabe5914922259539af5fa20f324a58add":[3,0,0,0,141,0],
+"dc/d17/group__complex16__blas__level3_ga7610d30107c40b4009d5c9359d9c6c28.html#ga7610d30107c40b4009d5c9359d9c6c28":[3,0,0,0,132,0],
 "dc/d17/group__complex16__blas__level3_gabe5914922259539af5fa20f324a58add.html#gabe5914922259539af5fa20f324a58add":[0,2,2,3,5],
+"dc/d17/group__complex16__blas__level3_gabe5914922259539af5fa20f324a58add.html#gabe5914922259539af5fa20f324a58add":[3,0,0,0,141,0],
 "dc/d17/group__complex16__blas__level3_gac571a0a6d43e969990456d0676edb786.html#gac571a0a6d43e969990456d0676edb786":[0,2,2,3,8],
 "dc/d17/group__complex16__blas__level3_gac571a0a6d43e969990456d0676edb786.html#gac571a0a6d43e969990456d0676edb786":[3,0,0,0,149,0],
 "dc/d17/group__complex16__blas__level3_gafa941b30529f8c06ffb6a1b2e09e0abd.html#gafa941b30529f8c06ffb6a1b2e09e0abd":[0,2,2,3,7],
 "dc/d17/group__complex16__blas__level3_gafa941b30529f8c06ffb6a1b2e09e0abd.html#gafa941b30529f8c06ffb6a1b2e09e0abd":[3,0,0,0,147,0],
 "dc/d18/cblas__dgemm_8c.html":[3,0,1,2,38],
 "dc/d18/cblas__dgemm_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,38,3],
+"dc/d18/cblas__dgemm_8c_a1f0d3fc6dfce9305281adbe5ac889488.html#a1f0d3fc6dfce9305281adbe5ac889488":[3,0,1,2,38,8],
 "dc/d18/cblas__dgemm_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,38,0],
 "dc/d18/cblas__dgemm_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,38,2],
 "dc/d18/cblas__dgemm_8c_a5e21023e217bd5a6db0984f3164ba6fc.html#a5e21023e217bd5a6db0984f3164ba6fc":[3,0,1,2,38,7],
 "dc/d18/cblas__dgemm_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,38,6],
 "dc/d18/cblas__dgemm_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,38,5],
 "dc/d18/cblas__dgemm_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,38,1],
-"dc/d18/cblas__dgemm_8c_ad07ba707cc7a6b23df8576123fac3e0d.html#ad07ba707cc7a6b23df8576123fac3e0d":[3,0,1,2,38,8],
 "dc/d18/cblas__dgemm_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,38,4],
 "dc/d18/cblas__dgemm_8c_source.html":[3,0,1,2,38],
 "dc/d18/cgeqrfp_8f.html":[3,0,5,50],
@@ -67,16 +66,16 @@ var NAVTREEINDEX92 =
 "dc/d1d/lapacke__ctbcon_8c_source.html":[3,0,4,3,532],
 "dc/d1e/strt06_8f.html":[3,0,6,1,568],
 "dc/d1e/strt06_8f_source.html":[3,0,6,1,568],
-"dc/d1f/sgeev_8f.html":[3,0,5,1050],
-"dc/d1f/sgeev_8f_source.html":[3,0,5,1050],
+"dc/d1f/sgeev_8f.html":[3,0,5,1048],
+"dc/d1f/sgeev_8f_source.html":[3,0,5,1048],
 "dc/d20/cla__syrcond__x_8f.html":[3,0,5,207],
 "dc/d20/cla__syrcond__x_8f_source.html":[3,0,5,207],
 "dc/d21/chetf2_8f.html":[3,0,5,141],
 "dc/d21/chetf2_8f_source.html":[3,0,5,141],
 "dc/d21/cunbdb5_8f.html":[3,0,5,466],
 "dc/d21/cunbdb5_8f_source.html":[3,0,5,466],
-"dc/d21/dgerfsx_8f.html":[3,0,5,557],
-"dc/d21/dgerfsx_8f_source.html":[3,0,5,557],
+"dc/d21/dgerfsx_8f.html":[3,0,5,556],
+"dc/d21/dgerfsx_8f_source.html":[3,0,5,556],
 "dc/d21/lapacke__cgt__nancheck_8c.html":[3,0,4,4,7],
 "dc/d21/lapacke__cgt__nancheck_8c_a63a94370c10fc2a97391fb77a0034e81.html#a63a94370c10fc2a97391fb77a0034e81":[3,0,4,4,7,0],
 "dc/d21/lapacke__cgt__nancheck_8c_source.html":[3,0,4,4,7],
@@ -88,9 +87,9 @@ var NAVTREEINDEX92 =
 "dc/d22/cblas__chbmv_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,9,1],
 "dc/d22/cblas__chbmv_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,9,2],
 "dc/d22/cblas__chbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,9,4],
-"dc/d22/cblas__chbmv_8c_a7e579dc6d784d2e6a96d1db25debcfe3.html#a7e579dc6d784d2e6a96d1db25debcfe3":[3,0,1,2,9,6],
 "dc/d22/cblas__chbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,9,3],
 "dc/d22/cblas__chbmv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,9,5],
+"dc/d22/cblas__chbmv_8c_ae7aa28112d7719fb8fc3e58b4a375a18.html#ae7aa28112d7719fb8fc3e58b4a375a18":[3,0,1,2,9,6],
 "dc/d22/cblas__chbmv_8c_source.html":[3,0,1,2,9],
 "dc/d23/dqrt03_8f.html":[3,0,6,1,357],
 "dc/d23/dqrt03_8f_source.html":[3,0,6,1,357],
@@ -98,8 +97,8 @@ var NAVTREEINDEX92 =
 "dc/d23/drot_8f_source.html":[3,0,0,0,45],
 "dc/d23/sqrt15_8f.html":[3,0,6,1,541],
 "dc/d23/sqrt15_8f_source.html":[3,0,6,1,541],
-"dc/d23/zlarfg_8f.html":[3,0,5,1806],
-"dc/d23/zlarfg_8f_source.html":[3,0,5,1806],
+"dc/d23/zlarfg_8f.html":[3,0,5,1804],
+"dc/d23/zlarfg_8f_source.html":[3,0,5,1804],
 "dc/d24/lapacke__dsgesv__work_8c.html":[3,0,4,3,1029],
 "dc/d24/lapacke__dsgesv__work_8c_a0a2b93b1a881c9b11074d31dd4c6dbea.html#a0a2b93b1a881c9b11074d31dd4c6dbea":[3,0,4,3,1029,0],
 "dc/d24/lapacke__dsgesv__work_8c_source.html":[3,0,4,3,1029],
@@ -116,8 +115,8 @@ var NAVTREEINDEX92 =
 "dc/d27/lapacke__cspsvx__work_8c.html":[3,0,4,3,455],
 "dc/d27/lapacke__cspsvx__work_8c_afd5828ee572776f7a034638f340cd0a6.html#afd5828ee572776f7a034638f340cd0a6":[3,0,4,3,455,0],
 "dc/d27/lapacke__cspsvx__work_8c_source.html":[3,0,4,3,455],
-"dc/d28/dorg2l_8f.html":[3,0,5,788],
-"dc/d28/dorg2l_8f_source.html":[3,0,5,788],
+"dc/d28/dorg2l_8f.html":[3,0,5,787],
+"dc/d28/dorg2l_8f_source.html":[3,0,5,787],
 "dc/d28/lapacke__cheevx__2stage_8c.html":[3,0,4,3,215],
 "dc/d28/lapacke__cheevx__2stage_8c_aca72bc9745272cb39d5f1ad17f0b20b4.html#aca72bc9745272cb39d5f1ad17f0b20b4":[3,0,4,3,215,0],
 "dc/d28/lapacke__cheevx__2stage_8c_source.html":[3,0,4,3,215],
@@ -132,8 +131,8 @@ var NAVTREEINDEX92 =
 "dc/d2d/lapacke__dsyconv__work_8c.html":[3,0,4,3,1089],
 "dc/d2d/lapacke__dsyconv__work_8c_ad40d7829a57ceb8fbb921be1cb89a4f0.html#ad40d7829a57ceb8fbb921be1cb89a4f0":[3,0,4,3,1089,0],
 "dc/d2d/lapacke__dsyconv__work_8c_source.html":[3,0,4,3,1089],
-"dc/d2e/_s_r_c_2xerbla__array_8f.html":[3,0,5,1520],
-"dc/d2e/_s_r_c_2xerbla__array_8f_source.html":[3,0,5,1520],
+"dc/d2e/_s_r_c_2xerbla__array_8f.html":[3,0,5,1518],
+"dc/d2e/_s_r_c_2xerbla__array_8f_source.html":[3,0,5,1518],
 "dc/d2e/c__sblat2_8f.html":[3,0,1,3,23],
 "dc/d2e/c__sblat2_8f_a1c298334ebbca6a82c3c32bc24fa9286.html#a1c298334ebbca6a82c3c32bc24fa9286":[3,0,1,3,23,0],
 "dc/d2e/c__sblat2_8f_a32d78fc1870b445eb93c08d4faa9e1f5.html#a32d78fc1870b445eb93c08d4faa9e1f5":[3,0,1,3,23,12],
@@ -152,10 +151,10 @@ var NAVTREEINDEX92 =
 "dc/d2e/lapacke__cgghrd__work_8c.html":[3,0,4,3,147],
 "dc/d2e/lapacke__cgghrd__work_8c_a0c58f8b9ec2af6a4d6dbcbd04c89c0df.html#a0c58f8b9ec2af6a4d6dbcbd04c89c0df":[3,0,4,3,147,0],
 "dc/d2e/lapacke__cgghrd__work_8c_source.html":[3,0,4,3,147],
-"dc/d2f/dsbgvx_8f.html":[3,0,5,870],
-"dc/d2f/dsbgvx_8f_source.html":[3,0,5,870],
-"dc/d31/dorbdb3_8f.html":[3,0,5,782],
-"dc/d31/dorbdb3_8f_source.html":[3,0,5,782],
+"dc/d2f/dsbgvx_8f.html":[3,0,5,869],
+"dc/d2f/dsbgvx_8f_source.html":[3,0,5,869],
+"dc/d31/dorbdb3_8f.html":[3,0,5,781],
+"dc/d31/dorbdb3_8f_source.html":[3,0,5,781],
 "dc/d32/lapacke__ssycon_8c.html":[3,0,4,3,1678],
 "dc/d32/lapacke__ssycon_8c_a331f11b66ea3e2bb962a5a2bcaef3220.html#a331f11b66ea3e2bb962a5a2bcaef3220":[3,0,4,3,1678,0],
 "dc/d32/lapacke__ssycon_8c_source.html":[3,0,4,3,1678],
@@ -176,16 +175,16 @@ var NAVTREEINDEX92 =
 "dc/d35/lapacke__zptrfs__work_8c.html":[3,0,4,3,2277],
 "dc/d35/lapacke__zptrfs__work_8c_ab69d2b4696788d2f099c55bcce2a14cd.html#ab69d2b4696788d2f099c55bcce2a14cd":[3,0,4,3,2277,0],
 "dc/d35/lapacke__zptrfs__work_8c_source.html":[3,0,4,3,2277],
-"dc/d35/slaed3_8f.html":[3,0,5,1157],
-"dc/d35/slaed3_8f_source.html":[3,0,5,1157],
+"dc/d35/slaed3_8f.html":[3,0,5,1155],
+"dc/d35/slaed3_8f_source.html":[3,0,5,1155],
 "dc/d35/zlaghe_8f.html":[3,0,6,2,57],
 "dc/d35/zlaghe_8f_source.html":[3,0,6,2,57],
-"dc/d36/dlarrv_8f.html":[3,0,5,724],
-"dc/d36/dlarrv_8f_source.html":[3,0,5,724],
+"dc/d36/dlarrv_8f.html":[3,0,5,723],
+"dc/d36/dlarrv_8f_source.html":[3,0,5,723],
 "dc/d37/cchkpo_8f.html":[3,0,6,1,22],
 "dc/d37/cchkpo_8f_source.html":[3,0,6,1,22],
-"dc/d37/ddisna_8f.html":[3,0,5,505],
-"dc/d37/ddisna_8f_source.html":[3,0,5,505],
+"dc/d37/ddisna_8f.html":[3,0,5,504],
+"dc/d37/ddisna_8f_source.html":[3,0,5,504],
 "dc/d37/dpbt02_8f.html":[3,0,6,1,335],
 "dc/d37/dpbt02_8f_source.html":[3,0,6,1,335],
 "dc/d37/lapacke__sgelq2_8c.html":[3,0,4,3,1299],
@@ -205,15 +204,15 @@ var NAVTREEINDEX92 =
 "dc/d3a/lapacke__zsyrfs__work_8c_source.html":[3,0,4,3,2321],
 "dc/d3a/sckglm_8f.html":[3,0,6,0,202],
 "dc/d3a/sckglm_8f_source.html":[3,0,6,0,202],
-"dc/d3a/strsna_8f.html":[3,0,5,1511],
-"dc/d3a/strsna_8f_source.html":[3,0,5,1511],
+"dc/d3a/strsna_8f.html":[3,0,5,1509],
+"dc/d3a/strsna_8f_source.html":[3,0,5,1509],
 "dc/d3b/ctpt03_8f.html":[3,0,6,1,200],
 "dc/d3b/ctpt03_8f_source.html":[3,0,6,1,200],
 "dc/d3b/lapacke__sgetsqrhrt_8c.html":[3,0,4,3,1372],
 "dc/d3b/lapacke__sgetsqrhrt_8c_ab97cda672dfad5f36fbfc00ae77eeb86.html#ab97cda672dfad5f36fbfc00ae77eeb86":[3,0,4,3,1372,0],
 "dc/d3b/lapacke__sgetsqrhrt_8c_source.html":[3,0,4,3,1372],
-"dc/d3c/strsen_8f.html":[3,0,5,1510],
-"dc/d3c/strsen_8f_source.html":[3,0,5,1510],
+"dc/d3c/strsen_8f.html":[3,0,5,1508],
+"dc/d3c/strsen_8f_source.html":[3,0,5,1508],
 "dc/d3d/lapacke__chesv__aa__2stage__work_8c.html":[3,0,4,3,235],
 "dc/d3d/lapacke__chesv__aa__2stage__work_8c_afe668e14ab1b2dc1aa3789ba9c3f0908.html#afe668e14ab1b2dc1aa3789ba9c3f0908":[3,0,4,3,235,0],
 "dc/d3d/lapacke__chesv__aa__2stage__work_8c_source.html":[3,0,4,3,235],
@@ -222,8 +221,8 @@ var NAVTREEINDEX92 =
 "dc/d3e/lapacke__cgeesx_8c.html":[3,0,4,3,40],
 "dc/d3e/lapacke__cgeesx_8c_a5f563f60c122711c05c8f4d69f4b847e.html#a5f563f60c122711c05c8f4d69f4b847e":[3,0,4,3,40,0],
 "dc/d3e/lapacke__cgeesx_8c_source.html":[3,0,4,3,40],
-"dc/d3e/slaev2_8f.html":[3,0,5,1166],
-"dc/d3e/slaev2_8f_source.html":[3,0,5,1166],
+"dc/d3e/slaev2_8f.html":[3,0,5,1164],
+"dc/d3e/slaev2_8f_source.html":[3,0,5,1164],
 "dc/d3f/lapacke__stpttr__work_8c.html":[3,0,4,3,1809],
 "dc/d3f/lapacke__stpttr__work_8c_abb963e518dc665ad9963fd9810753c7b.html#abb963e518dc665ad9963fd9810753c7b":[3,0,4,3,1809,0],
 "dc/d3f/lapacke__stpttr__work_8c_source.html":[3,0,4,3,1809],
@@ -234,20 +233,21 @@ var NAVTREEINDEX92 =
 "dc/d42/lapacke__sgbbrd__work_8c.html":[3,0,4,3,1253],
 "dc/d42/lapacke__sgbbrd__work_8c_a80fa191320146a9be40c6775849471eb.html#a80fa191320146a9be40c6775849471eb":[3,0,4,3,1253,0],
 "dc/d42/lapacke__sgbbrd__work_8c_source.html":[3,0,4,3,1253],
-"dc/d42/zgesvj_8f.html":[3,0,5,1586],
-"dc/d42/zgesvj_8f_source.html":[3,0,5,1586],
+"dc/d42/zgesvj_8f.html":[3,0,5,1584],
+"dc/d42/zgesvj_8f_source.html":[3,0,5,1584],
 "dc/d43/cpptrf_8f.html":[3,0,5,351],
 "dc/d43/cpptrf_8f_source.html":[3,0,5,351],
 "dc/d43/lapacke__sgebrd_8c.html":[3,0,4,3,1278],
 "dc/d43/lapacke__sgebrd_8c_a38acefe52d8d2dc7a97144bacdc2d794.html#a38acefe52d8d2dc7a97144bacdc2d794":[3,0,4,3,1278,0],
 "dc/d43/lapacke__sgebrd_8c_source.html":[3,0,4,3,1278],
-"dc/d43/ssygs2_8f.html":[3,0,5,1436],
-"dc/d43/ssygs2_8f_source.html":[3,0,5,1436],
+"dc/d43/ssygs2_8f.html":[3,0,5,1434],
+"dc/d43/ssygs2_8f_source.html":[3,0,5,1434],
 "dc/d44/lapacke__slarfx__work_8c.html":[3,0,4,3,1461],
 "dc/d44/lapacke__slarfx__work_8c_ad2d7783b2c34c31253158288dbb09611.html#ad2d7783b2c34c31253158288dbb09611":[3,0,4,3,1461,0],
 "dc/d44/lapacke__slarfx__work_8c_source.html":[3,0,4,3,1461],
 "dc/d44/slavsy__rook_8f.html":[3,0,6,1,504],
 "dc/d44/slavsy__rook_8f_source.html":[3,0,6,1,504],
 "dc/d45/_v_a_r_i_a_n_t_s_2qr_2_l_l_2sgeqrf_8f.html":[3,0,5,1,2,0,3],
-"dc/d45/_v_a_r_i_a_n_t_s_2qr_2_l_l_2sgeqrf_8f_source.html":[3,0,5,1,2,0,3]
+"dc/d45/_v_a_r_i_a_n_t_s_2qr_2_l_l_2sgeqrf_8f_source.html":[3,0,5,1,2,0,3],
+"dc/d47/zlarft_8f.html":[3,0,5,1806]
 };
