@@ -1,7 +1,6 @@
 var NAVTREEINDEX93 =
 {
-"dc/d47/zlarft_8f.html":[3,0,5,1808],
-"dc/d47/zlarft_8f_source.html":[3,0,5,1808],
+"dc/d47/zlarft_8f_source.html":[3,0,5,1806],
 "dc/d48/lapacke__ztfsm__work_8c.html":[3,0,4,3,2377],
 "dc/d48/lapacke__ztfsm__work_8c_a9765fae91d877fdc0ed99b9fb155aca6.html#a9765fae91d877fdc0ed99b9fb155aca6":[3,0,4,3,2377,0],
 "dc/d48/lapacke__ztfsm__work_8c_source.html":[3,0,4,3,2377],
@@ -13,12 +12,12 @@ var NAVTREEINDEX93 =
 "dc/d4c/lapacke__dgbequb__work_8c.html":[3,0,4,3,661],
 "dc/d4c/lapacke__dgbequb__work_8c_ae1c60717a61ed94b8a11f31e80303d7b.html#ae1c60717a61ed94b8a11f31e80303d7b":[3,0,4,3,661,0],
 "dc/d4c/lapacke__dgbequb__work_8c_source.html":[3,0,4,3,661],
-"dc/d4c/sgeqp3_8f.html":[3,0,5,1070],
-"dc/d4c/sgeqp3_8f_source.html":[3,0,5,1070],
+"dc/d4c/sgeqp3_8f.html":[3,0,5,1068],
+"dc/d4c/sgeqp3_8f_source.html":[3,0,5,1068],
 "dc/d4d/cgttrf_8f.html":[3,0,5,97],
 "dc/d4d/cgttrf_8f_source.html":[3,0,5,97],
-"dc/d4d/dorbdb5_8f.html":[3,0,5,784],
-"dc/d4d/dorbdb5_8f_source.html":[3,0,5,784],
+"dc/d4d/dorbdb5_8f.html":[3,0,5,783],
+"dc/d4d/dorbdb5_8f_source.html":[3,0,5,783],
 "dc/d4e/lapacke__sbdsdc__work_8c.html":[3,0,4,3,1245],
 "dc/d4e/lapacke__sbdsdc__work_8c_aa340973d648fb5dfb346f5d43bb5fb38.html#aa340973d648fb5dfb346f5d43bb5fb38":[3,0,4,3,1245,0],
 "dc/d4e/lapacke__sbdsdc__work_8c_source.html":[3,0,4,3,1245],
@@ -38,10 +37,10 @@ var NAVTREEINDEX93 =
 "dc/d50/lapacke__sgesv__work_8c.html":[3,0,4,3,1347],
 "dc/d50/lapacke__sgesv__work_8c_a6c29f5ea22888c7860d8e708c7d429ad.html#a6c29f5ea22888c7860d8e708c7d429ad":[3,0,4,3,1347,0],
 "dc/d50/lapacke__sgesv__work_8c_source.html":[3,0,4,3,1347],
-"dc/d50/zgbsvx_8f.html":[3,0,5,1533],
-"dc/d50/zgbsvx_8f_source.html":[3,0,5,1533],
-"dc/d51/dtrexc_8f.html":[3,0,5,988],
-"dc/d51/dtrexc_8f_source.html":[3,0,5,988],
+"dc/d50/zgbsvx_8f.html":[3,0,5,1531],
+"dc/d50/zgbsvx_8f_source.html":[3,0,5,1531],
+"dc/d51/dtrexc_8f.html":[3,0,5,987],
+"dc/d51/dtrexc_8f_source.html":[3,0,5,987],
 "dc/d52/dlarot_8f.html":[3,0,6,2,26],
 "dc/d52/dlarot_8f_source.html":[3,0,6,2,26],
 "dc/d53/lapacke__dpb__nancheck_8c.html":[3,0,4,4,48],
@@ -53,8 +52,8 @@ var NAVTREEINDEX93 =
 "dc/d53/lapacke__zhetrf__aa__2stage__work_8c.html":[3,0,4,3,2089],
 "dc/d53/lapacke__zhetrf__aa__2stage__work_8c_addea7787f870269dc6cfa616a1abf4c0.html#addea7787f870269dc6cfa616a1abf4c0":[3,0,4,3,2089,0],
 "dc/d53/lapacke__zhetrf__aa__2stage__work_8c_source.html":[3,0,4,3,2089],
-"dc/d54/zungtsqr_8f.html":[3,0,5,2002],
-"dc/d54/zungtsqr_8f_source.html":[3,0,5,2002],
+"dc/d54/zungtsqr_8f.html":[3,0,5,2000],
+"dc/d54/zungtsqr_8f_source.html":[3,0,5,2000],
 "dc/d55/lapacke__dgebak_8c.html":[3,0,4,3,676],
 "dc/d55/lapacke__dgebak_8c_ae2bbd5cbbb960b13365d0c5f67d3a139.html#ae2bbd5cbbb960b13365d0c5f67d3a139":[3,0,4,3,676,0],
 "dc/d55/lapacke__dgebak_8c_source.html":[3,0,4,3,676],
@@ -72,8 +71,8 @@ var NAVTREEINDEX93 =
 "dc/d57/lapacke__dgecon__work_8c.html":[3,0,4,3,683],
 "dc/d57/lapacke__dgecon__work_8c_a1e8bbb5963fa0cbb66691b64151f0371.html#a1e8bbb5963fa0cbb66691b64151f0371":[3,0,4,3,683,0],
 "dc/d57/lapacke__dgecon__work_8c_source.html":[3,0,4,3,683],
-"dc/d58/dlaset_8f.html":[3,0,5,749],
-"dc/d58/dlaset_8f_source.html":[3,0,5,749],
+"dc/d58/dlaset_8f.html":[3,0,5,748],
+"dc/d58/dlaset_8f_source.html":[3,0,5,748],
 "dc/d59/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2sgetrf_8f.html":[3,0,5,1,1,2,2],
 "dc/d59/_v_a_r_i_a_n_t_s_2lu_2_r_e_c_2sgetrf_8f_source.html":[3,0,5,1,1,2,2],
 "dc/d5a/lapacke__dgeevx__work_8c.html":[3,0,4,3,695],
@@ -89,10 +88,10 @@ var NAVTREEINDEX93 =
 "dc/d5e/dget36_8f.html":[3,0,6,0,142],
 "dc/d5e/dget36_8f_source.html":[3,0,6,0,142],
 "dc/d5e/group__real_p_tsolve.html":[0,0,6,0,1],
+"dc/d5e/group__real_p_tsolve_ga4b54ec5cf63547490c2a0258036b7f72.html#ga4b54ec5cf63547490c2a0258036b7f72":[3,0,5,1374,0],
 "dc/d5e/group__real_p_tsolve_ga4b54ec5cf63547490c2a0258036b7f72.html#ga4b54ec5cf63547490c2a0258036b7f72":[0,0,6,0,1,0],
-"dc/d5e/group__real_p_tsolve_ga4b54ec5cf63547490c2a0258036b7f72.html#ga4b54ec5cf63547490c2a0258036b7f72":[3,0,5,1376,0],
 "dc/d5e/group__real_p_tsolve_gab3fbf901ac3c3e7b56d7fd79b6c5b54d.html#gab3fbf901ac3c3e7b56d7fd79b6c5b54d":[0,0,6,0,1,1],
-"dc/d5e/group__real_p_tsolve_gab3fbf901ac3c3e7b56d7fd79b6c5b54d.html#gab3fbf901ac3c3e7b56d7fd79b6c5b54d":[3,0,5,1377,0],
+"dc/d5e/group__real_p_tsolve_gab3fbf901ac3c3e7b56d7fd79b6c5b54d.html#gab3fbf901ac3c3e7b56d7fd79b6c5b54d":[3,0,5,1375,0],
 "dc/d5e/zdrvvx_8f.html":[3,0,6,0,317],
 "dc/d5e/zdrvvx_8f_source.html":[3,0,6,0,317],
 "dc/d60/lapacke__dlarnv_8c.html":[3,0,4,3,864],
@@ -109,28 +108,28 @@ var NAVTREEINDEX93 =
 "dc/d62/lapacke__zsycon__work_8c.html":[3,0,4,3,2313],
 "dc/d62/lapacke__zsycon__work_8c_a8f4635a87ce70b97c1664dc36c927dd6.html#a8f4635a87ce70b97c1664dc36c927dd6":[3,0,4,3,2313,0],
 "dc/d62/lapacke__zsycon__work_8c_source.html":[3,0,4,3,2313],
-"dc/d63/sorbdb2_8f.html":[3,0,5,1303],
-"dc/d63/sorbdb2_8f_source.html":[3,0,5,1303],
+"dc/d63/sorbdb2_8f.html":[3,0,5,1301],
+"dc/d63/sorbdb2_8f_source.html":[3,0,5,1301],
 "dc/d64/lapacke__ctgsen_8c.html":[3,0,4,3,550],
 "dc/d64/lapacke__ctgsen_8c_a4fd9d114df1bd6245b2ce66875e0bcf8.html#a4fd9d114df1bd6245b2ce66875e0bcf8":[3,0,4,3,550,0],
 "dc/d64/lapacke__ctgsen_8c_source.html":[3,0,4,3,550],
 "dc/d64/lapacke__sspcon_8c.html":[3,0,4,3,1626],
 "dc/d64/lapacke__sspcon_8c_aa6b1b56f1071e542438b8b3c5db5b4a2.html#aa6b1b56f1071e542438b8b3c5db5b4a2":[3,0,4,3,1626,0],
 "dc/d64/lapacke__sspcon_8c_source.html":[3,0,4,3,1626],
-"dc/d65/dlaed9_8f.html":[3,0,5,640],
-"dc/d65/dlaed9_8f_source.html":[3,0,5,640],
+"dc/d65/dlaed9_8f.html":[3,0,5,639],
+"dc/d65/dlaed9_8f_source.html":[3,0,5,639],
 "dc/d66/lapacke__zsp__trans_8c.html":[3,0,4,4,136],
 "dc/d66/lapacke__zsp__trans_8c_a396a7b09e9fa73a2c099b11be37faed1.html#a396a7b09e9fa73a2c099b11be37faed1":[3,0,4,4,136,0],
 "dc/d66/lapacke__zsp__trans_8c_source.html":[3,0,4,4,136],
-"dc/d67/stgsyl_8f.html":[3,0,5,1491],
-"dc/d67/stgsyl_8f_source.html":[3,0,5,1491],
-"dc/d68/zhegst_8f.html":[3,0,5,1647],
-"dc/d68/zhegst_8f_source.html":[3,0,5,1647],
+"dc/d67/stgsyl_8f.html":[3,0,5,1489],
+"dc/d67/stgsyl_8f_source.html":[3,0,5,1489],
+"dc/d68/zhegst_8f.html":[3,0,5,1645],
+"dc/d68/zhegst_8f_source.html":[3,0,5,1645],
 "dc/d6a/lapacke__dlagge_8c.html":[3,0,4,3,836],
 "dc/d6a/lapacke__dlagge_8c_a141ef90ab8765306c7f0c88a04c72cb9.html#a141ef90ab8765306c7f0c88a04c72cb9":[3,0,4,3,836,0],
 "dc/d6a/lapacke__dlagge_8c_source.html":[3,0,4,3,836],
-"dc/d6a/zggbal_8f.html":[3,0,5,1598],
-"dc/d6a/zggbal_8f_source.html":[3,0,5,1598],
+"dc/d6a/zggbal_8f.html":[3,0,5,1596],
+"dc/d6a/zggbal_8f_source.html":[3,0,5,1596],
 "dc/d6e/cerrhex_8f.html":[3,0,6,1,80],
 "dc/d6e/cerrhex_8f_source.html":[3,0,6,1,80],
 "dc/d70/dget38_8f.html":[3,0,6,0,144],
@@ -146,34 +145,34 @@ var NAVTREEINDEX93 =
 "dc/d72/lapacke__zggbal_8c.html":[3,0,4,3,1966],
 "dc/d72/lapacke__zggbal_8c_aaa2e51af6d2ddf6a2a2907f29c79de6d.html#aaa2e51af6d2ddf6a2a2907f29c79de6d":[3,0,4,3,1966,0],
 "dc/d72/lapacke__zggbal_8c_source.html":[3,0,4,3,1966],
-"dc/d72/slanst_8f.html":[3,0,5,1194],
-"dc/d72/slanst_8f_source.html":[3,0,5,1194],
+"dc/d72/slanst_8f.html":[3,0,5,1192],
+"dc/d72/slanst_8f_source.html":[3,0,5,1192],
 "dc/d72/ztsqr01_8f.html":[3,0,6,1,779],
 "dc/d72/ztsqr01_8f_a1bfc008e17ab3b79171060777e7b9cdb.html#a1bfc008e17ab3b79171060777e7b9cdb":[3,0,6,1,779,0],
 "dc/d72/ztsqr01_8f_source.html":[3,0,6,1,779],
-"dc/d73/dpbtrs_8f.html":[3,0,5,824],
-"dc/d73/dpbtrs_8f_source.html":[3,0,5,824],
+"dc/d73/dpbtrs_8f.html":[3,0,5,823],
+"dc/d73/dpbtrs_8f_source.html":[3,0,5,823],
 "dc/d74/slatmt_8f.html":[3,0,6,2,55],
 "dc/d74/slatmt_8f_source.html":[3,0,6,2,55],
 "dc/d75/lapacke__dtftri__work_8c.html":[3,0,4,3,1179],
 "dc/d75/lapacke__dtftri__work_8c_a3378effeaa5e465f408c3397af23d1fe.html#a3378effeaa5e465f408c3397af23d1fe":[3,0,4,3,1179,0],
 "dc/d75/lapacke__dtftri__work_8c_source.html":[3,0,4,3,1179],
-"dc/d78/dlangt_8f.html":[3,0,5,666],
-"dc/d78/dlangt_8f_source.html":[3,0,5,666],
-"dc/d78/zlantp_8f.html":[3,0,5,1775],
-"dc/d78/zlantp_8f_source.html":[3,0,5,1775],
+"dc/d78/dlangt_8f.html":[3,0,5,665],
+"dc/d78/dlangt_8f_source.html":[3,0,5,665],
+"dc/d78/zlantp_8f.html":[3,0,5,1773],
+"dc/d78/zlantp_8f_source.html":[3,0,5,1773],
 "dc/d79/lapacke__cgels__work_8c.html":[3,0,4,3,57],
 "dc/d79/lapacke__cgels__work_8c_ab24af740af01f8fc8c5b83f9fdc6cf17.html#ab24af740af01f8fc8c5b83f9fdc6cf17":[3,0,4,3,57,0],
 "dc/d79/lapacke__cgels__work_8c_source.html":[3,0,4,3,57],
-"dc/d79/zgeesx_8f.html":[3,0,5,1546],
-"dc/d79/zgeesx_8f_source.html":[3,0,5,1546],
+"dc/d79/zgeesx_8f.html":[3,0,5,1544],
+"dc/d79/zgeesx_8f_source.html":[3,0,5,1544],
 "dc/d7a/lapacke__ctb__nancheck_8c.html":[3,0,4,4,30],
 "dc/d7a/lapacke__ctb__nancheck_8c_a4cea12219fd39171022126a6daf0d34c.html#a4cea12219fd39171022126a6daf0d34c":[3,0,4,4,30,0],
 "dc/d7a/lapacke__ctb__nancheck_8c_source.html":[3,0,4,4,30],
 "dc/d7b/chpgvx_8f.html":[3,0,5,175],
 "dc/d7b/chpgvx_8f_source.html":[3,0,5,175],
-"dc/d7b/zhbgvd_8f.html":[3,0,5,1631],
-"dc/d7b/zhbgvd_8f_source.html":[3,0,5,1631],
+"dc/d7b/zhbgvd_8f.html":[3,0,5,1629],
+"dc/d7b/zhbgvd_8f_source.html":[3,0,5,1629],
 "dc/d7c/dchkeq_8f.html":[3,0,6,1,213],
 "dc/d7c/dchkeq_8f_source.html":[3,0,6,1,213],
 "dc/d7c/lapacke__dsyevd__2stage_8c.html":[3,0,4,3,1097],
@@ -186,8 +185,8 @@ var NAVTREEINDEX93 =
 "dc/d7d/lapacke__sorghr__work_8c_source.html":[3,0,4,3,1495],
 "dc/d7e/cgerq2_8f.html":[3,0,5,56],
 "dc/d7e/cgerq2_8f_source.html":[3,0,5,56],
-"dc/d7e/dlasq2_8f.html":[3,0,5,751],
-"dc/d7e/dlasq2_8f_source.html":[3,0,5,751],
+"dc/d7e/dlasq2_8f.html":[3,0,5,750],
+"dc/d7e/dlasq2_8f_source.html":[3,0,5,750],
 "dc/d7e/dtrmv_8f.html":[3,0,0,0,67],
 "dc/d7e/dtrmv_8f_source.html":[3,0,0,0,67],
 "dc/d7f/lapacke__cgeesx__work_8c.html":[3,0,4,3,41],
@@ -208,20 +207,20 @@ var NAVTREEINDEX93 =
 "dc/d83/lapacke__cgeqlf__work_8c.html":[3,0,4,3,71],
 "dc/d83/lapacke__cgeqlf__work_8c_a6540b622f2af086d039cde38fbd212b5.html#a6540b622f2af086d039cde38fbd212b5":[3,0,4,3,71,0],
 "dc/d83/lapacke__cgeqlf__work_8c_source.html":[3,0,4,3,71],
-"dc/d83/zlantb_8f.html":[3,0,5,1774],
-"dc/d83/zlantb_8f_source.html":[3,0,5,1774],
-"dc/d85/dpbsv_8f.html":[3,0,5,820],
-"dc/d85/dpbsv_8f_source.html":[3,0,5,820],
-"dc/d85/spttrs_8f.html":[3,0,5,1379],
-"dc/d85/spttrs_8f_source.html":[3,0,5,1379],
+"dc/d83/zlantb_8f.html":[3,0,5,1772],
+"dc/d83/zlantb_8f_source.html":[3,0,5,1772],
+"dc/d85/dpbsv_8f.html":[3,0,5,819],
+"dc/d85/dpbsv_8f_source.html":[3,0,5,819],
+"dc/d85/spttrs_8f.html":[3,0,5,1377],
+"dc/d85/spttrs_8f_source.html":[3,0,5,1377],
 "dc/d86/lapacke__spbstf__work_8c.html":[3,0,4,3,1531],
 "dc/d86/lapacke__spbstf__work_8c_a1baa31e5948a43944ffbdecec584d2c8.html#a1baa31e5948a43944ffbdecec584d2c8":[3,0,4,3,1531,0],
 "dc/d86/lapacke__spbstf__work_8c_source.html":[3,0,4,3,1531],
 "dc/d86/lapacke__zsytri__3_8c.html":[3,0,4,3,2355],
 "dc/d86/lapacke__zsytri__3_8c_adac43f1ef88ee7838c941281ba128de1.html#adac43f1ef88ee7838c941281ba128de1":[3,0,4,3,2355,0],
 "dc/d86/lapacke__zsytri__3_8c_source.html":[3,0,4,3,2355],
-"dc/d86/ssysv__rook_8f.html":[3,0,5,1448],
-"dc/d86/ssysv__rook_8f_source.html":[3,0,5,1448],
+"dc/d86/ssysv__rook_8f.html":[3,0,5,1446],
+"dc/d86/ssysv__rook_8f_source.html":[3,0,5,1446],
 "dc/d88/cblas__example2_8c.html":[3,0,1,0,1],
 "dc/d88/cblas__example2_8c_a3c04138a5bfe5d72780bb7e82a18e627.html#a3c04138a5bfe5d72780bb7e82a18e627":[3,0,1,0,1,1],
 "dc/d88/cblas__example2_8c_adf770fe2eec438e3758ffe905dbae208.html#adf770fe2eec438e3758ffe905dbae208":[3,0,1,0,1,0],
@@ -231,8 +230,8 @@ var NAVTREEINDEX93 =
 "dc/d88/lapacke__dpo__trans_8c_source.html":[3,0,4,4,53],
 "dc/d89/cunmrq_8f.html":[3,0,5,495],
 "dc/d89/cunmrq_8f_source.html":[3,0,5,495],
-"dc/d89/dlabrd_8f.html":[3,0,5,624],
-"dc/d89/dlabrd_8f_source.html":[3,0,5,624],
+"dc/d89/dlabrd_8f.html":[3,0,5,623],
+"dc/d89/dlabrd_8f_source.html":[3,0,5,623],
 "dc/d89/lapacke__cunmtr__work_8c.html":[3,0,4,3,639],
 "dc/d89/lapacke__cunmtr__work_8c_ad686a2ce09e114dd9e7eff6c7269271c.html#ad686a2ce09e114dd9e7eff6c7269271c":[3,0,4,3,639,0],
 "dc/d89/lapacke__cunmtr__work_8c_source.html":[3,0,4,3,639],
@@ -247,7 +246,8 @@ var NAVTREEINDEX93 =
 "dc/d8d/lapacke__zlaswp__work_8c_source.html":[3,0,4,3,2203],
 "dc/d8d/scabs1_8f.html":[3,0,0,0,79],
 "dc/d8d/scabs1_8f_source.html":[3,0,0,0,79],
-"dc/d8d/zunmlq_8f.html":[3,0,5,2011],
-"dc/d8d/zunmlq_8f_source.html":[3,0,5,2011],
-"dc/d8e/sgeqrfp_8f.html":[3,0,5,1075]
+"dc/d8d/zunmlq_8f.html":[3,0,5,2009],
+"dc/d8d/zunmlq_8f_source.html":[3,0,5,2009],
+"dc/d8e/sgeqrfp_8f.html":[3,0,5,1073],
+"dc/d8e/sgeqrfp_8f_source.html":[3,0,5,1073]
 };
