@@ -1,6 +1,5 @@
 var NAVTREEINDEX94 =
 {
-"dc/d8e/sgeqrfp_8f_source.html":[3,0,5,1075],
 "dc/d8f/cchkhe__aa_8f.html":[3,0,6,1,13],
 "dc/d8f/cchkhe__aa_8f_source.html":[3,0,6,1,13],
 "dc/d8f/cgetc2_8f.html":[3,0,5,67],
@@ -16,10 +15,10 @@ var NAVTREEINDEX94 =
 "dc/d93/lapacke__cpbcon_8c.html":[3,0,4,3,370],
 "dc/d93/lapacke__cpbcon_8c_aa73f3ea769e3cfe3fe4118021e22e915.html#aa73f3ea769e3cfe3fe4118021e22e915":[3,0,4,3,370,0],
 "dc/d93/lapacke__cpbcon_8c_source.html":[3,0,4,3,370],
-"dc/d93/sla__wwaddw_8f.html":[3,0,5,1145],
-"dc/d93/sla__wwaddw_8f_source.html":[3,0,5,1145],
-"dc/d93/zunglq_8f.html":[3,0,5,1996],
-"dc/d93/zunglq_8f_source.html":[3,0,5,1996],
+"dc/d93/sla__wwaddw_8f.html":[3,0,5,1143],
+"dc/d93/sla__wwaddw_8f_source.html":[3,0,5,1143],
+"dc/d93/zunglq_8f.html":[3,0,5,1994],
+"dc/d93/zunglq_8f_source.html":[3,0,5,1994],
 "dc/d94/cpbequ_8f.html":[3,0,5,322],
 "dc/d94/cpbequ_8f_source.html":[3,0,5,322],
 "dc/d94/lapacke__cgesvxx_8c.html":[3,0,4,3,110],
@@ -28,27 +27,27 @@ var NAVTREEINDEX94 =
 "dc/d94/lapacke__cunmhr__work_8c.html":[3,0,4,3,627],
 "dc/d94/lapacke__cunmhr__work_8c_a71eb3767f88020b73fb0c5856433dd40.html#a71eb3767f88020b73fb0c5856433dd40":[3,0,4,3,627,0],
 "dc/d94/lapacke__cunmhr__work_8c_source.html":[3,0,4,3,627],
-"dc/d94/ssbev_8f.html":[3,0,5,1383],
-"dc/d94/ssbev_8f_source.html":[3,0,5,1383],
+"dc/d94/ssbev_8f.html":[3,0,5,1381],
+"dc/d94/ssbev_8f_source.html":[3,0,5,1381],
 "dc/d95/lapacke__ctzrzf_8c.html":[3,0,4,3,600],
 "dc/d95/lapacke__ctzrzf_8c_add5409f86d33e367629e1d321a213f6f.html#add5409f86d33e367629e1d321a213f6f":[3,0,4,3,600,0],
 "dc/d95/lapacke__ctzrzf_8c_source.html":[3,0,4,3,600],
 "dc/d96/lapacke__dgglse__work_8c.html":[3,0,4,3,799],
 "dc/d96/lapacke__dgglse__work_8c_a1a97f8316087a13fb2cce2124925d100.html#a1a97f8316087a13fb2cce2124925d100":[3,0,4,3,799,0],
 "dc/d96/lapacke__dgglse__work_8c_source.html":[3,0,4,3,799],
-"dc/d96/zheev__2stage_8f.html":[3,0,5,1639],
-"dc/d96/zheev__2stage_8f_source.html":[3,0,5,1639],
+"dc/d96/zheev__2stage_8f.html":[3,0,5,1637],
+"dc/d96/zheev__2stage_8f_source.html":[3,0,5,1637],
 "dc/d97/lapacke__clanhe_8c.html":[3,0,4,3,336],
 "dc/d97/lapacke__clanhe_8c_ad53f94e395724c5ab2ec035acc7fee04.html#ad53f94e395724c5ab2ec035acc7fee04":[3,0,4,3,336,0],
 "dc/d97/lapacke__clanhe_8c_source.html":[3,0,4,3,336],
-"dc/d97/slals0_8f.html":[3,0,5,1180],
-"dc/d97/slals0_8f_source.html":[3,0,5,1180],
+"dc/d97/slals0_8f.html":[3,0,5,1178],
+"dc/d97/slals0_8f_source.html":[3,0,5,1178],
 "dc/d98/csysv__aa__2stage_8f.html":[3,0,5,393],
 "dc/d98/csysv__aa__2stage_8f_source.html":[3,0,5,393],
 "dc/d98/zchkhp_8f.html":[3,0,6,1,583],
 "dc/d98/zchkhp_8f_source.html":[3,0,6,1,583],
-"dc/d98/zsysvxx_8f.html":[3,0,5,1918],
-"dc/d98/zsysvxx_8f_source.html":[3,0,5,1918],
+"dc/d98/zsysvxx_8f.html":[3,0,5,1916],
+"dc/d98/zsysvxx_8f_source.html":[3,0,5,1916],
 "dc/d99/cgbsvx_8f.html":[3,0,5,11],
 "dc/d99/cgbsvx_8f_source.html":[3,0,5,11],
 "dc/d99/sgsvts3_8f.html":[3,0,6,0,250],
@@ -56,19 +55,19 @@ var NAVTREEINDEX94 =
 "dc/d9b/lapacke__dorgrq__work_8c.html":[3,0,4,3,905],
 "dc/d9b/lapacke__dorgrq__work_8c_a9ff1dd3ee0a738714de2693e8b6a7a19.html#a9ff1dd3ee0a738714de2693e8b6a7a19":[3,0,4,3,905,0],
 "dc/d9b/lapacke__dorgrq__work_8c_source.html":[3,0,4,3,905],
-"dc/d9c/_i_n_s_t_a_l_l_2lsame_8f.html":[3,0,3,11],
-"dc/d9c/_i_n_s_t_a_l_l_2lsame_8f_ada799b40a93f1fd2c6d1a86a95f21631.html#ada799b40a93f1fd2c6d1a86a95f21631":[3,0,3,11,0],
-"dc/d9c/_i_n_s_t_a_l_l_2lsame_8f_source.html":[3,0,3,11],
+"dc/d9c/_i_n_s_t_a_l_l_2lsame_8f.html":[3,0,3,12],
+"dc/d9c/_i_n_s_t_a_l_l_2lsame_8f_ada799b40a93f1fd2c6d1a86a95f21631.html#ada799b40a93f1fd2c6d1a86a95f21631":[3,0,3,12,0],
+"dc/d9c/_i_n_s_t_a_l_l_2lsame_8f_source.html":[3,0,3,12],
 "dc/d9c/dlsets_8f.html":[3,0,6,0,165],
 "dc/d9c/dlsets_8f_source.html":[3,0,6,0,165],
-"dc/d9c/sgbsvxx_8f.html":[3,0,5,1037],
-"dc/d9c/sgbsvxx_8f_source.html":[3,0,5,1037],
-"dc/d9d/sstein_8f.html":[3,0,5,1413],
-"dc/d9d/sstein_8f_source.html":[3,0,5,1413],
-"dc/d9d/sstemr_8f.html":[3,0,5,1414],
-"dc/d9d/sstemr_8f_source.html":[3,0,5,1414],
-"dc/d9e/dlaed6_8f.html":[3,0,5,637],
-"dc/d9e/dlaed6_8f_source.html":[3,0,5,637],
+"dc/d9c/sgbsvxx_8f.html":[3,0,5,1035],
+"dc/d9c/sgbsvxx_8f_source.html":[3,0,5,1035],
+"dc/d9d/sstein_8f.html":[3,0,5,1411],
+"dc/d9d/sstein_8f_source.html":[3,0,5,1411],
+"dc/d9d/sstemr_8f.html":[3,0,5,1412],
+"dc/d9d/sstemr_8f_source.html":[3,0,5,1412],
+"dc/d9e/dlaed6_8f.html":[3,0,5,636],
+"dc/d9e/dlaed6_8f_source.html":[3,0,5,636],
 "dc/d9e/lapacke__spbsvx_8c.html":[3,0,4,3,1534],
 "dc/d9e/lapacke__spbsvx_8c_aceeffd1319080d0da6284c17be7a22b6.html#aceeffd1319080d0da6284c17be7a22b6":[3,0,4,3,1534,0],
 "dc/d9e/lapacke__spbsvx_8c_source.html":[3,0,4,3,1534],
@@ -82,18 +81,18 @@ var NAVTREEINDEX94 =
 "dc/da3/lapacke__dgges3__work_8c.html":[3,0,4,3,782],
 "dc/da3/lapacke__dgges3__work_8c_aaaea2a727ecc9f8e6b1da6ee07fac853.html#aaaea2a727ecc9f8e6b1da6ee07fac853":[3,0,4,3,782,0],
 "dc/da3/lapacke__dgges3__work_8c_source.html":[3,0,4,3,782],
-"dc/da3/ssyevr_8f.html":[3,0,5,1432],
-"dc/da3/ssyevr_8f_source.html":[3,0,5,1432],
-"dc/da4/dgelqf_8f.html":[3,0,5,534],
-"dc/da4/dgelqf_8f_source.html":[3,0,5,534],
+"dc/da3/ssyevr_8f.html":[3,0,5,1430],
+"dc/da3/ssyevr_8f_source.html":[3,0,5,1430],
+"dc/da4/dgelqf_8f.html":[3,0,5,533],
+"dc/da4/dgelqf_8f_source.html":[3,0,5,533],
 "dc/da5/lapacke__zptsvx__work_8c.html":[3,0,4,3,2281],
 "dc/da5/lapacke__zptsvx__work_8c_a38a85cdac9e9dd0e9004005b2f30cd6f.html#a38a85cdac9e9dd0e9004005b2f30cd6f":[3,0,4,3,2281,0],
 "dc/da5/lapacke__zptsvx__work_8c_source.html":[3,0,4,3,2281],
 "dc/da6/lapacke__dlarfx__work_8c.html":[3,0,4,3,863],
 "dc/da6/lapacke__dlarfx__work_8c_a07cb110d6ddfe3c35bab73684c69c6f6.html#a07cb110d6ddfe3c35bab73684c69c6f6":[3,0,4,3,863,0],
 "dc/da6/lapacke__dlarfx__work_8c_source.html":[3,0,4,3,863],
-"dc/da7/sladiv_8f.html":[3,0,5,1151],
-"dc/da7/sladiv_8f_source.html":[3,0,5,1151],
+"dc/da7/sladiv_8f.html":[3,0,5,1149],
+"dc/da7/sladiv_8f_source.html":[3,0,5,1149],
 "dc/da8/dgemv_8f.html":[3,0,0,0,42],
 "dc/da8/dgemv_8f_source.html":[3,0,0,0,42],
 "dc/da8/dger_8f.html":[3,0,0,0,43],
@@ -110,8 +109,8 @@ var NAVTREEINDEX94 =
 "dc/daa/lapacke__sggsvp3__work_8c.html":[3,0,4,3,1408],
 "dc/daa/lapacke__sggsvp3__work_8c_af3f98de26163bf4a520041e7b7d75aef.html#af3f98de26163bf4a520041e7b7d75aef":[3,0,4,3,1408,0],
 "dc/daa/lapacke__sggsvp3__work_8c_source.html":[3,0,4,3,1408],
-"dc/daa/slarf_8f.html":[3,0,5,1228],
-"dc/daa/slarf_8f_source.html":[3,0,5,1228],
+"dc/daa/slarf_8f.html":[3,0,5,1226],
+"dc/daa/slarf_8f_source.html":[3,0,5,1226],
 "dc/dab/dqrt04_8f.html":[3,0,6,1,358],
 "dc/dab/dqrt04_8f_source.html":[3,0,6,1,358],
 "dc/dab/lapacke__dgelqf__work_8c.html":[3,0,4,3,705],
@@ -119,29 +118,29 @@ var NAVTREEINDEX94 =
 "dc/dab/lapacke__dgelqf__work_8c_source.html":[3,0,4,3,705],
 "dc/dae/srqt02_8f.html":[3,0,6,1,545],
 "dc/dae/srqt02_8f_source.html":[3,0,6,1,545],
-"dc/daf/zgehd2_8f.html":[3,0,5,1549],
-"dc/daf/zgehd2_8f_source.html":[3,0,5,1549],
+"dc/daf/zgehd2_8f.html":[3,0,5,1547],
+"dc/daf/zgehd2_8f_source.html":[3,0,5,1547],
 "dc/db0/clanhb_8f.html":[3,0,5,244],
 "dc/db0/clanhb_8f_source.html":[3,0,5,244],
-"dc/db0/sgbsvx_8f.html":[3,0,5,1036],
-"dc/db0/sgbsvx_8f_source.html":[3,0,5,1036],
+"dc/db0/sgbsvx_8f.html":[3,0,5,1034],
+"dc/db0/sgbsvx_8f_source.html":[3,0,5,1034],
 "dc/db1/sgeqls_8f.html":[3,0,6,1,481],
 "dc/db1/sgeqls_8f_source.html":[3,0,6,1,481],
 "dc/db2/group__real_g_bsolve.html":[0,0,1,0,1],
-"dc/db2/group__real_g_bsolve_ga3656935309a19ed624052103572a4a47.html#ga3656935309a19ed624052103572a4a47":[3,0,5,1035,0],
 "dc/db2/group__real_g_bsolve_ga3656935309a19ed624052103572a4a47.html#ga3656935309a19ed624052103572a4a47":[0,0,1,0,1,0],
+"dc/db2/group__real_g_bsolve_ga3656935309a19ed624052103572a4a47.html#ga3656935309a19ed624052103572a4a47":[3,0,5,1033,0],
 "dc/db2/group__real_g_bsolve_gab7b2d018021516f6f0b0f4f6199f32ae.html#gab7b2d018021516f6f0b0f4f6199f32ae":[0,0,1,0,1,2],
-"dc/db2/group__real_g_bsolve_gab7b2d018021516f6f0b0f4f6199f32ae.html#gab7b2d018021516f6f0b0f4f6199f32ae":[3,0,5,1037,0],
+"dc/db2/group__real_g_bsolve_gab7b2d018021516f6f0b0f4f6199f32ae.html#gab7b2d018021516f6f0b0f4f6199f32ae":[3,0,5,1035,0],
+"dc/db2/group__real_g_bsolve_gae509be897c5d8dc6885d2b5f13ec2e4a.html#gae509be897c5d8dc6885d2b5f13ec2e4a":[3,0,5,1034,0],
 "dc/db2/group__real_g_bsolve_gae509be897c5d8dc6885d2b5f13ec2e4a.html#gae509be897c5d8dc6885d2b5f13ec2e4a":[0,0,1,0,1,1],
-"dc/db2/group__real_g_bsolve_gae509be897c5d8dc6885d2b5f13ec2e4a.html#gae509be897c5d8dc6885d2b5f13ec2e4a":[3,0,5,1036,0],
 "dc/db2/sqpt01_8f.html":[3,0,6,1,530],
 "dc/db2/sqpt01_8f_source.html":[3,0,6,1,530],
-"dc/db4/zhbev__2stage_8f.html":[3,0,5,1624],
-"dc/db4/zhbev__2stage_8f_source.html":[3,0,5,1624],
+"dc/db4/zhbev__2stage_8f.html":[3,0,5,1622],
+"dc/db4/zhbev__2stage_8f_source.html":[3,0,5,1622],
 "dc/db5/zgrqts_8f.html":[3,0,6,0,338],
 "dc/db5/zgrqts_8f_source.html":[3,0,6,0,338],
-"dc/db6/sgelsy_8f.html":[3,0,5,1063],
-"dc/db6/sgelsy_8f_source.html":[3,0,5,1063],
+"dc/db6/sgelsy_8f.html":[3,0,5,1061],
+"dc/db6/sgelsy_8f_source.html":[3,0,5,1061],
 "dc/db8/sstech_8f.html":[3,0,6,0,268],
 "dc/db8/sstech_8f_source.html":[3,0,6,0,268],
 "dc/db8/zlatm1_8f.html":[3,0,6,2,65],
@@ -169,16 +168,16 @@ var NAVTREEINDEX94 =
 "dc/dc1/group__complex16__blas__level2_ga0a0a44bede5155c38da7cbca20880662.html#ga0a0a44bede5155c38da7cbca20880662":[3,0,0,0,129,0],
 "dc/dc1/group__complex16__blas__level2_ga20d3fa0fe7cc708608dc658c743bfcab.html#ga20d3fa0fe7cc708608dc658c743bfcab":[0,2,1,3,12],
 "dc/dc1/group__complex16__blas__level2_ga20d3fa0fe7cc708608dc658c743bfcab.html#ga20d3fa0fe7cc708608dc658c743bfcab":[3,0,0,0,144,0],
-"dc/dc1/group__complex16__blas__level2_ga2eb62f52e98a997e5f88f86d53cd0d4f.html#ga2eb62f52e98a997e5f88f86d53cd0d4f":[0,2,1,3,11],
 "dc/dc1/group__complex16__blas__level2_ga2eb62f52e98a997e5f88f86d53cd0d4f.html#ga2eb62f52e98a997e5f88f86d53cd0d4f":[3,0,0,0,143,0],
-"dc/dc1/group__complex16__blas__level2_ga449f8a34be469eab7caf327caa086711.html#ga449f8a34be469eab7caf327caa086711":[0,2,1,3,9],
+"dc/dc1/group__complex16__blas__level2_ga2eb62f52e98a997e5f88f86d53cd0d4f.html#ga2eb62f52e98a997e5f88f86d53cd0d4f":[0,2,1,3,11],
 "dc/dc1/group__complex16__blas__level2_ga449f8a34be469eab7caf327caa086711.html#ga449f8a34be469eab7caf327caa086711":[3,0,0,0,135,0],
+"dc/dc1/group__complex16__blas__level2_ga449f8a34be469eab7caf327caa086711.html#ga449f8a34be469eab7caf327caa086711":[0,2,1,3,9],
 "dc/dc1/group__complex16__blas__level2_ga44a6afc0e18dc1b5d50bf12b79129843.html#ga44a6afc0e18dc1b5d50bf12b79129843":[0,2,1,3,10],
 "dc/dc1/group__complex16__blas__level2_ga44a6afc0e18dc1b5d50bf12b79129843.html#ga44a6afc0e18dc1b5d50bf12b79129843":[3,0,0,0,136,0],
-"dc/dc1/group__complex16__blas__level2_ga5a60882e2e5a7d604f2f16c1e0d8f4b4.html#ga5a60882e2e5a7d604f2f16c1e0d8f4b4":[3,0,0,0,148,0],
 "dc/dc1/group__complex16__blas__level2_ga5a60882e2e5a7d604f2f16c1e0d8f4b4.html#ga5a60882e2e5a7d604f2f16c1e0d8f4b4":[0,2,1,3,15],
-"dc/dc1/group__complex16__blas__level2_ga6f0283c18c02df85b4d4ad5e9f37c61d.html#ga6f0283c18c02df85b4d4ad5e9f37c61d":[3,0,0,0,127,0],
+"dc/dc1/group__complex16__blas__level2_ga5a60882e2e5a7d604f2f16c1e0d8f4b4.html#ga5a60882e2e5a7d604f2f16c1e0d8f4b4":[3,0,0,0,148,0],
 "dc/dc1/group__complex16__blas__level2_ga6f0283c18c02df85b4d4ad5e9f37c61d.html#ga6f0283c18c02df85b4d4ad5e9f37c61d":[0,2,1,3,4],
+"dc/dc1/group__complex16__blas__level2_ga6f0283c18c02df85b4d4ad5e9f37c61d.html#ga6f0283c18c02df85b4d4ad5e9f37c61d":[3,0,0,0,127,0],
 "dc/dc1/group__complex16__blas__level2_ga7d9c75aa8d9865d271db9ced1d08d097.html#ga7d9c75aa8d9865d271db9ced1d08d097":[0,2,1,3,3],
 "dc/dc1/group__complex16__blas__level2_ga7d9c75aa8d9865d271db9ced1d08d097.html#ga7d9c75aa8d9865d271db9ced1d08d097":[3,0,0,0,126,0],
 "dc/dc1/group__complex16__blas__level2_ga88dcc222d4bdf735fb9ff1bdbb0d8f82.html#ga88dcc222d4bdf735fb9ff1bdbb0d8f82":[0,2,1,3,2],
@@ -191,14 +190,14 @@ var NAVTREEINDEX94 =
 "dc/dc1/group__complex16__blas__level2_gab289624f8fdc44e20c5ab79f9cc1f631.html#gab289624f8fdc44e20c5ab79f9cc1f631":[3,0,0,0,122,0],
 "dc/dc1/group__complex16__blas__level2_gab493f9f41552f058ed4f75e7d182ed65.html#gab493f9f41552f058ed4f75e7d182ed65":[0,2,1,3,6],
 "dc/dc1/group__complex16__blas__level2_gab493f9f41552f058ed4f75e7d182ed65.html#gab493f9f41552f058ed4f75e7d182ed65":[3,0,0,0,130,0],
-"dc/dc1/group__complex16__blas__level2_gac1d92c5939cc624b2fd9e832121a0fd4.html#gac1d92c5939cc624b2fd9e832121a0fd4":[3,0,0,0,131,0],
 "dc/dc1/group__complex16__blas__level2_gac1d92c5939cc624b2fd9e832121a0fd4.html#gac1d92c5939cc624b2fd9e832121a0fd4":[0,2,1,3,7],
-"dc/dc1/group__complex16__blas__level2_gad4a66a9d545e2f11dd6ca5a666cc5316.html#gad4a66a9d545e2f11dd6ca5a666cc5316":[0,2,1,3,8],
+"dc/dc1/group__complex16__blas__level2_gac1d92c5939cc624b2fd9e832121a0fd4.html#gac1d92c5939cc624b2fd9e832121a0fd4":[3,0,0,0,131,0],
 "dc/dc1/group__complex16__blas__level2_gad4a66a9d545e2f11dd6ca5a666cc5316.html#gad4a66a9d545e2f11dd6ca5a666cc5316":[3,0,0,0,134,0],
-"dc/dc1/group__complex16__blas__level2_gaed33e3470ec372c730960b6038d1e037.html#gaed33e3470ec372c730960b6038d1e037":[3,0,0,0,145,0],
+"dc/dc1/group__complex16__blas__level2_gad4a66a9d545e2f11dd6ca5a666cc5316.html#gad4a66a9d545e2f11dd6ca5a666cc5316":[0,2,1,3,8],
 "dc/dc1/group__complex16__blas__level2_gaed33e3470ec372c730960b6038d1e037.html#gaed33e3470ec372c730960b6038d1e037":[0,2,1,3,13],
-"dc/dc1/group__complex16__blas__level2_gafaeb2abd9fffa7442b938dc384aeaf47.html#gafaeb2abd9fffa7442b938dc384aeaf47":[0,2,1,3,1],
+"dc/dc1/group__complex16__blas__level2_gaed33e3470ec372c730960b6038d1e037.html#gaed33e3470ec372c730960b6038d1e037":[3,0,0,0,145,0],
 "dc/dc1/group__complex16__blas__level2_gafaeb2abd9fffa7442b938dc384aeaf47.html#gafaeb2abd9fffa7442b938dc384aeaf47":[3,0,0,0,124,0],
+"dc/dc1/group__complex16__blas__level2_gafaeb2abd9fffa7442b938dc384aeaf47.html#gafaeb2abd9fffa7442b938dc384aeaf47":[0,2,1,3,1],
 "dc/dc2/lapacke__stgsen_8c.html":[3,0,4,3,1782],
 "dc/dc2/lapacke__stgsen_8c_a00f09e7edb4ee040a8c87bb2bfa1662c.html#a00f09e7edb4ee040a8c87bb2bfa1662c":[3,0,4,3,1782,0],
 "dc/dc2/lapacke__stgsen_8c_source.html":[3,0,4,3,1782],
@@ -214,16 +213,16 @@ var NAVTREEINDEX94 =
 "dc/dc4/lapacke__zggsvd__work_8c.html":[3,0,4,3,1995],
 "dc/dc4/lapacke__zggsvd__work_8c_ab74683e8ce825734299e6c27bf8774bb.html#ab74683e8ce825734299e6c27bf8774bb":[3,0,4,3,1995,0],
 "dc/dc4/lapacke__zggsvd__work_8c_source.html":[3,0,4,3,1995],
-"dc/dc4/zhpsv_8f.html":[3,0,5,1698],
-"dc/dc4/zhpsv_8f_source.html":[3,0,5,1698],
+"dc/dc4/zhpsv_8f.html":[3,0,5,1696],
+"dc/dc4/zhpsv_8f_source.html":[3,0,5,1696],
 "dc/dc5/lapacke__dtrrfs_8c.html":[3,0,4,3,1222],
 "dc/dc5/lapacke__dtrrfs_8c_a122a04dee04c4cdf082f5d818e16f7f4.html#a122a04dee04c4cdf082f5d818e16f7f4":[3,0,4,3,1222,0],
 "dc/dc5/lapacke__dtrrfs_8c_source.html":[3,0,4,3,1222],
 "dc/dc5/lapacke__slapmt__work_8c.html":[3,0,4,3,1449],
 "dc/dc5/lapacke__slapmt__work_8c_aea0f057bdc767db24cc6408275102ec7.html#aea0f057bdc767db24cc6408275102ec7":[3,0,4,3,1449,0],
 "dc/dc5/lapacke__slapmt__work_8c_source.html":[3,0,4,3,1449],
-"dc/dc6/dlaqgb_8f.html":[3,0,5,684],
-"dc/dc6/dlaqgb_8f_source.html":[3,0,5,684],
+"dc/dc6/dlaqgb_8f.html":[3,0,5,683],
+"dc/dc6/dlaqgb_8f_source.html":[3,0,5,683],
 "dc/dc6/lapacke__dgerfsx__work_8c.html":[3,0,4,3,743],
 "dc/dc6/lapacke__dgerfsx__work_8c_a485b27ab4ce087fa7e02c5d4fb9d12f4.html#a485b27ab4ce087fa7e02c5d4fb9d12f4":[3,0,4,3,743,0],
 "dc/dc6/lapacke__dgerfsx__work_8c_source.html":[3,0,4,3,743],
@@ -231,8 +230,8 @@ var NAVTREEINDEX94 =
 "dc/dc6/serrtz_8f_source.html":[3,0,6,1,473],
 "dc/dc6/slatm2_8f.html":[3,0,6,2,47],
 "dc/dc6/slatm2_8f_source.html":[3,0,6,2,47],
-"dc/dc8/dlagtm_8f.html":[3,0,5,649],
-"dc/dc8/dlagtm_8f_source.html":[3,0,5,649],
+"dc/dc8/dlagtm_8f.html":[3,0,5,648],
+"dc/dc8/dlagtm_8f_source.html":[3,0,5,648],
 "dc/dc8/lapacke__zhptrs__work_8c.html":[3,0,4,3,2149],
 "dc/dc8/lapacke__zhptrs__work_8c_a23e1514b267cc3c19c5c5331392fd7f7.html#a23e1514b267cc3c19c5c5331392fd7f7":[3,0,4,3,2149,0],
 "dc/dc8/lapacke__zhptrs__work_8c_source.html":[3,0,4,3,2149],
@@ -242,12 +241,13 @@ var NAVTREEINDEX94 =
 "dc/dca/lapacke__sge__nancheck_8c.html":[3,0,4,4,78],
 "dc/dca/lapacke__sge__nancheck_8c_a6edcba7e26e7f2437ca5bbc8a91c81fc.html#a6edcba7e26e7f2437ca5bbc8a91c81fc":[3,0,4,4,78,0],
 "dc/dca/lapacke__sge__nancheck_8c_source.html":[3,0,4,4,78],
-"dc/dcb/dgelqt_8f.html":[3,0,5,535],
-"dc/dcb/dgelqt_8f_source.html":[3,0,5,535],
-"dc/dcb/ilazlc_8f.html":[3,0,5,1014],
-"dc/dcb/ilazlc_8f_source.html":[3,0,5,1014],
-"dc/dcb/zgbtrf_8f.html":[3,0,5,1536],
-"dc/dcb/zgbtrf_8f_source.html":[3,0,5,1536],
+"dc/dcb/dgelqt_8f.html":[3,0,5,534],
+"dc/dcb/dgelqt_8f_source.html":[3,0,5,534],
+"dc/dcb/ilazlc_8f.html":[3,0,5,1013],
+"dc/dcb/ilazlc_8f_source.html":[3,0,5,1013],
+"dc/dcb/zgbtrf_8f.html":[3,0,5,1534],
+"dc/dcb/zgbtrf_8f_source.html":[3,0,5,1534],
 "dc/dcd/cblas__cgerc_8c.html":[3,0,1,2,7],
-"dc/dcd/cblas__cgerc_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,7,0]
+"dc/dcd/cblas__cgerc_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,7,0],
+"dc/dcd/cblas__cgerc_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,7,1]
 };
