@@ -1,9 +1,8 @@
 var NAVTREEINDEX95 =
 {
-"dc/dcd/cblas__cgerc_8c_a2a4edb85416c90d4639e1300f9f4cd76.html#a2a4edb85416c90d4639e1300f9f4cd76":[3,0,1,2,7,1],
-"dc/dcd/cblas__cgerc_8c_a2ef4f2654d3b2973cdf38e3fea587eb0.html#a2ef4f2654d3b2973cdf38e3fea587eb0":[3,0,1,2,7,5],
 "dc/dcd/cblas__cgerc_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,7,4],
 "dc/dcd/cblas__cgerc_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,7,2],
+"dc/dcd/cblas__cgerc_8c_ab41f6a540ed5dc011c81ded892d6885e.html#ab41f6a540ed5dc011c81ded892d6885e":[3,0,1,2,7,5],
 "dc/dcd/cblas__cgerc_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,7,3],
 "dc/dcd/cblas__cgerc_8c_source.html":[3,0,1,2,7],
 "dc/dcd/dtpmv_8f.html":[3,0,0,0,64],
@@ -25,53 +24,53 @@ var NAVTREEINDEX95 =
 "dc/dcf/lapacke__zhb__trans_8c.html":[3,0,4,4,119],
 "dc/dcf/lapacke__zhb__trans_8c_add468cb733725321ea85118ceb2aecc5.html#add468cb733725321ea85118ceb2aecc5":[3,0,4,4,119,0],
 "dc/dcf/lapacke__zhb__trans_8c_source.html":[3,0,4,4,119],
-"dc/dd0/zlarfb_8f.html":[3,0,5,1804],
-"dc/dd0/zlarfb_8f_source.html":[3,0,5,1804],
+"dc/dd0/zlarfb_8f.html":[3,0,5,1802],
+"dc/dd0/zlarfb_8f_source.html":[3,0,5,1802],
 "dc/dd2/group__double_o_t_h_e_reigen.html":[0,0,7,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga059beb16ce5345c3a2dfbf9692650401.html#ga059beb16ce5345c3a2dfbf9692650401":[0,0,7,0,16],
-"dc/dd2/group__double_o_t_h_e_reigen_ga059beb16ce5345c3a2dfbf9692650401.html#ga059beb16ce5345c3a2dfbf9692650401":[3,0,5,881,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga059beb16ce5345c3a2dfbf9692650401.html#ga059beb16ce5345c3a2dfbf9692650401":[3,0,5,880,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga07ee2c397b1b0f73e296f20f8d36990a.html#ga07ee2c397b1b0f73e296f20f8d36990a":[0,0,7,0,13],
-"dc/dd2/group__double_o_t_h_e_reigen_ga07ee2c397b1b0f73e296f20f8d36990a.html#ga07ee2c397b1b0f73e296f20f8d36990a":[3,0,5,877,0],
-"dc/dd2/group__double_o_t_h_e_reigen_ga162dd4b59d335a08a8c9dfb8d984f0cc.html#ga162dd4b59d335a08a8c9dfb8d984f0cc":[3,0,5,898,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga07ee2c397b1b0f73e296f20f8d36990a.html#ga07ee2c397b1b0f73e296f20f8d36990a":[3,0,5,876,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga162dd4b59d335a08a8c9dfb8d984f0cc.html#ga162dd4b59d335a08a8c9dfb8d984f0cc":[0,0,7,0,18],
+"dc/dd2/group__double_o_t_h_e_reigen_ga162dd4b59d335a08a8c9dfb8d984f0cc.html#ga162dd4b59d335a08a8c9dfb8d984f0cc":[3,0,5,897,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga323734560b8bd052fbc474dc2f0b5605.html#ga323734560b8bd052fbc474dc2f0b5605":[3,0,5,898,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga323734560b8bd052fbc474dc2f0b5605.html#ga323734560b8bd052fbc474dc2f0b5605":[0,0,7,0,19],
-"dc/dd2/group__double_o_t_h_e_reigen_ga323734560b8bd052fbc474dc2f0b5605.html#ga323734560b8bd052fbc474dc2f0b5605":[3,0,5,899,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga33924228a8f3dbde0a4f7e4e58e45267.html#ga33924228a8f3dbde0a4f7e4e58e45267":[0,0,7,0,8],
-"dc/dd2/group__double_o_t_h_e_reigen_ga33924228a8f3dbde0a4f7e4e58e45267.html#ga33924228a8f3dbde0a4f7e4e58e45267":[3,0,5,868,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga33924228a8f3dbde0a4f7e4e58e45267.html#ga33924228a8f3dbde0a4f7e4e58e45267":[3,0,5,867,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga4b0b81bd79a12be53d13a172c8950995.html#ga4b0b81bd79a12be53d13a172c8950995":[0,0,7,0,6],
-"dc/dd2/group__double_o_t_h_e_reigen_ga4b0b81bd79a12be53d13a172c8950995.html#ga4b0b81bd79a12be53d13a172c8950995":[3,0,5,865,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga4b0b81bd79a12be53d13a172c8950995.html#ga4b0b81bd79a12be53d13a172c8950995":[3,0,5,864,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga4e4203d1260f4deffe7679ac49af4f10.html#ga4e4203d1260f4deffe7679ac49af4f10":[0,0,7,0,14],
-"dc/dd2/group__double_o_t_h_e_reigen_ga4e4203d1260f4deffe7679ac49af4f10.html#ga4e4203d1260f4deffe7679ac49af4f10":[3,0,5,879,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga4e4203d1260f4deffe7679ac49af4f10.html#ga4e4203d1260f4deffe7679ac49af4f10":[3,0,5,878,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga5399550432eeee3ce0e4429f53bf4286.html#ga5399550432eeee3ce0e4429f53bf4286":[0,0,7,0,9],
-"dc/dd2/group__double_o_t_h_e_reigen_ga5399550432eeee3ce0e4429f53bf4286.html#ga5399550432eeee3ce0e4429f53bf4286":[3,0,5,869,0],
-"dc/dd2/group__double_o_t_h_e_reigen_ga63829fd8c0a1ae89779a35c9c1093fa6.html#ga63829fd8c0a1ae89779a35c9c1093fa6":[0,0,7,0,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga5399550432eeee3ce0e4429f53bf4286.html#ga5399550432eeee3ce0e4429f53bf4286":[3,0,5,868,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga63829fd8c0a1ae89779a35c9c1093fa6.html#ga63829fd8c0a1ae89779a35c9c1093fa6":[3,0,5,503,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga63829fd8c0a1ae89779a35c9c1093fa6.html#ga63829fd8c0a1ae89779a35c9c1093fa6":[0,0,7,0,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga7dd8a9cc7cc531b8665db125165d5e8c.html#ga7dd8a9cc7cc531b8665db125165d5e8c":[0,0,7,0,12],
-"dc/dd2/group__double_o_t_h_e_reigen_ga7dd8a9cc7cc531b8665db125165d5e8c.html#ga7dd8a9cc7cc531b8665db125165d5e8c":[3,0,5,876,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga7dd8a9cc7cc531b8665db125165d5e8c.html#ga7dd8a9cc7cc531b8665db125165d5e8c":[3,0,5,875,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga874417315bccf2de7547e30338da4101.html#ga874417315bccf2de7547e30338da4101":[0,0,7,0,20],
-"dc/dd2/group__double_o_t_h_e_reigen_ga874417315bccf2de7547e30338da4101.html#ga874417315bccf2de7547e30338da4101":[3,0,5,900,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga874417315bccf2de7547e30338da4101.html#ga874417315bccf2de7547e30338da4101":[3,0,5,899,0],
+"dc/dd2/group__double_o_t_h_e_reigen_ga972f824f8b9216991726b9d992db7cf5.html#ga972f824f8b9216991726b9d992db7cf5":[3,0,5,863,0],
 "dc/dd2/group__double_o_t_h_e_reigen_ga972f824f8b9216991726b9d992db7cf5.html#ga972f824f8b9216991726b9d992db7cf5":[0,0,7,0,5],
-"dc/dd2/group__double_o_t_h_e_reigen_ga972f824f8b9216991726b9d992db7cf5.html#ga972f824f8b9216991726b9d992db7cf5":[3,0,5,864,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gaa31d35b52c937fdbacaa2e034d8bb52b.html#gaa31d35b52c937fdbacaa2e034d8bb52b":[3,0,5,874,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gaa31d35b52c937fdbacaa2e034d8bb52b.html#gaa31d35b52c937fdbacaa2e034d8bb52b":[0,0,7,0,11],
-"dc/dd2/group__double_o_t_h_e_reigen_gaa31d35b52c937fdbacaa2e034d8bb52b.html#gaa31d35b52c937fdbacaa2e034d8bb52b":[3,0,5,875,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gaa57d98303960d30584b35662a539bffb.html#gaa57d98303960d30584b35662a539bffb":[0,0,7,0,3],
-"dc/dd2/group__double_o_t_h_e_reigen_gaa57d98303960d30584b35662a539bffb.html#gaa57d98303960d30584b35662a539bffb":[3,0,5,862,0],
-"dc/dd2/group__double_o_t_h_e_reigen_gaa7c4f7b52f415b808e935845f19300ed.html#gaa7c4f7b52f415b808e935845f19300ed":[3,0,5,585,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gaa57d98303960d30584b35662a539bffb.html#gaa57d98303960d30584b35662a539bffb":[3,0,5,861,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gaa7c4f7b52f415b808e935845f19300ed.html#gaa7c4f7b52f415b808e935845f19300ed":[3,0,5,584,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gaa7c4f7b52f415b808e935845f19300ed.html#gaa7c4f7b52f415b808e935845f19300ed":[0,0,7,0,1],
 "dc/dd2/group__double_o_t_h_e_reigen_gaaa6df51cfd92c4ab08d41a54bf05c3ab.html#gaaa6df51cfd92c4ab08d41a54bf05c3ab":[0,0,7,0,17],
-"dc/dd2/group__double_o_t_h_e_reigen_gaaa6df51cfd92c4ab08d41a54bf05c3ab.html#gaaa6df51cfd92c4ab08d41a54bf05c3ab":[3,0,5,897,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gaaa6df51cfd92c4ab08d41a54bf05c3ab.html#gaaa6df51cfd92c4ab08d41a54bf05c3ab":[3,0,5,896,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gac1ea24e07f3e2522ef6e8e9768eea5c5.html#gac1ea24e07f3e2522ef6e8e9768eea5c5":[0,0,7,0,10],
-"dc/dd2/group__double_o_t_h_e_reigen_gac1ea24e07f3e2522ef6e8e9768eea5c5.html#gac1ea24e07f3e2522ef6e8e9768eea5c5":[3,0,5,870,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gac1ea24e07f3e2522ef6e8e9768eea5c5.html#gac1ea24e07f3e2522ef6e8e9768eea5c5":[3,0,5,869,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gacb3c31bbcb04111d818e44f5596d7280.html#gacb3c31bbcb04111d818e44f5596d7280":[0,0,7,0,7],
-"dc/dd2/group__double_o_t_h_e_reigen_gacb3c31bbcb04111d818e44f5596d7280.html#gacb3c31bbcb04111d818e44f5596d7280":[3,0,5,866,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gacb3c31bbcb04111d818e44f5596d7280.html#gacb3c31bbcb04111d818e44f5596d7280":[3,0,5,865,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gad6db4d2faf998bf423820341e477e98f.html#gad6db4d2faf998bf423820341e477e98f":[3,0,5,860,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gad6db4d2faf998bf423820341e477e98f.html#gad6db4d2faf998bf423820341e477e98f":[0,0,7,0,2],
-"dc/dd2/group__double_o_t_h_e_reigen_gad6db4d2faf998bf423820341e477e98f.html#gad6db4d2faf998bf423820341e477e98f":[3,0,5,861,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gaef7c2ecb94476cef947dcc461450012f.html#gaef7c2ecb94476cef947dcc461450012f":[0,0,7,0,15],
-"dc/dd2/group__double_o_t_h_e_reigen_gaef7c2ecb94476cef947dcc461450012f.html#gaef7c2ecb94476cef947dcc461450012f":[3,0,5,880,0],
+"dc/dd2/group__double_o_t_h_e_reigen_gaef7c2ecb94476cef947dcc461450012f.html#gaef7c2ecb94476cef947dcc461450012f":[3,0,5,879,0],
 "dc/dd2/group__double_o_t_h_e_reigen_gaf8e2a8f5ea7f515fa0b5bd5ae8427322.html#gaf8e2a8f5ea7f515fa0b5bd5ae8427322":[0,0,7,0,4],
-"dc/dd2/group__double_o_t_h_e_reigen_gaf8e2a8f5ea7f515fa0b5bd5ae8427322.html#gaf8e2a8f5ea7f515fa0b5bd5ae8427322":[3,0,5,863,0],
-"dc/dd4/dporfsx_8f.html":[3,0,5,832],
-"dc/dd4/dporfsx_8f_source.html":[3,0,5,832],
+"dc/dd2/group__double_o_t_h_e_reigen_gaf8e2a8f5ea7f515fa0b5bd5ae8427322.html#gaf8e2a8f5ea7f515fa0b5bd5ae8427322":[3,0,5,862,0],
+"dc/dd4/dporfsx_8f.html":[3,0,5,831],
+"dc/dd4/dporfsx_8f_source.html":[3,0,5,831],
 "dc/dd5/_e_i_g_2cget02_8f.html":[3,0,6,0,51],
 "dc/dd5/_e_i_g_2cget02_8f_source.html":[3,0,6,0,51],
 "dc/dd5/cchkbd_8f.html":[3,0,6,0,11],
@@ -81,8 +80,8 @@ var NAVTREEINDEX95 =
 "dc/dd5/lapacke__stbcon__work_8c.html":[3,0,4,3,1765],
 "dc/dd5/lapacke__stbcon__work_8c_adef916cf1c2dcf3a9660c68ac64238cc.html#adef916cf1c2dcf3a9660c68ac64238cc":[3,0,4,3,1765,0],
 "dc/dd5/lapacke__stbcon__work_8c_source.html":[3,0,4,3,1765],
-"dc/dd5/zupgtr_8f.html":[3,0,5,2019],
-"dc/dd5/zupgtr_8f_source.html":[3,0,5,2019],
+"dc/dd5/zupgtr_8f.html":[3,0,5,2017],
+"dc/dd5/zupgtr_8f_source.html":[3,0,5,2017],
 "dc/dd6/ctfttp_8f.html":[3,0,5,424],
 "dc/dd6/ctfttp_8f_source.html":[3,0,5,424],
 "dc/dd7/chbevx__2stage_8f.html":[3,0,5,106],
@@ -104,22 +103,22 @@ var NAVTREEINDEX95 =
 "dc/dd9/lapacke__sgemqr_8c.html":[3,0,4,3,1314],
 "dc/dd9/lapacke__sgemqr_8c_a75602f72ae6f6d7c06d294ebb5c897bc.html#a75602f72ae6f6d7c06d294ebb5c897bc":[3,0,4,3,1314,0],
 "dc/dd9/lapacke__sgemqr_8c_source.html":[3,0,4,3,1314],
-"dc/dd9/slarfg_8f.html":[3,0,5,1231],
-"dc/dd9/slarfg_8f_source.html":[3,0,5,1231],
+"dc/dd9/slarfg_8f.html":[3,0,5,1229],
+"dc/dd9/slarfg_8f_source.html":[3,0,5,1229],
 "dc/ddb/_e_i_g_2zsbmv_8f.html":[3,0,6,0,351],
 "dc/ddb/_e_i_g_2zsbmv_8f_source.html":[3,0,6,0,351],
 "dc/dde/lapacke__zhetrs_8c.html":[3,0,4,3,2104],
 "dc/dde/lapacke__zhetrs_8c_abeadd52811c1db9efcaf657329d07d23.html#abeadd52811c1db9efcaf657329d07d23":[3,0,4,3,2104,0],
 "dc/dde/lapacke__zhetrs_8c_source.html":[3,0,4,3,2104],
-"dc/ddf/sgerfsx_8f.html":[3,0,5,1080],
-"dc/ddf/sgerfsx_8f_source.html":[3,0,5,1080],
+"dc/ddf/sgerfsx_8f.html":[3,0,5,1078],
+"dc/ddf/sgerfsx_8f_source.html":[3,0,5,1078],
 "dc/de0/cblas__cscal_8c.html":[3,0,1,2,19],
 "dc/de0/cblas__cscal_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,19,0],
+"dc/de0/cblas__cscal_8c_a1c9461805146af48b3626a34819606ba.html#a1c9461805146af48b3626a34819606ba":[3,0,1,2,19,2],
 "dc/de0/cblas__cscal_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,19,1],
-"dc/de0/cblas__cscal_8c_ac27784467b22773ed4154fffe89331f3.html#ac27784467b22773ed4154fffe89331f3":[3,0,1,2,19,2],
 "dc/de0/cblas__cscal_8c_source.html":[3,0,1,2,19],
-"dc/de0/zlarcm_8f.html":[3,0,5,1802],
-"dc/de0/zlarcm_8f_source.html":[3,0,5,1802],
+"dc/de0/zlarcm_8f.html":[3,0,5,1800],
+"dc/de0/zlarcm_8f_source.html":[3,0,5,1800],
 "dc/de1/lapacke__csyswapr__work_8c.html":[3,0,4,3,501],
 "dc/de1/lapacke__csyswapr__work_8c_a293ac2f84acb4925096c11b0d47bda84.html#a293ac2f84acb4925096c11b0d47bda84":[3,0,4,3,501,0],
 "dc/de1/lapacke__csyswapr__work_8c_source.html":[3,0,4,3,501],
@@ -132,10 +131,10 @@ var NAVTREEINDEX95 =
 "dc/de2/lapacke__ssytrf__aa__2stage_8c.html":[3,0,4,3,1736],
 "dc/de2/lapacke__ssytrf__aa__2stage_8c_a5049547bfbc3650e630058c804bcb266.html#a5049547bfbc3650e630058c804bcb266":[3,0,4,3,1736,0],
 "dc/de2/lapacke__ssytrf__aa__2stage_8c_source.html":[3,0,4,3,1736],
-"dc/de2/strcon_8f.html":[3,0,5,1505],
-"dc/de2/strcon_8f_source.html":[3,0,5,1505],
-"dc/de2/zgelqf_8f.html":[3,0,5,1554],
-"dc/de2/zgelqf_8f_source.html":[3,0,5,1554],
+"dc/de2/strcon_8f.html":[3,0,5,1503],
+"dc/de2/strcon_8f_source.html":[3,0,5,1503],
+"dc/de2/zgelqf_8f.html":[3,0,5,1552],
+"dc/de2/zgelqf_8f_source.html":[3,0,5,1552],
 "dc/de3/lapacke__clacp2__work_8c.html":[3,0,4,3,321],
 "dc/de3/lapacke__clacp2__work_8c_ade4d8bbcc2f39b73be8be759a229473e.html#ade4d8bbcc2f39b73be8be759a229473e":[3,0,4,3,321,0],
 "dc/de3/lapacke__clacp2__work_8c_source.html":[3,0,4,3,321],
@@ -145,8 +144,8 @@ var NAVTREEINDEX95 =
 "dc/de3/lapacke__ztprfs__work_8c.html":[3,0,4,3,2407],
 "dc/de3/lapacke__ztprfs__work_8c_ac18823f3a73745033f9478fc496ad27c.html#ac18823f3a73745033f9478fc496ad27c":[3,0,4,3,2407,0],
 "dc/de3/lapacke__ztprfs__work_8c_source.html":[3,0,4,3,2407],
-"dc/de3/zsyequb_8f.html":[3,0,5,1907],
-"dc/de3/zsyequb_8f_source.html":[3,0,5,1907],
+"dc/de3/zsyequb_8f.html":[3,0,5,1905],
+"dc/de3/zsyequb_8f_source.html":[3,0,5,1905],
 "dc/de4/lapacke__chptri__work_8c.html":[3,0,4,3,309],
 "dc/de4/lapacke__chptri__work_8c_a781270a51f3298e42df460160f926d4b.html#a781270a51f3298e42df460160f926d4b":[3,0,4,3,309,0],
 "dc/de4/lapacke__chptri__work_8c_source.html":[3,0,4,3,309],
@@ -159,35 +158,35 @@ var NAVTREEINDEX95 =
 "dc/de6/lapacke__zungtr_8c.html":[3,0,4,3,2458],
 "dc/de6/lapacke__zungtr_8c_a222822f34a8ff9bdd4cfec48fbdc6cbb.html#a222822f34a8ff9bdd4cfec48fbdc6cbb":[3,0,4,3,2458,0],
 "dc/de6/lapacke__zungtr_8c_source.html":[3,0,4,3,2458],
-"dc/de6/zgghrd_8f.html":[3,0,5,1607],
-"dc/de6/zgghrd_8f_source.html":[3,0,5,1607],
+"dc/de6/zgghrd_8f.html":[3,0,5,1605],
+"dc/de6/zgghrd_8f_source.html":[3,0,5,1605],
 "dc/de9/group__double_p_osolve.html":[0,0,4,0,0],
 "dc/de9/group__double_p_osolve_ga423141487077727ec3bc52edd1fccd44.html#ga423141487077727ec3bc52edd1fccd44":[0,0,4,0,0,2],
-"dc/de9/group__double_p_osolve_ga423141487077727ec3bc52edd1fccd44.html#ga423141487077727ec3bc52edd1fccd44":[3,0,5,835,0],
+"dc/de9/group__double_p_osolve_ga423141487077727ec3bc52edd1fccd44.html#ga423141487077727ec3bc52edd1fccd44":[3,0,5,834,0],
 "dc/de9/group__double_p_osolve_ga91ea95252aad898ccba02b2ebd7eab22.html#ga91ea95252aad898ccba02b2ebd7eab22":[0,0,4,0,0,3],
-"dc/de9/group__double_p_osolve_ga91ea95252aad898ccba02b2ebd7eab22.html#ga91ea95252aad898ccba02b2ebd7eab22":[3,0,5,882,0],
-"dc/de9/group__double_p_osolve_ga9ce56acceb70eb6484a768eaa841f70d.html#ga9ce56acceb70eb6484a768eaa841f70d":[3,0,5,833,0],
+"dc/de9/group__double_p_osolve_ga91ea95252aad898ccba02b2ebd7eab22.html#ga91ea95252aad898ccba02b2ebd7eab22":[3,0,5,881,0],
+"dc/de9/group__double_p_osolve_ga9ce56acceb70eb6484a768eaa841f70d.html#ga9ce56acceb70eb6484a768eaa841f70d":[3,0,5,832,0],
 "dc/de9/group__double_p_osolve_ga9ce56acceb70eb6484a768eaa841f70d.html#ga9ce56acceb70eb6484a768eaa841f70d":[0,0,4,0,0,0],
+"dc/de9/group__double_p_osolve_gac9c72f254642bcc4d512c24c00e47d33.html#gac9c72f254642bcc4d512c24c00e47d33":[3,0,5,833,0],
 "dc/de9/group__double_p_osolve_gac9c72f254642bcc4d512c24c00e47d33.html#gac9c72f254642bcc4d512c24c00e47d33":[0,0,4,0,0,1],
-"dc/de9/group__double_p_osolve_gac9c72f254642bcc4d512c24c00e47d33.html#gac9c72f254642bcc4d512c24c00e47d33":[3,0,5,834,0],
 "dc/de9/lapacke__cstein_8c.html":[3,0,4,3,466],
 "dc/de9/lapacke__cstein_8c_ad3619b117523c706339f0e0b2eabef28.html#ad3619b117523c706339f0e0b2eabef28":[3,0,4,3,466,0],
 "dc/de9/lapacke__cstein_8c_source.html":[3,0,4,3,466],
-"dc/deb/dposvx_8f.html":[3,0,5,834],
-"dc/deb/dposvx_8f_source.html":[3,0,5,834],
+"dc/deb/dposvx_8f.html":[3,0,5,833],
+"dc/deb/dposvx_8f_source.html":[3,0,5,833],
 "dc/dec/dchksy__rk_8f.html":[3,0,6,1,237],
 "dc/dec/dchksy__rk_8f_source.html":[3,0,6,1,237],
-"dc/dec/ilauplo_8f.html":[3,0,5,1013],
-"dc/dec/ilauplo_8f_source.html":[3,0,5,1013],
-"dc/ded/dsytrs__aa__2stage_8f.html":[3,0,5,955],
-"dc/ded/dsytrs__aa__2stage_8f_source.html":[3,0,5,955],
+"dc/dec/ilauplo_8f.html":[3,0,5,1012],
+"dc/dec/ilauplo_8f_source.html":[3,0,5,1012],
+"dc/ded/dsytrs__aa__2stage_8f.html":[3,0,5,954],
+"dc/ded/dsytrs__aa__2stage_8f_source.html":[3,0,5,954],
 "dc/ded/lapacke__sgbequ__work_8c.html":[3,0,4,3,1257],
 "dc/ded/lapacke__sgbequ__work_8c_a585b1d56bf0821db430288e68147d5aa.html#a585b1d56bf0821db430288e68147d5aa":[3,0,4,3,1257,0],
 "dc/ded/lapacke__sgbequ__work_8c_source.html":[3,0,4,3,1257],
-"dc/def/dpftrs_8f.html":[3,0,5,827],
-"dc/def/dpftrs_8f_source.html":[3,0,5,827],
-"dc/df0/zlaesy_8f.html":[3,0,5,1745],
-"dc/df0/zlaesy_8f_source.html":[3,0,5,1745],
+"dc/def/dpftrs_8f.html":[3,0,5,826],
+"dc/def/dpftrs_8f_source.html":[3,0,5,826],
+"dc/df0/zlaesy_8f.html":[3,0,5,1743],
+"dc/df0/zlaesy_8f_source.html":[3,0,5,1743],
 "dc/df1/lapacke__dpbsv__work_8c.html":[3,0,4,3,935],
 "dc/df1/lapacke__dpbsv__work_8c_ad53e9afdce3868c552482d030c7265eb.html#ad53e9afdce3868c552482d030c7265eb":[3,0,4,3,935,0],
 "dc/df1/lapacke__dpbsv__work_8c_source.html":[3,0,4,3,935],
@@ -197,8 +196,8 @@ var NAVTREEINDEX95 =
 "dc/df4/group__solve_p_t.html":[0,0,6,0],
 "dc/df4/sgeqpf_8f.html":[3,0,5,0,21],
 "dc/df4/sgeqpf_8f_source.html":[3,0,5,0,21],
-"dc/df4/slarrd_8f.html":[3,0,5,1241],
-"dc/df4/slarrd_8f_source.html":[3,0,5,1241],
+"dc/df4/slarrd_8f.html":[3,0,5,1239],
+"dc/df4/slarrd_8f_source.html":[3,0,5,1239],
 "dc/df5/dlqt01_8f.html":[3,0,6,1,327],
 "dc/df5/dlqt01_8f_source.html":[3,0,6,1,327],
 "dc/df6/ztpt05_8f.html":[3,0,6,1,772],
@@ -213,8 +212,8 @@ var NAVTREEINDEX95 =
 "dc/df7/lapacke__sgemqrt__work_8c_source.html":[3,0,4,3,1317],
 "dc/df7/zerrunhr__col_8f.html":[3,0,6,1,670],
 "dc/df7/zerrunhr__col_8f_source.html":[3,0,6,1,670],
-"dc/df8/zunhr__col_8f.html":[3,0,5,2004],
-"dc/df8/zunhr__col_8f_source.html":[3,0,5,2004],
+"dc/df8/zunhr__col_8f.html":[3,0,5,2002],
+"dc/df8/zunhr__col_8f_source.html":[3,0,5,2002],
 "dc/df9/lapacke__cspsvx_8c.html":[3,0,4,3,454],
 "dc/df9/lapacke__cspsvx_8c_a134b27cbcc885ad1fc6f438a862626fc.html#a134b27cbcc885ad1fc6f438a862626fc":[3,0,4,3,454,0],
 "dc/df9/lapacke__cspsvx_8c_source.html":[3,0,4,3,454],
@@ -223,7 +222,7 @@ var NAVTREEINDEX95 =
 "dc/dfb/lapacke__zpftrs__work_8c_source.html":[3,0,4,3,2229],
 "dc/dfc/cblas__isamax_8c.html":[3,0,1,2,72],
 "dc/dfc/cblas__isamax_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,72,0],
-"dc/dfc/cblas__isamax_8c_a3628bee5540eb1fa2d1baa119b339d79.html#a3628bee5540eb1fa2d1baa119b339d79":[3,0,1,2,72,2],
+"dc/dfc/cblas__isamax_8c_a2fca30c75d3aa7d1e9b9ac189818d8be.html#a2fca30c75d3aa7d1e9b9ac189818d8be":[3,0,1,2,72,2],
 "dc/dfc/cblas__isamax_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,72,1],
 "dc/dfc/cblas__isamax_8c_source.html":[3,0,1,2,72],
 "dc/dfd/lapacke__dstemr_8c.html":[3,0,4,3,1070],
@@ -249,5 +248,6 @@ var NAVTREEINDEX95 =
 "dd/d02/dblat1_8f_af82694537a350a6cb3615ece843dcede.html#af82694537a350a6cb3615ece843dcede":[3,0,0,1,3,6],
 "dd/d02/dblat1_8f_source.html":[3,0,0,1,3],
 "dd/d02/sorhr__col01_8f.html":[3,0,6,1,510],
-"dd/d02/sorhr__col01_8f_source.html":[3,0,6,1,510]
+"dd/d02/sorhr__col01_8f_source.html":[3,0,6,1,510],
+"dd/d02/ztbtrs_8f.html":[3,0,5,1940]
 };
