@@ -1,24 +1,23 @@
 var NAVTREEINDEX96 =
 {
-"dd/d02/ztbtrs_8f.html":[3,0,5,1942],
-"dd/d02/ztbtrs_8f_source.html":[3,0,5,1942],
+"dd/d02/ztbtrs_8f_source.html":[3,0,5,1940],
 "dd/d03/lapacke__dspcon_8c.html":[3,0,4,3,1030],
 "dd/d03/lapacke__dspcon_8c_a1bcced27252f8f43ca1725a0781152bc.html#a1bcced27252f8f43ca1725a0781152bc":[3,0,4,3,1030,0],
 "dd/d03/lapacke__dspcon_8c_source.html":[3,0,4,3,1030],
 "dd/d04/ddrvrfp_8f.html":[3,0,6,1,261],
 "dd/d04/ddrvrfp_8f_source.html":[3,0,6,1,261],
-"dd/d04/dgebal_8f.html":[3,0,5,519],
-"dd/d04/dgebal_8f_source.html":[3,0,5,519],
+"dd/d04/dgebal_8f.html":[3,0,5,518],
+"dd/d04/dgebal_8f_source.html":[3,0,5,518],
 "dd/d05/lapacke__zlaset__work_8c.html":[3,0,4,3,2199],
 "dd/d05/lapacke__zlaset__work_8c_ac8403a7407987e83ec2c1c446b44aa10.html#ac8403a7407987e83ec2c1c446b44aa10":[3,0,4,3,2199,0],
 "dd/d05/lapacke__zlaset__work_8c_source.html":[3,0,4,3,2199],
 "dd/d08/lapacke__zhpgst_8c.html":[3,0,4,3,2128],
 "dd/d08/lapacke__zhpgst_8c_a18c17f1b1a736ae57257e130c8cc2d65.html#a18c17f1b1a736ae57257e130c8cc2d65":[3,0,4,3,2128,0],
 "dd/d08/lapacke__zhpgst_8c_source.html":[3,0,4,3,2128],
-"dd/d08/zggesx_8f.html":[3,0,5,1601],
-"dd/d08/zggesx_8f_source.html":[3,0,5,1601],
-"dd/d09/shgeqz_8f.html":[3,0,5,1125],
-"dd/d09/shgeqz_8f_source.html":[3,0,5,1125],
+"dd/d08/zggesx_8f.html":[3,0,5,1599],
+"dd/d08/zggesx_8f_source.html":[3,0,5,1599],
+"dd/d09/shgeqz_8f.html":[3,0,5,1123],
+"dd/d09/shgeqz_8f_source.html":[3,0,5,1123],
 "dd/d0c/_l_i_n_2clahilb_8f.html":[3,0,6,1,125],
 "dd/d0c/_l_i_n_2clahilb_8f_source.html":[3,0,6,1,125],
 "dd/d0c/lapacke__spotrf__work_8c.html":[3,0,4,3,1565],
@@ -33,12 +32,12 @@ var NAVTREEINDEX96 =
 "dd/d0e/lapacke__shs__trans_8c.html":[3,0,4,4,84],
 "dd/d0e/lapacke__shs__trans_8c_a46d0c043cf2d10eac1c25aac37ca14e9.html#a46d0c043cf2d10eac1c25aac37ca14e9":[3,0,4,4,84,0],
 "dd/d0e/lapacke__shs__trans_8c_source.html":[3,0,4,4,84],
-"dd/d0e/zlarz_8f.html":[3,0,5,1817],
-"dd/d0e/zlarz_8f_source.html":[3,0,5,1817],
-"dd/d0e/ztrcon_8f.html":[3,0,5,1968],
-"dd/d0e/ztrcon_8f_source.html":[3,0,5,1968],
-"dd/d0f/dsycon_8f.html":[3,0,5,901],
-"dd/d0f/dsycon_8f_source.html":[3,0,5,901],
+"dd/d0e/zlarz_8f.html":[3,0,5,1815],
+"dd/d0e/zlarz_8f_source.html":[3,0,5,1815],
+"dd/d0e/ztrcon_8f.html":[3,0,5,1966],
+"dd/d0e/ztrcon_8f_source.html":[3,0,5,1966],
+"dd/d0f/dsycon_8f.html":[3,0,5,900],
+"dd/d0f/dsycon_8f_source.html":[3,0,5,900],
 "dd/d0f/lapacke__make__complex__double_8c.html":[3,0,4,4,73],
 "dd/d0f/lapacke__make__complex__double_8c_aa7f436a0a9e536b6c15664d12a8b5cd3.html#aa7f436a0a9e536b6c15664d12a8b5cd3":[3,0,4,4,73,0],
 "dd/d0f/lapacke__make__complex__double_8c_source.html":[3,0,4,4,73],
@@ -46,8 +45,8 @@ var NAVTREEINDEX96 =
 "dd/d10/cgtt02_8f_source.html":[3,0,6,1,117],
 "dd/d11/cblas__dsyr2k_8c.html":[3,0,1,2,57],
 "dd/d11/cblas__dsyr2k_8c_a1529e95e9a56176f6aa13a722ad68db5.html#a1529e95e9a56176f6aa13a722ad68db5":[3,0,1,2,57,3],
-"dd/d11/cblas__dsyr2k_8c_a1e41891a1427340562e726484599eeeb.html#a1e41891a1427340562e726484599eeeb":[3,0,1,2,57,7],
 "dd/d11/cblas__dsyr2k_8c_a4a72d02a1f5f2e876023895d4d2294dc.html#a4a72d02a1f5f2e876023895d4d2294dc":[3,0,1,2,57,0],
+"dd/d11/cblas__dsyr2k_8c_a523c911be5db41978ec570ce80c4d8e1.html#a523c911be5db41978ec570ce80c4d8e1":[3,0,1,2,57,7],
 "dd/d11/cblas__dsyr2k_8c_a55e46443180a696556cc74551e183016.html#a55e46443180a696556cc74551e183016":[3,0,1,2,57,2],
 "dd/d11/cblas__dsyr2k_8c_a6973991f19ad23c7de69091c9e269606.html#a6973991f19ad23c7de69091c9e269606":[3,0,1,2,57,5],
 "dd/d11/cblas__dsyr2k_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,57,4],
@@ -80,8 +79,8 @@ var NAVTREEINDEX96 =
 "dd/d15/lapacke__zhetri2_8c_source.html":[3,0,4,3,2097],
 "dd/d16/cchkhp_8f.html":[3,0,6,1,17],
 "dd/d16/cchkhp_8f_source.html":[3,0,6,1,17],
-"dd/d17/dlaqz1_8f.html":[3,0,5,699],
-"dd/d17/dlaqz1_8f_source.html":[3,0,5,699],
+"dd/d17/dlaqz1_8f.html":[3,0,5,698],
+"dd/d17/dlaqz1_8f_source.html":[3,0,5,698],
 "dd/d18/claqsb_8f.html":[3,0,5,272],
 "dd/d18/claqsb_8f_source.html":[3,0,5,272],
 "dd/d18/lapacke__csytrf__work_8c.html":[3,0,4,3,511],
@@ -100,8 +99,8 @@ var NAVTREEINDEX96 =
 "dd/d19/lapacke__stbcon_8c_source.html":[3,0,4,3,1764],
 "dd/d1a/clacp2_8f.html":[3,0,5,215],
 "dd/d1a/clacp2_8f_source.html":[3,0,5,215],
-"dd/d1a/dgbtf2_8f.html":[3,0,5,515],
-"dd/d1a/dgbtf2_8f_source.html":[3,0,5,515],
+"dd/d1a/dgbtf2_8f.html":[3,0,5,514],
+"dd/d1a/dgbtf2_8f_source.html":[3,0,5,514],
 "dd/d1a/zbdt03_8f.html":[3,0,6,0,281],
 "dd/d1a/zbdt03_8f_source.html":[3,0,6,0,281],
 "dd/d1b/lapacke__zlatms__work_8c.html":[3,0,4,3,2205],
@@ -134,19 +133,19 @@ var NAVTREEINDEX96 =
 "dd/d20/lapacke__ssyevd__2stage_8c.html":[3,0,4,3,1691],
 "dd/d20/lapacke__ssyevd__2stage_8c_a00c1831b337e39a3c3018f3d66d24241.html#a00c1831b337e39a3c3018f3d66d24241":[3,0,4,3,1691,0],
 "dd/d20/lapacke__ssyevd__2stage_8c_source.html":[3,0,4,3,1691],
-"dd/d21/dlasd3_8f.html":[3,0,5,740],
-"dd/d21/dlasd3_8f_source.html":[3,0,5,740],
+"dd/d21/dlasd3_8f.html":[3,0,5,739],
+"dd/d21/dlasd3_8f_source.html":[3,0,5,739],
 "dd/d22/cdrvhe_8f.html":[3,0,6,1,50],
 "dd/d22/cdrvhe_8f_source.html":[3,0,6,1,50],
 "dd/d22/lapacke__zsytri2x__work_8c.html":[3,0,4,3,2354],
 "dd/d22/lapacke__zsytri2x__work_8c_a3633b7d097888018b548fa6c5305a02e.html#a3633b7d097888018b548fa6c5305a02e":[3,0,4,3,2354,0],
 "dd/d22/lapacke__zsytri2x__work_8c_source.html":[3,0,4,3,2354],
-"dd/d22/zhetri2x_8f.html":[3,0,5,1677],
-"dd/d22/zhetri2x_8f_source.html":[3,0,5,1677],
-"dd/d23/sgesvxx_8f.html":[3,0,5,1091],
-"dd/d23/sgesvxx_8f_source.html":[3,0,5,1091],
-"dd/d23/ztrti2_8f.html":[3,0,5,1976],
-"dd/d23/ztrti2_8f_source.html":[3,0,5,1976],
+"dd/d22/zhetri2x_8f.html":[3,0,5,1675],
+"dd/d22/zhetri2x_8f_source.html":[3,0,5,1675],
+"dd/d23/sgesvxx_8f.html":[3,0,5,1089],
+"dd/d23/sgesvxx_8f_source.html":[3,0,5,1089],
+"dd/d23/ztrti2_8f.html":[3,0,5,1974],
+"dd/d23/ztrti2_8f_source.html":[3,0,5,1974],
 "dd/d25/dchkpo_8f.html":[3,0,6,1,222],
 "dd/d25/dchkpo_8f_source.html":[3,0,6,1,222],
 "dd/d26/dsdotsub_8f.html":[3,0,1,2,149],
@@ -171,10 +170,10 @@ var NAVTREEINDEX96 =
 "dd/d29/lapacke__dsyswapr__work_8c.html":[3,0,4,3,1137],
 "dd/d29/lapacke__dsyswapr__work_8c_aab515adb9e64368b6b34f4859c2ad110.html#aab515adb9e64368b6b34f4859c2ad110":[3,0,4,3,1137,0],
 "dd/d29/lapacke__dsyswapr__work_8c_source.html":[3,0,4,3,1137],
-"dd/d2a/dgebak_8f.html":[3,0,5,518],
-"dd/d2a/dgebak_8f_source.html":[3,0,5,518],
-"dd/d2a/zhptri_8f.html":[3,0,5,1702],
-"dd/d2a/zhptri_8f_source.html":[3,0,5,1702],
+"dd/d2a/dgebak_8f.html":[3,0,5,517],
+"dd/d2a/dgebak_8f_source.html":[3,0,5,517],
+"dd/d2a/zhptri_8f.html":[3,0,5,1700],
+"dd/d2a/zhptri_8f_source.html":[3,0,5,1700],
 "dd/d2b/lapacke__dgttrf__work_8c.html":[3,0,4,3,821],
 "dd/d2b/lapacke__dgttrf__work_8c_a0cb9118e215be77a0d123f12cef00540.html#a0cb9118e215be77a0d123f12cef00540":[3,0,4,3,821,0],
 "dd/d2b/lapacke__dgttrf__work_8c_source.html":[3,0,4,3,821],
@@ -207,8 +206,8 @@ var NAVTREEINDEX96 =
 "dd/d31/zggsvd_8f.html":[3,0,5,0,31],
 "dd/d31/zggsvd_8f_afa4ba38256f4d15e886bb4681fa6e688.html#afa4ba38256f4d15e886bb4681fa6e688":[3,0,5,0,31,0],
 "dd/d31/zggsvd_8f_source.html":[3,0,5,0,31],
-"dd/d32/dgttrs_8f.html":[3,0,5,600],
-"dd/d32/dgttrs_8f_source.html":[3,0,5,600],
+"dd/d32/dgttrs_8f.html":[3,0,5,599],
+"dd/d32/dgttrs_8f_source.html":[3,0,5,599],
 "dd/d33/clatmr_8f.html":[3,0,6,2,15],
 "dd/d33/clatmr_8f_source.html":[3,0,6,2,15],
 "dd/d33/csyt02_8f.html":[3,0,6,1,192],
@@ -225,8 +224,8 @@ var NAVTREEINDEX96 =
 "dd/d35/chbt21_8f_source.html":[3,0,6,0,67],
 "dd/d35/cstt21_8f.html":[3,0,6,0,82],
 "dd/d35/cstt21_8f_source.html":[3,0,6,0,82],
-"dd/d35/srscl_8f.html":[3,0,5,1381],
-"dd/d35/srscl_8f_source.html":[3,0,5,1381],
+"dd/d35/srscl_8f.html":[3,0,5,1379],
+"dd/d35/srscl_8f_source.html":[3,0,5,1379],
 "dd/d36/lapacke__sgbsvx_8c.html":[3,0,4,3,1266],
 "dd/d36/lapacke__sgbsvx_8c_a7741de9f1530283643b9dec76c0071a3.html#a7741de9f1530283643b9dec76c0071a3":[3,0,4,3,1266,0],
 "dd/d36/lapacke__sgbsvx_8c_source.html":[3,0,4,3,1266],
@@ -249,5 +248,6 @@ var NAVTREEINDEX96 =
 "dd/d3c/lapacke__dgeqrt__work_8c.html":[3,0,4,3,739],
 "dd/d3c/lapacke__dgeqrt__work_8c_ae28d8ded356c2a56b45981db6b22bf1b.html#ae28d8ded356c2a56b45981db6b22bf1b":[3,0,4,3,739,0],
 "dd/d3c/lapacke__dgeqrt__work_8c_source.html":[3,0,4,3,739],
-"dd/d3d/ztrsen_8f.html":[3,0,5,1973]
+"dd/d3d/ztrsen_8f.html":[3,0,5,1971],
+"dd/d3d/ztrsen_8f_source.html":[3,0,5,1971]
 };
