@@ -1,13 +1,12 @@
 var NAVTREEINDEX97 =
 {
-"dd/d3d/ztrsen_8f_source.html":[3,0,5,1973],
 "dd/d3e/lapacke__cgeequ__work_8c.html":[3,0,4,3,35],
 "dd/d3e/lapacke__cgeequ__work_8c_a7e10f53d3bdd09083f741eb36b452f70.html#a7e10f53d3bdd09083f741eb36b452f70":[3,0,4,3,35,0],
 "dd/d3e/lapacke__cgeequ__work_8c_source.html":[3,0,4,3,35],
-"dd/d3f/zsytrs__aa__2stage_8f.html":[3,0,5,1938],
-"dd/d3f/zsytrs__aa__2stage_8f_source.html":[3,0,5,1938],
-"dd/d40/sla__syrfsx__extended_8f.html":[3,0,5,1143],
-"dd/d40/sla__syrfsx__extended_8f_source.html":[3,0,5,1143],
+"dd/d3f/zsytrs__aa__2stage_8f.html":[3,0,5,1936],
+"dd/d3f/zsytrs__aa__2stage_8f_source.html":[3,0,5,1936],
+"dd/d40/sla__syrfsx__extended_8f.html":[3,0,5,1141],
+"dd/d40/sla__syrfsx__extended_8f_source.html":[3,0,5,1141],
 "dd/d44/cchktp_8f.html":[3,0,6,1,40],
 "dd/d44/cchktp_8f_source.html":[3,0,6,1,40],
 "dd/d44/cgesvdq_8f.html":[3,0,5,62],
@@ -15,8 +14,8 @@ var NAVTREEINDEX97 =
 "dd/d44/lapacke__zgg__trans_8c.html":[3,0,4,4,116],
 "dd/d44/lapacke__zgg__trans_8c_a38a9eb7eea154f94f313f8d1ac4b45a3.html#a38a9eb7eea154f94f313f8d1ac4b45a3":[3,0,4,4,116,0],
 "dd/d44/lapacke__zgg__trans_8c_source.html":[3,0,4,4,116],
-"dd/d44/stbcon_8f.html":[3,0,5,1477],
-"dd/d44/stbcon_8f_source.html":[3,0,5,1477],
+"dd/d44/stbcon_8f.html":[3,0,5,1475],
+"dd/d44/stbcon_8f_source.html":[3,0,5,1475],
 "dd/d45/lapacke__csyr_8c.html":[3,0,4,3,480],
 "dd/d45/lapacke__csyr_8c_a56137f4d11940a505035b082afea8d1d.html#a56137f4d11940a505035b082afea8d1d":[3,0,4,3,480,0],
 "dd/d45/lapacke__csyr_8c_source.html":[3,0,4,3,480],
@@ -30,19 +29,19 @@ var NAVTREEINDEX97 =
 "dd/d49/lapacke__slamch__work_8c.html":[3,0,4,3,1439],
 "dd/d49/lapacke__slamch__work_8c_a4a69dda2a5b97411d17e8ebac5852238.html#a4a69dda2a5b97411d17e8ebac5852238":[3,0,4,3,1439,0],
 "dd/d49/lapacke__slamch__work_8c_source.html":[3,0,4,3,1439],
-"dd/d49/slaqr4_8f.html":[3,0,5,1215],
-"dd/d49/slaqr4_8f_source.html":[3,0,5,1215],
-"dd/d49/sposv_8f.html":[3,0,5,1355],
-"dd/d49/sposv_8f_source.html":[3,0,5,1355],
-"dd/d4a/dspsvx_8f.html":[3,0,5,885],
-"dd/d4a/dspsvx_8f_source.html":[3,0,5,885],
+"dd/d49/slaqr4_8f.html":[3,0,5,1213],
+"dd/d49/slaqr4_8f_source.html":[3,0,5,1213],
+"dd/d49/sposv_8f.html":[3,0,5,1353],
+"dd/d49/sposv_8f_source.html":[3,0,5,1353],
+"dd/d4a/dspsvx_8f.html":[3,0,5,884],
+"dd/d4a/dspsvx_8f_source.html":[3,0,5,884],
 "dd/d4b/lapacke__ztfttr_8c.html":[3,0,4,3,2382],
 "dd/d4b/lapacke__ztfttr_8c_a0348b981fa3d196ffd66642c7d598b74.html#a0348b981fa3d196ffd66642c7d598b74":[3,0,4,3,2382,0],
 "dd/d4b/lapacke__ztfttr_8c_source.html":[3,0,4,3,2382],
 "dd/d4c/clartg_8f90.html":[3,0,5,294],
 "dd/d4c/clartg_8f90_source.html":[3,0,5,294],
-"dd/d4c/dsyev_8f.html":[3,0,5,908],
-"dd/d4c/dsyev_8f_source.html":[3,0,5,908],
+"dd/d4c/dsyev_8f.html":[3,0,5,907],
+"dd/d4c/dsyev_8f_source.html":[3,0,5,907],
 "dd/d4d/c__cblat3_8f.html":[3,0,1,3,8],
 "dd/d4d/c__cblat3_8f_a0c20050a20e26f6d10a9a5c4d1de5992.html#a0c20050a20e26f6d10a9a5c4d1de5992":[3,0,1,3,8,6],
 "dd/d4d/c__cblat3_8f_a29cdc74880c0b93748ab4428d37f3099.html#a29cdc74880c0b93748ab4428d37f3099":[3,0,1,3,8,4],
@@ -72,17 +71,17 @@ var NAVTREEINDEX97 =
 "dd/d4d/lapacke__dptcon_8c_source.html":[3,0,4,3,990],
 "dd/d4e/cget38_8f.html":[3,0,6,0,59],
 "dd/d4e/cget38_8f_source.html":[3,0,6,0,59],
-"dd/d4e/dsposv_8f.html":[3,0,5,882],
-"dd/d4e/dsposv_8f_source.html":[3,0,5,882],
+"dd/d4e/dsposv_8f.html":[3,0,5,881],
+"dd/d4e/dsposv_8f_source.html":[3,0,5,881],
 "dd/d4e/xerbla_8c.html":[3,0,1,2,162],
 "dd/d4e/xerbla_8c_a0977131ed05e646dd125feb45d67524d.html#a0977131ed05e646dd125feb45d67524d":[3,0,1,2,162,0],
-"dd/d4e/xerbla_8c_a9dba6501cb46384a8c483ecb5a916ed2.html#a9dba6501cb46384a8c483ecb5a916ed2":[3,0,1,2,162,2],
+"dd/d4e/xerbla_8c_aa8c89baf67271d9c44cdcfb24798f1d3.html#aa8c89baf67271d9c44cdcfb24798f1d3":[3,0,1,2,162,2],
 "dd/d4e/xerbla_8c_aebcb9809cdcfb564405c0fcd85b07fcd.html#aebcb9809cdcfb564405c0fcd85b07fcd":[3,0,1,2,162,1],
 "dd/d4e/xerbla_8c_source.html":[3,0,1,2,162],
 "dd/d4e/zhet01__3_8f.html":[3,0,6,1,691],
 "dd/d4e/zhet01__3_8f_source.html":[3,0,6,1,691],
-"dd/d4f/zgetrf2_8f.html":[3,0,5,1592],
-"dd/d4f/zgetrf2_8f_source.html":[3,0,5,1592],
+"dd/d4f/zgetrf2_8f.html":[3,0,5,1590],
+"dd/d4f/zgetrf2_8f_source.html":[3,0,5,1590],
 "dd/d50/lapacke__dorgql_8c.html":[3,0,4,3,900],
 "dd/d50/lapacke__dorgql_8c_a26f302952d0dea0799b9b9f4c7e87b69.html#a26f302952d0dea0799b9b9f4c7e87b69":[3,0,4,3,900,0],
 "dd/d50/lapacke__dorgql_8c_source.html":[3,0,4,3,900],
@@ -99,18 +98,18 @@ var NAVTREEINDEX97 =
 "dd/d52/cblas__zherk_8c_a6973991f19ad23c7de69091c9e269606.html#a6973991f19ad23c7de69091c9e269606":[3,0,1,2,127,4],
 "dd/d52/cblas__zherk_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,127,3],
 "dd/d52/cblas__zherk_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,127,1],
+"dd/d52/cblas__zherk_8c_a948dafe9c78c53b9c59d7e5155d54ec6.html#a948dafe9c78c53b9c59d7e5155d54ec6":[3,0,1,2,127,6],
 "dd/d52/cblas__zherk_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,127,5],
-"dd/d52/cblas__zherk_8c_ac7aaf08163e4268e0508b9629a260000.html#ac7aaf08163e4268e0508b9629a260000":[3,0,1,2,127,6],
 "dd/d52/cblas__zherk_8c_source.html":[3,0,1,2,127],
-"dd/d52/ztgsen_8f.html":[3,0,5,1950],
-"dd/d52/ztgsen_8f_source.html":[3,0,5,1950],
+"dd/d52/ztgsen_8f.html":[3,0,5,1948],
+"dd/d52/ztgsen_8f_source.html":[3,0,5,1948],
 "dd/d53/cbdt03_8f.html":[3,0,6,0,8],
 "dd/d53/cbdt03_8f_source.html":[3,0,6,0,8],
 "dd/d53/lapacke__ztrsyl_8c.html":[3,0,4,3,2428],
 "dd/d53/lapacke__ztrsyl_8c_a9f5039bc9779b6c4834dd46fc71ab572.html#a9f5039bc9779b6c4834dd46fc71ab572":[3,0,4,3,2428,0],
 "dd/d53/lapacke__ztrsyl_8c_source.html":[3,0,4,3,2428],
-"dd/d53/zgebal_8f.html":[3,0,5,1539],
-"dd/d53/zgebal_8f_source.html":[3,0,5,1539],
+"dd/d53/zgebal_8f.html":[3,0,5,1537],
+"dd/d53/zgebal_8f_source.html":[3,0,5,1537],
 "dd/d54/ctrt02_8f.html":[3,0,6,1,204],
 "dd/d54/ctrt02_8f_source.html":[3,0,6,1,204],
 "dd/d55/cgebak_8f.html":[3,0,5,16],
@@ -129,8 +128,8 @@ var NAVTREEINDEX97 =
 "dd/d59/lapacke__slarnv_8c.html":[3,0,4,3,1462],
 "dd/d59/lapacke__slarnv_8c_a8f04ad1959ebc70ef7a3fb016d861439.html#a8f04ad1959ebc70ef7a3fb016d861439":[3,0,4,3,1462,0],
 "dd/d59/lapacke__slarnv_8c_source.html":[3,0,4,3,1462],
-"dd/d59/sorbdb5_8f.html":[3,0,5,1306],
-"dd/d59/sorbdb5_8f_source.html":[3,0,5,1306],
+"dd/d59/sorbdb5_8f.html":[3,0,5,1304],
+"dd/d59/sorbdb5_8f_source.html":[3,0,5,1304],
 "dd/d5a/cheevx_8f.html":[3,0,5,122],
 "dd/d5a/cheevx_8f_source.html":[3,0,5,122],
 "dd/d5a/lapacke__spotri_8c.html":[3,0,4,3,1566],
@@ -139,8 +138,8 @@ var NAVTREEINDEX97 =
 "dd/d5a/schksy__aa_8f.html":[3,0,6,1,418],
 "dd/d5a/schksy__aa_8f_ad6d5063b29a916e9dc0325c467899c76.html#ad6d5063b29a916e9dc0325c467899c76":[3,0,6,1,418,0],
 "dd/d5a/schksy__aa_8f_source.html":[3,0,6,1,418],
-"dd/d5a/slauum_8f.html":[3,0,5,1298],
-"dd/d5a/slauum_8f_source.html":[3,0,5,1298],
+"dd/d5a/slauum_8f.html":[3,0,5,1296],
+"dd/d5a/slauum_8f_source.html":[3,0,5,1296],
 "dd/d5b/lapacke__zggev3__work_8c.html":[3,0,4,3,1976],
 "dd/d5b/lapacke__zggev3__work_8c_a8ee6b3784c951c2479c2a2d317dc32b7.html#a8ee6b3784c951c2479c2a2d317dc32b7":[3,0,4,3,1976,0],
 "dd/d5b/lapacke__zggev3__work_8c_source.html":[3,0,4,3,1976],
@@ -150,8 +149,8 @@ var NAVTREEINDEX97 =
 "dd/d5b/lapacke__zungrq_8c.html":[3,0,4,3,2456],
 "dd/d5b/lapacke__zungrq_8c_a536308996ab6bdfe8522f39be524acaa.html#a536308996ab6bdfe8522f39be524acaa":[3,0,4,3,2456,0],
 "dd/d5b/lapacke__zungrq_8c_source.html":[3,0,4,3,2456],
-"dd/d5c/zsytrf__aa__2stage_8f.html":[3,0,5,1925],
-"dd/d5c/zsytrf__aa__2stage_8f_source.html":[3,0,5,1925],
+"dd/d5c/zsytrf__aa__2stage_8f.html":[3,0,5,1923],
+"dd/d5c/zsytrf__aa__2stage_8f_source.html":[3,0,5,1923],
 "dd/d5d/cblas__dgbmv_8c.html":[3,0,1,2,37],
 "dd/d5d/cblas__dgbmv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,37,0],
 "dd/d5d/cblas__dgbmv_8c_a29ba8bdd334215dc3b4217c4959d2649.html#a29ba8bdd334215dc3b4217c4959d2649":[3,0,1,2,37,3],
@@ -159,7 +158,7 @@ var NAVTREEINDEX97 =
 "dd/d5d/cblas__dgbmv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,37,7],
 "dd/d5d/cblas__dgbmv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,37,6],
 "dd/d5d/cblas__dgbmv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,37,4],
-"dd/d5d/cblas__dgbmv_8c_a960eb5d282314a53e54e6fe7fe839a3a.html#a960eb5d282314a53e54e6fe7fe839a3a":[3,0,1,2,37,8],
+"dd/d5d/cblas__dgbmv_8c_a92423482bf71731eef4e663bbba0f22b.html#a92423482bf71731eef4e663bbba0f22b":[3,0,1,2,37,8],
 "dd/d5d/cblas__dgbmv_8c_ad18301a8cabd9aaa1d009cb115da640a.html#ad18301a8cabd9aaa1d009cb115da640a":[3,0,1,2,37,5],
 "dd/d5d/cblas__dgbmv_8c_ae807ea950f545d041c6bcc92187e1f10.html#ae807ea950f545d041c6bcc92187e1f10":[3,0,1,2,37,2],
 "dd/d5d/cblas__dgbmv_8c_source.html":[3,0,1,2,37],
@@ -182,8 +181,8 @@ var NAVTREEINDEX97 =
 "dd/d5f/lapacke__zlapmr_8c.html":[3,0,4,3,2180],
 "dd/d5f/lapacke__zlapmr_8c_a222687d1bffc8d6f1d6f0ff78c39bb8d.html#a222687d1bffc8d6f1d6f0ff78c39bb8d":[3,0,4,3,2180,0],
 "dd/d5f/lapacke__zlapmr_8c_source.html":[3,0,4,3,2180],
-"dd/d61/dlahr2_8f.html":[3,0,5,653],
-"dd/d61/dlahr2_8f_source.html":[3,0,5,653],
+"dd/d61/dlahr2_8f.html":[3,0,5,652],
+"dd/d61/dlahr2_8f_source.html":[3,0,5,652],
 "dd/d61/lapacke__cgbrfs__work_8c.html":[3,0,4,3,13],
 "dd/d61/lapacke__cgbrfs__work_8c_a83d7a57b33390f5565dd11e400746d8e.html#a83d7a57b33390f5565dd11e400746d8e":[3,0,4,3,13,0],
 "dd/d61/lapacke__cgbrfs__work_8c_source.html":[3,0,4,3,13],
@@ -196,58 +195,59 @@ var NAVTREEINDEX97 =
 "dd/d63/lapacke__cgglse_8c.html":[3,0,4,3,148],
 "dd/d63/lapacke__cgglse_8c_a89a13604fb44f01feed2c5c0a133be40.html#a89a13604fb44f01feed2c5c0a133be40":[3,0,4,3,148,0],
 "dd/d63/lapacke__cgglse_8c_source.html":[3,0,4,3,148],
-"dd/d63/sbdsdc_8f.html":[3,0,5,1023],
-"dd/d63/sbdsdc_8f_source.html":[3,0,5,1023],
-"dd/d63/sorbdb4_8f.html":[3,0,5,1305],
-"dd/d63/sorbdb4_8f_source.html":[3,0,5,1305],
+"dd/d63/sbdsdc_8f.html":[3,0,5,1022],
+"dd/d63/sbdsdc_8f_source.html":[3,0,5,1022],
+"dd/d63/sorbdb4_8f.html":[3,0,5,1303],
+"dd/d63/sorbdb4_8f_source.html":[3,0,5,1303],
 "dd/d64/cblas__strsv_8c.html":[3,0,1,2,109],
 "dd/d64/cblas__strsv_8c_a001cec3e2ef802c8eeb9be7b53ce936a.html#a001cec3e2ef802c8eeb9be7b53ce936a":[3,0,1,2,109,0],
 "dd/d64/cblas__strsv_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,109,1],
+"dd/d64/cblas__strsv_8c_a575f1b349ea6c9024eea817a51182a52.html#a575f1b349ea6c9024eea817a51182a52":[3,0,1,2,109,6],
 "dd/d64/cblas__strsv_8c_a63b8a88ed01e8de43ec370e5d7e34708.html#a63b8a88ed01e8de43ec370e5d7e34708":[3,0,1,2,109,4],
 "dd/d64/cblas__strsv_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,109,3],
 "dd/d64/cblas__strsv_8c_a8f11a6c3dbbee40c5527d8330c620eb1.html#a8f11a6c3dbbee40c5527d8330c620eb1":[3,0,1,2,109,2],
 "dd/d64/cblas__strsv_8c_aa5bf03463b42c2fc891b880903a8d92e.html#aa5bf03463b42c2fc891b880903a8d92e":[3,0,1,2,109,5],
-"dd/d64/cblas__strsv_8c_af4c00bcd7ea0f0a89681b57692f71405.html#af4c00bcd7ea0f0a89681b57692f71405":[3,0,1,2,109,6],
 "dd/d64/cblas__strsv_8c_source.html":[3,0,1,2,109],
 "dd/d64/lapacke__clauum_8c.html":[3,0,4,3,368],
 "dd/d64/lapacke__clauum_8c_ae6e906da294465da5b9724f790374db2.html#ae6e906da294465da5b9724f790374db2":[3,0,4,3,368,0],
 "dd/d64/lapacke__clauum_8c_source.html":[3,0,4,3,368],
 "dd/d66/dget06_8f.html":[3,0,6,1,309],
 "dd/d66/dget06_8f_source.html":[3,0,6,1,309],
-"dd/d66/dlantb_8f.html":[3,0,5,673],
-"dd/d66/dlantb_8f_source.html":[3,0,5,673],
-"dd/d66/dsyconv_8f.html":[3,0,5,904],
-"dd/d66/dsyconv_8f_source.html":[3,0,5,904],
-"dd/d67/stfsm_8f.html":[3,0,5,1480],
-"dd/d67/stfsm_8f_source.html":[3,0,5,1480],
+"dd/d66/dlantb_8f.html":[3,0,5,672],
+"dd/d66/dlantb_8f_source.html":[3,0,5,672],
+"dd/d66/dsyconv_8f.html":[3,0,5,903],
+"dd/d66/dsyconv_8f_source.html":[3,0,5,903],
+"dd/d67/stfsm_8f.html":[3,0,5,1478],
+"dd/d67/stfsm_8f_source.html":[3,0,5,1478],
 "dd/d69/group__complex16_s_ysolve.html":[0,0,2,0,3],
+"dd/d69/group__complex16_s_ysolve_ga1b7d9097a3e5d0b85c257f2f84c12f0e.html#ga1b7d9097a3e5d0b85c257f2f84c12f0e":[3,0,5,1916,0],
 "dd/d69/group__complex16_s_ysolve_ga1b7d9097a3e5d0b85c257f2f84c12f0e.html#ga1b7d9097a3e5d0b85c257f2f84c12f0e":[0,0,2,0,3,5],
-"dd/d69/group__complex16_s_ysolve_ga1b7d9097a3e5d0b85c257f2f84c12f0e.html#ga1b7d9097a3e5d0b85c257f2f84c12f0e":[3,0,5,1918,0],
-"dd/d69/group__complex16_s_ysolve_ga5519f6ffc88b185b0e8e7ffc3517e1d6.html#ga5519f6ffc88b185b0e8e7ffc3517e1d6":[3,0,5,1916,0],
 "dd/d69/group__complex16_s_ysolve_ga5519f6ffc88b185b0e8e7ffc3517e1d6.html#ga5519f6ffc88b185b0e8e7ffc3517e1d6":[0,0,2,0,3,3],
+"dd/d69/group__complex16_s_ysolve_ga5519f6ffc88b185b0e8e7ffc3517e1d6.html#ga5519f6ffc88b185b0e8e7ffc3517e1d6":[3,0,5,1914,0],
+"dd/d69/group__complex16_s_ysolve_ga6109aefb1ad317ed676178c4154f3fdd.html#ga6109aefb1ad317ed676178c4154f3fdd":[3,0,5,1910,0],
 "dd/d69/group__complex16_s_ysolve_ga6109aefb1ad317ed676178c4154f3fdd.html#ga6109aefb1ad317ed676178c4154f3fdd":[0,0,2,0,3,0],
-"dd/d69/group__complex16_s_ysolve_ga6109aefb1ad317ed676178c4154f3fdd.html#ga6109aefb1ad317ed676178c4154f3fdd":[3,0,5,1912,0],
-"dd/d69/group__complex16_s_ysolve_gaa1981f5edb6738375e4193aa5713c61d.html#gaa1981f5edb6738375e4193aa5713c61d":[3,0,5,1913,0],
+"dd/d69/group__complex16_s_ysolve_gaa1981f5edb6738375e4193aa5713c61d.html#gaa1981f5edb6738375e4193aa5713c61d":[3,0,5,1911,0],
 "dd/d69/group__complex16_s_ysolve_gaa1981f5edb6738375e4193aa5713c61d.html#gaa1981f5edb6738375e4193aa5713c61d":[0,0,2,0,3,1],
+"dd/d69/group__complex16_s_ysolve_gaa7f68ec02e1a2998e9d1904afbe51f37.html#gaa7f68ec02e1a2998e9d1904afbe51f37":[3,0,5,1913,0],
 "dd/d69/group__complex16_s_ysolve_gaa7f68ec02e1a2998e9d1904afbe51f37.html#gaa7f68ec02e1a2998e9d1904afbe51f37":[0,0,2,0,3,2],
-"dd/d69/group__complex16_s_ysolve_gaa7f68ec02e1a2998e9d1904afbe51f37.html#gaa7f68ec02e1a2998e9d1904afbe51f37":[3,0,5,1915,0],
-"dd/d69/group__complex16_s_ysolve_gaf30daece155f45c0e3cc89338a23dfb2.html#gaf30daece155f45c0e3cc89338a23dfb2":[3,0,5,1917,0],
+"dd/d69/group__complex16_s_ysolve_gaf30daece155f45c0e3cc89338a23dfb2.html#gaf30daece155f45c0e3cc89338a23dfb2":[3,0,5,1915,0],
 "dd/d69/group__complex16_s_ysolve_gaf30daece155f45c0e3cc89338a23dfb2.html#gaf30daece155f45c0e3cc89338a23dfb2":[0,0,2,0,3,4],
 "dd/d69/lapacke__dptsvx__work_8c.html":[3,0,4,3,999],
 "dd/d69/lapacke__dptsvx__work_8c_a26727b5bf65653174d5c7e7c5b1f0d67.html#a26727b5bf65653174d5c7e7c5b1f0d67":[3,0,4,3,999,0],
 "dd/d69/lapacke__dptsvx__work_8c_source.html":[3,0,4,3,999],
 "dd/d6a/serrpox_8f.html":[3,0,6,1,460],
 "dd/d6a/serrpox_8f_source.html":[3,0,6,1,460],
-"dd/d6b/dgesvdq_8f.html":[3,0,5,564],
-"dd/d6b/dgesvdq_8f_source.html":[3,0,5,564],
-"dd/d6b/dpotf2_8f.html":[3,0,5,836],
-"dd/d6b/dpotf2_8f_source.html":[3,0,5,836],
+"dd/d6b/dgesvdq_8f.html":[3,0,5,563],
+"dd/d6b/dgesvdq_8f_source.html":[3,0,5,563],
+"dd/d6b/dpotf2_8f.html":[3,0,5,835],
+"dd/d6b/dpotf2_8f_source.html":[3,0,5,835],
 "dd/d6b/lapacke__zgeqrf_8c.html":[3,0,4,3,1918],
 "dd/d6b/lapacke__zgeqrf_8c_afa82b718e6d2de133172d3467da2d117.html#afa82b718e6d2de133172d3467da2d117":[3,0,4,3,1918,0],
 "dd/d6b/lapacke__zgeqrf_8c_source.html":[3,0,4,3,1918],
-"dd/d6d/dlabad_8f.html":[3,0,5,623],
-"dd/d6d/dlabad_8f_source.html":[3,0,5,623],
-"dd/d6f/slabrd_8f.html":[3,0,5,1147],
-"dd/d6f/slabrd_8f_source.html":[3,0,5,1147],
-"dd/d70/cppt05_8f.html":[3,0,6,1,157]
+"dd/d6d/dlabad_8f.html":[3,0,5,622],
+"dd/d6d/dlabad_8f_source.html":[3,0,5,622],
+"dd/d6f/slabrd_8f.html":[3,0,5,1145],
+"dd/d6f/slabrd_8f_source.html":[3,0,5,1145],
+"dd/d70/cppt05_8f.html":[3,0,6,1,157],
+"dd/d70/cppt05_8f_source.html":[3,0,6,1,157]
 };
