@@ -1,6 +1,5 @@
 var NAVTREEINDEX98 =
 {
-"dd/d70/cppt05_8f_source.html":[3,0,6,1,157],
 "dd/d71/clatb5_8f.html":[3,0,6,1,130],
 "dd/d71/clatb5_8f_source.html":[3,0,6,1,130],
 "dd/d71/spot03_8f.html":[3,0,6,1,517],
@@ -30,14 +29,14 @@ var NAVTREEINDEX98 =
 "dd/d74/lapacke__sopmtr_8c.html":[3,0,4,3,1484],
 "dd/d74/lapacke__sopmtr_8c_a92081d89791397bf6576a01a46c2ee55.html#a92081d89791397bf6576a01a46c2ee55":[3,0,4,3,1484,0],
 "dd/d74/lapacke__sopmtr_8c_source.html":[3,0,4,3,1484],
-"dd/d75/dlatrd_8f.html":[3,0,5,771],
-"dd/d75/dlatrd_8f_source.html":[3,0,5,771],
+"dd/d75/dlatrd_8f.html":[3,0,5,770],
+"dd/d75/dlatrd_8f_source.html":[3,0,5,770],
 "dd/d76/cherfs_8f.html":[3,0,5,130],
 "dd/d76/cherfs_8f_source.html":[3,0,5,130],
 "dd/d76/cla__herpvgrw_8f.html":[3,0,5,199],
 "dd/d76/cla__herpvgrw_8f_source.html":[3,0,5,199],
-"dd/d76/dgbequ_8f.html":[3,0,5,508],
-"dd/d76/dgbequ_8f_source.html":[3,0,5,508],
+"dd/d76/dgbequ_8f.html":[3,0,5,507],
+"dd/d76/dgbequ_8f_source.html":[3,0,5,507],
 "dd/d76/lapacke__zstemr_8c.html":[3,0,4,3,2306],
 "dd/d76/lapacke__zstemr_8c_ae00420b1371dc49db618b85240c9ac50.html#ae00420b1371dc49db618b85240c9ac50":[3,0,4,3,2306,0],
 "dd/d76/lapacke__zstemr_8c_source.html":[3,0,4,3,2306],
@@ -52,10 +51,10 @@ var NAVTREEINDEX98 =
 "dd/d77/sget06_8f.html":[3,0,6,1,488],
 "dd/d77/sget06_8f_source.html":[3,0,6,1,488],
 "dd/d78/group__complex_h_eauxiliary.html":[0,0,3,3,0],
-"dd/d78/group__complex_h_eauxiliary_ga09b1ed617e21468711fecf331ef1b045.html#ga09b1ed617e21468711fecf331ef1b045":[0,0,3,3,0,2],
 "dd/d78/group__complex_h_eauxiliary_ga09b1ed617e21468711fecf331ef1b045.html#ga09b1ed617e21468711fecf331ef1b045":[3,0,5,262,0],
-"dd/d78/group__complex_h_eauxiliary_ga398301349b086de6970721f0eae026bc.html#ga398301349b086de6970721f0eae026bc":[3,0,5,245,0],
+"dd/d78/group__complex_h_eauxiliary_ga09b1ed617e21468711fecf331ef1b045.html#ga09b1ed617e21468711fecf331ef1b045":[0,0,3,3,0,2],
 "dd/d78/group__complex_h_eauxiliary_ga398301349b086de6970721f0eae026bc.html#ga398301349b086de6970721f0eae026bc":[0,0,3,3,0,1],
+"dd/d78/group__complex_h_eauxiliary_ga398301349b086de6970721f0eae026bc.html#ga398301349b086de6970721f0eae026bc":[3,0,5,245,0],
 "dd/d78/group__complex_h_eauxiliary_ga955ef3394562af1ae4ae2d113e4423bd.html#ga955ef3394562af1ae4ae2d113e4423bd":[3,0,5,139,0],
 "dd/d78/group__complex_h_eauxiliary_ga955ef3394562af1ae4ae2d113e4423bd.html#ga955ef3394562af1ae4ae2d113e4423bd":[0,0,3,3,0,0],
 "dd/d79/lapacke__zhetri2x__work_8c.html":[3,0,4,3,2100],
@@ -63,15 +62,15 @@ var NAVTREEINDEX98 =
 "dd/d79/lapacke__zhetri2x__work_8c_source.html":[3,0,4,3,2100],
 "dd/d79/zchksy_8f.html":[3,0,6,1,600],
 "dd/d79/zchksy_8f_source.html":[3,0,6,1,600],
-"dd/d7a/dlaqsy_8f.html":[3,0,5,696],
-"dd/d7a/dlaqsy_8f_source.html":[3,0,5,696],
-"dd/d7b/izmax1_8f.html":[3,0,5,1018],
-"dd/d7b/izmax1_8f_source.html":[3,0,5,1018],
+"dd/d7a/dlaqsy_8f.html":[3,0,5,695],
+"dd/d7a/dlaqsy_8f_source.html":[3,0,5,695],
+"dd/d7b/izmax1_8f.html":[3,0,5,1017],
+"dd/d7b/izmax1_8f_source.html":[3,0,5,1017],
 "dd/d7b/lapacke__zheequb__work_8c.html":[3,0,4,3,2039],
 "dd/d7b/lapacke__zheequb__work_8c_a57f016cb74884d26c73ebb8d314e5094.html#a57f016cb74884d26c73ebb8d314e5094":[3,0,4,3,2039,0],
 "dd/d7b/lapacke__zheequb__work_8c_source.html":[3,0,4,3,2039],
-"dd/d7b/zungr2_8f.html":[3,0,5,1999],
-"dd/d7b/zungr2_8f_source.html":[3,0,5,1999],
+"dd/d7b/zungr2_8f.html":[3,0,5,1997],
+"dd/d7b/zungr2_8f_source.html":[3,0,5,1997],
 "dd/d7c/lapacke__cppsvx_8c.html":[3,0,4,3,424],
 "dd/d7c/lapacke__cppsvx_8c_a6c46cda68cb0452c8b84f8097c2a4af4.html#a6c46cda68cb0452c8b84f8097c2a4af4":[3,0,4,3,424,0],
 "dd/d7c/lapacke__cppsvx_8c_source.html":[3,0,4,3,424],
@@ -83,8 +82,8 @@ var NAVTREEINDEX98 =
 "dd/d7e/lapacke__ztbtrs_8c.html":[3,0,4,3,2374],
 "dd/d7e/lapacke__ztbtrs_8c_ac5be2fe06c5d18037419583a79a06565.html#ac5be2fe06c5d18037419583a79a06565":[3,0,4,3,2374,0],
 "dd/d7e/lapacke__ztbtrs_8c_source.html":[3,0,4,3,2374],
-"dd/d7e/spotrf2_8f.html":[3,0,5,1360],
-"dd/d7e/spotrf2_8f_source.html":[3,0,5,1360],
+"dd/d7e/spotrf2_8f.html":[3,0,5,1358],
+"dd/d7e/spotrf2_8f_source.html":[3,0,5,1358],
 "dd/d7f/dchkgg_8f.html":[3,0,6,0,97],
 "dd/d7f/dchkgg_8f_source.html":[3,0,6,0,97],
 "dd/d80/lapacke__dsbgvx__work_8c.html":[3,0,4,3,1023],
@@ -93,12 +92,12 @@ var NAVTREEINDEX98 =
 "dd/d81/lapacke__dlaset__work_8c.html":[3,0,4,3,873],
 "dd/d81/lapacke__dlaset__work_8c_af20944d005041172cc7281a8f09dc8e0.html#af20944d005041172cc7281a8f09dc8e0":[3,0,4,3,873,0],
 "dd/d81/lapacke__dlaset__work_8c_source.html":[3,0,4,3,873],
-"dd/d83/dsysv__aa__2stage_8f.html":[3,0,5,926],
-"dd/d83/dsysv__aa__2stage_8f_source.html":[3,0,5,926],
+"dd/d83/dsysv__aa__2stage_8f.html":[3,0,5,925],
+"dd/d83/dsysv__aa__2stage_8f_source.html":[3,0,5,925],
 "dd/d84/cgerc_8f.html":[3,0,0,0,7],
 "dd/d84/cgerc_8f_source.html":[3,0,0,0,7],
-"dd/d84/dsyevd__2stage_8f.html":[3,0,5,911],
-"dd/d84/dsyevd__2stage_8f_source.html":[3,0,5,911],
+"dd/d84/dsyevd__2stage_8f.html":[3,0,5,910],
+"dd/d84/dsyevd__2stage_8f_source.html":[3,0,5,910],
 "dd/d84/lapacke__ssbgvx__work_8c.html":[3,0,4,3,1621],
 "dd/d84/lapacke__ssbgvx__work_8c_a9d67630ec497ed562d3f7bc1dc305f27.html#a9d67630ec497ed562d3f7bc1dc305f27":[3,0,4,3,1621,0],
 "dd/d84/lapacke__ssbgvx__work_8c_source.html":[3,0,4,3,1621],
@@ -107,8 +106,8 @@ var NAVTREEINDEX98 =
 "dd/d85/lapacke__zhbgv__work_8c_source.html":[3,0,4,3,2027],
 "dd/d86/cblas__dasum_8c.html":[3,0,1,2,33],
 "dd/d86/cblas__dasum_8c_a139197c2794f0146cf88d5843390fe58.html#a139197c2794f0146cf88d5843390fe58":[3,0,1,2,33,0],
+"dd/d86/cblas__dasum_8c_a5b639e2e4927ea4db507bfe3642eaabc.html#a5b639e2e4927ea4db507bfe3642eaabc":[3,0,1,2,33,2],
 "dd/d86/cblas__dasum_8c_a7aa43258b178b70e6ade4420b3d84609.html#a7aa43258b178b70e6ade4420b3d84609":[3,0,1,2,33,1],
-"dd/d86/cblas__dasum_8c_ac562028130486fab49239d0d77474adf.html#ac562028130486fab49239d0d77474adf":[3,0,1,2,33,2],
 "dd/d86/cblas__dasum_8c_source.html":[3,0,1,2,33],
 "dd/d86/cla__gbrfsx__extended_8f.html":[3,0,5,188],
 "dd/d86/cla__gbrfsx__extended_8f_source.html":[3,0,5,188],
@@ -122,8 +121,8 @@ var NAVTREEINDEX98 =
 "dd/d87/lapacke__example__aux_8h_aca4a7f245594ed0dceb562747019aa23.html#aca4a7f245594ed0dceb562747019aa23":[3,0,4,0,6,2],
 "dd/d87/lapacke__example__aux_8h_aea6079ddbe35ed06b9550a0680179643.html#aea6079ddbe35ed06b9550a0680179643":[3,0,4,0,6,0],
 "dd/d87/lapacke__example__aux_8h_source.html":[3,0,4,0,6],
-"dd/d8a/dorghr_8f.html":[3,0,5,791],
-"dd/d8a/dorghr_8f_source.html":[3,0,5,791],
+"dd/d8a/dorghr_8f.html":[3,0,5,790],
+"dd/d8a/dorghr_8f_source.html":[3,0,5,790],
 "dd/d8a/lapacke__zlarnv__work_8c.html":[3,0,4,3,2195],
 "dd/d8a/lapacke__zlarnv__work_8c_ad2a990ecbb560f746f9a598359dc1e01.html#ad2a990ecbb560f746f9a598359dc1e01":[3,0,4,3,2195,0],
 "dd/d8a/lapacke__zlarnv__work_8c_source.html":[3,0,4,3,2195],
@@ -147,20 +146,20 @@ var NAVTREEINDEX98 =
 "dd/d8f/dorhr__col01_8f_source.html":[3,0,6,1,332],
 "dd/d91/serrqrtp_8f.html":[3,0,6,1,466],
 "dd/d91/serrqrtp_8f_source.html":[3,0,6,1,466],
-"dd/d92/dgetc2_8f.html":[3,0,5,569],
-"dd/d92/dgetc2_8f_source.html":[3,0,5,569],
+"dd/d92/dgetc2_8f.html":[3,0,5,568],
+"dd/d92/dgetc2_8f_source.html":[3,0,5,568],
 "dd/d92/lapacke__slatms__work_8c.html":[3,0,4,3,1479],
 "dd/d92/lapacke__slatms__work_8c_a593087ce669ce66d54399dd1b50d0ba1.html#a593087ce669ce66d54399dd1b50d0ba1":[3,0,4,3,1479,0],
 "dd/d92/lapacke__slatms__work_8c_source.html":[3,0,4,3,1479],
-"dd/d92/zhesv__aa__2stage_8f.html":[3,0,5,1656],
-"dd/d92/zhesv__aa__2stage_8f_source.html":[3,0,5,1656],
-"dd/d94/dsytrs__rook_8f.html":[3,0,5,956],
-"dd/d94/dsytrs__rook_8f_source.html":[3,0,5,956],
+"dd/d92/zhesv__aa__2stage_8f.html":[3,0,5,1654],
+"dd/d92/zhesv__aa__2stage_8f_source.html":[3,0,5,1654],
+"dd/d94/dsytrs__rook_8f.html":[3,0,5,955],
+"dd/d94/dsytrs__rook_8f_source.html":[3,0,5,955],
 "dd/d94/lapacke__chpgvx_8c.html":[3,0,4,3,296],
 "dd/d94/lapacke__chpgvx_8c_aa72da7a6c46c8a1eebe458b7648ed5b3.html#aa72da7a6c46c8a1eebe458b7648ed5b3":[3,0,4,3,296,0],
 "dd/d94/lapacke__chpgvx_8c_source.html":[3,0,4,3,296],
-"dd/d95/zheevx_8f.html":[3,0,5,1644],
-"dd/d95/zheevx_8f_source.html":[3,0,5,1644],
+"dd/d95/zheevx_8f.html":[3,0,5,1642],
+"dd/d95/zheevx_8f_source.html":[3,0,5,1642],
 "dd/d96/lapacke__ssbtrd__work_8c.html":[3,0,4,3,1623],
 "dd/d96/lapacke__ssbtrd__work_8c_a675cb281124f533dc14d8765e8be932a.html#a675cb281124f533dc14d8765e8be932a":[3,0,4,3,1623,0],
 "dd/d96/lapacke__ssbtrd__work_8c_source.html":[3,0,4,3,1623],
@@ -168,86 +167,87 @@ var NAVTREEINDEX98 =
 "dd/d97/clatm6_8f_source.html":[3,0,6,2,13],
 "dd/d98/cchkbb_8f.html":[3,0,6,0,10],
 "dd/d98/cchkbb_8f_source.html":[3,0,6,0,10],
-"dd/d98/strttf_8f.html":[3,0,5,1516],
-"dd/d98/strttf_8f_source.html":[3,0,5,1516],
+"dd/d98/strttf_8f.html":[3,0,5,1514],
+"dd/d98/strttf_8f_source.html":[3,0,5,1514],
 "dd/d98/ztrt01_8f.html":[3,0,6,1,774],
 "dd/d98/ztrt01_8f_source.html":[3,0,6,1,774],
 "dd/d9a/group__double_g_ecomputational.html":[0,0,0,3,0],
-"dd/d9a/group__double_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[3,0,5,571,0],
+"dd/d9a/group__double_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[3,0,5,570,0],
 "dd/d9a/group__double_g_ecomputational_ga0019443faea08275ca60a734d0593e60.html#ga0019443faea08275ca60a734d0593e60":[0,0,0,3,0,35],
-"dd/d9a/group__double_g_ecomputational_ga0860daeae9b6084202a647418f54af27.html#ga0860daeae9b6084202a647418f54af27":[3,0,5,546,0],
 "dd/d9a/group__double_g_ecomputational_ga0860daeae9b6084202a647418f54af27.html#ga0860daeae9b6084202a647418f54af27":[0,0,0,3,0,19],
+"dd/d9a/group__double_g_ecomputational_ga0860daeae9b6084202a647418f54af27.html#ga0860daeae9b6084202a647418f54af27":[3,0,5,545,0],
 "dd/d9a/group__double_g_ecomputational_ga14ddd93ddf8aa38daf5a0ce1f6052ce3.html#ga14ddd93ddf8aa38daf5a0ce1f6052ce3":[0,0,0,3,0,5],
-"dd/d9a/group__double_g_ecomputational_ga14ddd93ddf8aa38daf5a0ce1f6052ce3.html#ga14ddd93ddf8aa38daf5a0ce1f6052ce3":[3,0,5,520,0],
+"dd/d9a/group__double_g_ecomputational_ga14ddd93ddf8aa38daf5a0ce1f6052ce3.html#ga14ddd93ddf8aa38daf5a0ce1f6052ce3":[3,0,5,519,0],
 "dd/d9a/group__double_g_ecomputational_ga188b8d30443d14b1a3f7f8331d87ae60.html#ga188b8d30443d14b1a3f7f8331d87ae60":[0,0,0,3,0,7],
-"dd/d9a/group__double_g_ecomputational_ga188b8d30443d14b1a3f7f8331d87ae60.html#ga188b8d30443d14b1a3f7f8331d87ae60":[3,0,5,522,0],
+"dd/d9a/group__double_g_ecomputational_ga188b8d30443d14b1a3f7f8331d87ae60.html#ga188b8d30443d14b1a3f7f8331d87ae60":[3,0,5,521,0],
+"dd/d9a/group__double_g_ecomputational_ga19c6e9e133a5ea3f59a24959889429f2.html#ga19c6e9e133a5ea3f59a24959889429f2":[3,0,5,611,0],
 "dd/d9a/group__double_g_ecomputational_ga19c6e9e133a5ea3f59a24959889429f2.html#ga19c6e9e133a5ea3f59a24959889429f2":[0,0,0,3,0,42],
-"dd/d9a/group__double_g_ecomputational_ga19c6e9e133a5ea3f59a24959889429f2.html#ga19c6e9e133a5ea3f59a24959889429f2":[3,0,5,612,0],
 "dd/d9a/group__double_g_ecomputational_ga1a3e42d2dea189bfdd5ca5de2a0439e7.html#ga1a3e42d2dea189bfdd5ca5de2a0439e7":[0,0,0,3,0,0],
 "dd/d9a/group__double_g_ecomputational_ga1a3e42d2dea189bfdd5ca5de2a0439e7.html#ga1a3e42d2dea189bfdd5ca5de2a0439e7":[3,0,5,33,0],
 "dd/d9a/group__double_g_ecomputational_ga1b0500f49e03d2771b797c6e88adabbb.html#ga1b0500f49e03d2771b797c6e88adabbb":[0,0,0,3,0,20],
-"dd/d9a/group__double_g_ecomputational_ga1b0500f49e03d2771b797c6e88adabbb.html#ga1b0500f49e03d2771b797c6e88adabbb":[3,0,5,547,0],
-"dd/d9a/group__double_g_ecomputational_ga21c89aba210fbfb8cca635e47dccbdb3.html#ga21c89aba210fbfb8cca635e47dccbdb3":[3,0,5,602,0],
+"dd/d9a/group__double_g_ecomputational_ga1b0500f49e03d2771b797c6e88adabbb.html#ga1b0500f49e03d2771b797c6e88adabbb":[3,0,5,546,0],
+"dd/d9a/group__double_g_ecomputational_ga21c89aba210fbfb8cca635e47dccbdb3.html#ga21c89aba210fbfb8cca635e47dccbdb3":[3,0,5,601,0],
 "dd/d9a/group__double_g_ecomputational_ga21c89aba210fbfb8cca635e47dccbdb3.html#ga21c89aba210fbfb8cca635e47dccbdb3":[0,0,0,3,0,39],
-"dd/d9a/group__double_g_ecomputational_ga2510d68d70194719d570cbcfe24b3e74.html#ga2510d68d70194719d570cbcfe24b3e74":[3,0,5,966,0],
 "dd/d9a/group__double_g_ecomputational_ga2510d68d70194719d570cbcfe24b3e74.html#ga2510d68d70194719d570cbcfe24b3e74":[0,0,0,3,0,52],
-"dd/d9a/group__double_g_ecomputational_ga2611cc9dfdc84e2a08ec57a5dd6cdd2e.html#ga2611cc9dfdc84e2a08ec57a5dd6cdd2e":[3,0,5,530,0],
+"dd/d9a/group__double_g_ecomputational_ga2510d68d70194719d570cbcfe24b3e74.html#ga2510d68d70194719d570cbcfe24b3e74":[3,0,5,965,0],
 "dd/d9a/group__double_g_ecomputational_ga2611cc9dfdc84e2a08ec57a5dd6cdd2e.html#ga2611cc9dfdc84e2a08ec57a5dd6cdd2e":[0,0,0,3,0,11],
-"dd/d9a/group__double_g_ecomputational_ga2b04b68d98323a2aabbc3ea09de5a276.html#ga2b04b68d98323a2aabbc3ea09de5a276":[3,0,5,1223,0],
+"dd/d9a/group__double_g_ecomputational_ga2611cc9dfdc84e2a08ec57a5dd6cdd2e.html#ga2611cc9dfdc84e2a08ec57a5dd6cdd2e":[3,0,5,529,0],
+"dd/d9a/group__double_g_ecomputational_ga2b04b68d98323a2aabbc3ea09de5a276.html#ga2b04b68d98323a2aabbc3ea09de5a276":[3,0,5,1221,0],
 "dd/d9a/group__double_g_ecomputational_ga2b04b68d98323a2aabbc3ea09de5a276.html#ga2b04b68d98323a2aabbc3ea09de5a276":[0,0,0,3,0,58],
-"dd/d9a/group__double_g_ecomputational_ga2f10ebf79772a5399be9ed6169c9d975.html#ga2f10ebf79772a5399be9ed6169c9d975":[3,0,5,533,0],
 "dd/d9a/group__double_g_ecomputational_ga2f10ebf79772a5399be9ed6169c9d975.html#ga2f10ebf79772a5399be9ed6169c9d975":[0,0,0,3,0,12],
+"dd/d9a/group__double_g_ecomputational_ga2f10ebf79772a5399be9ed6169c9d975.html#ga2f10ebf79772a5399be9ed6169c9d975":[3,0,5,532,0],
+"dd/d9a/group__double_g_ecomputational_ga360f5b8b756dc7d366c3decfcdf89000.html#ga360f5b8b756dc7d366c3decfcdf89000":[3,0,5,557,0],
 "dd/d9a/group__double_g_ecomputational_ga360f5b8b756dc7d366c3decfcdf89000.html#ga360f5b8b756dc7d366c3decfcdf89000":[0,0,0,3,0,31],
-"dd/d9a/group__double_g_ecomputational_ga360f5b8b756dc7d366c3decfcdf89000.html#ga360f5b8b756dc7d366c3decfcdf89000":[3,0,5,558,0],
 "dd/d9a/group__double_g_ecomputational_ga3766ea903391b5cf9008132f7440ec7b.html#ga3766ea903391b5cf9008132f7440ec7b":[0,0,0,3,0,24],
-"dd/d9a/group__double_g_ecomputational_ga3766ea903391b5cf9008132f7440ec7b.html#ga3766ea903391b5cf9008132f7440ec7b":[3,0,5,551,0],
+"dd/d9a/group__double_g_ecomputational_ga3766ea903391b5cf9008132f7440ec7b.html#ga3766ea903391b5cf9008132f7440ec7b":[3,0,5,550,0],
 "dd/d9a/group__double_g_ecomputational_ga3a43ee755a96cc411fcf7e4c58156839.html#ga3a43ee755a96cc411fcf7e4c58156839":[0,0,0,3,0,15],
-"dd/d9a/group__double_g_ecomputational_ga3a43ee755a96cc411fcf7e4c58156839.html#ga3a43ee755a96cc411fcf7e4c58156839":[3,0,5,536,0],
-"dd/d9a/group__double_g_ecomputational_ga3ad112f2b0890b3815e696628906f30c.html#ga3ad112f2b0890b3815e696628906f30c":[3,0,5,555,0],
+"dd/d9a/group__double_g_ecomputational_ga3a43ee755a96cc411fcf7e4c58156839.html#ga3a43ee755a96cc411fcf7e4c58156839":[3,0,5,535,0],
 "dd/d9a/group__double_g_ecomputational_ga3ad112f2b0890b3815e696628906f30c.html#ga3ad112f2b0890b3815e696628906f30c":[0,0,0,3,0,28],
-"dd/d9a/group__double_g_ecomputational_ga3b18b13aeed841f1d7d6c5581573ee4e.html#ga3b18b13aeed841f1d7d6c5581573ee4e":[3,0,5,1562,0],
+"dd/d9a/group__double_g_ecomputational_ga3ad112f2b0890b3815e696628906f30c.html#ga3ad112f2b0890b3815e696628906f30c":[3,0,5,554,0],
 "dd/d9a/group__double_g_ecomputational_ga3b18b13aeed841f1d7d6c5581573ee4e.html#ga3b18b13aeed841f1d7d6c5581573ee4e":[0,0,0,3,0,63],
-"dd/d9a/group__double_g_ecomputational_ga411292dd693c20ff9c27650fb7bddf85.html#ga411292dd693c20ff9c27650fb7bddf85":[3,0,5,519,0],
+"dd/d9a/group__double_g_ecomputational_ga3b18b13aeed841f1d7d6c5581573ee4e.html#ga3b18b13aeed841f1d7d6c5581573ee4e":[3,0,5,1560,0],
 "dd/d9a/group__double_g_ecomputational_ga411292dd693c20ff9c27650fb7bddf85.html#ga411292dd693c20ff9c27650fb7bddf85":[0,0,0,3,0,4],
+"dd/d9a/group__double_g_ecomputational_ga411292dd693c20ff9c27650fb7bddf85.html#ga411292dd693c20ff9c27650fb7bddf85":[3,0,5,518,0],
 "dd/d9a/group__double_g_ecomputational_ga436228e38ef5c55e3229502afa2c4220.html#ga436228e38ef5c55e3229502afa2c4220":[0,0,0,3,0,13],
-"dd/d9a/group__double_g_ecomputational_ga436228e38ef5c55e3229502afa2c4220.html#ga436228e38ef5c55e3229502afa2c4220":[3,0,5,534,0],
+"dd/d9a/group__double_g_ecomputational_ga436228e38ef5c55e3229502afa2c4220.html#ga436228e38ef5c55e3229502afa2c4220":[3,0,5,533,0],
 "dd/d9a/group__double_g_ecomputational_ga4547be7cf34938979c5d741d148e4d3b.html#ga4547be7cf34938979c5d741d148e4d3b":[0,0,0,3,0,9],
-"dd/d9a/group__double_g_ecomputational_ga4547be7cf34938979c5d741d148e4d3b.html#ga4547be7cf34938979c5d741d148e4d3b":[3,0,5,524,0],
+"dd/d9a/group__double_g_ecomputational_ga4547be7cf34938979c5d741d148e4d3b.html#ga4547be7cf34938979c5d741d148e4d3b":[3,0,5,523,0],
 "dd/d9a/group__double_g_ecomputational_ga464f0a0d80d32e6d6b164de84460e027.html#ga464f0a0d80d32e6d6b164de84460e027":[0,0,0,3,0,16],
-"dd/d9a/group__double_g_ecomputational_ga464f0a0d80d32e6d6b164de84460e027.html#ga464f0a0d80d32e6d6b164de84460e027":[3,0,5,542,0],
+"dd/d9a/group__double_g_ecomputational_ga464f0a0d80d32e6d6b164de84460e027.html#ga464f0a0d80d32e6d6b164de84460e027":[3,0,5,541,0],
 "dd/d9a/group__double_g_ecomputational_ga486d8da01d3304d595dab4cef3353ce6.html#ga486d8da01d3304d595dab4cef3353ce6":[0,0,0,3,0,3],
-"dd/d9a/group__double_g_ecomputational_ga486d8da01d3304d595dab4cef3353ce6.html#ga486d8da01d3304d595dab4cef3353ce6":[3,0,5,518,0],
+"dd/d9a/group__double_g_ecomputational_ga486d8da01d3304d595dab4cef3353ce6.html#ga486d8da01d3304d595dab4cef3353ce6":[3,0,5,517,0],
 "dd/d9a/group__double_g_ecomputational_ga50aa58c97b389375440f74164d508537.html#ga50aa58c97b389375440f74164d508537":[0,0,0,3,0,53],
-"dd/d9a/group__double_g_ecomputational_ga50aa58c97b389375440f74164d508537.html#ga50aa58c97b389375440f74164d508537":[3,0,5,1058,0],
-"dd/d9a/group__double_g_ecomputational_ga5539077fbd3a92c4d92b75bf58da5db3.html#ga5539077fbd3a92c4d92b75bf58da5db3":[3,0,5,611,0],
+"dd/d9a/group__double_g_ecomputational_ga50aa58c97b389375440f74164d508537.html#ga50aa58c97b389375440f74164d508537":[3,0,5,1056,0],
+"dd/d9a/group__double_g_ecomputational_ga5539077fbd3a92c4d92b75bf58da5db3.html#ga5539077fbd3a92c4d92b75bf58da5db3":[3,0,5,610,0],
 "dd/d9a/group__double_g_ecomputational_ga5539077fbd3a92c4d92b75bf58da5db3.html#ga5539077fbd3a92c4d92b75bf58da5db3":[0,0,0,3,0,41],
+"dd/d9a/group__double_g_ecomputational_ga56565ae06016954202aee24cdfc38257.html#ga56565ae06016954202aee24cdfc38257":[3,0,5,522,0],
 "dd/d9a/group__double_g_ecomputational_ga56565ae06016954202aee24cdfc38257.html#ga56565ae06016954202aee24cdfc38257":[0,0,0,3,0,8],
-"dd/d9a/group__double_g_ecomputational_ga56565ae06016954202aee24cdfc38257.html#ga56565ae06016954202aee24cdfc38257":[3,0,5,523,0],
+"dd/d9a/group__double_g_ecomputational_ga56d9c860ce4ce42ded7f914fdb0683ff.html#ga56d9c860ce4ce42ded7f914fdb0683ff":[3,0,5,572,0],
 "dd/d9a/group__double_g_ecomputational_ga56d9c860ce4ce42ded7f914fdb0683ff.html#ga56d9c860ce4ce42ded7f914fdb0683ff":[0,0,0,3,0,37],
-"dd/d9a/group__double_g_ecomputational_ga56d9c860ce4ce42ded7f914fdb0683ff.html#ga56d9c860ce4ce42ded7f914fdb0683ff":[3,0,5,573,0],
-"dd/d9a/group__double_g_ecomputational_ga58e332cb1b8ab770270843221a48296d.html#ga58e332cb1b8ab770270843221a48296d":[3,0,5,574,0],
+"dd/d9a/group__double_g_ecomputational_ga58e332cb1b8ab770270843221a48296d.html#ga58e332cb1b8ab770270843221a48296d":[3,0,5,573,0],
 "dd/d9a/group__double_g_ecomputational_ga58e332cb1b8ab770270843221a48296d.html#ga58e332cb1b8ab770270843221a48296d":[0,0,0,3,0,38],
 "dd/d9a/group__double_g_ecomputational_ga5dc72a0f55ff4c08f1a3596f56e04aaa.html#ga5dc72a0f55ff4c08f1a3596f56e04aaa":[0,0,0,3,0,25],
-"dd/d9a/group__double_g_ecomputational_ga5dc72a0f55ff4c08f1a3596f56e04aaa.html#ga5dc72a0f55ff4c08f1a3596f56e04aaa":[3,0,5,552,0],
-"dd/d9a/group__double_g_ecomputational_ga60fe6f45ae036702cf7affea4f0de69c.html#ga60fe6f45ae036702cf7affea4f0de69c":[3,0,5,964,0],
+"dd/d9a/group__double_g_ecomputational_ga5dc72a0f55ff4c08f1a3596f56e04aaa.html#ga5dc72a0f55ff4c08f1a3596f56e04aaa":[3,0,5,551,0],
 "dd/d9a/group__double_g_ecomputational_ga60fe6f45ae036702cf7affea4f0de69c.html#ga60fe6f45ae036702cf7affea4f0de69c":[0,0,0,3,0,51],
-"dd/d9a/group__double_g_ecomputational_ga6102636cbcb42cf52f5057a3e3f9f383.html#ga6102636cbcb42cf52f5057a3e3f9f383":[3,0,5,677,0],
+"dd/d9a/group__double_g_ecomputational_ga60fe6f45ae036702cf7affea4f0de69c.html#ga60fe6f45ae036702cf7affea4f0de69c":[3,0,5,963,0],
+"dd/d9a/group__double_g_ecomputational_ga6102636cbcb42cf52f5057a3e3f9f383.html#ga6102636cbcb42cf52f5057a3e3f9f383":[3,0,5,676,0],
 "dd/d9a/group__double_g_ecomputational_ga6102636cbcb42cf52f5057a3e3f9f383.html#ga6102636cbcb42cf52f5057a3e3f9f383":[0,0,0,3,0,44],
-"dd/d9a/group__double_g_ecomputational_ga64ae394c770b6fbb30c1d6d6727d003c.html#ga64ae394c770b6fbb30c1d6d6727d003c":[3,0,5,698,0],
 "dd/d9a/group__double_g_ecomputational_ga64ae394c770b6fbb30c1d6d6727d003c.html#ga64ae394c770b6fbb30c1d6d6727d003c":[0,0,0,3,0,46],
-"dd/d9a/group__double_g_ecomputational_ga6895515e31c40bf17757930335b81fce.html#ga6895515e31c40bf17757930335b81fce":[3,0,5,1225,0],
+"dd/d9a/group__double_g_ecomputational_ga64ae394c770b6fbb30c1d6d6727d003c.html#ga64ae394c770b6fbb30c1d6d6727d003c":[3,0,5,697,0],
 "dd/d9a/group__double_g_ecomputational_ga6895515e31c40bf17757930335b81fce.html#ga6895515e31c40bf17757930335b81fce":[0,0,0,3,0,60],
-"dd/d9a/group__double_g_ecomputational_ga73bdcea87a883105153631bef9879363.html#ga73bdcea87a883105153631bef9879363":[3,0,5,702,0],
+"dd/d9a/group__double_g_ecomputational_ga6895515e31c40bf17757930335b81fce.html#ga6895515e31c40bf17757930335b81fce":[3,0,5,1223,0],
+"dd/d9a/group__double_g_ecomputational_ga73bdcea87a883105153631bef9879363.html#ga73bdcea87a883105153631bef9879363":[3,0,5,701,0],
 "dd/d9a/group__double_g_ecomputational_ga73bdcea87a883105153631bef9879363.html#ga73bdcea87a883105153631bef9879363":[0,0,0,3,0,50],
-"dd/d9a/group__double_g_ecomputational_ga7bba0d791b011eb5425ecbf500e9be2c.html#ga7bba0d791b011eb5425ecbf500e9be2c":[3,0,5,559,0],
 "dd/d9a/group__double_g_ecomputational_ga7bba0d791b011eb5425ecbf500e9be2c.html#ga7bba0d791b011eb5425ecbf500e9be2c":[0,0,0,3,0,32],
+"dd/d9a/group__double_g_ecomputational_ga7bba0d791b011eb5425ecbf500e9be2c.html#ga7bba0d791b011eb5425ecbf500e9be2c":[3,0,5,558,0],
+"dd/d9a/group__double_g_ecomputational_ga7c4cd88a2446ad8eef46eb37fc4fbeb5.html#ga7c4cd88a2446ad8eef46eb37fc4fbeb5":[3,0,5,1063,0],
 "dd/d9a/group__double_g_ecomputational_ga7c4cd88a2446ad8eef46eb37fc4fbeb5.html#ga7c4cd88a2446ad8eef46eb37fc4fbeb5":[0,0,0,3,0,55],
-"dd/d9a/group__double_g_ecomputational_ga7c4cd88a2446ad8eef46eb37fc4fbeb5.html#ga7c4cd88a2446ad8eef46eb37fc4fbeb5":[3,0,5,1065,0],
+"dd/d9a/group__double_g_ecomputational_ga8360b5b2c819e19c82bfd7e6b8285f74.html#ga8360b5b2c819e19c82bfd7e6b8285f74":[3,0,5,569,0],
 "dd/d9a/group__double_g_ecomputational_ga8360b5b2c819e19c82bfd7e6b8285f74.html#ga8360b5b2c819e19c82bfd7e6b8285f74":[0,0,0,3,0,34],
-"dd/d9a/group__double_g_ecomputational_ga8360b5b2c819e19c82bfd7e6b8285f74.html#ga8360b5b2c819e19c82bfd7e6b8285f74":[3,0,5,570,0],
 "dd/d9a/group__double_g_ecomputational_ga86586a8c4f1c31707724ed70e92f6f34.html#ga86586a8c4f1c31707724ed70e92f6f34":[0,0,0,3,0,22],
-"dd/d9a/group__double_g_ecomputational_ga86586a8c4f1c31707724ed70e92f6f34.html#ga86586a8c4f1c31707724ed70e92f6f34":[3,0,5,549,0],
+"dd/d9a/group__double_g_ecomputational_ga86586a8c4f1c31707724ed70e92f6f34.html#ga86586a8c4f1c31707724ed70e92f6f34":[3,0,5,548,0],
+"dd/d9a/group__double_g_ecomputational_ga8b4838ff12c7f40680ad11f601093b47.html#ga8b4838ff12c7f40680ad11f601093b47":[3,0,5,677,0],
 "dd/d9a/group__double_g_ecomputational_ga8b4838ff12c7f40680ad11f601093b47.html#ga8b4838ff12c7f40680ad11f601093b47":[0,0,0,3,0,45],
-"dd/d9a/group__double_g_ecomputational_ga8b4838ff12c7f40680ad11f601093b47.html#ga8b4838ff12c7f40680ad11f601093b47":[3,0,5,678,0],
-"dd/d9a/group__double_g_ecomputational_ga8dad4aabc60c0b1cdc76901db8f195e2.html#ga8dad4aabc60c0b1cdc76901db8f195e2":[3,0,5,1224,0]
+"dd/d9a/group__double_g_ecomputational_ga8dad4aabc60c0b1cdc76901db8f195e2.html#ga8dad4aabc60c0b1cdc76901db8f195e2":[0,0,0,3,0,59],
+"dd/d9a/group__double_g_ecomputational_ga8dad4aabc60c0b1cdc76901db8f195e2.html#ga8dad4aabc60c0b1cdc76901db8f195e2":[3,0,5,1222,0]
 };
